import { __decorate, __metadata, __awaiter } from 'tslib';
import { Injectable, ElementRef, Input, Directive, NgModule, ViewChild, TemplateRef, Output, Component, Renderer2 } from '@angular/core';
import { CustomFieldsModule, ControlErrorsModule, EmptyStateModule, DynamicFormModule, ButtonModule, LoadingStateModule, InfoSignModule, FieldType, FormField, LocaleModule } from '@seniorsistemas/angular-components';
import { CommonModule } from '@angular/common';
import { AbstractControl, FormsModule, ReactiveFormsModule, Validators, FormControl, FormGroup, FormBuilder } from '@angular/forms';
import { TranslateService, TranslateModule } from '@ngx-translate/core';
import { HotkeyModule, Hotkey, HotkeysService } from 'angular2-hotkeys';
import { CurrencyMaskModule } from 'ng2-currency-mask';
import { CalendarModule } from 'primeng/calendar';
import { ConfirmDialogModule } from 'primeng/confirmdialog';
import { InputTextModule } from 'primeng/inputtext';
import { MessagesModule } from 'primeng/messages';
import { PanelModule } from 'primeng/panel';
import { MessageService, SharedModule, ConfirmationService } from 'primeng/api';
import { SplitButtonModule } from 'primeng/splitbutton';
import { HttpClient, HttpParams } from '@angular/common/http';
import { throwError, Subject, forkJoin, of, Observable } from 'rxjs';
import { catchError, takeUntil, filter, map, tap } from 'rxjs/operators';
import { user } from '@seniorsistemas/senior-platform-data';
import { InputTextareaModule } from 'primeng/inputtextarea';
import { InputMaskModule } from 'primeng/inputmask';
import { DropdownModule } from 'primeng/dropdown';
import { InputSwitchModule, InputSwitch } from 'primeng/inputswitch';
import { Router, ActivatedRoute } from '@angular/router';
import * as moment_ from 'moment';
import { PermissionsModule } from '@seniorsistemas/platform-components';

let FocusService = class FocusService {
    focusFirstInvalidInput() {
        const invalidFields = Array.from(document.getElementsByClassName("ng-invalid"));
        const firstField = invalidFields.find((f) => f.nodeName !== "FORM");
        if (firstField.nodeName === "P-CALENDAR") {
            const firstInputId = firstField.getAttribute("ng-reflect-input-id");
            const firstInvalidInput = document.getElementById(firstInputId);
            if (firstInvalidInput)
                firstInvalidInput.focus();
        }
        else if (firstField.nodeName === "S-LOOKUP") {
            const nestedInput = this.getNestedInput(firstField.firstElementChild);
            if (nestedInput)
                nestedInput.focus();
        }
        else
            firstField.focus();
    }
    getNestedInput(element) {
        if (element.nodeName === "INPUT") {
            return element;
        }
        return this.getNestedInput(element.firstElementChild);
    }
};
FocusService = __decorate([
    Injectable()
], FocusService);

let FieldCustomizationService = class FieldCustomizationService {
    constructor(http, messageService) {
        this.http = http;
        this.messageService = messageService;
        this.http = http;
        this.messageService = messageService;
        this.defaultCatch = this.defaultCatch.bind(this);
    }
    commitFiles(objects) {
        return this.http.post("platform/field_customization/actions/commitObject", { objects }).pipe(this.defaultCatch());
    }
    deleteFiles(objects) {
        return this.http.post("platform/field_customization/actions/deleteObjects", objects).pipe(this.defaultCatch());
    }
    getFiles(formGroup) {
        let fieldCustomization = [];
        if (formGroup.value.custom) {
            fieldCustomization = formGroup.value.custom.fieldCustomization || [];
            delete formGroup.value.custom.fieldCustomization;
        }
        const filesToCommit = [];
        let filesToDelete = {};
        fieldCustomization.forEach(({ domain, service, entity, toDelete, toInsert }) => {
            if (!this.isEmpty(toInsert)) {
                const files = Object.keys(toInsert).map((key) => {
                    const version = toInsert[key].version;
                    const fileName = toInsert[key].name;
                    const objectId = toInsert[key].objectId;
                    return { version, fileName, objectId };
                });
                if (!this.isEmpty(files)) {
                    filesToCommit.push(...files);
                }
            }
            if (!this.isEmpty(toDelete)) {
                const objects = [];
                Object.keys(toDelete).forEach((key) => {
                    const fields = toDelete[key] || [];
                    const files = fields.map((file) => {
                        return {
                            field: key,
                            objectId: file,
                        };
                    });
                    objects.push(...files);
                });
                filesToDelete = { domain, service, entityName: entity, objects };
            }
        });
        return { filesToCommit, filesToDelete };
    }
    isEmpty(object) {
        if (Array.isArray(object)) {
            return object.length === 0;
        }
        return Object.entries(object).length === 0 && object.constructor === Object;
    }
    defaultCatch() {
        return catchError((err) => {
            if (err) {
                const summary = err.status ? String(err.status) : "Error";
                const detail = (err.error && err.error.message) || err.statusText || err.message || "Error";
                this.messageService.add({
                    severity: "error",
                    summary,
                    detail,
                });
            }
            return throwError(err);
        });
    }
};
FieldCustomizationService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService }
];
FieldCustomizationService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [HttpClient, MessageService])
], FieldCustomizationService);

class StorageService {
    constructor() {
        this.GET_USER_ID = user.getUserData().then(user => user.id);
    }
    store(key, value) {
        return __awaiter(this, void 0, void 0, function* () {
            localStorage.setItem(`${yield this.GET_USER_ID}_${key}`, JSON.stringify(value));
        });
    }
    get(key) {
        return __awaiter(this, void 0, void 0, function* () {
            return JSON.parse(localStorage.getItem(`${yield this.GET_USER_ID}_${key}`)) || {};
        });
    }
}

let FiltersStorageService = class FiltersStorageService extends StorageService {
    constructor() {
        super(...arguments);
        this.FILTERS_KEY = "SENIOR_FILTERS";
    }
    storeFilters(key, filters) {
        const _super = Object.create(null, {
            get: { get: () => super.get },
            store: { get: () => super.store }
        });
        return __awaiter(this, void 0, void 0, function* () {
            const store = (yield _super.get.call(this, this.FILTERS_KEY)) || {};
            this.removeEmptyValues(filters);
            store[key] = filters;
            yield _super.store.call(this, this.FILTERS_KEY, store);
        });
    }
    getFilters(key) {
        const _super = Object.create(null, {
            get: { get: () => super.get }
        });
        return __awaiter(this, void 0, void 0, function* () {
            const store = (yield _super.get.call(this, this.FILTERS_KEY)) || {};
            return store[key] || {};
        });
    }
    removeFilter(key) {
        const _super = Object.create(null, {
            get: { get: () => super.get },
            store: { get: () => super.store }
        });
        return __awaiter(this, void 0, void 0, function* () {
            const store = (yield _super.get.call(this, this.FILTERS_KEY)) || {};
            delete store[key];
            yield _super.store.call(this, this.FILTERS_KEY, store);
        });
    }
    clearFilterValue(key, filters) {
        const _super = Object.create(null, {
            get: { get: () => super.get },
            store: { get: () => super.store }
        });
        return __awaiter(this, void 0, void 0, function* () {
            const store = (yield _super.get.call(this, this.FILTERS_KEY)) || {};
            this.removeEmptyValues(filters);
            store[key] = filters;
            yield _super.store.call(this, this.FILTERS_KEY, store);
        });
    }
    removeEmptyValues(filters) {
        Object.keys(filters).forEach((field) => {
            if (Array.isArray(filters[field]) ? filters[field].length === 0 : !filters[field]) {
                delete filters[field];
            }
        });
    }
};
FiltersStorageService = __decorate([
    Injectable()
], FiltersStorageService);

let PaginatorStorageService = class PaginatorStorageService {
    constructor() {
        this.GET_USER_ID = user.getUserData().then(user => user.id);
        this.PAGINATOR_KEY = "SENIOR_PAGINATOR";
    }
    store(key, value) {
        return __awaiter(this, void 0, void 0, function* () {
            sessionStorage.setItem(`${yield this.GET_USER_ID}_${key}`, JSON.stringify(value));
        });
    }
    get(key) {
        return __awaiter(this, void 0, void 0, function* () {
            return JSON.parse(sessionStorage.getItem(`${yield this.GET_USER_ID}_${key}`)) || {};
        });
    }
    storePaginator(key, listParams = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const store = (yield this.get(this.PAGINATOR_KEY)) || {};
            store[key] = listParams;
            yield this.store(this.PAGINATOR_KEY, store);
        });
    }
    getPaginator(key) {
        return __awaiter(this, void 0, void 0, function* () {
            const store = (yield this.get(this.PAGINATOR_KEY)) || {};
            return store[key] || {};
        });
    }
};
PaginatorStorageService = __decorate([
    Injectable()
], PaginatorStorageService);

let DescriptionSwitchDirective = class DescriptionSwitchDirective {
    constructor(element, _translate) {
        this.element = element;
        this._translate = _translate;
        this.defaultStyle = true;
        this.ngUnsubscribe = new Subject();
    }
    ngOnChanges(changes) {
        this.ngOnInit();
    }
    ngOnInit() {
        this.setStyle(this.defaultStyle);
        this.setDescription(this.appDescriptionSwitch.value);
        if (this.parentComponent) {
            this.setStyle(this.parentComponent.value);
            this.parentComponent.valueChanges.pipe(takeUntil(this.ngUnsubscribe)).subscribe((value) => {
                this.setStyle(value);
            });
        }
        this.appDescriptionSwitch.valueChanges.pipe(takeUntil(this.ngUnsubscribe)).subscribe((value) => {
            this.setDescription(value);
        });
    }
    setDescription(value) {
        if (value) {
            this.element.nativeElement.innerHTML = this._translate.instant('hcm_clocking_event_foundation.general.generic_yes');
        }
        else {
            this.element.nativeElement.innerHTML = this._translate.instant('hcm_clocking_event_foundation.general.generic_no');
        }
    }
    setStyle(value) {
        if (value) {
            this.element.nativeElement.style.color = "#333333";
        }
        else {
            this.element.nativeElement.style.color = "#cccccc";
        }
    }
};
DescriptionSwitchDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: TranslateService }
];
__decorate([
    Input(),
    __metadata("design:type", AbstractControl)
], DescriptionSwitchDirective.prototype, "appDescriptionSwitch", void 0);
__decorate([
    Input(),
    __metadata("design:type", AbstractControl)
], DescriptionSwitchDirective.prototype, "parentComponent", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], DescriptionSwitchDirective.prototype, "defaultStyle", void 0);
DescriptionSwitchDirective = __decorate([
    Directive({
        selector: '[appDescriptionSwitch]'
    }),
    __metadata("design:paramtypes", [ElementRef,
        TranslateService])
], DescriptionSwitchDirective);

/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let SharedScheduleModule = class SharedScheduleModule {
};
SharedScheduleModule = __decorate([
    NgModule({
        imports: [
            /*{CA:MODULE_IMPORTS:START}*/
            SplitButtonModule,
            MessagesModule,
            FormsModule,
            ReactiveFormsModule,
            CommonModule,
            TranslateModule,
            CustomFieldsModule,
            ControlErrorsModule,
            CurrencyMaskModule,
            EmptyStateModule,
            DynamicFormModule,
            PanelModule,
            InputTextModule,
            ButtonModule,
            ConfirmDialogModule,
            CalendarModule,
            SharedModule,
            HotkeyModule,
            LoadingStateModule,
            InputMaskModule,
            InfoSignModule,
            DropdownModule,
            InputTextareaModule
            /*{CA:MODULE_IMPORTS:END}*/
        ],
        providers: [
            FiltersStorageService,
            PaginatorStorageService,
            FocusService,
            FieldCustomizationService,
        ],
        declarations: [
            /*{CA:MODULE_DECLARATIONS:START}*/
            DescriptionSwitchDirective
            /*{CA:MODULE_DECLARATIONS:END}*/
        ],
        /*{CA:MODULE_CONFIG:START}*/
        exports: [
            SplitButtonModule,
            MessagesModule,
            FormsModule,
            ReactiveFormsModule,
            CommonModule,
            TranslateModule,
            CustomFieldsModule,
            ControlErrorsModule,
            EmptyStateModule,
            DynamicFormModule,
            PanelModule,
            InputTextModule,
            ButtonModule,
            ConfirmDialogModule,
            CalendarModule,
            SharedModule,
            HotkeyModule,
            LoadingStateModule,
            InputTextareaModule,
            InputSwitchModule,
            DescriptionSwitchDirective
        ]
        /*{CA:MODULE_CONFIG:END}*/
    })
], SharedScheduleModule);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

const moment = moment_; // @HACK Necessary because of https://github.com/rollup/rollup/issues/670
class E001Pes {
    constructor() {
        this.excluido = false;
    }
    static fromDto(e001PesDto, originEntity) {
        const model = Object.assign({}, e001PesDto);
        model.createdDate = model.createdDate && moment(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment(model.lastModifiedDate).toDate();
        const lookupSeparator = " - ";
        const displayFields = ["nomPes"];
        model.label = displayFields.map(field => model[field]).join(lookupSeparator);
        return model;
    }
    static toDto(e001Pes, originEntity) {
        const dto = Object.assign({}, e001Pes);
        dto.createdDate = dto.createdDate && moment(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment(dto.lastModifiedDate).format();
        delete dto.label;
        return dto;
    }
}

const moment$1 = moment_; // @HACK Necessary because of https://github.com/rollup/rollup/issues/670
class Employee {
    constructor() {
        this.deleted = false;
    }
    static fromDto(employeeDto, originEntity) {
        const model = Object.assign({}, employeeDto);
        model.hireDate = model.hireDate && moment$1(model.hireDate).toDate();
        model.dismissalDate = model.dismissalDate && moment$1(model.dismissalDate).toDate();
        model.createdDate = model.createdDate && moment$1(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$1(model.lastModifiedDate).toDate();
        const lookupSeparator = " - ";
        const displayFields = [
            "id",
            "code",
            "person.nomPes",
            "hireDate",
            "dismissalDate",
            "deleted",
            "extIntSts",
            "extIntMsg",
            "createdBy",
            "createdDate",
            "lastModifiedBy",
            "lastModifiedDate",
        ];
        model.label = displayFields.map(field => model[field]).join(lookupSeparator);
        if (originEntity !== "E001Pes" && model.person)
            model.person = E001Pes.fromDto(model.person, "Employee");
        return model;
    }
    static toDto(employee, originEntity) {
        const dto = Object.assign({}, employee);
        dto.hireDate = dto.hireDate && moment$1(dto.hireDate).format("YYYY-MM-DD");
        dto.dismissalDate = dto.dismissalDate && moment$1(dto.dismissalDate).format("YYYY-MM-DD");
        dto.createdDate = dto.createdDate && moment$1(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$1(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "E001Pes" && dto.person)
            dto.person = E001Pes.toDto(dto.person, "Employee");
        return dto;
    }
}

const moment$2 = moment_; // @HACK Necessary because of https://github.com/rollup/rollup/issues/670
class Bridge {
    static fromDto(bridgeDto, originEntity) {
        const model = Object.assign({}, bridgeDto);
        model.originDate = model.originDate && moment$2(model.originDate).toDate();
        model.destinationDate = model.destinationDate && moment$2(model.destinationDate).toDate();
        model.createdDate = model.createdDate && moment$2(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$2(model.lastModifiedDate).toDate();
        const lookupSeparator = " - ";
        const displayFields = [
            "id",
            "employee.code",
            "employee.person.nomPes",
            "originDate",
            "destinationDate",
            "createdBy",
            "createdDate",
            "lastModifiedBy",
            "lastModifiedDate",
        ];
        model.label = displayFields.map(field => model[field]).join(lookupSeparator);
        if (originEntity !== "Employee" && model.employee)
            model.employee = Employee.fromDto(model.employee, "Bridge");
        return model;
    }
    static toDto(bridge, originEntity) {
        const dto = Object.assign({}, bridge);
        dto.originDate = dto.originDate && moment$2(dto.originDate).format("YYYY-MM-DD");
        dto.destinationDate = dto.destinationDate && moment$2(dto.destinationDate).format("YYYY-MM-DD");
        dto.createdDate = dto.createdDate && moment$2(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$2(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "Employee" && dto.employee)
            dto.employee = Employee.toDto(dto.employee, "Bridge");
        return dto;
    }
}

class EntityService {
    constructor(http, messageService, entityUrl, actionsUrl, translate) {
        this.http = http;
        this.messageService = messageService;
        this.entityUrl = entityUrl;
        this.actionsUrl = actionsUrl;
        this.translate = translate;
        this.http = http;
        this.messageService = messageService;
        this.entityUrl = entityUrl;
        this.actionsUrl = actionsUrl;
        this.translate = translate;
        this.defaultCatch = this.defaultCatch.bind(this);
    }
    getListQueryParams(listParams) {
        const { page = 0, size = 10, sort = [], filterQuery = "", displayFields = [] } = listParams;
        let params = new HttpParams();
        params = params.append("size", String(size));
        params = params.append("offset", String(page));
        if (sort && sort.length) {
            params = params.append("orderby", sort
                .map(s => {
                let order = "";
                if (s.order === 1)
                    order = " asc";
                else if (s.order === -1)
                    order = " desc";
                return `${s.field}${order}`;
            })
                .join(", "));
        }
        if (filterQuery)
            params = params.append("filter", filterQuery);
        if (displayFields && displayFields.length)
            params = params.append("displayfields", displayFields.join());
        return params;
    }
    getBodyParams(listParams) {
        const { page = 0, size = 10, sort = [], filterQuery = "", displayFields = [] } = listParams;
        const bodyParams = {};
        bodyParams.size = size;
        bodyParams.offset = page;
        if (sort && sort.length) {
            bodyParams.orderBy = sort
                .map(s => {
                let order = "";
                if (s.order === 1)
                    order = " asc";
                else if (s.order === -1)
                    order = " desc";
                return `${s.field}${order}`;
            })
                .join(", ");
        }
        if (filterQuery)
            bodyParams.filter = filterQuery;
        if (displayFields && displayFields.length)
            bodyParams.displayfields = displayFields.join();
        return bodyParams;
    }
    defaultCatch() {
        return catchError((err) => {
            if (err) {
                let summary = err.status ? String(err.status) : "Error";
                let detail = (err.error && err.error.message) || err.statusText || err.message || "Error";
                if (err.status === 401) {
                    summary = this.translate.instant("hcm_clocking_event_foundation.general.error_unauthorized_title");
                    detail = this.translate.instant("hcm_clocking_event_foundation.general.error_unauthorized_description");
                }
                this.messageService.add({
                    severity: "error",
                    summary,
                    detail,
                });
            }
            return throwError(err);
        });
    }
    list(listParams) {
        return this.http.get(this.entityUrl, { params: this.getListQueryParams(listParams) }).pipe(this.defaultCatch());
    }
    get(id) {
        return this.http.get(`${this.entityUrl}/${id}`).pipe(this.defaultCatch());
    }
    insert(entity) {
        return this.http.post(`${this.entityUrl}`, entity).pipe(this.defaultCatch());
    }
    update(id, entity) {
        return this.http.put(`${this.entityUrl}/${id}`, entity).pipe(this.defaultCatch());
    }
    delete(id) {
        return this.http.delete(`${this.entityUrl}/${id}`).pipe(this.defaultCatch());
    }
    listCustomFilter(listParams, action) {
        return this.http.post(`${this.actionsUrl}/${action}`, this.getBodyParams(listParams)).pipe(this.defaultCatch());
    }
}

let BridgeService = class BridgeService extends EntityService {
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/bridge`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
    }
};
BridgeService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
BridgeService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [HttpClient, MessageService, TranslateService])
], BridgeService);

let CompanyClockingEventIndicationsService = class CompanyClockingEventIndicationsService extends EntityService {
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/companyClockingEventIndications`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
    }
};
CompanyClockingEventIndicationsService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
CompanyClockingEventIndicationsService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [HttpClient, MessageService, TranslateService])
], CompanyClockingEventIndicationsService);

let EmployeeService = class EmployeeService extends EntityService {
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_contract/employment_contract/entities/employee`, `hcm_contract/employment_contract/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
    }
    listExternalEmployee(listParams) {
        return this.http
            .get("hcm_contract/employment_contract/entities/employee", {
            params: this.getListQueryParams(listParams),
        })
            .pipe(this.defaultCatch());
    }
};
EmployeeService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
EmployeeService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [HttpClient, MessageService, TranslateService])
], EmployeeService);

const numberTypes = [FieldType.Integer, FieldType.Double];
const numberPattern = /^\d+\b$/;
const mergeUnique = (array, otherArray) => array.concat(otherArray.filter(item => !array.includes(item)));
const isValidFilter = (type, value) => {
    const { isValidValue, typeExists } = getTypeInformation(type, value);
    return !(typeExists && !isValidValue);
};
const getTypeInformation = (type, value) => {
    switch (type) {
        case FieldType.Time:
        case FieldType.Date:
        case FieldType.DateTime:
            return { isValidValue: false, typeExists: true };
        case FieldType.Integer:
        case FieldType.Double:
            return {
                isValidValue: value.match(numberPattern),
                typeExists: numberTypes.includes(type),
            };
        default:
            return {
                isValidValue: value.match(numberPattern),
                typeExists: numberTypes.includes(type),
            };
    }
};
const convertMinutesToTime = (minutes, monthMinute) => {
    const time = minutes.replace(".", "");
    const hour = Math.floor(parseInt(time) / 60);
    const minute = parseInt(time) % 60;
    let msg = (hour < 10) ? "0" + hour : hour;
    msg += ":";
    msg += (minute < 10) ? "0" + minute : "" + minute;
    if (monthMinute) {
        msg = putZeroAtHours(msg.toString());
    }
    return msg;
};
const putZeroAtHours = (msg) => {
    if (msg.length === 4) {
        return "00" + msg;
    }
    else if (msg.length === 5) {
        return "0" + msg;
    }
    else {
        return msg;
    }
};
const ɵ0 = putZeroAtHours;
const convertTimeToMinutes = (time) => {
    if (time) {
        const array = time.toString().split(":");
        return (array[0] * 60) + parseInt(array[1]);
    }
    return null;
};
const mergeDateTime = (date, hour) => {
    const momentHour = moment_(hour);
    return moment_(date)
        .hour(momentHour.hour())
        .minute(momentHour.minute())
        .second(0).toDate();
};

const moment$3 = moment_; // @HACK Necessary because of https://github.com/rollup/rollup/issues/670
function startDateTimeIsBeforeEndDateTimeValidator(startDateTime, endDateTime) {
    if (startDateTime && endDateTime && startDateTime.value && endDateTime.value) {
        const isInvalid = moment$3(startDateTime.value).seconds(0).isSameOrAfter(moment$3(endDateTime.value).seconds(0)) ? { startDateTimeIsBeforeEndDateTime: { value: [endDateTime.value, startDateTime.value] } } : null;
        if (isInvalid) {
            startDateTime.markAsDirty();
            endDateTime.markAsDirty();
            endDateTime.setErrors(isInvalid);
            startDateTime.setErrors(isInvalid);
            return isInvalid;
        }
        removeErrorFromField(endDateTime, 'startDateTimeIsBeforeEndDateTime');
        removeErrorFromField(startDateTime, 'startDateTimeIsBeforeEndDateTime');
    }
    else if (startDateTime && startDateTime.value && !(endDateTime && endDateTime.value)) {
        removeErrorFromField(startDateTime, 'startDateTimeIsBeforeEndDateTime');
    }
    else if (!(startDateTime && startDateTime.value) && endDateTime && endDateTime.value) {
        removeErrorFromField(endDateTime, 'startDateTimeIsBeforeEndDateTime');
    }
    return null;
}
;
function startTimeIsBeforeEndTimeValidator(control) {
    const startDate = control.get('startDate');
    const startTime = control.get('startTime');
    const endDate = control.get('endDate');
    const endTime = control.get('endTime');
    const isStartDefined = startDate && startDate.value && startTime && startTime.value;
    const isEndDefined = endDate && endDate.value && endTime && endTime.value;
    if (isStartDefined && isEndDefined) {
        const startDateTime = mergeDateTime(startDate.value, startTime.value);
        const endDateTime = mergeDateTime(endDate.value, endTime.value);
        const error = { startTimeIsBeforeEndTime: { value: [endDateTime, startDateTime] } };
        const isStartDateBeforeOrEqualToEndDate = startDate.value <= endDate.value;
        const isSameOrAfter = startDateTime.toString() === endDateTime.toString() || startDateTime > endDateTime;
        const isInvalid = isSameOrAfter ? error : null;
        if (isInvalid && isStartDateBeforeOrEqualToEndDate) {
            startTime.markAsDirty();
            startTime.setErrors(isInvalid);
            endTime.markAsDirty();
            endTime.setErrors(isInvalid);
            return isInvalid;
        }
        removeErrorFromField(startTime, 'startTimeIsBeforeEndTime');
        removeErrorFromField(endTime, 'startTimeIsBeforeEndTime');
    }
    else if (isStartDefined && !isEndDefined) {
        removeErrorFromField(startTime, 'startTimeIsBeforeEndTime');
    }
    else if (!isStartDefined && isEndDefined) {
        removeErrorFromField(endTime, 'startTimeIsBeforeEndTime');
    }
    return null;
}
;
function startDateIsBeforeOrEqualToEndDateValidator(startDate, endDate) {
    if (startDate && endDate && startDate.value && endDate.value) {
        const forbidden = startDate.value > endDate.value ? { startDateIsBeforeEndDate: { value: endDate.value } } : null;
        if (forbidden) {
            startDate.markAsDirty();
            endDate.markAsDirty();
            startDate.setErrors(forbidden);
            endDate.setErrors(forbidden);
            return forbidden;
        }
        removeErrorFromField(endDate, 'startDateIsBeforeEndDate');
        removeErrorFromField(startDate, 'startDateIsBeforeEndDate');
    }
    else if (startDate && startDate.value && !(endDate && endDate.value)) {
        removeErrorFromField(startDate, 'startDateIsBeforeEndDate');
    }
    else if (!(startDate && startDate.value) && endDate && endDate.value) {
        removeErrorFromField(endDate, 'startDateIsBeforeEndDate');
    }
    return null;
}
function removeErrorFromField(field, error) {
    if (field.errors) {
        delete field.errors[error];
    }
    if (JSON.stringify(field.errors) == JSON.stringify({})) {
        field.setErrors(null);
    }
}
function startDateIsBeforeEndDateValidator(startDate, endDate) {
    if (startDate && endDate && startDate.value && endDate.value) {
        const forbidden = moment$3(startDate.value).isSameOrAfter(endDate.value) ? { startDateIsBeforeEndDate: { value: endDate.value } } : null;
        if (forbidden) {
            startDate.markAsDirty();
            endDate.markAsDirty();
            startDate.setErrors(forbidden);
            endDate.setErrors(forbidden);
            return forbidden;
        }
        removeErrorFromField(endDate, 'startDateIsBeforeEndDate');
        removeErrorFromField(startDate, 'startDateIsBeforeEndDate');
    }
    else if (startDate && startDate.value && !(endDate && endDate.value)) {
        removeErrorFromField(startDate, 'startDateIsBeforeEndDate');
    }
    else if (!(startDate && startDate.value) && endDate && endDate.value) {
        removeErrorFromField(endDate, 'startDateIsBeforeEndDate');
    }
    return null;
}

var BridgeFormComponent_1;
const moment$4 = moment_; // @HACK Necessary because of https://github.com/rollup/rollup/issues/670
let BridgeFormComponent = BridgeFormComponent_1 = class BridgeFormComponent {
    constructor(
    /*{CA:INJECTIONS:START}*/
    companyClockingEventIndicationsService, 
    /*{CA:INJECTIONS:END}*/
    bridgeService, router, route, messageService, confirmationService, formBuilder, translate, hotkeysService, fieldCustomization, focusService, employeeService) {
        this.companyClockingEventIndicationsService = companyClockingEventIndicationsService;
        this.bridgeService = bridgeService;
        this.router = router;
        this.route = route;
        this.messageService = messageService;
        this.confirmationService = confirmationService;
        this.formBuilder = formBuilder;
        this.translate = translate;
        this.hotkeysService = hotkeysService;
        this.fieldCustomization = fieldCustomization;
        this.focusService = focusService;
        this.employeeService = employeeService;
        this.localeConfig = {};
        this.currencyLocaleOptions = {};
        this.permissions = {};
        this.allPermissions = {};
        this.mainPanelCollapsed = false;
        this.contractTypeOptions = [
            {
                label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_employee"),
                value: "EMPLOYEE",
            },
            {
                label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_director"),
                value: "DIRECTOR",
            },
            {
                label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_trainee"),
                value: "TRAINEE",
            },
            {
                label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_aprentice"),
                value: "APRENTICE",
            },
            {
                label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_third_party"),
                value: "THIRD_PARTY",
            },
        ];
        this.employeeLookupDisplayFields = [
            "employer.codEmp",
            "code",
            "person.nomPes",
            "employmentRelationship.contractType",
        ];
        this.employeeAdvancedDisplayFields = ["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractType"];
        this.employeeLookupSeparator = " - ";
        /*{CA:CLASS_ATTRIBUTES:START}*/
        this.cacheLimitDaysBackwardScheduling = new Map();
        this.onClose = new Subject();
        this.onLoadFormSubject = new Subject();
        this.onCloseObservable = this.onClose.asObservable();
        this.onLoadForm = this.onLoadFormSubject.asObservable();
        this.ngUnsubscribe = new Subject();
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
    ngOnInit() {
        /*{CA:ON_INIT_START:START}*/
        this.route.params.pipe(takeUntil(this.ngUnsubscribe)).subscribe((params) => this.onRouteParamsChange(params));
        /*{CA:ON_INIT_START:END}*/
        this.formGroup = this.getFormGroup();
        if (this.lockedEmployee) {
            this.loadLockedEmployee(this.lockedEmployee);
            this.onSubmitObservable.pipe(takeUntil(this.ngUnsubscribe), filter(name => name === "bridge" || name === "bridgeDelete")).subscribe((value) => {
                switch (value) {
                    case "bridge":
                        this.onSave();
                        break;
                    case "bridgeDelete":
                        this.onDelete();
                        break;
                    default:
                        break;
                }
            });
            this.onLockedEmployeeChanges
                .pipe(takeUntil(this.ngUnsubscribe))
                .subscribe((value) => {
                this.bridge = value.schedule;
                this.loadLockedEmployee(value);
            });
        }
        else {
            this.setHotkeys();
        }
        this.route.data
            .pipe(takeUntil(this.ngUnsubscribe))
            .subscribe((data) => this.onRouteDataChange(data));
        this.employeeSearchFields = this.getEmployeeSearchFields();
        this.employeeSearchGridFields = this.getEmployeeSearchGridFields();
        /*{CA:ON_INIT_END:START}*/
        /*{CA:ON_INIT_END:END}*/
    }
    patchValuesAndUpdateSuggestions(value, result) {
        this.updateSuggestions(this.bridge);
        this.formGroup.patchValue(this.bridge);
        this.formGroup.controls[BridgeFormComponent_1.EMPLOYEE].disable();
        if (value.schedule) {
            this.formGroup.controls[BridgeFormComponent_1.ORIGIN_DATE].disable();
            this.formGroup.value.id = result.originDate;
            this.formGroup.value.id = result.id;
            const canEdit = this.permissions.editar;
            if (!canEdit) {
                this.formGroup.disable();
            }
        }
        this.loading = false;
    }
    loadLockedEmployee(value) {
        const employee = this.formGroup.controls[BridgeFormComponent_1.EMPLOYEE].value;
        this.formGroup.reset();
        this.formGroup.controls[BridgeFormComponent_1.EMPLOYEE].setValue(employee);
        if (this.formGroup.controls[BridgeFormComponent_1.EMPLOYEE].value) {
            this.formGroup.controls[BridgeFormComponent_1.ORIGIN_DATE].setValue(moment$4(value.evaluationDate).toDate());
            this.onLoadFormSubject.next(false);
        }
        else {
            this.loading = true;
            this.employeeService.listExternalEmployee({
                filterQuery: `id eq '${value.employeeId}'`,
                displayFields: this.employeeLookupDisplayFields
            }).subscribe((dto) => {
                if (!value.schedule) {
                    this.bridge = new Bridge();
                    this.bridge.originDate = moment$4(value.evaluationDate).toDate();
                    this.bridge.employee = Employee.fromDto(dto.contents[0], "Bridge");
                    this.patchValuesAndUpdateSuggestions(value, null);
                }
                else {
                    this.bridgeService.get(value.schedule).subscribe((result) => {
                        this.bridge = Bridge.fromDto(result);
                        this.patchValuesAndUpdateSuggestions(value, result);
                    });
                }
                this.onLoadFormSubject.next(false);
            });
        }
    }
    ngAfterViewInit() {
        /*{CA:ON_VIEW_INIT_START:START}*/
        /*{CA:ON_VIEW_INIT_START:END}*/
        /*{CA:ON_VIEW_INIT_END:START}*/
        /*{CA:ON_VIEW_INIT_END:END}*/
    }
    ngOnDestroy() {
        /*{CA:ON_DESTROY_START:START}*/
        /*{CA:ON_DESTROY_START:END}*/
        this.ngUnsubscribe.unsubscribe();
        this.cacheLimitDaysBackwardScheduling.clear();
        /*{CA:ON_DESTROY_END:START}*/
        /*{CA:ON_DESTROY_END:END}*/
    }
    setHotkeys() {
        /*{CA:SET_HOTKEYS_START:START}*/
        /*{CA:SET_HOTKEYS_START:END}*/
        this.hotkeysService.add(new Hotkey("alt+shift+x", () => {
            if (this.permissions.excluir) {
                this.onDelete();
            }
            return false;
        }, ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+s", () => {
            if (this.isNew() || this.permissions.editar) {
                this.onSave();
            }
            return false;
        }, ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+c", () => {
            this.onCancel();
            return false;
        }, ["INPUT", "SELECT", "TEXTAREA"]));
        /*{CA:SET_HOTKEYS_END:START}*/
        /*{CA:SET_HOTKEYS_END:END}*/
    }
    isNew() {
        return this.routeParams.bridge === "new";
    }
    onRouteParamsChange(params) {
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:END}*/
        this.routeParams = params;
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:END}*/
    }
    updateSuggestions(value) {
        /*{CA:ON_UPDATE_SUGGESTIONS_START:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_START:END}*/
        if (value.employee) {
            value.employee.employmentRelationship.contractTypeLabel = this.loadLabelFromEnum(value.employee.employmentRelationship.contractType);
            value.employee.label = this.getSuggestionValue([
                "employer.codEmp",
                "code",
                "person.nomPes",
                "employmentRelationship.contractTypeLabel",
            ], "employee", value, this.employeeLookupSeparator);
            if (value.employee.label.trim() === this.employeeLookupSeparator.trim()) {
                delete value.employee.label;
            }
        }
        /*{CA:ON_UPDATE_SUGGESTIONS_END:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_END:END}*/
    }
    getSuggestionValue(displayFields, ownerEntity, value, separator) {
        return displayFields
            .map((field) => this.getProp(value, `${ownerEntity}.${field}`))
            .reduce((acc, val) => `${acc}${separator}${val}`);
    }
    onRouteDataChange(data) {
        /*{CA:ON_ROUTE_DATA_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_START:END}*/
        const { currencySymbol, thousandsSeparator, decimalSeparator } = data.localeConfig.number;
        this.localeConfig = data.localeConfig;
        this.currencyLocaleOptions = {
            align: "left",
            prefix: currencySymbol,
            thousands: thousandsSeparator,
            decimal: decimalSeparator,
        };
        this.permissions = data.allPermissions.bridge;
        this.allPermissions = data.allPermissions;
        this.validateVisualization();
        if (this.lockedEmployee) {
            return;
        }
        else if (data.entity && data.entity[0]) {
            const canEdit = this.permissions.editar;
            if (!canEdit) {
                this.formGroup.disable();
            }
            const value = Bridge.fromDto(data.entity[0]);
            this.updateSuggestions(value);
            this.formGroup.patchValue(value);
            const limitDate = new Date();
            limitDate.setDate(limitDate.getDate() -
                data.entity[1].timeEvaluationDefinition.limitDaysBackwardScheduling);
            this.cacheLimitDaysBackwardScheduling.set(data.entity[1].id, limitDate);
        }
        else {
            this.formGroup.patchValue(new Bridge());
        }
        /*{CA:ON_ROUTE_DATA_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_END:END}*/
    }
    onCancel() {
        /*{CA:ON_CANCEL_START:START}*/
        /*{CA:ON_CANCEL_START:END}*/
        this.goBack();
        /*{CA:ON_CANCEL_END:START}*/
        /*{CA:ON_CANCEL_END:END}*/
    }
    onSendFile(filesToDelete, filesToCommit) {
        /*{CA:ON_SEND_FILE:START}*/
        /*{CA:ON_SEND_FILE:END}*/
        const observables = [];
        if (!this.fieldCustomization.isEmpty(filesToDelete)) {
            observables.push(this.fieldCustomization.deleteFiles(filesToDelete));
        }
        if (!this.fieldCustomization.isEmpty(filesToCommit)) {
            observables.push(this.fieldCustomization.commitFiles(filesToCommit));
        }
        if (!this.fieldCustomization.isEmpty(observables)) {
            return forkJoin(observables);
        }
        else {
            return of({});
        }
    }
    onSave() {
        /*{CA:ON_SAVE_START:START}*/
        /*{CA:ON_SAVE_START:END}*/
        this.loading = true;
        this.onLoadFormSubject.next(true);
        if (!this.formGroup.valid) {
            this.loading = false;
            this.onLoadFormSubject.next(false);
            return this.validateAllFormFields(this.formGroup);
        }
        const { filesToDelete, filesToCommit } = this.fieldCustomization.getFiles(this.formGroup);
        this.getSaveObservable()
            .pipe(takeUntil(this.ngUnsubscribe), catchError((err) => {
            this.loading = false;
            this.onLoadFormSubject.next(false);
            return throwError(err);
        }))
            .subscribe(() => {
            /*{CA:ON_SAVE_START_TOP:START}*/
            /*{CA:ON_SAVE_START_TOP:END}*/
            this.onSendFile(filesToDelete, filesToCommit)
                .pipe(takeUntil(this.ngUnsubscribe), catchError((err) => {
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                this.loading = false;
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                return throwError(err);
            }))
                .subscribe(() => {
                this.addMessage("success", "hcm_clocking_event_foundation.general.saved_message_title", "hcm_clocking_event_foundation.general.saved_message_content");
                this.finishOperation();
                /*{CA:ON_SAVE_START_BOTTOM:START}*/
                /*{CA:ON_SAVE_START_BOTTOM:END}*/
            });
        });
        /*{CA:ON_SAVE_END:START}*/
        /*{CA:ON_SAVE_END:END}*/
    }
    finishOperation() {
        if (this.lockedEmployee) {
            this.onClose.next();
            this.loading = false;
        }
        else {
            this.goBack();
        }
    }
    onDelete() {
        /*{CA:ON_DELETE_START:START}*/
        /*{CA:ON_DELETE_START:END}*/
        this.confirmationService.confirm({
            message: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_message"),
            header: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_title"),
            accept: () => {
                this.loading = true;
                this.onLoadFormSubject.next(true);
                this.getDeleteObservable()
                    .pipe(takeUntil(this.ngUnsubscribe))
                    .subscribe(() => this.finishOperation());
            },
            reject: () => this.loading = false
        });
        /*{CA:ON_DELETE_END:START}*/
        /*{CA:ON_DELETE_END:END}*/
    }
    getProp(obj, path) {
        return path
            .split(".")
            .reduce((result, prop) => (result[prop] === undefined ? "" : result[prop]), obj);
    }
    loadLabelFromEnum(value) {
        return this.contractTypeOptions.filter((r) => r.value === value)[0].label;
    }
    loadEnumFromLabel(value) {
        value = value.toUpperCase().trim();
        if (value && value !== undefined) {
            return this.contractTypeOptions
                .filter((r) => {
                const match = r.label.toUpperCase().match(value);
                return match !== null && match.length !== 0;
            })
                .map((r) => r.value);
        }
        return [];
    }
    onEmployeeLookupRequest(value) {
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:END}*/
        const sort = this.employeeLookupDisplayFields.map((field) => ({ field, order: 1 }));
        const filterQuery = this.getEmployeeSearchFields()
            .filter(({ type }) => isValidFilter(type, value))
            .map(({ name, type }) => {
            if (typeof value === "number") {
                return `${name} eq ${value}`;
            }
            else if (type === FieldType.Date) {
                return `${name} eq '${moment$4(value).format("YYYY-MM-DD")}'`;
            }
            else if (type === FieldType.Time) {
                return `${name} eq '${moment$4(value).format("HH:mm:ss")}'`;
            }
            else if (type === FieldType.DateTime) {
                return `${name} eq '${moment$4(value).format()}'`;
            }
            else if (type === FieldType.Enum) {
                return this.loadEnumFromLabel(value)
                    .map((enumConstant) => `${name} eq '${enumConstant}'`)
                    .join(" or ");
            }
            else if (type === FieldType.String) {
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            }
            else {
                return `${name} eq '${value}'`;
            }
        })
            .filter((filter) => filter !== "")
            .join(" or ");
        const displayFields = mergeUnique(this.employeeLookupDisplayFields, this.employeeAdvancedDisplayFields).concat("hireDate", "dismissalDate");
        this.employeeService
            .listExternalEmployee({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.employeeLookupDisplayFields
                    .map((field) => {
                    if (field.indexOf(".") > 0) {
                        item[field] = this.getProp(item, field);
                    }
                    if (field === "employmentRelationship.contractType") {
                        item[field] = this.loadLabelFromEnum(item[field]);
                    }
                    return item[field];
                })
                    .join(this.employeeLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.employeeLookupSuggestions = list.contents;
        });
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:END}*/
    }
    onEmployeeSearchRequest(event) {
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        const page = first / rows;
        const sort = multiSortMeta;
        const filterQuery = this.getEmployeeSearchFields()
            .filter(({ name }) => !!filterData[name] && filterData[name] !== "")
            .map(({ name, type }) => {
            const value = filterData[name];
            if (typeof value === "number") {
                return `${name} eq ${value}`;
            }
            else if (type === FieldType.Date) {
                return `${name} eq '${moment$4(value).format("YYYY-MM-DD")}'`;
            }
            else if (type === FieldType.Time) {
                return `${name} eq '${moment$4(value).format("HH:mm:ss")}'`;
            }
            else if (type === FieldType.DateTime) {
                return `${name} eq '${moment$4(value).format()}'`;
            }
            else if (type === FieldType.Enum) {
                return `${name} eq '${value}'`;
            }
            else if (type === FieldType.String) {
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            }
            else {
                return `${name} eq '${value}'`;
            }
        })
            .join(" and ");
        const displayFields = mergeUnique(this.employeeLookupDisplayFields, this.employeeAdvancedDisplayFields).concat("hireDate", "dismissalDate");
        this.employeeService
            .listExternalEmployee({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.employeeLookupDisplayFields
                    .map((field) => {
                    if (field.indexOf(".") > 0) {
                        item[field] = this.getProp(item, field); // NOSONAR
                    }
                    if (field === "employmentRelationship.contractType") { // NOSONAR
                        item[field] = this.loadLabelFromEnum(item[field]); // NOSONAR
                    } // NOSONAR
                    return item[field]; // NOSONAR
                }) // NOSONAR
                    .join(this.employeeLookupSeparator) }))) }))) // NOSONAR
        ) // NOSONAR
            .subscribe((list) => {
            this.employeeSearchGridData = list.contents; // NOSONAR
            this.employeeSearchTotalRecords = list.totalElements; // NOSONAR
        }); // NOSONAR
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:END}*/
    }
    getFormGroup() {
        const formGroup = this.formBuilder.group({
            id: [{ value: undefined, disabled: true }, Validators.compose([])],
            employee: [
                { value: undefined, disabled: false },
                Validators.compose([Validators.required]),
            ],
            originDate: [
                { value: undefined, disabled: false },
                Validators.compose([Validators.required]),
            ],
            destinationDate: [
                { value: undefined, disabled: false },
                Validators.compose([Validators.required]),
            ],
            createdBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            createdDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            custom: [],
        }, {
            validators: [
                this.validLimitDaysBackwardScheduling(),
                this.startDateIsBeforeEndDate(),
            ],
        });
        formGroup.controls.employee.valueChanges.subscribe((employee) => {
            if (employee) {
                const limitDaysBackwardScheduling = this.cacheLimitDaysBackwardScheduling.get(employee.employer.id);
                if (limitDaysBackwardScheduling === undefined) {
                    this.companyClockingEventIndicationsService
                        .list({
                        filterQuery: `id eq '${employee.employer.id}'`,
                        displayFields: ["timeEvaluationDefinition.limitDaysBackwardScheduling"]
                    })
                        .pipe(map((data) => data.contents[0]), catchError((error) => {
                        formGroup.controls.employee.setErrors({
                            hasNotCompanyClockingEventIndications: { value: error },
                        });
                        return throwError(error);
                    }))
                        .subscribe(companyClockingEventIndications => {
                        const limitDate = new Date();
                        limitDate.setDate(limitDate.getDate() -
                            companyClockingEventIndications.timeEvaluationDefinition
                                .limitDaysBackwardScheduling);
                        this.cacheLimitDaysBackwardScheduling.set(companyClockingEventIndications.id, limitDate);
                    });
                }
            }
        });
        this.disableFieldsOnEdit(formGroup);
        return formGroup;
    }
    getEmployeeSearchFields() {
        const searchFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions,
            }),
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    getEmployeeSearchGridFields() {
        const searchGridFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions
            }),
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    goBack() {
        const previousRoute = "../";
        this.router.navigate([previousRoute], { relativeTo: this.route.parent });
    }
    validateAllFormFields(formGroup) {
        Object.keys(formGroup.controls).forEach((field) => {
            const control = formGroup.get(field);
            if (control instanceof FormControl) {
                control.markAsDirty({ onlySelf: true });
            }
            else if (control instanceof FormGroup) {
                this.validateAllFormFields(control);
            }
        });
        this.focusService.focusFirstInvalidInput();
        /*{CA:FOCUS_FIRST_INVALID:START}*/
        /*{CA:FOCUS_FIRST_INVALID:END}*/
    }
    getSaveObservable() {
        const { value } = this.formGroup;
        value.employee = this.formGroup.controls[BridgeFormComponent_1.EMPLOYEE].value;
        value.id = this.formGroup.controls["id"].value;
        value.originDate = this.formGroup.controls["originDate"].value;
        const bridgeDto = Bridge.toDto(value);
        let observable;
        if (this.isNew() || (this.lockedEmployee && !value.id)) {
            observable = this.bridgeService.insert(bridgeDto);
        }
        else {
            const id = this.lockedEmployee ? value.id : this.routeParams.bridge;
            observable = this.bridgeService.update(id, bridgeDto);
        }
        return observable;
    }
    getDeleteObservable() {
        let bridgeId = this.routeParams.bridge;
        if (this.lockedEmployee && this.lockedEmployee.schedule) {
            bridgeId = this.lockedEmployee.schedule;
        }
        return this.bridgeService.delete(bridgeId).pipe(tap(() => {
            this.addMessage(// NOSONAR
            "success", // NOSONAR
            "hcm_clocking_event_foundation.general.deleted_message_title", // NOSONAR
            "hcm_clocking_event_foundation.general.deleted_message_content" // NOSONAR
            ); // NOSONAR
        }) // NOSONAR
        ); // NOSONAR
    } // NOSONAR
    validateVisualization() {
        /*{CA:VALIDATE_VISUALIZATION_START:START}*/
        /*{CA:VALIDATE_VISUALIZATION_START:END}*/
        const toValidate = ["employee"];
        if (!toValidate.every((e) => this.allPermissions[e] && this.allPermissions[e].visualizar)) {
            this.router.navigate(["forbidden"]);
        }
        /*{CA:VALIDATE_VISUALIZATION_END:START}*/
        /*{CA:VALIDATE_VISUALIZATION_END:END}*/
    }
    validLimitDaysBackwardScheduling() {
        return (control) => {
            const originDate = control.get("originDate");
            const employee = control.get("employee");
            if (employee.value && originDate.value) {
                const limitDate = this.cacheLimitDaysBackwardScheduling.get(employee.value.employer.id);
                if (limitDate && moment$4(originDate.value).isBefore(limitDate, "day")) {
                    originDate.setErrors({ exceededLimit: { value: originDate.value } });
                }
                else {
                    removeErrorFromField(originDate, "exceededLimit");
                }
            }
            return null;
        };
    }
    startDateIsBeforeEndDate() {
        return (control) => {
            const originDate = control.get("originDate");
            const destinationDate = control.get("destinationDate");
            startDateIsBeforeEndDateValidator(originDate, destinationDate);
            return null;
        };
    }
    /*{CA:CLASS_METHODS:END}*/
    addMessage(severity, summary, detail) {
        if (this.lockedEmployee) {
            this.messageService.add({
                key: "employee-clocking-event-adjustment-list-view",
                severity,
                summary: this.translate.instant(summary),
                detail: this.translate.instant(detail),
            });
        }
        else {
            this.messageService.add({
                severity,
                summary: this.translate.instant(summary),
                detail: this.translate.instant(detail),
            });
        }
    }
    disableFieldsOnEdit(formGroup) {
        if (!this.isNew() && !this.lockedEmployee) {
            formGroup.controls.employee.disable();
        }
    }
};
BridgeFormComponent.EMPLOYEE = "employee";
BridgeFormComponent.ORIGIN_DATE = "originDate";
BridgeFormComponent.ctorParameters = () => [
    { type: CompanyClockingEventIndicationsService },
    { type: BridgeService },
    { type: Router },
    { type: ActivatedRoute },
    { type: MessageService },
    { type: ConfirmationService },
    { type: FormBuilder },
    { type: TranslateService },
    { type: HotkeysService },
    { type: FieldCustomizationService },
    { type: FocusService },
    { type: EmployeeService }
];
__decorate([
    ViewChild("customTemplate"),
    __metadata("design:type", TemplateRef)
], BridgeFormComponent.prototype, "customTemplate", void 0);
__decorate([
    ViewChild("customFormFields"),
    __metadata("design:type", TemplateRef)
], BridgeFormComponent.prototype, "customFormFields", void 0);
__decorate([
    Input(),
    __metadata("design:type", Observable)
], BridgeFormComponent.prototype, "onSubmitObservable", void 0);
__decorate([
    Input(),
    __metadata("design:type", Observable)
], BridgeFormComponent.prototype, "onLockedEmployeeChanges", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], BridgeFormComponent.prototype, "lockedEmployee", void 0);
__decorate([
    Output(),
    __metadata("design:type", Observable)
], BridgeFormComponent.prototype, "onCloseObservable", void 0);
__decorate([
    Output(),
    __metadata("design:type", Observable)
], BridgeFormComponent.prototype, "onLoadForm", void 0);
BridgeFormComponent = BridgeFormComponent_1 = __decorate([
    Component({
        template: "<div *ngIf=\"!customTemplate else customTemplate\">\n    <p-confirmDialog acceptLabel=\"{{'hcm_clocking_event_foundation.general.yes' | translate}}\" acceptIcon=\"\" appendTo=\"body\"\n        rejectLabel=\"{{'hcm_clocking_event_foundation.general.no' | translate}}\" rejectIcon=\"\">\n    </p-confirmDialog>\n    <form [formGroup]=\"formGroup\" novalidate>\n        <p-panel *sLoadingState=\"loading\" [styleClass]=\"lockedEmployee ? 'form-group sidebar-panel' : 'form-group'\"\n            [toggleable]=\"false\" [collapsed]=\"mainPanelCollapsed\" [showHeader]=\"!lockedEmployee\">\n            <p-header>\n                {{\"hcm_clocking_event_foundation.general.bridge_form_general_title\" | translate}}\n            </p-header>\n            <div class=\"ui-fluid\" *ngIf=\"!customFormFields else customFormFields\">\n                <div class=\"ui-g\">\n                    <div [attr.data-hidden]=\"true\" class=\"ui-g-12 ui-md-6\">\n                        <label for=\"id\">{{\"hcm_clocking_event_foundation.general.bridge_id\" | translate}}</label>\n                        <input #idFormInput type=\"text\" id=\"id\" name=\"id\" pInputText formControlName=\"id\" autocomplete=\"off\"\n                        />\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.employee.visualizar\" class=\"ui-g-12 ui-md-6 required\">\n                        <label for=\"employee\">{{\"hcm_clocking_event_foundation.general.bridge_employee\" | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"employee\" name=\"employee\" formControlName=\"employee\" [searchFields]=\"employeeSearchGridFields\"\n                        [searchGridFields]=\"employeeSearchGridFields\" [searchGridData]=\"employeeSearchGridData\"\n                        [multiple]=\"false\" [lookupSuggestions]=\"employeeLookupSuggestions\" (onLookupRequest)=\"onEmployeeLookupRequest($event)\"\n                        (onSearchRequest)=\"onEmployeeSearchRequest($event)\" lookupDisplayField=\"label\"\n                        [searchTotalRecords]=employeeSearchTotalRecords [searchTitle]=\"'hcm_clocking_event_foundation.general.bridge_employee_search_title' | translate\"\n                        [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                        [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                        [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                        [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\" [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: employeeSearchTotalRecords}\"></s-lookup>\n                        <s-control-errors [control]=\"formGroup.controls['employee']\"\n                        [errorMessages]=\"{\n                            required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                            hasNotCompanyClockingEventIndications: 'hcm_clocking_event_foundation.general.error_company_of_employee_need_time_evaluation_definition' | translate\n                        }\"\n                        ></s-control-errors>\n                    </div>\n                    <div class=\"ui-md-6\"></div>\n                    <div class=\"ui-g-12 ui-md-6 required\">\n                        <label for=\"originDate\">{{\"hcm_clocking_event_foundation.general.bridge_origin_date\" | translate}}</label>\n                        <p-calendar #originDateFormInput inputId=\"originDate\" name=\"originDate\" [showIcon]=\"true\" formControlName=\"originDate\"\n                            [locale]=\"localeConfig.calendar\" [dateFormat]=\"localeConfig.calendar.dateFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['originDate']\"\n                            [errorMessages]=\"{\n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                                exceededLimit: 'hcm_clocking_event_foundation.general.error_exceeded_limit_days_backward_scheduling' | translate,\n                                startDateIsBeforeEndDate: 'hcm_clocking_event_foundation.general.error_origin_date_after_destination_date_to_start_date' | translate\n                            }\"\n                        ></s-control-errors>\n                    </div>\n                    <div class=\"ui-g-12 ui-md-6 required\">\n                        <label for=\"destinationDate\">{{\"hcm_clocking_event_foundation.general.bridge_destination_date\" | translate}}</label>\n                        <p-calendar #destinationDateFormInput inputId=\"destinationDate\" name=\"destinationDate\" [showIcon]=\"true\"\n                            formControlName=\"destinationDate\" [locale]=\"localeConfig.calendar\" [dateFormat]=\"localeConfig.calendar.dateFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['destinationDate']\"\n                            [errorMessages]=\"{\n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                                startDateIsBeforeEndDate: 'hcm_clocking_event_foundation.general.error_origin_date_after_destination_date_to_end_date' | translate\n                            }\"\n                        ></s-control-errors>\n                    </div>\n                </div>\n            </div>\n            <s-custom-fields domain=\"hcm_clocking_event_foundation\" service=\"general\" entity=\"bridge\" formControlName=\"custom\" *ngIf=\"formGroup.controls['custom']\"\n                [invalidErrorLabel]=\"'hcm_clocking_event_foundation.general.error_invalid' | translate\"></s-custom-fields>\n            <div class=\"ui-g\" *ngIf=\"!isNew() && !lockedEmployee\">\n                <div class=\"ui-g-12 ui-inputgroup\">\n                    <label *ngIf=\"formGroup.get('createdBy').value !== ''\" style=\"color: #a3a3a3; margin-right: 2px;\">{{'hcm_clocking_event_foundation.general.created_by' | translate}} {{formGroup.get('createdBy').value}} {{'hcm_clocking_event_foundation.general.at_date' | translate}} {{formGroup.get('createdDate').value | date: 'dd/MM/yyyy'}} {{'hcm_clocking_event_foundation.general.at_time' | translate}} {{formGroup.get('createdDate').value | date: 'HH:mm'}}. </label>\n                    <label *ngIf=\"formGroup.get('lastModifiedBy').value !== ''\" style=\"color: #a3a3a3;\">{{'hcm_clocking_event_foundation.general.updated_by' | translate}} {{formGroup.get('lastModifiedBy').value}} {{'hcm_clocking_event_foundation.general.at_date' | translate}} {{formGroup.get('lastModifiedDate').value | date: 'dd/MM/yyyy'}} {{'hcm_clocking_event_foundation.general.at_time' | translate}} {{formGroup.get('lastModifiedDate').value | date: 'HH:mm'}}.</label>\n                </div>\n            </div>\n            <p-footer *ngIf=\"!lockedEmployee\">\n                <button id=\"save-button\" title=\"{{'hcm_clocking_event_foundation.general.save' | translate}} (Alt + Shift + S)\"\n                    type=\"submit\" pButton label=\"{{'hcm_clocking_event_foundation.general.save' | translate}}\"\n                    (click)=\"onSave()\" *ngIf=\"isNew() || permissions.editar\"></button>\n                <button id=\"delete-button\" title=\"{{'hcm_clocking_event_foundation.general.delete' | translate}} (Alt + Shift + X)\"\n                    type=\"button\" class=\"ui-button-secondary\" pButton label=\"{{'hcm_clocking_event_foundation.general.delete' | translate}}\"\n                    (click)=\"onDelete()\" *ngIf=\"!isNew() && permissions.excluir\" [disabled]=\"loading\"></button>\n                <button id=\"cancel-button\" title=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}} (Alt + Shift + C)\"\n                    type=\"button\" class=\"ui-button-link\" pButton label=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}}\"\n                    (click)=\"onCancel()\"></button>\n            </p-footer>\n        </p-panel>\n    </form>\n</div>\n<!--{CA:FILE_CONTENTS:START}-->\n<!--{CA:FILE_CONTENTS:END}-->\n",
        providers: [
            ConfirmationService,
        ],
        selector: "cem-bridge-form",
        styles: [":host ::ng-deep .sidebar-panel{border:none!important;padding-left:0!important}"]
    }),
    __metadata("design:paramtypes", [CompanyClockingEventIndicationsService,
        BridgeService,
        Router,
        ActivatedRoute,
        MessageService,
        ConfirmationService,
        FormBuilder,
        TranslateService,
        HotkeysService,
        FieldCustomizationService,
        FocusService,
        EmployeeService])
], BridgeFormComponent);

let BridgeFormModule = class BridgeFormModule {
};
BridgeFormModule = __decorate([
    NgModule({
        imports: [
            LocaleModule.forChild(),
            SharedScheduleModule
        ],
        declarations: [
            BridgeFormComponent
        ],
        exports: [
            BridgeFormComponent
        ]
    })
], BridgeFormModule);

/*{CA:PACKAGE_IMPORTS:START}*/
const moment$5 = moment_; // @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PACKAGE_IMPORTS:END}*/
class Situation {
    constructor() {
        this.deleted = false;
        /*{CA:CLASS_METHODS:START}*/
        /*{CA:CLASS_METHODS:END}*/
    }
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    static fromDto(situationDto, originEntity) {
        const model = Object.assign({}, situationDto);
        model.createdDate = model.createdDate && moment$5(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$5(model.lastModifiedDate).toDate();
        const lookupSeparator = " - ";
        const displayFields = ["code", "name"];
        model.label = displayFields.map(field => model[field]).join(lookupSeparator);
        return model;
    }
    static toDto(situation, originEntity) {
        const dto = Object.assign({}, situation);
        dto.createdDate = dto.createdDate && moment$5(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$5(dto.lastModifiedDate).format();
        delete dto.label;
        return dto;
    }
}
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
const moment$6 = moment_; // @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PROJECT_IMPORTS:END}*/
class Readiness {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    static fromDto(readinessDto, originEntity) {
        const model = Object.assign({}, readinessDto);
        model.createdDate = model.createdDate && moment$6(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$6(model.lastModifiedDate).toDate();
        model.startDate = model.startDateTime && moment$6(model.startDateTime).hour(0).minute(0).second(0).toDate();
        model.startTime = model.startDateTime && moment$6(model.startDateTime).toDate();
        model.endDate = model.endDateTime && moment$6(model.endDateTime).hour(0).minute(0).second(0).toDate();
        model.endTime = model.endDateTime && moment$6(model.endDateTime).toDate();
        const lookupSeparator = " - ";
        const displayFields = [
            "id",
            "employee.code",
            "employee.person.nomPes",
            "startDate",
            "startTime",
            "endDate",
            "endTime",
            "situation.code",
            "situation.name",
            "situation.situationType",
            "observation",
            "continuous",
            "createdBy",
            "createdDate",
            "lastModifiedBy",
            "lastModifiedDate",
        ];
        model.label = displayFields.map(field => model[field]).join(lookupSeparator);
        if (originEntity !== "Employee" && model.employee)
            model.employee = Employee.fromDto(model.employee, "Readiness");
        if (originEntity !== "Situation" && model.situation)
            model.situation = Situation.fromDto(model.situation, "Readiness");
        return model;
    }
    static toDto(readiness, originEntity) {
        const dto = Object.assign({}, readiness);
        dto.startDateTime = mergeDateTime(dto.startDate, dto.startTime);
        if (dto.endDate) {
            dto.endDateTime = mergeDateTime(dto.endDate, dto.endTime);
        }
        dto.createdDate = dto.createdDate && moment$6(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$6(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "Employee" && dto.employee)
            dto.employee = Employee.toDto(dto.employee, "Readiness");
        if (originEntity !== "Situation" && dto.situation)
            dto.situation = Situation.toDto(dto.situation, "Readiness");
        return dto;
    }
}
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let ReadinessService = class ReadinessService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/readiness`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
};
ReadinessService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
ReadinessService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [HttpClient, MessageService, TranslateService])
], ReadinessService);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let SituationService = class SituationService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_foundation/general/entities/situation`, `hcm_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
    listExternalSituation(listParams) {
        return this.http
            .get("hcm_foundation/general/entities/situation", {
            params: this.getListQueryParams(listParams),
        })
            .pipe(this.defaultCatch());
    }
};
SituationService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
SituationService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [HttpClient, MessageService, TranslateService])
], SituationService);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PACKAGE_IMPORTS:START}*/
const moment$7 = moment_; // @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let ReadinessFormComponent = class ReadinessFormComponent {
    constructor(
    /*{CA:INJECTIONS:START}*/
    /*{CA:INJECTIONS:END}*/
    readinessService, router, route, messageService, confirmationService, formBuilder, translate, hotkeysService, fieldCustomization, focusService, employeeService, situationService) {
        /*{CA:CONSTRUCTOR_END:START}*/
        this.readinessService = readinessService;
        this.router = router;
        this.route = route;
        this.messageService = messageService;
        this.confirmationService = confirmationService;
        this.formBuilder = formBuilder;
        this.translate = translate;
        this.hotkeysService = hotkeysService;
        this.fieldCustomization = fieldCustomization;
        this.focusService = focusService;
        this.employeeService = employeeService;
        this.situationService = situationService;
        this.localeConfig = {};
        this.currencyLocaleOptions = {};
        this.permissions = {};
        this.allPermissions = {};
        this.mainPanelCollapsed = false;
        this.contractTypeOptions = [
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_employee"), value: "EMPLOYEE" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_director"), value: "DIRECTOR" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_trainee"), value: "TRAINEE" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_aprentice"), value: "APRENTICE" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_third_party"), value: "THIRD_PARTY" },
        ];
        this.employeeLookupDisplayFields = ["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractType"];
        this.employeeAdvancedDisplayFields = ["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractType"];
        this.employeeLookupSeparator = " - ";
        this.situationLookupDisplayFields = ["code", "name"];
        this.situationAdvancedDisplayFields = ["code", "name", "situationType"];
        this.situationLookupSeparator = " - ";
        this.onClose = new Subject();
        this.onLoadFormSubject = new Subject();
        this.onCloseObservable = this.onClose.asObservable();
        this.onLoadForm = this.onLoadFormSubject.asObservable();
        this.dateAndTimeConfigs = [];
        this.ngUnsubscribe = new Subject();
        /*{CA:CONSTRUCTOR_END:END}*/
    }
    ngOnInit() {
        /*{CA:ON_INIT_START:START}*/
        this.route.params.pipe(takeUntil(this.ngUnsubscribe)).subscribe((params) => this.onRouteParamsChange(params));
        /*{CA:ON_INIT_START:END}*/
        this.formGroup = this.getFormGroup();
        if (this.lockedEmployee) {
            this.loadLockedEmployee(this.lockedEmployee);
            this.onSubmitObservable.pipe(takeUntil(this.ngUnsubscribe), filter(name => name === "readiness" || name === "readinessDelete")).subscribe((value) => {
                switch (value) {
                    case "readiness":
                        this.onSave();
                        break;
                    case "readinessDelete":
                        this.onDelete();
                        break;
                    default:
                        break;
                }
            });
            this.onLockedEmployeeChanges
                .pipe(takeUntil(this.ngUnsubscribe))
                .subscribe((value) => {
                this.readiness = value.schedule;
                this.loadLockedEmployee(value);
            });
        }
        else {
            this.setHotkeys();
        }
        this.route.data.pipe(takeUntil(this.ngUnsubscribe)).subscribe((data) => this.onRouteDataChange(data));
        this.employeeSearchFields = this.getEmployeeSearchFields();
        this.employeeSearchGridFields = this.getEmployeeSearchGridFields();
        this.situationSearchFields = this.getSituationSearchFields();
        this.situationSearchGridFields = this.getSituationSearchGridFields();
        this.setHotkeys();
        /*{CA:ON_INIT_END:START}*/
        /*{CA:ON_INIT_END:END}*/
    }
    ngAfterViewInit() {
        /*{CA:ON_VIEW_INIT_START:START}*/
        /*{CA:ON_VIEW_INIT_START:END}*/
        /*{CA:ON_VIEW_INIT_END:START}*/
        /*{CA:ON_VIEW_INIT_END:END}*/
    }
    ngOnDestroy() {
        /*{CA:ON_DESTROY_START:START}*/
        /*{CA:ON_DESTROY_START:END}*/
        this.ngUnsubscribe.next();
        this.ngUnsubscribe.complete();
        /*{CA:ON_DESTROY_END:START}*/
        /*{CA:ON_DESTROY_END:END}*/
    }
    patchValuesAndUpdateSuggestions(value, result) {
        this.updateSuggestions(this.readiness);
        this.formGroup.patchValue(this.readiness);
        this.formGroup.controls["employee"].disable();
        if (value.schedule) {
            this.formGroup.controls["startDate"].disable();
            this.formGroup.controls["startTime"].disable();
            this.formGroup.value.startDate = result.startDateTime && moment$7(result.startDateTime)
                .hour(0).minute(0).second(0).toDate();
            this.formGroup.value.startTime = result.startDateTime && moment$7(result.startDateTime).toDate();
            this.formGroup.value.id = result.id;
            const canEdit = this.permissions.editar;
            if (!canEdit) {
                this.formGroup.disable();
            }
        }
        this.loading = false;
    }
    loadLockedEmployee(value) {
        const employee = this.formGroup.controls['employee'].value;
        this.formGroup.reset();
        this.formGroup.controls['continuous'].setValue(false);
        this.formGroup.controls['employee'].setValue(employee);
        if (this.formGroup.controls['employee'].value) {
            this.readiness.startDateTime = moment$7(value.evaluationDate).toDate();
            this.onLoadFormSubject.next(false);
        }
        else {
            this.loading = true;
            this.employeeService.listExternalEmployee({
                filterQuery: `id eq '${value.employeeId}'`,
                displayFields: this.employeeLookupDisplayFields
            }).subscribe((dto) => {
                if (!value.schedule) {
                    this.readiness = new Readiness();
                    this.readiness.startDate = moment$7(value.evaluationDate).hour(0)
                        .minute(0).second(0).toDate();
                    this.readiness.startTime = moment$7(value.evaluationDate).toDate();
                    this.readiness.employee = Employee.fromDto(dto.contents[0], "Readiness");
                    this.patchValuesAndUpdateSuggestions(value, null);
                }
                else {
                    this.readinessService.get(value.schedule).subscribe((result) => {
                        this.readiness = Readiness.fromDto(result);
                        this.patchValuesAndUpdateSuggestions(value, result);
                    });
                }
                this.onLoadFormSubject.next(false);
            });
        }
    }
    setHotkeys() {
        /*{CA:SET_HOTKEYS_START:START}*/
        /*{CA:SET_HOTKEYS_START:END}*/
        this.hotkeysService.add(new Hotkey("alt+shift+x", () => {
            if (this.permissions.excluir) {
                this.onDelete();
            }
            return false;
        }, ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+s", () => {
            if (this.isNew() || this.permissions.editar)
                this.onSave();
            return false;
        }, ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+c", () => {
            this.onCancel();
            return false;
        }, ["INPUT", "SELECT", "TEXTAREA"]));
        /*{CA:SET_HOTKEYS_END:START}*/
        /*{CA:SET_HOTKEYS_END:END}*/
    }
    isNew() {
        return this.routeParams.readiness === "new";
    }
    onRouteParamsChange(params) {
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:END}*/
        this.routeParams = params;
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:END}*/
    }
    updateSuggestions(value) {
        /*{CA:ON_UPDATE_SUGGESTIONS_START:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_START:END}*/
        if (value.employee) {
            value.employee.employmentRelationship.contractTypeLabel =
                this.loadLabelFromEnum(value.employee.employmentRelationship.contractType);
            value.employee.label = this.getSuggestionValue([
                "employer.codEmp",
                "code",
                "person.nomPes",
                "employmentRelationship.contractTypeLabel"
            ], "employee", value, this.employeeLookupSeparator);
            if (value.employee.label.toString().trim() === this.employeeLookupSeparator.trim()) {
                delete value.employee.label;
            }
        }
        if (value.situation) {
            value.situation.label = this.getSuggestionValue(["code", "name"], "situation", value, this.situationLookupSeparator);
            if (value.situation.label.trim() === this.situationLookupSeparator.trim()) {
                delete value.situation.label;
            }
        }
        /*{CA:ON_UPDATE_SUGGESTIONS_END:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_END:END}*/
    }
    getSuggestionValue(displayFields, ownerEntity, value, separator) {
        return displayFields
            .map(field => this.getProp(value, `${ownerEntity}.${field}`))
            .reduce((acc, val) => `${acc}${separator}${val}`);
    }
    onRouteDataChange(data) {
        /*{CA:ON_ROUTE_DATA_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_START:END}*/
        const { currencySymbol, thousandsSeparator, decimalSeparator } = data.localeConfig.number;
        this.localeConfig = data.localeConfig;
        this.currencyLocaleOptions = {
            align: "left",
            prefix: currencySymbol,
            thousands: thousandsSeparator,
            decimal: decimalSeparator,
        };
        this.permissions = data.allPermissions.readiness;
        this.allPermissions = data.allPermissions;
        this.validateVisualization();
        if (this.lockedEmployee) {
            return;
        }
        else if (data.entity) {
            const canEdit = this.permissions.editar;
            if (!canEdit) {
                this.formGroup.disable();
            }
            const value = Readiness.fromDto(data.entity);
            this.updateSuggestions(value);
            this.formGroup.patchValue(value);
        }
        else {
            this.formGroup.patchValue(new Readiness());
        }
        /*{CA:ON_ROUTE_DATA_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_END:END}*/
    }
    onCancel() {
        /*{CA:ON_CANCEL_START:START}*/
        /*{CA:ON_CANCEL_START:END}*/
        this.goBack();
        /*{CA:ON_CANCEL_END:START}*/
        /*{CA:ON_CANCEL_END:END}*/
    }
    onSendFile(filesToDelete, filesToCommit) {
        /*{CA:ON_SEND_FILE:START}*/
        /*{CA:ON_SEND_FILE:END}*/
        const observables = [];
        if (!this.fieldCustomization.isEmpty(filesToDelete)) {
            observables.push(this.fieldCustomization.deleteFiles(filesToDelete));
        }
        if (!this.fieldCustomization.isEmpty(filesToCommit)) {
            observables.push(this.fieldCustomization.commitFiles(filesToCommit));
        }
        if (!this.fieldCustomization.isEmpty(observables)) {
            return forkJoin(observables);
        }
        else {
            return of({});
        }
    }
    onSave() {
        /*{CA:ON_SAVE_START:START}*/
        this.onLoadFormSubject.next(true);
        /*{CA:ON_SAVE_START:END}*/
        this.loading = true;
        if (!this.formGroup.valid) {
            this.loading = false;
            this.onLoadFormSubject.next(false);
            return this.validateAllFormFields(this.formGroup);
        }
        const { filesToDelete, filesToCommit } = this.fieldCustomization.getFiles(this.formGroup);
        this.getSaveObservable()
            .pipe(takeUntil(this.ngUnsubscribe), catchError((err) => {
            this.loading = false;
            this.onLoadFormSubject.next(false);
            return throwError(err);
        }))
            .subscribe(() => {
            /*{CA:ON_SAVE_START_TOP:START}*/
            /*{CA:ON_SAVE_START_TOP:END}*/
            this.onSendFile(filesToDelete, filesToCommit)
                .pipe(takeUntil(this.ngUnsubscribe), catchError((err) => {
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                this.loading = false;
                this.onLoadFormSubject.next(false);
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                return throwError(err);
            }))
                .subscribe(() => {
                this.addMessage("success", "hcm_clocking_event_foundation.general.saved_message_title", "hcm_clocking_event_foundation.general.saved_message_content");
                this.finishOperation();
                /*{CA:ON_SAVE_START_BOTTOM:START}*/
                /*{CA:ON_SAVE_START_BOTTOM:END}*/
            });
        });
        /*{CA:ON_SAVE_END:START}*/
        /*{CA:ON_SAVE_END:END}*/
    }
    onDelete() {
        /*{CA:ON_DELETE_START:START}*/
        /*{CA:ON_DELETE_START:END}*/
        this.confirmationService.confirm({
            message: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_message"),
            header: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_title"),
            accept: () => {
                this.loading = true;
                this.onLoadFormSubject.next(true);
                this.getDeleteObservable()
                    .pipe(takeUntil(this.ngUnsubscribe))
                    .subscribe(() => this.finishOperation());
            },
            reject: () => this.loading = false
        });
        /*{CA:ON_DELETE_END:START}*/
        /*{CA:ON_DELETE_END:END}*/
    }
    finishOperation() {
        if (this.lockedEmployee) {
            this.onClose.next();
            this.loading = false;
        }
        else {
            this.goBack();
        }
    }
    getProp(obj, path) {
        return path.split(".").reduce((result, prop) => (result[prop] === undefined ? "" : result[prop]), obj);
    }
    loadLabelFromEnum(value) {
        return this.contractTypeOptions.filter(r => r.value === value)[0].label;
    }
    loadEnumFromLabel(value) {
        value = value.toUpperCase().trim();
        if (value && value !== undefined) {
            return this.contractTypeOptions.filter(r => {
                const match = r.label.toUpperCase().match(value);
                return match !== null && match.length !== 0;
            })
                .map(r => r.value);
        }
        return [];
    }
    onEmployeeLookupRequest(value) {
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:END}*/
        const sort = this.employeeLookupDisplayFields.map((field) => ({ field, order: 1 }));
        const filterQuery = this.getEmployeeSearchFields()
            .filter(({ type }) => isValidFilter(type, value))
            .map(({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$7(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$7(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$7(value).format()}'`;
            else if (type == FieldType.Enum)
                return this.loadEnumFromLabel(value).map(enumConstant => `${name} eq '${enumConstant}'`).join(' or ');
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        })
            .filter(filter => filter !== '')
            .join(" or ");
        const displayFields = mergeUnique(this.employeeLookupDisplayFields, this.employeeAdvancedDisplayFields).concat("hireDate", "dismissalDate");
        this.employeeService
            .listExternalEmployee({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.employeeLookupDisplayFields
                    .map(field => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field);
                    if (field === 'employmentRelationship.contractType') {
                        item[field] = this.loadLabelFromEnum(item[field]);
                    }
                    return item[field];
                })
                    .join(this.employeeLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.employeeLookupSuggestions = list.contents;
        });
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:END}*/
    }
    onEmployeeSearchRequest(event) {
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        const page = first / rows;
        const sort = multiSortMeta;
        const filterQuery = this.getEmployeeSearchFields()
            .filter(({ name }) => filterData[name] != undefined && filterData[name] != "")
            .map(({ name, type }) => {
            const value = filterData[name];
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$7(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$7(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$7(value).format()}'`;
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`;
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        })
            .join(" and ");
        const displayFields = mergeUnique(this.employeeLookupDisplayFields, this.employeeAdvancedDisplayFields).concat("hireDate", "dismissalDate");
        this.employeeService
            .listExternalEmployee({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.employeeLookupDisplayFields
                    .map(field => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field);
                    if (field === 'employmentRelationship.contractType') {
                        item[field] = this.loadLabelFromEnum(item[field]);
                    }
                    return item[field];
                })
                    .join(this.employeeLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.employeeSearchGridData = list.contents;
            this.employeeSearchTotalRecords = list.totalElements;
        });
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:END}*/
    }
    onSituationLookupRequest(value) {
        /*{CA:ON_SITUATION_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_SITUATION_LOOKUP_REQUEST_START:END}*/
        var filterQuery = this.getSituationSearchFields()
            .filter(({ type }) => isValidFilter(type, value))
            .map(({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$7(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$7(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$7(value).format()}'`;
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        })
            .join(" or ");
        if (filterQuery != "") {
            filterQuery = "( " + filterQuery + " ) and ";
        }
        filterQuery = filterQuery.concat("situationType eq 'PRECAUTIONREADINESS'");
        const displayFields = mergeUnique(this.situationLookupDisplayFields, this.situationAdvancedDisplayFields);
        this.situationService
            .listExternalSituation({ filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.situationLookupDisplayFields
                    .map(field => {
                    if (field.indexOf(".") > 0)
                        return this.getProp(item, field);
                    return item[field];
                })
                    .join(this.situationLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.situationLookupSuggestions = list.contents;
        });
        /*{CA:ON_SITUATION_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_SITUATION_LOOKUP_REQUEST_END:END}*/
    }
    onSituationSearchRequest(event) {
        /*{CA:ON_SITUATION_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_SITUATION_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        const page = first / rows;
        const sort = multiSortMeta;
        var filterQuery = this.getSituationSearchFields()
            .filter(({ name }) => filterData[name] != undefined && filterData[name] != "")
            .map(({ name, type }) => {
            const value = filterData[name];
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$7(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$7(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$7(value).format()}'`;
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`;
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        })
            .join(" and ");
        if (filterQuery != "") {
            filterQuery = "( " + filterQuery + " ) and ";
        }
        filterQuery = filterQuery.concat("situationType eq 'PRECAUTIONREADINESS'");
        const displayFields = mergeUnique(this.situationLookupDisplayFields, this.situationAdvancedDisplayFields);
        this.situationService
            .listExternalSituation({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.situationLookupDisplayFields
                    .map(field => {
                    if (field.indexOf(".") > 0)
                        return this.getProp(item, field);
                    return item[field];
                })
                    .join(this.situationLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.situationSearchGridData = list.contents;
            this.situationSearchTotalRecords = list.totalElements;
        });
        /*{CA:ON_SITUATION_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_SITUATION_SEARCH_REQUEST_END:END}*/
    }
    getFormGroup() {
        const formGroup = this.formBuilder.group({
            id: [{ value: undefined, disabled: true }, Validators.compose([])],
            employee: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            startDate: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            startTime: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            endDate: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            endTime: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            startDateTime: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            endDateTime: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            situation: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            observation: [{ value: undefined, disabled: false }, Validators.compose([Validators.maxLength(255)])],
            continuous: [{ value: false, disabled: false }, Validators.compose([])],
            createdBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            createdDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            custom: [],
        }, {
            validators: [
                this.startTimeIsBeforeEndTime(),
                this.startDateIsBeforeOrEqualToEndDate()
            ]
        });
        this.disableFieldsOnEdit(formGroup);
        return formGroup;
    }
    getEmployeeSearchFields() {
        const searchFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions
            })
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    getEmployeeSearchGridFields() {
        const searchGridFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions
            }),
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    getSituationSearchFields() {
        const searchFields = [
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.situation_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "name",
                label: this.translate.instant("hcm_clocking_event_foundation.general.situation_name"),
                type: FieldType.String,
            }),
        ];
        /*{CA:GET_SITUATION_SEARCH_FIELDS:START}*/
        /*{CA:GET_SITUATION_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    getSituationSearchGridFields() {
        const searchGridFields = [
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.situation_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "name",
                label: this.translate.instant("hcm_clocking_event_foundation.general.situation_name"),
                type: FieldType.String,
            }),
            new FormField({
                name: "situationType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.situation_situation_type"),
                type: FieldType.Enum,
                placeholder: this.translate.instant("hcm_clocking_event_foundation.general.situation_situation_type_placeholder"),
                options: [
                    { label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_working"), value: "WORKING" },
                    { label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_vacation"), value: "VACATION" },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_illnessaid"),
                        value: "ILLNESSAID",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_laboraccident"),
                        value: "LABORACCIDENT",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_militaryservice"),
                        value: "MILITARYSERVICE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_maternityleave"),
                        value: "MATERNITYLEAVE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_maternityleavenoncriminalabortion"),
                        value: "MATERNITYLEAVENONCRIMINALABORTION",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_maternityleaveanticipationextension"),
                        value: "MATERNITYLEAVEANTICIPATIONEXTENSION",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_citizencompanymaternity"),
                        value: "CITIZENCOMPANYMATERNITY",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_inssmaternityleave"),
                        value: "INSSMATERNITYLEAVE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_leavewithoutcompensation"),
                        value: "LEAVEWITHOUTCOMPENSATION",
                    },
                    { label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_paidleave"), value: "PAIDLEAVE" },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_paternityleave"),
                        value: "PATERNITYLEAVE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_citizencompanypaternity"),
                        value: "CITIZENCOMPANYPATERNITY",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_collectivevacation"),
                        value: "COLLECTIVEVACATION",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_medicalleave"),
                        value: "MEDICALLEAVE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_medicalleavewithoutinss"),
                        value: "MEDICALLEAVEWITHOUTINSS",
                    },
                    { label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_absences"), value: "ABSENCES" },
                    { label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_overtime"), value: "OVERTIME" },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_timeevaluationsituation"),
                        value: "TIMEEVALUATIONSITUATION",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_precautionreadiness"),
                        value: "PRECAUTIONREADINESS",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_tradeunionmandate"),
                        value: "TRADEUNIONMANDATE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_workaccidentleave"),
                        value: "WORKACCIDENTLEAVE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_workaccidentleavewithoutinss"),
                        value: "WORKACCIDENTLEAVEWITHOUTINSS",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_retirementduetodisability"),
                        value: "RETIREMENTDUETODISABILITY",
                    },
                    { label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_others"), value: "OTHERS" },
                ],
            }),
        ];
        /*{CA:GET_SITUATION_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_SITUATION_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    goBack() {
        const previousRoute = "../";
        this.router.navigate([previousRoute], { relativeTo: this.route.parent });
    }
    validateAllFormFields(formGroup) {
        Object.keys(formGroup.controls).forEach(field => {
            const control = formGroup.get(field);
            if (control instanceof FormControl)
                control.markAsDirty({ onlySelf: true });
            else if (control instanceof FormGroup)
                this.validateAllFormFields(control);
        });
        this.focusService.focusFirstInvalidInput();
        /*{CA:FOCUS_FIRST_INVALID:START}*/
        /*{CA:FOCUS_FIRST_INVALID:END}*/
    }
    getSaveObservable() {
        const { value } = this.formGroup;
        value.employee = this.formGroup.controls["employee"].value;
        value.id = this.formGroup.controls["id"].value;
        value.startDate = this.formGroup.controls["startDate"].value;
        value.startTime = this.formGroup.controls["startTime"].value;
        const readinessDto = Readiness.toDto(value);
        let observable;
        if (this.isNew() || (this.lockedEmployee && !value.id)) {
            observable = this.readinessService.insert(readinessDto);
        }
        else {
            const id = this.lockedEmployee ? value.id : this.routeParams.readiness;
            observable = this.readinessService.update(id, readinessDto);
        }
        return observable;
    }
    getDeleteObservable() {
        let readinessId = this.routeParams.readiness;
        if (this.lockedEmployee && this.lockedEmployee.schedule) {
            readinessId = this.lockedEmployee.schedule;
        }
        return this.readinessService.delete(readinessId).pipe(tap(() => {
            this.addMessage("success", "hcm_clocking_event_foundation.general.deleted_message_title", "hcm_clocking_event_foundation.general.deleted_message_content");
        }));
    }
    validateVisualization() {
        /*{CA:VALIDATE_VISUALIZATION_START:START}*/
        /*{CA:VALIDATE_VISUALIZATION_START:END}*/
        const toValidate = ["employee", "situation"];
        if (!toValidate.every(e => this.allPermissions[e] && this.allPermissions[e].visualizar)) {
            this.router.navigate(["forbidden"]);
        }
        /*{CA:VALIDATE_VISUALIZATION_END:START}*/
        /*{CA:VALIDATE_VISUALIZATION_END:END}*/
    }
    /*{CA:CLASS_METHODS:START}*/
    startTimeIsBeforeEndTime() {
        return (control) => {
            return startTimeIsBeforeEndTimeValidator(control);
        };
    }
    startDateIsBeforeOrEqualToEndDate() {
        return (control) => {
            const startDate = control.get("startDate");
            const endDate = control.get("endDate");
            return startDateIsBeforeOrEqualToEndDateValidator(startDate, endDate);
        };
    }
    /*{CA:CLASS_METHODS:END}*/
    addMessage(severity, summary, detail) {
        if (this.lockedEmployee) {
            this.messageService.add({
                key: "employee-clocking-event-adjustment-list-view",
                severity,
                summary: this.translate.instant(summary),
                detail: this.translate.instant(detail),
            });
        }
        else {
            this.messageService.add({
                severity,
                summary: this.translate.instant(summary),
                detail: this.translate.instant(detail),
            });
        }
    }
    disableFieldsOnEdit(formGroup) {
        if (!this.isNew() && !this.lockedEmployee) {
            formGroup.controls.employee.disable();
        }
    }
};
ReadinessFormComponent.ctorParameters = () => [
    { type: ReadinessService },
    { type: Router },
    { type: ActivatedRoute },
    { type: MessageService },
    { type: ConfirmationService },
    { type: FormBuilder },
    { type: TranslateService },
    { type: HotkeysService },
    { type: FieldCustomizationService },
    { type: FocusService },
    { type: EmployeeService },
    { type: SituationService }
];
__decorate([
    ViewChild("customTemplate"),
    __metadata("design:type", TemplateRef)
], ReadinessFormComponent.prototype, "customTemplate", void 0);
__decorate([
    ViewChild("customFormFields"),
    __metadata("design:type", TemplateRef)
], ReadinessFormComponent.prototype, "customFormFields", void 0);
__decorate([
    Input(),
    __metadata("design:type", Observable)
], ReadinessFormComponent.prototype, "onSubmitObservable", void 0);
__decorate([
    Input(),
    __metadata("design:type", Observable)
], ReadinessFormComponent.prototype, "onLockedEmployeeChanges", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], ReadinessFormComponent.prototype, "lockedEmployee", void 0);
__decorate([
    Output(),
    __metadata("design:type", Observable)
], ReadinessFormComponent.prototype, "onCloseObservable", void 0);
__decorate([
    Output(),
    __metadata("design:type", Observable)
], ReadinessFormComponent.prototype, "onLoadForm", void 0);
ReadinessFormComponent = __decorate([
    Component({
        template: "<div *ngIf=\"!customTemplate else customTemplate\">\n    <p-confirmDialog acceptLabel=\"{{'hcm_clocking_event_foundation.general.yes' | translate}}\" acceptIcon=\"\" appendTo=\"body\"\n        rejectLabel=\"{{'hcm_clocking_event_foundation.general.no' | translate}}\" rejectIcon=\"\">\n    </p-confirmDialog>\n    <form [formGroup]=\"formGroup\" novalidate>\n        <p-panel *sLoadingState=\"loading\" [styleClass]=\"lockedEmployee ? 'form-group sidebar-panel' : 'form-group'\"\n            [toggleable]=\"false\" [collapsed]=\"mainPanelCollapsed\" [showHeader]=\"!lockedEmployee\">\n            <p-header>\n                {{\"hcm_clocking_event_foundation.general.readiness_form_general_title\" | translate}}\n            </p-header>\n            <div class=\"ui-fluid\" *ngIf=\"!customFormFields else customFormFields\">\n                <div class=\"ui-g\">\n                    <div [attr.data-hidden]=\"true\" class=\"ui-g-12 ui-md-6\">\n                        <label for=\"id\">{{\"hcm_clocking_event_foundation.general.readiness_id\" | translate}}</label>\n                        <input #idFormInput type=\"text\" id=\"id\" name=\"id\" pInputText formControlName=\"id\" autocomplete=\"off\"/>\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.employee.visualizar\" class=\"ui-g-12 ui-md-6 required\">\n                        <label for=\"employee\">{{\"hcm_clocking_event_foundation.general.readiness_employee\" | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"employee\" name=\"employee\" formControlName=\"employee\" [searchFields]=\"employeeSearchGridFields\"\n                            [searchGridFields]=\"employeeSearchGridFields\" [searchGridData]=\"employeeSearchGridData\"\n                            [multiple]=\"false\" [lookupSuggestions]=\"employeeLookupSuggestions\" (onLookupRequest)=\"onEmployeeLookupRequest($event)\"\n                            (onSearchRequest)=\"onEmployeeSearchRequest($event)\" lookupDisplayField=\"label\"\n                            [searchTotalRecords]=employeeSearchTotalRecords [searchTitle]=\"'hcm_clocking_event_foundation.general.readiness_employee_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\" [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: employeeSearchTotalRecords}\"></s-lookup>\n                        <s-control-errors [control]=\"formGroup.controls['employee']\"\n                            [errorMessages]=\"{\n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate\n                            }\"\n                        ></s-control-errors>\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.situation.visualizar\" class=\"ui-g-12 ui-md-6 required\">\n                        <label for=\"situation\">{{\"hcm_clocking_event_foundation.general.readiness_situation\" | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"situation\" name=\"situation\" formControlName=\"situation\" [searchFields]=\"situationSearchFields\"\n                            [searchGridFields]=\"situationSearchGridFields\" [searchGridData]=\"situationSearchGridData\"\n                            [multiple]=\"false\" [lookupSuggestions]=\"situationLookupSuggestions\" (onLookupRequest)=\"onSituationLookupRequest($event)\"\n                            (onSearchRequest)=\"onSituationSearchRequest($event)\" lookupDisplayField=\"label\"\n                            [searchTotalRecords]=situationSearchTotalRecords [searchTitle]=\"'hcm_clocking_event_foundation.general.readiness_situation_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\"\n                            [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: situationSearchTotalRecords}\"\n                            [emptyFieldLabel]=\"'hcm_clocking_event_foundation.general.list_grid_empty_field' | translate\"></s-lookup>\n                        <s-control-errors [control]=\"formGroup.controls['situation']\" [errorMessages]=\"{ required: 'hcm_clocking_event_foundation.general.error_required' | translate }\"></s-control-errors>\n                    </div>\n                    <div class=\"ui-g-6 ui-md-3 required\">\n                        <label for=\"startDate\">{{\"hcm_clocking_event_foundation.general.readiness_start_date\" | translate}}</label>\n                        <p-calendar inputId=\"startDate\" name=\"startDate\" [showIcon]=\"true\" formControlName=\"startDate\"\n                            [locale]=\"localeConfig.calendar\" [dateFormat]=\"localeConfig.calendar.dateFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['startDate']\"\n                            [errorMessages]=\"{\n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                                startDateIsBeforeEndDate: 'hcm_clocking_event_foundation.general.error_start_date_after_end_date_to_start_date' | translate\n                            }\"\n                        ></s-control-errors>\n                    </div>\n                    <div class=\"ui-g-6 ui-md-3 required\">\n                        <label for=\"startTime\">{{\"hcm_clocking_event_foundation.general.readiness_start_time\" | translate}}</label>\n                        <p-calendar icon=\"fa fa-clock-o\" inputId=\"startTime\" name=\"startTime\" [showIcon]=\"true\" formControlName=\"startTime\"\n                            [locale]=\"localeConfig.calendar\" [timeOnly]=\"true\" [hourFormat]=\"localeConfig.calendar.hourFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['startTime']\"\n                            [errorMessages]=\"{\n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                                startTimeIsBeforeEndTime: 'hcm_clocking_event_foundation.general.error_start_time_after_end_time_to_start_date' | translate\n                            }\"\n                        ></s-control-errors>\n                    </div>                    \n                    <div class=\"ui-g-6 ui-md-3 required\">\n                        <label for=\"endDate\">{{\"hcm_clocking_event_foundation.general.readiness_end_date\" | translate}}</label>\n                        <p-calendar inputId=\"endDate\" name=\"endDate\" [showIcon]=\"true\" formControlName=\"endDate\" [locale]=\"localeConfig.calendar\"\n                            [dateFormat]=\"localeConfig.calendar.dateFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['endDate']\"\n                            [errorMessages]=\"{\n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                                startDateIsBeforeEndDate: 'hcm_clocking_event_foundation.general.error_start_date_after_end_date_to_end_date' | translate\n                            }\"\n                        ></s-control-errors>\n                    </div>\n                    <div class=\"ui-g-6 ui-md-3 required\">\n                        <label for=\"endTime\">{{\"hcm_clocking_event_foundation.general.readiness_end_time\" | translate}}</label>\n                        <p-calendar icon=\"fa fa-clock-o\" inputId=\"endTime\" name=\"endTime\" [showIcon]=\"true\" formControlName=\"endTime\"\n                            [locale]=\"localeConfig.calendar\" [hourFormat]=\"localeConfig.calendar.hourFormat\" [timeOnly]=\"true\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['endTime']\"\n                            [errorMessages]=\"{\n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                                startTimeIsBeforeEndTime: 'hcm_clocking_event_foundation.general.error_start_time_after_end_time_to_end_date' | translate\n                            }\"\n                        ></s-control-errors>\n                    </div>                 \n                    <div class=\"ui-g-12 ui-md-12\">\n                        <label for=\"observation\">{{\"hcm_clocking_event_foundation.general.readiness_observation\" | translate}}</label>\n                        <textarea #observationFormInput type=\"text\" id=\"observation\" name=\"observation\" rows=\"5\" pInputTextarea formControlName=\"observation\"\n                            autocomplete=\"off\"></textarea>\n                        <s-control-errors [control]=\"formGroup.controls['observation']\" [errorMessages]=\"{ maxlength: 'hcm_clocking_event_foundation.general.error_max_length' | translate: {value: '255'} }\"></s-control-errors>\n                    </div>\n                    <div class=\"ui-g-12 ui-md-6\">\n                        <label for=\"continuous\">{{\"hcm_clocking_event_foundation.general.readiness_continuous\" | translate}}</label>\n                        <div class=\"ui-grid ui-grid-responsive ui-grid-pad ui-fluid\">\n                            <div class=\"ui-inputgroup\">\n                                <p-inputSwitch id=\"continuous\" formControlName=\"continuous\"></p-inputSwitch>\n                                <div style=\"padding-right: 0.75em;\"></div>\n                                <ng-container *ngIf=\"formGroup.get('continuous').value; else noContinuous\">\n                                    <span>{{ 'hcm_clocking_event_foundation.general.generic_yes' | translate }}</span>\n                                </ng-container>\n                                <ng-template #noContinuous>\n                                    <span>{{ 'hcm_clocking_event_foundation.general.generic_no' | translate }}</span>\n                                </ng-template>\n                            </div>\n                        </div>\n                    </div>\n                </div>\n            </div>\n            <s-custom-fields domain=\"hcm_clocking_event_foundation\" service=\"general\" entity=\"readiness\" formControlName=\"custom\"\n                [invalidErrorLabel]=\"'hcm_clocking_event_foundation.general.error_invalid' | translate\"></s-custom-fields>\n            <div class=\"ui-g\" *ngIf=\"!isNew() && !lockedEmployee\">\n                <div class=\"ui-g-12 ui-inputgroup\">\n                    <label *ngIf=\"formGroup.get('createdBy').value !== ''\" style=\"color: #a3a3a3; margin-right: 2px;\">{{'hcm_clocking_event_foundation.general.created_by' | translate}} {{formGroup.get('createdBy').value}} {{'hcm_clocking_event_foundation.general.at_date' | translate}} {{formGroup.get('createdDate').value | date: 'dd/MM/yyyy'}} {{'hcm_clocking_event_foundation.general.at_time' | translate}} {{formGroup.get('createdDate').value | date: 'HH:mm'}}. </label>\n                    <label *ngIf=\"formGroup.get('lastModifiedBy').value !== ''\" style=\"color: #a3a3a3;\">{{'hcm_clocking_event_foundation.general.updated_by' | translate}} {{formGroup.get('lastModifiedBy').value}} {{'hcm_clocking_event_foundation.general.at_date' | translate}} {{formGroup.get('lastModifiedDate').value | date: 'dd/MM/yyyy'}} {{'hcm_clocking_event_foundation.general.at_time' | translate}} {{formGroup.get('lastModifiedDate').value | date: 'HH:mm'}}.</label>\n                </div>\n            </div>\n            <p-footer *ngIf=\"!lockedEmployee\">\n                <button id=\"save-button\" title=\"{{'hcm_clocking_event_foundation.general.save' | translate}} (Alt + Shift + S)\"\n                    type=\"submit\" pButton label=\"{{'hcm_clocking_event_foundation.general.save' | translate}}\"\n                    (click)=\"onSave()\" *ngIf=\"isNew() || permissions.editar\"></button>\n                <button id=\"delete-button\" title=\"{{'hcm_clocking_event_foundation.general.delete' | translate}} (Alt + Shift + X)\"\n                    type=\"button\" class=\"ui-button-secondary\" pButton label=\"{{'hcm_clocking_event_foundation.general.delete' | translate}}\"\n                    (click)=\"onDelete()\" *ngIf=\"!isNew() && permissions.excluir\" [disabled]=\"loading\"></button>\n                <button id=\"cancel-button\" title=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}} (Alt + Shift + C)\"\n                    type=\"button\" class=\"ui-button-link\" pButton label=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}}\"\n                    (click)=\"onCancel()\"></button>\n            </p-footer>\n        </p-panel>\n    </form>\n</div>\n<!--{CA:FILE_CONTENTS:START}-->\n<!--{CA:FILE_CONTENTS:END}-->\n",
        providers: [
            ConfirmationService,
        ],
        /*{CA:COMPONENT_CONFIG:START}*/
        selector: 'cem-readiness-form'
        /*{CA:COMPONENT_CONFIG:END}*/
        ,
        styles: [":host ::ng-deep .sidebar-panel{border:none!important;padding-left:0!important}#observation{max-width:100%!important}"]
    }),
    __metadata("design:paramtypes", [ReadinessService,
        Router,
        ActivatedRoute,
        MessageService,
        ConfirmationService,
        FormBuilder,
        TranslateService,
        HotkeysService,
        FieldCustomizationService,
        FocusService,
        EmployeeService,
        SituationService])
], ReadinessFormComponent);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

let ReadinessFormModule = class ReadinessFormModule {
};
ReadinessFormModule = __decorate([
    NgModule({
        imports: [
            LocaleModule.forChild(),
            SharedScheduleModule
        ],
        declarations: [
            ReadinessFormComponent
        ],
        exports: [
            ReadinessFormComponent
        ]
    })
], ReadinessFormModule);

/*{CA:PACKAGE_IMPORTS:START}*/
const moment$8 = moment_; // @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class Workschedule {
    constructor() {
        this.deleted = false;
        /*{CA:CLASS_METHODS:START}*/
        /*{CA:CLASS_METHODS:END}*/
    }
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    static fromDto(workscheduleDto, originEntity) {
        const model = Object.assign({}, workscheduleDto);
        model.createdDate = model.createdDate && moment$8(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$8(model.lastModifiedDate).toDate();
        const lookupSeparator = " - ";
        const displayFields = [
            "id",
            "code",
            "name",
            "deleted",
            "extIntSts",
            "extIntMsg",
            "createdBy",
            "createdDate",
            "lastModifiedBy",
            "lastModifiedDate",
        ];
        model.label = displayFields.map(field => model[field]).join(lookupSeparator);
        return model;
    }
    static toDto(workschedule, originEntity) {
        const dto = Object.assign({}, workschedule);
        dto.createdDate = dto.createdDate && moment$8(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$8(dto.lastModifiedDate).format();
        delete dto.label;
        return dto;
    }
}
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PACKAGE_IMPORTS:START}*/
const moment$9 = moment_; // @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class WorkScheduleChange {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    static fromDto(workScheduleChangeDto, originEntity) {
        const model = Object.assign({}, workScheduleChangeDto);
        model.date = model.date && moment$9(model.date).toDate();
        model.createdDate = model.createdDate && moment$9(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$9(model.lastModifiedDate).toDate();
        const lookupSeparator = " - ";
        const displayFields = [
            "id",
            "employee.code",
            "employee.person.nomPes",
            "date",
            "workSchedule.code",
            "workSchedule.name",
            "createdBy",
            "createdDate",
            "lastModifiedBy",
            "lastModifiedDate",
        ];
        model.label = displayFields.map(field => model[field]).join(lookupSeparator);
        if (originEntity !== "Employee" && model.employee) {
            model.employee = Employee.fromDto(model.employee, "WorkScheduleChange");
        }
        if (originEntity !== "Workschedule" && model.workSchedule) {
            model.workSchedule = Workschedule.fromDto(model.workSchedule, "WorkScheduleChange");
        }
        return model;
    }
    static toDto(workScheduleChange, originEntity) {
        const dto = Object.assign({}, workScheduleChange);
        dto.date = dto.date && moment$9(dto.date).format("YYYY-MM-DD");
        dto.createdDate = dto.createdDate && moment$9(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$9(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "Employee" && dto.employee) {
            dto.employee = Employee.toDto(dto.employee, "WorkScheduleChange");
        }
        if (originEntity !== "Workschedule" && dto.workSchedule) {
            dto.workSchedule = Workschedule.toDto(dto.workSchedule, "WorkScheduleChange");
        }
        return dto;
    }
}
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let WorkScheduleChangeService = class WorkScheduleChangeService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/workScheduleChange`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
};
WorkScheduleChangeService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
WorkScheduleChangeService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [HttpClient, MessageService, TranslateService])
], WorkScheduleChangeService);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let WorkscheduleService = class WorkscheduleService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_foundation/work_schedule/entities/workschedule`, `hcm_foundation/work_schedule/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
};
WorkscheduleService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
WorkscheduleService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [HttpClient, MessageService, TranslateService])
], WorkscheduleService);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
const moment$a = moment_; // @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PROJECT_IMPORTS:END}*/
let WorkScheduleChangeFormComponent = class WorkScheduleChangeFormComponent {
    constructor(
    /*{CA:INJECTIONS:START}*/
    /*{CA:INJECTIONS:END}*/
    workScheduleChangeService, router, route, messageService, confirmationService, formBuilder, translate, hotkeysService, fieldCustomization, focusService, employeeService, workscheduleService) {
        this.workScheduleChangeService = workScheduleChangeService;
        this.router = router;
        this.route = route;
        this.messageService = messageService;
        this.confirmationService = confirmationService;
        this.formBuilder = formBuilder;
        this.translate = translate;
        this.hotkeysService = hotkeysService;
        this.fieldCustomization = fieldCustomization;
        this.focusService = focusService;
        this.employeeService = employeeService;
        this.workscheduleService = workscheduleService;
        this.localeConfig = {};
        this.currencyLocaleOptions = {};
        this.permissions = {};
        this.allPermissions = {};
        this.loading = false;
        this.mainPanelCollapsed = false;
        this.contractTypeOptions = [
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_employee"), value: "EMPLOYEE" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_director"), value: "DIRECTOR" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_trainee"), value: "TRAINEE" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_aprentice"), value: "APRENTICE" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_third_party"), value: "THIRD_PARTY" },
        ];
        this.employeeLookupDisplayFields = ["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractType"];
        this.employeeAdvancedDisplayFields = ["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractType"];
        this.employeeLookupSeparator = " - ";
        this.workScheduleLookupDisplayFields = ["code", "name"];
        this.workScheduleAdvancedDisplayFields = ["code", "name"];
        this.workScheduleLookupSeparator = " - ";
        this.onClose = new Subject();
        this.onLoadFormSubject = new Subject();
        this.onCloseObservable = this.onClose.asObservable();
        this.onLoadForm = this.onLoadFormSubject.asObservable();
        this.ngUnsubscribe = new Subject();
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
    ngOnInit() {
        /*{CA:ON_INIT_START:START}*/
        this.route.params.pipe(takeUntil(this.ngUnsubscribe)).subscribe((params) => this.onRouteParamsChange(params));
        /*{CA:ON_INIT_START:END}*/
        this.formGroup = this.getFormGroup();
        if (this.lockedEmployee) {
            this.loadLockedEmployee(this.lockedEmployee);
            this.onSubmitObservable.pipe(takeUntil(this.ngUnsubscribe), filter(name => name === "workScheduleChange" || name === "workScheduleChangeDelete")).subscribe((value) => {
                switch (value) {
                    case "workScheduleChange":
                        this.onSave();
                        break;
                    case "workScheduleChangeDelete":
                        this.onDelete();
                        break;
                    default:
                        break;
                }
            });
            this.onLockedEmployeeChanges
                .pipe(takeUntil(this.ngUnsubscribe))
                .subscribe((value) => {
                this.workScheduleChange = value.schedule;
                this.loadLockedEmployee(value);
            });
        }
        else {
            this.setHotkeys();
        }
        this.route.data.pipe(takeUntil(this.ngUnsubscribe)).subscribe((data) => this.onRouteDataChange(data));
        this.employeeSearchFields = this.getEmployeeSearchFields();
        this.employeeSearchGridFields = this.getEmployeeSearchGridFields();
        this.workScheduleSearchFields = this.getWorkScheduleSearchFields();
        this.workScheduleSearchGridFields = this.getWorkScheduleSearchGridFields();
        /*{CA:ON_INIT_END:START}*/
        /*{CA:ON_INIT_END:END}*/
    }
    ngAfterViewInit() {
        /*{CA:ON_VIEW_INIT_START:START}*/
        /*{CA:ON_VIEW_INIT_START:END}*/
        /*{CA:ON_VIEW_INIT_END:START}*/
        /*{CA:ON_VIEW_INIT_END:END}*/
    }
    ngOnDestroy() {
        /*{CA:ON_DESTROY_START:START}*/
        /*{CA:ON_DESTROY_START:END}*/
        this.ngUnsubscribe.next();
        this.ngUnsubscribe.complete();
        /*{CA:ON_DESTROY_END:START}*/
        /*{CA:ON_DESTROY_END:END}*/
    }
    loadLockedEmployee(value) {
        const employee = this.formGroup.controls["employee"].value;
        this.formGroup.reset();
        this.formGroup.controls["employee"].setValue(employee);
        if (this.formGroup.controls["employee"].value) {
            this.formGroup.controls["date"].setValue(moment$a(value.evaluationDate).toDate());
            this.onLoadFormSubject.next(false);
        }
        else {
            this.loading = true;
            this.employeeService.listExternalEmployee({
                filterQuery: `id eq '${value.employeeId}'`,
                displayFields: this.employeeLookupDisplayFields
            }).subscribe((dto) => {
                if (!value.schedule) {
                    this.workScheduleChange = new WorkScheduleChange();
                    this.workScheduleChange.date = moment$a(value.evaluationDate).toDate();
                    this.workScheduleChange.employee = Employee.fromDto(dto.contents[0], "WorkScheduleChange");
                    this.patchValuesAndUpdateSuggestions(value, null);
                }
                else {
                    this.workScheduleChangeService.get(value.schedule).subscribe((result) => {
                        this.workScheduleChange = WorkScheduleChange.fromDto(result);
                        this.patchValuesAndUpdateSuggestions(value, result);
                    });
                }
                this.onLoadFormSubject.next(false);
            });
        }
    }
    patchValuesAndUpdateSuggestions(value, result) {
        this.updateSuggestions(this.workScheduleChange);
        this.formGroup.patchValue(this.workScheduleChange);
        this.formGroup.controls["employee"].disable();
        if (value.schedule) {
            this.formGroup.controls["date"].disable();
            this.formGroup.value.id = result.id;
            this.formGroup.value.date = result.date;
            const canEdit = this.permissions.editar;
            if (!canEdit) {
                this.formGroup.disable();
            }
        }
        this.loading = false;
    }
    setHotkeys() {
        /*{CA:SET_HOTKEYS_START:START}*/
        /*{CA:SET_HOTKEYS_START:END}*/
        this.hotkeysService.add(new Hotkey("alt+shift+x", () => {
            if (this.permissions.excluir) {
                this.onDelete();
            }
            return false;
        }, ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+s", () => {
            if (this.isNew() || this.permissions.editar)
                this.onSave();
            return false;
        }, ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+c", () => {
            this.onCancel();
            return false;
        }, ["INPUT", "SELECT", "TEXTAREA"]));
        /*{CA:SET_HOTKEYS_END:START}*/
        /*{CA:SET_HOTKEYS_END:END}*/
    }
    isNew() {
        return this.routeParams.workScheduleChange === "new";
    }
    onRouteParamsChange(params) {
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:END}*/
        this.routeParams = params;
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:END}*/
    }
    updateSuggestions(value) {
        /*{CA:ON_UPDATE_SUGGESTIONS_START:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_START:END}*/
        if (value.employee) {
            value.employee.employmentRelationship.contractTypeLabel =
                this.loadLabelFromEnum(value.employee.employmentRelationship.contractType);
            value.employee.label = this.getSuggestionValue(["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractTypeLabel"], "employee", value, this.employeeLookupSeparator);
            if (value.employee.label.toString().trim() === this.employeeLookupSeparator.trim()) {
                delete value.employee.label;
            }
        }
        if (value.workSchedule) {
            value.workSchedule.label = this.getSuggestionValue(["code", "name"], "workSchedule", value, this.workScheduleLookupSeparator);
            if (value.workSchedule.label.trim() === this.workScheduleLookupSeparator.trim()) {
                delete value.workSchedule.label;
            }
        }
        /*{CA:ON_UPDATE_SUGGESTIONS_END:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_END:END}*/
    }
    getSuggestionValue(displayFields, ownerEntity, value, separator) {
        return displayFields
            .map(field => this.getProp(value, `${ownerEntity}.${field}`))
            .reduce((acc, val) => `${acc}${separator}${val}`);
    }
    onRouteDataChange(data) {
        /*{CA:ON_ROUTE_DATA_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_START:END}*/
        const { currencySymbol, thousandsSeparator, decimalSeparator } = data.localeConfig.number;
        this.localeConfig = data.localeConfig;
        this.currencyLocaleOptions = {
            align: "left",
            prefix: currencySymbol,
            thousands: thousandsSeparator,
            decimal: decimalSeparator,
        };
        this.permissions = data.allPermissions.workScheduleChange;
        this.allPermissions = data.allPermissions;
        this.validateVisualization();
        if (this.lockedEmployee) {
            return;
        }
        else if (data.entity) {
            const canEdit = this.permissions.editar;
            if (!canEdit) {
                this.formGroup.disable();
            }
            const value = WorkScheduleChange.fromDto(data.entity);
            this.updateSuggestions(value);
            this.formGroup.patchValue(value);
        }
        else {
            this.formGroup.patchValue(new WorkScheduleChange());
        }
        /*{CA:ON_ROUTE_DATA_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_END:END}*/
    }
    onCancel() {
        /*{CA:ON_CANCEL_START:START}*/
        /*{CA:ON_CANCEL_START:END}*/
        this.goBack();
        /*{CA:ON_CANCEL_END:START}*/
        /*{CA:ON_CANCEL_END:END}*/
    }
    onSendFile(filesToDelete, filesToCommit) {
        /*{CA:ON_SEND_FILE:START}*/
        /*{CA:ON_SEND_FILE:END}*/
        const observables = [];
        if (!this.fieldCustomization.isEmpty(filesToDelete)) {
            observables.push(this.fieldCustomization.deleteFiles(filesToDelete));
        }
        if (!this.fieldCustomization.isEmpty(filesToCommit)) {
            observables.push(this.fieldCustomization.commitFiles(filesToCommit));
        }
        if (!this.fieldCustomization.isEmpty(observables)) {
            return forkJoin(observables);
        }
        else {
            return of({});
        }
    }
    onSave() {
        /*{CA:ON_SAVE_START:START}*/
        /*{CA:ON_SAVE_START:END}*/
        this.loading = true;
        this.onLoadFormSubject.next(true);
        if (!this.formGroup.valid) {
            this.loading = false;
            this.onLoadFormSubject.next(false);
            return this.validateAllFormFields(this.formGroup);
        }
        const { filesToDelete, filesToCommit } = this.fieldCustomization.getFiles(this.formGroup);
        this.getSaveObservable()
            .pipe(takeUntil(this.ngUnsubscribe), catchError((err) => {
            this.loading = false;
            this.onLoadFormSubject.next(false);
            return throwError(err);
        }))
            .subscribe(() => {
            /*{CA:ON_SAVE_START_TOP:START}*/
            /*{CA:ON_SAVE_START_TOP:END}*/
            this.onSendFile(filesToDelete, filesToCommit)
                .pipe(takeUntil(this.ngUnsubscribe), catchError((err) => {
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                this.loading = false;
                this.onLoadFormSubject.next(false);
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                return throwError(err);
            }))
                .subscribe(() => {
                this.addMessage("success", "hcm_clocking_event_foundation.general.saved_message_title", "hcm_clocking_event_foundation.general.saved_message_content");
                /*{CA:ON_SAVE_START_BOTTOM:START}*/
                this.finishOperation();
                /*{CA:ON_SAVE_START_BOTTOM:END}*/
            });
        });
        /*{CA:ON_SAVE_END:START}*/
        /*{CA:ON_SAVE_END:END}*/
    }
    onDelete() {
        /*{CA:ON_DELETE_START:START}*/
        /*{CA:ON_DELETE_START:END}*/
        this.confirmationService.confirm({
            message: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_message"),
            header: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_title"),
            accept: () => {
                this.loading = true;
                this.onLoadFormSubject.next(true);
                this.getDeleteObservable()
                    .pipe(takeUntil(this.ngUnsubscribe))
                    .subscribe(() => this.finishOperation());
            },
            reject: () => this.loading = false
        });
        /*{CA:ON_DELETE_END:START}*/
        /*{CA:ON_DELETE_END:END}*/
    }
    finishOperation() {
        if (this.lockedEmployee) {
            this.onClose.next();
            this.loading = false;
        }
        else {
            this.goBack();
        }
    }
    getProp(obj, path) {
        return path.split(".").reduce((result, prop) => (result[prop] === undefined ? "" : result[prop]), obj);
    }
    loadLabelFromEnum(value) {
        return this.contractTypeOptions.filter(r => r.value === value)[0].label;
    }
    loadEnumFromLabel(value) {
        value = value.toUpperCase().trim();
        if (value && value !== undefined) {
            return this.contractTypeOptions.filter(r => {
                const match = r.label.toUpperCase().match(value);
                return match !== null && match.length !== 0;
            })
                .map(r => r.value);
        }
        return [];
    }
    onEmployeeLookupRequest(value) {
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:END}*/
        const sort = this.employeeLookupDisplayFields.map((field) => ({ field, order: 1 }));
        const filterQuery = this.getEmployeeSearchFields()
            .filter(({ type }) => isValidFilter(type, value))
            .map(({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$a(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$a(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$a(value).format()}'`;
            else if (type == FieldType.Enum)
                return this.loadEnumFromLabel(value).map(enumConstant => `${name} eq '${enumConstant}'`).join(' or ');
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        })
            .filter(filter => filter !== '')
            .join(" or ");
        const displayFields = this.employeeLookupDisplayFields;
        this.employeeService
            .listExternalEmployee({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.employeeLookupDisplayFields
                    .map(field => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field);
                    if (field === 'employmentRelationship.contractType') {
                        item[field] = this.loadLabelFromEnum(item[field]);
                    }
                    return item[field];
                })
                    .join(this.employeeLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.employeeLookupSuggestions = list.contents;
        });
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:END}*/
    }
    onEmployeeSearchRequest(event) {
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        const page = first / rows;
        const sort = multiSortMeta;
        const filterQuery = this.getEmployeeSearchFields()
            .filter(({ name }) => filterData[name] != undefined && filterData[name] != "")
            .map(({ name, type }) => {
            const value = filterData[name];
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$a(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$a(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$a(value).format()}'`;
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`;
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        })
            .join(" and ");
        const displayFields = this.employeeLookupDisplayFields;
        this.employeeService
            .listExternalEmployee({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.employeeLookupDisplayFields
                    .map(field => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field);
                    if (field === 'employmentRelationship.contractType') {
                        item[field] = this.loadLabelFromEnum(item[field]);
                    }
                    return item[field];
                })
                    .join(this.employeeLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.employeeSearchGridData = list.contents;
            this.employeeSearchTotalRecords = list.totalElements;
        });
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:END}*/
    }
    onWorkScheduleLookupRequest(value) {
        /*{CA:ON_WORK_SCHEDULE_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_WORK_SCHEDULE_LOOKUP_REQUEST_START:END}*/
        const sort = this.workScheduleLookupDisplayFields.map((field) => ({ field, order: 1 }));
        let filterQuery = this.getWorkScheduleSearchFields()
            .filter(({ type }) => isValidFilter(type, value))
            .map(({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$a(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$a(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$a(value).format()}'`;
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        })
            .join(" or ");
        const date = moment$a(this.formGroup.value.date).format("YYYY-MM-DD");
        const filters = [`(initialValidity <= '${date}' and finalValidity >= '${date}' or initialValidity is null and finalValidity > '${date}' or initialValidity < '${date}' and finalValidity is null or initialValidity is null and finalValidity is null)`];
        if (filterQuery !== '')
            filters.push(filterQuery);
        filterQuery = filters.join(' and ');
        const displayFields = mergeUnique(["code", "name", "initialValidity", "finalValidity"], ["code", "name", "initialValidity", "finalValidity"]);
        this.workscheduleService
            .list({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.workScheduleLookupDisplayFields
                    .map(field => {
                    if (field.indexOf(".") > 0)
                        return this.getProp(item, field);
                    return item[field];
                })
                    .join(this.workScheduleLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.workScheduleLookupSuggestions = list.contents;
        });
        /*{CA:ON_WORK_SCHEDULE_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_WORK_SCHEDULE_LOOKUP_REQUEST_END:END}*/
    }
    onWorkScheduleSearchRequest(event) {
        /*{CA:ON_WORK_SCHEDULE_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_WORK_SCHEDULE_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        const page = first / rows;
        const sort = multiSortMeta;
        let filterQuery = this.getWorkScheduleSearchFields()
            .filter(({ name }) => filterData[name] != undefined && filterData[name] != "")
            .map(({ name, type }) => {
            const value = filterData[name];
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$a(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$a(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$a(value).format()}'`;
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`;
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        })
            .join(" and ");
        const date = moment$a(this.formGroup.value.date).format("YYYY-MM-DD");
        const filters = [`(initialValidity <= '${date}' and finalValidity >= '${date}' or initialValidity is null and finalValidity >= '${date}' or initialValidity <= '${date}' and finalValidity is null or initialValidity is null and finalValidity is null)`];
        if (filterQuery !== '')
            filters.push(filterQuery);
        filterQuery = filters.join(' and ');
        const displayFields = mergeUnique(["code", "name", "initialValidity", "finalValidity"], ["code", "name", "initialValidity", "finalValidity"]);
        this.workscheduleService
            .list({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.workScheduleLookupDisplayFields
                    .map(field => {
                    if (field.indexOf(".") > 0) {
                        return this.getProp(item, field);
                    }
                    return item[field];
                })
                    .join(this.workScheduleLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.workScheduleSearchGridData = list.contents;
            this.workScheduleSearchTotalRecords = list.totalElements;
        });
        /*{CA:ON_WORK_SCHEDULE_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_WORK_SCHEDULE_SEARCH_REQUEST_END:END}*/
    }
    getFormGroup() {
        const formGroup = this.formBuilder.group({
            id: [{ value: undefined, disabled: true }, Validators.compose([])],
            employee: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            date: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            workSchedule: [{ value: undefined, disabled: true }, Validators.compose([Validators.required])],
            createdBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            createdDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            custom: [],
        });
        formGroup.controls['date'].valueChanges.subscribe(date => {
            this.verifyWorkscheduleLookupDisabled(date);
        });
        this.disableFieldsOnEdit(formGroup);
        return formGroup;
    }
    getEmployeeSearchFields() {
        const searchFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions
            })
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    getEmployeeSearchGridFields() {
        const searchGridFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions
            }),
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    getWorkScheduleSearchFields() {
        const searchFields = [
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workschedule_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "name",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workschedule_name"),
                type: FieldType.String,
            }),
        ];
        /*{CA:GET_WORK_SCHEDULE_SEARCH_FIELDS:START}*/
        /*{CA:GET_WORK_SCHEDULE_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    getWorkScheduleSearchGridFields() {
        const searchGridFields = [
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workschedule_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "name",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workschedule_name"),
                type: FieldType.String,
            }),
        ];
        /*{CA:GET_WORK_SCHEDULE_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_WORK_SCHEDULE_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    goBack() {
        const previousRoute = "../";
        this.router.navigate([previousRoute], { relativeTo: this.route.parent });
    }
    validateAllFormFields(formGroup) {
        Object.keys(formGroup.controls).forEach(field => {
            const control = formGroup.get(field);
            if (control instanceof FormControl) {
                control.markAsDirty({ onlySelf: true });
            }
            else if (control instanceof FormGroup) {
                this.validateAllFormFields(control);
            }
        });
        this.focusService.focusFirstInvalidInput();
        /*{CA:FOCUS_FIRST_INVALID:START}*/
        /*{CA:FOCUS_FIRST_INVALID:END}*/
    }
    getSaveObservable() {
        const { value } = this.formGroup;
        value.employee = this.formGroup.controls["employee"].value;
        value.id = this.formGroup.controls["id"].value;
        value.date = this.formGroup.controls["date"].value;
        const workScheduleChangeDto = WorkScheduleChange.toDto(value);
        let observable;
        if (this.isNew() || (this.lockedEmployee && !value.id)) {
            observable = this.workScheduleChangeService.insert(workScheduleChangeDto);
        }
        else {
            const id = this.lockedEmployee ? value.id : this.routeParams.workScheduleChange;
            observable = this.workScheduleChangeService.update(id, workScheduleChangeDto);
        }
        return observable;
    }
    getDeleteObservable() {
        let workscheduleChangeId = this.routeParams.workScheduleChange;
        if (this.lockedEmployee && this.lockedEmployee.schedule) {
            workscheduleChangeId = this.lockedEmployee.schedule;
        }
        return this.workScheduleChangeService.delete(workscheduleChangeId).pipe(tap(() => {
            this.addMessage("success", "hcm_clocking_event_foundation.general.deleted_message_title", "hcm_clocking_event_foundation.general.deleted_message_content");
        }));
    }
    verifyWorkscheduleLookupDisabled(date = this.formGroup.controls.date.value) {
        if (date != null) {
            this.formGroup.controls.workSchedule.enable();
        }
        else {
            this.formGroup.controls.workSchedule.disable();
            this.formGroup.controls.workSchedule.setValue(null);
        }
    }
    validateVisualization() {
        /*{CA:VALIDATE_VISUALIZATION_START:START}*/
        /*{CA:VALIDATE_VISUALIZATION_START:END}*/
        const toValidate = ["employee", "workschedule"];
        if (!toValidate.every(e => this.allPermissions[e] && this.allPermissions[e].visualizar)) {
            this.router.navigate(["forbidden"]);
        }
        /*{CA:VALIDATE_VISUALIZATION_END:START}*/
        /*{CA:VALIDATE_VISUALIZATION_END:END}*/
    }
    /*{CA:CLASS_METHODS:START}*/
    /*{CA:CLASS_METHODS:END}*/
    addMessage(severity, summary, detail) {
        if (this.lockedEmployee) {
            this.messageService.add({
                key: "employee-clocking-event-adjustment-list-view",
                severity,
                summary: this.translate.instant(summary),
                detail: this.translate.instant(detail),
            });
        }
        else {
            this.messageService.add({
                severity,
                summary: this.translate.instant(summary),
                detail: this.translate.instant(detail),
            });
        }
    }
    disableFieldsOnEdit(formGroup) {
        if (!this.isNew() && !this.lockedEmployee) {
            formGroup.controls.employee.disable();
        }
    }
};
WorkScheduleChangeFormComponent.ctorParameters = () => [
    { type: WorkScheduleChangeService },
    { type: Router },
    { type: ActivatedRoute },
    { type: MessageService },
    { type: ConfirmationService },
    { type: FormBuilder },
    { type: TranslateService },
    { type: HotkeysService },
    { type: FieldCustomizationService },
    { type: FocusService },
    { type: EmployeeService },
    { type: WorkscheduleService }
];
__decorate([
    ViewChild("customTemplate"),
    __metadata("design:type", TemplateRef)
], WorkScheduleChangeFormComponent.prototype, "customTemplate", void 0);
__decorate([
    ViewChild("customFormFields"),
    __metadata("design:type", TemplateRef)
], WorkScheduleChangeFormComponent.prototype, "customFormFields", void 0);
__decorate([
    Input(),
    __metadata("design:type", Observable)
], WorkScheduleChangeFormComponent.prototype, "onSubmitObservable", void 0);
__decorate([
    Input(),
    __metadata("design:type", Observable)
], WorkScheduleChangeFormComponent.prototype, "onLockedEmployeeChanges", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], WorkScheduleChangeFormComponent.prototype, "lockedEmployee", void 0);
__decorate([
    Output(),
    __metadata("design:type", Observable)
], WorkScheduleChangeFormComponent.prototype, "onCloseObservable", void 0);
__decorate([
    Output(),
    __metadata("design:type", Observable)
], WorkScheduleChangeFormComponent.prototype, "onLoadForm", void 0);
WorkScheduleChangeFormComponent = __decorate([
    Component({
        template: "<div *ngIf=\"!customTemplate else customTemplate\">\n    <p-confirmDialog acceptLabel=\"{{'hcm_clocking_event_foundation.general.yes' | translate}}\" acceptIcon=\"\" appendTo=\"body\"\n        rejectLabel=\"{{'hcm_clocking_event_foundation.general.no' | translate}}\" rejectIcon=\"\">\n    </p-confirmDialog>\n    <form [formGroup]=\"formGroup\" novalidate>\n        <p-panel *sLoadingState=\"loading\" [styleClass]=\"lockedEmployee ? 'form-group sidebar-panel' : 'form-group'\"\n            [toggleable]=\"false\" [collapsed]=\"mainPanelCollapsed\" [showHeader]=\"!lockedEmployee\">\n            <p-header>\n                {{\"hcm_clocking_event_foundation.general.work_schedule_change_form_general_title\" | translate}}\n            </p-header>\n            <div class=\"ui-fluid\" *ngIf=\"!customFormFields else customFormFields\">\n                <div class=\"ui-g\">\n                    <div [attr.data-hidden]=\"true\" class=\"ui-g-12 ui-md-6\">\n                        <label for=\"id\">{{\"hcm_clocking_event_foundation.general.work_schedule_change_id\" | translate}}</label>\n                        <input #idFormInput type=\"text\" id=\"id\" name=\"id\" pInputText formControlName=\"id\" autocomplete=\"off\"\n                        />\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.employee.visualizar\" class=\"ui-g-12 ui-md-6 required\">\n                        <label for=\"employee\">{{\"hcm_clocking_event_foundation.general.work_schedule_change_employee\" | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"employee\" name=\"employee\" formControlName=\"employee\" [searchFields]=\"employeeSearchGridFields\"\n                            [searchGridFields]=\"employeeSearchGridFields\" [searchGridData]=\"employeeSearchGridData\"\n                            [multiple]=\"false\" [lookupSuggestions]=\"employeeLookupSuggestions\" (onLookupRequest)=\"onEmployeeLookupRequest($event)\"\n                            (onSearchRequest)=\"onEmployeeSearchRequest($event)\" lookupDisplayField=\"label\"\n                            [searchTotalRecords]=employeeSearchTotalRecords [searchTitle]=\"'hcm_clocking_event_foundation.general.work_schedule_change_employee_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\" [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: employeeSearchTotalRecords}\"></s-lookup>\n                        <s-control-errors [control]=\"formGroup.controls['employee']\" [errorMessages]=\"{ required: 'hcm_clocking_event_foundation.general.error_required' | translate }\"></s-control-errors>\n                    </div>\n                    <div class=\"ui-g-12 ui-md-6 required\">\n                        <label for=\"date\">{{\"hcm_clocking_event_foundation.general.work_schedule_change_date\" | translate}}</label>\n                        <p-calendar #dateFormInput inputId=\"date\" name=\"date\" [showIcon]=\"true\" formControlName=\"date\" [locale]=\"localeConfig.calendar\"\n                            [dateFormat]=\"localeConfig.calendar.dateFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['date']\" [errorMessages]=\"{ required: 'hcm_clocking_event_foundation.general.error_required' | translate}\"></s-control-errors>\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.workschedule.visualizar\" class=\"ui-g-12 ui-md-6 required\">\n                        <label for=\"workSchedule\">{{\"hcm_clocking_event_foundation.general.work_schedule_change_work_schedule\" | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"workSchedule\" name=\"workSchedule\" formControlName=\"workSchedule\" [searchFields]=\"workScheduleSearchFields\"\n                            [searchGridFields]=\"workScheduleSearchGridFields\" [searchGridData]=\"workScheduleSearchGridData\"\n                            [multiple]=\"false\" [lookupSuggestions]=\"workScheduleLookupSuggestions\" (onLookupRequest)=\"onWorkScheduleLookupRequest($event)\"\n                            (onSearchRequest)=\"onWorkScheduleSearchRequest($event)\" lookupDisplayField=\"label\"\n                            [searchTotalRecords]=workScheduleSearchTotalRecords [searchTitle]=\"'hcm_clocking_event_foundation.general.work_schedule_change_work_schedule_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\"\n                            [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: workScheduleSearchTotalRecords}\"\n                            [emptyFieldLabel]=\"'hcm_clocking_event_foundation.general.list_grid_empty_field' | translate\"></s-lookup>\n                        <s-control-errors [control]=\"formGroup.controls['workSchedule']\" [errorMessages]=\"{ required: 'hcm_clocking_event_foundation.general.error_required' | translate }\"></s-control-errors>\n                    </div>\n                </div>\n            </div>\n            <s-custom-fields domain=\"hcm_clocking_event_foundation\" service=\"general\" entity=\"workScheduleChange\" *ngIf=\"formGroup.controls['custom']\"\n                formControlName=\"custom\" [invalidErrorLabel]=\"'hcm_clocking_event_foundation.general.error_invalid' | translate\"></s-custom-fields>\n            <div class=\"ui-g\" *ngIf=\"!isNew() && !lockedEmployee\">\n                <div class=\"ui-g-12 ui-inputgroup\">\n                    <label *ngIf=\"formGroup.get('createdBy').value !== ''\" style=\"color: #a3a3a3; margin-right: 2px;\">{{'hcm_clocking_event_foundation.general.created_by' | translate}} {{formGroup.get('createdBy').value}} {{'hcm_clocking_event_foundation.general.at_date' | translate}} {{formGroup.get('createdDate').value | date: 'dd/MM/yyyy'}} {{'hcm_clocking_event_foundation.general.at_time' | translate}} {{formGroup.get('createdDate').value | date: 'HH:mm'}}. </label>\n                    <label *ngIf=\"formGroup.get('lastModifiedBy').value !== ''\" style=\"color: #a3a3a3;\">{{'hcm_clocking_event_foundation.general.updated_by' | translate}} {{formGroup.get('lastModifiedBy').value}} {{'hcm_clocking_event_foundation.general.at_date' | translate}} {{formGroup.get('lastModifiedDate').value | date: 'dd/MM/yyyy'}} {{'hcm_clocking_event_foundation.general.at_time' | translate}} {{formGroup.get('lastModifiedDate').value | date: 'HH:mm'}}.</label>\n                </div>\n            </div>\n            <p-footer *ngIf=\"!lockedEmployee\">\n                <button id=\"save-button\" title=\"{{'hcm_clocking_event_foundation.general.save' | translate}} (Alt + Shift + S)\"\n                    type=\"submit\" pButton label=\"{{'hcm_clocking_event_foundation.general.save' | translate}}\"\n                    (click)=\"onSave()\" *ngIf=\"isNew() || permissions.editar\"></button>\n                <button id=\"delete-button\" title=\"{{'hcm_clocking_event_foundation.general.delete' | translate}} (Alt + Shift + X)\"\n                    type=\"button\" class=\"ui-button-secondary\" pButton label=\"{{'hcm_clocking_event_foundation.general.delete' | translate}}\"\n                    (click)=\"onDelete()\" *ngIf=\"!isNew() && permissions.excluir\" [disabled]=\"loading\"></button>\n                <button id=\"cancel-button\" title=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}} (Alt + Shift + C)\"\n                    type=\"button\" class=\"ui-button-link\" pButton label=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}}\"\n                    (click)=\"onCancel()\"></button>\n            </p-footer>\n        </p-panel>\n    </form>\n</div>\n<!--{CA:FILE_CONTENTS:START}-->\n<!--{CA:FILE_CONTENTS:END}-->\n",
        providers: [
            ConfirmationService,
        ],
        /*{CA:COMPONENT_CONFIG:START}*/
        selector: 'cem-work-schedule-change-form'
        /*{CA:COMPONENT_CONFIG:END}*/
        ,
        styles: [":host ::ng-deep .sidebar-panel{border:none!important;padding-left:0!important}"]
    }),
    __metadata("design:paramtypes", [WorkScheduleChangeService,
        Router,
        ActivatedRoute,
        MessageService,
        ConfirmationService,
        FormBuilder,
        TranslateService,
        HotkeysService,
        FieldCustomizationService,
        FocusService,
        EmployeeService,
        WorkscheduleService])
], WorkScheduleChangeFormComponent);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

let WorkScheduleChangeFormModule = class WorkScheduleChangeFormModule {
};
WorkScheduleChangeFormModule = __decorate([
    NgModule({
        imports: [
            LocaleModule.forChild(),
            SharedScheduleModule
        ],
        declarations: [
            WorkScheduleChangeFormComponent
        ],
        exports: [
            WorkScheduleChangeFormComponent
        ]
    })
], WorkScheduleChangeFormModule);

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
const moment$b = moment_; // @HACK Necessary because of https://github.com/rollup/rollup/issues/670
class OvertimeAuthorization {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    static fromDto(overtimeAuthorizationDto, originEntity) {
        const model = Object.assign({}, overtimeAuthorizationDto);
        model.startDate = model.startDateTime && moment$b(model.startDateTime).hour(0).minute(0).second(0).toDate();
        model.startTime = model.startDateTime && moment$b(model.startDateTime).toDate();
        model.endDate = model.endDateTime && moment$b(model.endDateTime).hour(0).minute(0).second(0).toDate();
        model.endTime = model.endDateTime && moment$b(model.endDateTime).toDate();
        model.createdDate = model.createdDate && moment$b(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$b(model.lastModifiedDate).toDate();
        const lookupSeparator = " - ";
        const displayFields = [
            "id",
            "employee.code",
            "employee.person.nomPes",
            "startDate",
            "startTime",
            "endDate",
            "endTime",
            "authorizer.code",
            "authorizer.person.nomPes",
            "observation",
            "createdBy",
            "createdDate",
            "lastModifiedBy",
            "lastModifiedDate",
        ];
        model.label = displayFields.map(field => model[field]).join(lookupSeparator);
        if (originEntity !== "Employee" && model.employee)
            model.employee = Employee.fromDto(model.employee, "OvertimeAuthorization");
        if (originEntity !== "Employee" && model.authorizer)
            model.authorizer = Employee.fromDto(model.authorizer, "OvertimeAuthorization");
        return model;
    }
    static toDto(overtimeAuthorization, originEntity) {
        const dto = Object.assign({}, overtimeAuthorization);
        const startDate = dto.startDate && moment$b(dto.startDate);
        const startTime = dto.startTime && moment$b(dto.startTime);
        const endDate = dto.endDate && moment$b(dto.endDate);
        const endTime = dto.endTime && moment$b(dto.endTime);
        dto.startDateTime = startDate && startTime && moment$b(startDate)
            .hour(startTime.hour())
            .minute(startTime.minute()).format();
        dto.endDateTime = endDate && endTime && moment$b(endDate)
            .hour(endTime.hour())
            .minute(endTime.minute()).format();
        dto.createdDate = dto.createdDate && moment$b(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$b(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "Employee" && dto.employee)
            dto.employee = Employee.toDto(dto.employee, "OvertimeAuthorization");
        if (originEntity !== "Employee" && dto.authorizer)
            dto.authorizer = Employee.toDto(dto.authorizer, "OvertimeAuthorization");
        return dto;
    }
}
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let OvertimeAuthorizationService = class OvertimeAuthorizationService extends EntityService {
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/overtimeAuthorization`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
};
OvertimeAuthorizationService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
OvertimeAuthorizationService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [HttpClient, MessageService, TranslateService])
], OvertimeAuthorizationService);

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
const moment$c = moment_; // @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PROJECT_IMPORTS:END}*/
let OvertimeAuthorizationFormComponent = class OvertimeAuthorizationFormComponent {
    constructor(
    /*{CA:INJECTIONS:START}*/
    /*{CA:INJECTIONS:END}*/
    overtimeAuthorizationService, router, route, messageService, confirmationService, formBuilder, translate, hotkeysService, fieldCustomization, focusService, renderer, employeeService) {
        this.overtimeAuthorizationService = overtimeAuthorizationService;
        this.router = router;
        this.route = route;
        this.messageService = messageService;
        this.confirmationService = confirmationService;
        this.formBuilder = formBuilder;
        this.translate = translate;
        this.hotkeysService = hotkeysService;
        this.fieldCustomization = fieldCustomization;
        this.focusService = focusService;
        this.renderer = renderer;
        this.employeeService = employeeService;
        this.localeConfig = {};
        this.currencyLocaleOptions = {};
        this.permissions = {};
        this.allPermissions = {};
        this.mainPanelCollapsed = false;
        this.contractTypeOptions = [
            {
                label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_employee"),
                value: "EMPLOYEE",
            },
            {
                label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_director"),
                value: "DIRECTOR",
            },
            {
                label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_trainee"),
                value: "TRAINEE",
            },
            {
                label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_aprentice"),
                value: "APRENTICE",
            },
            {
                label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_third_party"),
                value: "THIRD_PARTY",
            },
        ];
        this.employeeLookupDisplayFields = [
            "employer.codEmp",
            "code",
            "person.nomPes",
            "employmentRelationship.contractType"
        ];
        this.employeeAdvancedDisplayFields = [
            "employer.codEmp",
            "code",
            "person.nomPes",
            "employmentRelationship.contractType"
        ];
        this.employeeLookupSeparator = " - ";
        this.authorizerLookupDisplayFields = [
            "employer.codEmp",
            "code",
            "person.nomPes",
            "employmentRelationship.contractType",
        ];
        this.authorizerAdvancedDisplayFields = [
            "employer.codEmp",
            "code",
            "person.nomPes",
            "employmentRelationship.contractType"
        ];
        this.authorizerLookupSeparator = " - ";
        this.onClose = new Subject();
        this.onLoadFormSubject = new Subject();
        this.onCloseObservable = this.onClose.asObservable();
        this.onLoadForm = this.onLoadFormSubject.asObservable();
        this.dateAndTimeConfigs = [];
        this.ngUnsubscribe = new Subject();
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
    ngOnInit() {
        /*{CA:ON_INIT_START:START}*/
        this.route.params.pipe(takeUntil(this.ngUnsubscribe)).subscribe((params) => this.onRouteParamsChange(params));
        /*{CA:ON_INIT_START:END}*/
        this.formGroup = this.getFormGroup();
        if (this.lockedEmployee) {
            this.loadLockedEmployee(this.lockedEmployee);
            this.onSubmitObservable.pipe(takeUntil(this.ngUnsubscribe), filter(name => name === 'overtimeAuthorization' || name === 'overtimeAuthorizationDelete')).subscribe((value) => {
                switch (value) {
                    case 'overtimeAuthorization':
                        this.onSave();
                        break;
                    case 'overtimeAuthorizationDelete':
                        this.onDelete();
                        break;
                    default:
                        break;
                }
            });
            this.onLockedEmployeeChanges
                .pipe(takeUntil(this.ngUnsubscribe))
                .subscribe((value) => {
                this.loadLockedEmployee(value);
            });
        }
        else {
            this.setHotkeys();
        }
        this.route.data.pipe(takeUntil(this.ngUnsubscribe)).subscribe((data) => this.onRouteDataChange(data));
        this.employeeSearchFields = this.getEmployeeSearchFields();
        this.employeeSearchGridFields = this.getEmployeeSearchGridFields();
        this.authorizerSearchFields = this.getAuthorizerSearchFields();
        this.authorizerSearchGridFields = this.getAuthorizerSearchGridFields();
        /*{CA:ON_INIT_END:START}*/
        /*{CA:ON_INIT_END:END}*/
    }
    ngAfterViewInit() {
        /*{CA:ON_VIEW_INIT_START:START}*/
        /*{CA:ON_VIEW_INIT_START:END}*/
        /*{CA:ON_VIEW_INIT_END:START}*/
        /*{CA:ON_VIEW_INIT_END:END}*/
    }
    ngOnDestroy() {
        /*{CA:ON_DESTROY_START:START}*/
        /*{CA:ON_DESTROY_START:END}*/
        this.ngUnsubscribe.next();
        this.ngUnsubscribe.complete();
        /*{CA:ON_DESTROY_END:START}*/
        /*{CA:ON_DESTROY_END:END}*/
    }
    setHotkeys() {
        /*{CA:SET_HOTKEYS_START:START}*/
        /*{CA:SET_HOTKEYS_START:END}*/
        this.hotkeysService.add(new Hotkey("alt+shift+x", () => {
            if (this.permissions.excluir)
                this.onDelete();
            return false;
        }, ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+s", () => {
            if (this.isNew() || this.permissions.editar)
                this.onSave();
            return false;
        }, ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+c", () => {
            this.onCancel();
            return false;
        }, ["INPUT", "SELECT", "TEXTAREA"]));
        /*{CA:SET_HOTKEYS_END:START}*/
        /*{CA:SET_HOTKEYS_END:END}*/
    }
    isNew() {
        return this.routeParams.overtimeAuthorization === "new";
    }
    onRouteParamsChange(params) {
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:END}*/
        this.routeParams = params;
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:END}*/
    }
    updateSuggestions(value) {
        /*{CA:ON_UPDATE_SUGGESTIONS_START:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_START:END}*/
        if (value.employee) {
            value.employee.employmentRelationship.contractTypeLabel = this.loadLabelFromEnum(value.employee.employmentRelationship.contractType);
            value.employee.label = this.getSuggestionValue([
                "employer.codEmp",
                "code",
                "person.nomPes",
                "employmentRelationship.contractTypeLabel",
            ], "employee", value, this.employeeLookupSeparator);
            if (value.employee.label.trim() === this.employeeLookupSeparator.trim()) {
                delete value.employee.label;
            }
        }
        if (value.authorizer) {
            value.authorizer.label = this.getSuggestionValue(["code", "person.nomPes"], "authorizer", value, this.authorizerLookupSeparator);
            if (value.authorizer.label.trim() === this.authorizerLookupSeparator.trim()) {
                delete value.authorizer.label;
            }
        }
        /*{CA:ON_UPDATE_SUGGESTIONS_END:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_END:END}*/
    }
    getSuggestionValue(displayFields, ownerEntity, value, separator) {
        return displayFields
            .map((field) => this.getProp(value, `${ownerEntity}.${field}`))
            .reduce((acc, val) => `${acc}${separator}${val}`);
    }
    onRouteDataChange(data) {
        /*{CA:ON_ROUTE_DATA_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_START:END}*/
        const { currencySymbol, thousandsSeparator, decimalSeparator } = data.localeConfig.number;
        this.localeConfig = data.localeConfig;
        this.currencyLocaleOptions = {
            align: "left",
            prefix: currencySymbol,
            thousands: thousandsSeparator,
            decimal: decimalSeparator,
        };
        this.permissions = data.allPermissions.overtimeAuthorization;
        this.allPermissions = data.allPermissions;
        this.validateVisualization();
        if (data.entity) {
            const canEdit = this.permissions.editar;
            if (!canEdit) {
                this.formGroup.disable();
            }
            const value = OvertimeAuthorization.fromDto(data.entity);
            this.updateSuggestions(value);
            this.formGroup.patchValue(value);
        }
        else {
            this.formGroup.patchValue(new OvertimeAuthorization());
        }
        /*{CA:ON_ROUTE_DATA_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_END:END}*/
    }
    onCancel() {
        /*{CA:ON_CANCEL_START:START}*/
        /*{CA:ON_CANCEL_START:END}*/
        this.goBack();
        /*{CA:ON_CANCEL_END:START}*/
        /*{CA:ON_CANCEL_END:END}*/
    }
    onSendFile(filesToDelete, filesToCommit) {
        /*{CA:ON_SEND_FILE:START}*/
        /*{CA:ON_SEND_FILE:END}*/
        const observables = [];
        if (!this.fieldCustomization.isEmpty(filesToDelete)) {
            observables.push(this.fieldCustomization.deleteFiles(filesToDelete));
        }
        if (!this.fieldCustomization.isEmpty(filesToCommit)) {
            observables.push(this.fieldCustomization.commitFiles(filesToCommit));
        }
        if (!this.fieldCustomization.isEmpty(observables)) {
            return forkJoin(observables);
        }
        else {
            return of({});
        }
    }
    onSave() {
        /*{CA:ON_SAVE_START:START}*/
        /*{CA:ON_SAVE_START:END}*/
        this.loading = true;
        this.onLoadFormSubject.next(true);
        if (!this.formGroup.valid) {
            this.loading = false;
            this.onLoadFormSubject.next(false);
            return this.validateAllFormFields(this.formGroup);
        }
        const { filesToDelete, filesToCommit } = this.fieldCustomization.getFiles(this.formGroup);
        this.getSaveObservable()
            .pipe(takeUntil(this.ngUnsubscribe), catchError((err) => {
            this.loading = false;
            this.onLoadFormSubject.next(false);
            return throwError(err);
        }))
            .subscribe(() => {
            /*{CA:ON_SAVE_START_TOP:START}*/
            /*{CA:ON_SAVE_START_TOP:END}*/
            this.onSendFile(filesToDelete, filesToCommit)
                .pipe(takeUntil(this.ngUnsubscribe), catchError((err) => {
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                this.loading = false;
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                return throwError(err);
            }))
                .subscribe(() => {
                this.addMessage("success", "hcm_clocking_event_foundation.general.saved_message_title", "hcm_clocking_event_foundation.general.saved_message_content");
                if (this.lockedEmployee) {
                    this.onClose.next(true);
                    this.loading = false;
                }
                else {
                    this.goBack();
                }
                /*{CA:ON_SAVE_START_BOTTOM:START}*/
                /*{CA:ON_SAVE_START_BOTTOM:END}*/
            });
        });
        /*{CA:ON_SAVE_END:START}*/
        /*{CA:ON_SAVE_END:END}*/
    }
    onDelete() {
        /*{CA:ON_DELETE_START:START}*/
        /*{CA:ON_DELETE_START:END}*/
        this.confirmationService.confirm({
            message: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_message"),
            header: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_title"),
            accept: () => {
                this.loading = true;
                this.onLoadFormSubject.next(true);
                this.getDeleteObservable()
                    .pipe(takeUntil(this.ngUnsubscribe))
                    .subscribe(() => this.finishOperation());
            },
            reject: () => this.loading = false
        });
        /*{CA:ON_DELETE_END:START}*/
        /*{CA:ON_DELETE_END:END}*/
    }
    finishOperation() {
        if (this.lockedEmployee) {
            this.onClose.next();
            this.loading = false;
        }
        else {
            this.goBack();
        }
    }
    getProp(obj, path) {
        return path
            .split(".")
            .reduce((result, prop) => (result[prop] === undefined ? "" : result[prop]), obj);
    }
    loadLabelFromEnum(value) {
        return this.contractTypeOptions.filter((r) => r.value === value)[0].label;
    }
    loadEnumFromLabel(value) {
        value = value.toUpperCase().trim();
        if (value && value !== undefined) {
            return this.contractTypeOptions
                .filter((r) => {
                const match = r.label.toUpperCase().match(value);
                return match !== null && match.length !== 0;
            })
                .map((r) => r.value);
        }
        return [];
    }
    onEmployeeLookupRequest(value) {
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:END}*/
        const sort = this.employeeLookupDisplayFields.map((field) => ({ field, order: 1 }));
        const filterQuery = this.getEmployeeSearchFields()
            .filter(({ type }) => isValidFilter(type, value))
            .map(({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$c(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$c(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$c(value).format()}'`;
            else if (type == FieldType.Enum)
                return this.loadEnumFromLabel(value)
                    .map((enumConstant) => `${name} eq '${enumConstant}'`)
                    .join(" or ");
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        })
            .filter((filter) => filter !== "")
            .join(" or ");
        const displayFields = mergeUnique(this.employeeLookupDisplayFields, this.employeeAdvancedDisplayFields).concat("hireDate", "dismissalDate");
        this.employeeService
            .listExternalEmployee({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.employeeLookupDisplayFields
                    .map((field) => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field); // NOSONAR
                    if (field === "employmentRelationship.contractType") { // NOSONAR
                        item[field] = this.loadLabelFromEnum(item[field]); // NOSONAR
                    } // NOSONAR
                    return item[field]; // NOSONAR
                }) // NOSONAR
                    .join(this.employeeLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.employeeLookupSuggestions = list.contents;
        });
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:END}*/
    }
    onEmployeeSearchRequest(event) {
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        const page = first / rows;
        const sort = multiSortMeta;
        const filterQuery = this.getEmployeeSearchFields()
            .filter(({ name }) => filterData[name] != undefined && filterData[name] != "")
            .map(({ name, type }) => {
            const value = filterData[name];
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$c(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$c(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$c(value).format()}'`;
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`;
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        })
            .join(" and ");
        const displayFields = mergeUnique(this.employeeLookupDisplayFields, this.employeeAdvancedDisplayFields).concat("hireDate", "dismissalDate");
        this.employeeService
            .listExternalEmployee({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.employeeLookupDisplayFields
                    .map((field) => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field); // NOSONAR
                    if (field === "employmentRelationship.contractType") { // NOSONAR
                        item[field] = this.loadLabelFromEnum(item[field]); // NOSONAR
                    } // NOSONAR
                    return item[field]; // NOSONAR
                }) // NOSONAR
                    .join(this.employeeLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.employeeSearchGridData = list.contents;
            this.employeeSearchTotalRecords = list.totalElements;
        });
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:END}*/
    }
    onAuthorizerLookupRequest(value) {
        /*{CA:ON_AUTHORIZER_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_AUTHORIZER_LOOKUP_REQUEST_START:END}*/
        const sort = this.authorizerLookupDisplayFields.map((field) => ({ field, order: 1 }));
        const filterQuery = this.getAuthorizerSearchFields()
            .filter(({ type }) => isValidFilter(type, value))
            .map(({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`; // NOSONAR
            else if (type == FieldType.Date) // NOSONAR
                return `${name} eq '${moment$c(value).format("YYYY-MM-DD")}'`; // NOSONAR
            else if (type == FieldType.Time) // NOSONAR
                return `${name} eq '${moment$c(value).format("HH:mm:ss")}'`; // NOSONAR
            else if (type == FieldType.DateTime) // NOSONAR
                return `${name} eq '${moment$c(value).format()}'`; // NOSONAR
            else if (type == FieldType.Enum) // NOSONAR
                return this.loadEnumFromLabel(value) // NOSONAR
                    .map((enumConstant) => `${name} eq '${enumConstant}'`) // NOSONAR
                    .join(" or "); // NOSONAR
            else if (type == FieldType.String) // NOSONAR
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`; // NOSONAR
            else
                return `${name} eq '${value}'`; // NOSONAR
        })
            .filter((filter) => filter !== "")
            .join(" or ");
        const displayFields = mergeUnique(this.authorizerLookupDisplayFields, this.authorizerAdvancedDisplayFields).concat("hireDate", "dismissalDate");
        this.employeeService
            .listExternalEmployee({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.authorizerLookupDisplayFields
                    .map((field) => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field); // NOSONAR
                    if (field === "employmentRelationship.contractType") { // NOSONAR
                        item[field] = this.loadLabelFromEnum(item[field]); // NOSONAR
                    } // NOSONAR
                    return item[field]; // NOSONAR
                }) // NOSONAR
                    .join(this.authorizerLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.authorizerLookupSuggestions = list.contents;
        });
        /*{CA:ON_AUTHORIZER_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_AUTHORIZER_LOOKUP_REQUEST_END:END}*/
    }
    onAuthorizerSearchRequest(event) {
        /*{CA:ON_AUTHORIZER_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_AUTHORIZER_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        const page = first / rows;
        const sort = multiSortMeta;
        const filterQuery = this.getAuthorizerSearchFields()
            .filter(({ name }) => filterData[name] != undefined && filterData[name] != "")
            .map(({ name, type }) => {
            const value = filterData[name]; // NOSONAR
            if (typeof value == "number")
                return `${name} eq ${value}`; // NOSONAR
            else if (type == FieldType.Date) // NOSONAR
                return `${name} eq '${moment$c(value).format("YYYY-MM-DD")}'`; // NOSONAR
            else if (type == FieldType.Time) // NOSONAR
                return `${name} eq '${moment$c(value).format("HH:mm:ss")}'`; // NOSONAR
            else if (type == FieldType.DateTime) // NOSONAR
                return `${name} eq '${moment$c(value).format()}'`; // NOSONAR
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`; // NOSONAR
            else if (type == FieldType.String) // NOSONAR
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`; // NOSONAR
            else
                return `${name} eq '${value}'`; // NOSONAR
        }) // NOSONAR
            .join(" and "); // NOSONAR
        const displayFields = mergeUnique(this.authorizerLookupDisplayFields, this.authorizerAdvancedDisplayFields).concat("hireDate", "dismissalDate");
        this.employeeService
            .listExternalEmployee({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.authorizerLookupDisplayFields
                    .map((field) => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field); // NOSONAR
                    if (field === "employmentRelationship.contractType") { // NOSONAR
                        item[field] = this.loadLabelFromEnum(item[field]); // NOSONAR
                    } // NOSONAR
                    return item[field]; // NOSONAR
                }) // NOSONAR
                    .join(this.authorizerLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.authorizerSearchGridData = list.contents;
            this.authorizerSearchTotalRecords = list.totalElements;
        });
        /*{CA:ON_AUTHORIZER_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_AUTHORIZER_SEARCH_REQUEST_END:END}*/
    }
    getFormGroup() {
        const formGroup = this.formBuilder.group({
            id: [{ value: undefined, disabled: true }, Validators.compose([])],
            employee: [{ value: undefined, disabled: false }, Validators.compose([Validators.required]),],
            startDate: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            startTime: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            endDate: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            endTime: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            authorizer: [{ value: undefined, disabled: false }, Validators.compose([])],
            observation: [{ value: undefined, disabled: false }, Validators.compose([Validators.maxLength(255)]),],
            createdBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            createdDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            custom: [],
        }, {
            validators: [
                this.startTimeIsBeforeEndTime(),
                this.startDateIsBeforeOrEqualToEndDate()
            ],
        });
        /*{CA:GET_FORM_CONTROLS:START}*/
        this.disableFieldsOnEdit(formGroup);
        /*{CA:GET_FORM_CONTROLS:END}*/
        return formGroup;
    }
    getEmployeeSearchFields() {
        const searchFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions,
            }),
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    getEmployeeSearchGridFields() {
        const searchGridFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions
            }),
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    getAuthorizerSearchFields() {
        const searchFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant(// NOSONAR
                "hcm_clocking_event_foundation.general.employee_employer_cod_emp" // NOSONAR
                ),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant(// NOSONAR
                "hcm_clocking_event_foundation.general.employee_code" // NOSONAR
                ),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant(// NOSONAR
                "hcm_clocking_event_foundation.general.employee_person_nom_pes" // NOSONAR
                ),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant(// NOSONAR
                "hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type" // NOSONAR
                ),
                type: FieldType.Enum,
                options: this.contractTypeOptions,
            }),
        ]; // NOSONAR
        /*{CA:GET_AUTHORIZER_SEARCH_FIELDS:START}*/
        /*{CA:GET_AUTHORIZER_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    getAuthorizerSearchGridFields() {
        const searchGridFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions // NOSONAR
            }),
        ]; // NOSONAR
        /*{CA:GET_AUTHORIZER_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_AUTHORIZER_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    goBack() {
        const previousRoute = "../";
        this.router.navigate([previousRoute], { relativeTo: this.route.parent });
    }
    validateAllFormFields(formGroup) {
        Object.keys(formGroup.controls).forEach((field) => {
            const control = formGroup.get(field);
            if (control instanceof FormControl)
                control.markAsDirty({ onlySelf: true });
            else if (control instanceof FormGroup)
                this.validateAllFormFields(control);
        });
        this.focusService.focusFirstInvalidInput();
        /*{CA:FOCUS_FIRST_INVALID:START}*/
        /*{CA:FOCUS_FIRST_INVALID:END}*/
    }
    getSaveObservable() {
        const { value } = this.formGroup;
        value.employee = this.formGroup.controls["employee"].value;
        value.id = this.formGroup.controls["id"].value;
        const overtimeAuthorizationDto = OvertimeAuthorization.toDto(value);
        let observable;
        if (this.isNew() || (this.lockedEmployee && !value.id)) {
            observable = this.overtimeAuthorizationService.insert(overtimeAuthorizationDto);
        }
        else {
            const id = this.lockedEmployee ? value.id : this.routeParams.overtimeAuthorization;
            observable = this.overtimeAuthorizationService.update(id, overtimeAuthorizationDto);
        }
        return observable;
    }
    getDeleteObservable() {
        let overtimeAuthorizationId = this.routeParams.overtimeAuthorization;
        if (this.lockedEmployee && this.lockedEmployee.schedule) {
            overtimeAuthorizationId = this.lockedEmployee.schedule;
        }
        return this.overtimeAuthorizationService
            .delete(overtimeAuthorizationId)
            .pipe(tap(() => {
            this.addMessage(// NOSONAR
            "success", // NOSONAR
            "hcm_clocking_event_foundation.general.deleted_message_title", // NOSONAR
            "hcm_clocking_event_foundation.general.deleted_message_content" // NOSONAR
            ); // NOSONAR
        }) // NOSONAR
        ); // NOSONAR
    }
    validateVisualization() {
        /*{CA:VALIDATE_VISUALIZATION_START:START}*/
        /*{CA:VALIDATE_VISUALIZATION_START:END}*/
        const toValidate = ["employee"];
        if (!toValidate.every((e) => this.allPermissions[e] && this.allPermissions[e].visualizar)) {
            this.router.navigate(["forbidden"]);
        }
        /*{CA:VALIDATE_VISUALIZATION_END:START}*/
        /*{CA:VALIDATE_VISUALIZATION_END:END}*/
    }
    /*{CA:CLASS_METHODS:START}*/
    startTimeIsBeforeEndTime() {
        return (control) => {
            return startTimeIsBeforeEndTimeValidator(control);
        };
    }
    startDateIsBeforeOrEqualToEndDate() {
        return (control) => {
            const startDate = control.get("startDate");
            const endDate = control.get("endDate");
            return startDateIsBeforeOrEqualToEndDateValidator(startDate, endDate);
        };
    }
    /*{CA:CLASS_METHODS:END}*/
    addMessage(severity, summary, detail) {
        if (this.lockedEmployee) {
            this.messageService.add({
                key: "employee-clocking-event-adjustment-list-view",
                severity,
                summary: this.translate.instant(summary),
                detail: this.translate.instant(detail),
            });
        }
        else {
            this.messageService.add({
                severity,
                summary: this.translate.instant(summary),
                detail: this.translate.instant(detail),
            });
        }
    }
    patchValuesAndUpdateSuggestions(value, result) {
        this.updateSuggestions(this.overtimeAuthorization);
        this.formGroup.patchValue(this.overtimeAuthorization);
        this.formGroup.controls["employee"].disable();
        if (value.schedule) {
            this.formGroup.controls["startDate"].disable();
            this.formGroup.controls["startTime"].disable();
            this.formGroup.value.startDate = result.startDateTime && moment$c(result.startDateTime)
                .hour(0).minute(0).second(0).toDate();
            this.formGroup.value.startTime = result.startDateTime && moment$c(result.startDateTime).toDate();
            this.formGroup.value.id = result.id;
            const canEdit = this.permissions.editar;
            if (!canEdit) {
                this.formGroup.disable();
            }
        }
        this.loading = false;
    }
    loadLockedEmployee(value) {
        const employee = this.formGroup.controls["employee"].value;
        this.formGroup.reset();
        this.formGroup.controls["employee"].setValue(employee);
        if (this.formGroup.controls["employee"].value) {
            this.formGroup.controls["startDateTime"].setValue(moment$c(value.evaluationDate).toDate());
            this.onLoadFormSubject.next(false);
        }
        else {
            this.loading = true;
            this.employeeService.listExternalEmployee({
                filterQuery: `id eq '${value.employeeId}'`,
                displayFields: this.employeeLookupDisplayFields
            }).subscribe((dto) => {
                if (!value.schedule) {
                    this.overtimeAuthorization = new OvertimeAuthorization();
                    this.overtimeAuthorization.startDate = moment$c(value.evaluationDate)
                        .hour(0).minute(0).second(0).toDate();
                    this.overtimeAuthorization.startTime = moment$c(value.evaluationDate).toDate();
                    this.overtimeAuthorization.employee = Employee.fromDto(dto.contents[0], "OvertimeAuthorization");
                    this.patchValuesAndUpdateSuggestions(value, null);
                }
                else {
                    this.overtimeAuthorizationService.get(value.schedule).subscribe((result) => {
                        this.overtimeAuthorization = OvertimeAuthorization.fromDto(result);
                        this.patchValuesAndUpdateSuggestions(value, result);
                    });
                }
                this.onLoadFormSubject.next(false);
            });
        }
    }
    disableFieldsOnEdit(formGroup) {
        if (!this.isNew() && !this.lockedEmployee) {
            formGroup.controls.employee.disable();
        }
    }
};
OvertimeAuthorizationFormComponent.ctorParameters = () => [
    { type: OvertimeAuthorizationService },
    { type: Router },
    { type: ActivatedRoute },
    { type: MessageService },
    { type: ConfirmationService },
    { type: FormBuilder },
    { type: TranslateService },
    { type: HotkeysService },
    { type: FieldCustomizationService },
    { type: FocusService },
    { type: Renderer2 },
    { type: EmployeeService }
];
__decorate([
    ViewChild("customTemplate"),
    __metadata("design:type", TemplateRef)
], OvertimeAuthorizationFormComponent.prototype, "customTemplate", void 0);
__decorate([
    ViewChild("customFormFields"),
    __metadata("design:type", TemplateRef)
], OvertimeAuthorizationFormComponent.prototype, "customFormFields", void 0);
__decorate([
    Input(),
    __metadata("design:type", Observable)
], OvertimeAuthorizationFormComponent.prototype, "onSubmitObservable", void 0);
__decorate([
    Input(),
    __metadata("design:type", Observable)
], OvertimeAuthorizationFormComponent.prototype, "onLockedEmployeeChanges", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], OvertimeAuthorizationFormComponent.prototype, "lockedEmployee", void 0);
__decorate([
    Output(),
    __metadata("design:type", Observable)
], OvertimeAuthorizationFormComponent.prototype, "onCloseObservable", void 0);
__decorate([
    Output(),
    __metadata("design:type", Observable)
], OvertimeAuthorizationFormComponent.prototype, "onLoadForm", void 0);
OvertimeAuthorizationFormComponent = __decorate([
    Component({
        template: "<div *ngIf=\"!customTemplate else customTemplate\">\n    <p-confirmDialog acceptLabel=\"{{'hcm_clocking_event_foundation.general.yes' | translate}}\" acceptIcon=\"\" appendTo=\"body\"\n        rejectLabel=\"{{'hcm_clocking_event_foundation.general.no' | translate}}\" rejectIcon=\"\">\n    </p-confirmDialog>\n    <form [formGroup]=\"formGroup\" novalidate>\n        <p-panel *sLoadingState=\"loading\" [styleClass]=\"lockedEmployee ? 'form-group sidebar-panel' : 'form-group'\"  [toggleable]=\"false\"\n        [showHeader]=\"!lockedEmployee\" [collapsed]=\"mainPanelCollapsed\">\n            <p-header>\n                {{\"hcm_clocking_event_foundation.general.overtime_authorization_form_general_title\" | translate}}\n            </p-header>\n            <div class=\"ui-fluid\" *ngIf=\"!customFormFields else customFormFields\">\n                <div class=\"ui-g\">\n                    <div [attr.data-hidden]=\"true\" class=\"ui-g-12 ui-md-6\">\n                        <label for=\"id\">{{\"hcm_clocking_event_foundation.general.overtime_authorization_id\" | translate}}</label>\n                        <input #idFormInput type=\"text\" id=\"id\" name=\"id\" pInputText formControlName=\"id\" autocomplete=\"off\"\n                        />\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.employee.visualizar\" class=\"ui-g-12 ui-md-6 required\">\n                        <label for=\"employee\">{{\"hcm_clocking_event_foundation.general.overtime_authorization_employee\" | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"employee\" name=\"employee\" formControlName=\"employee\" [searchFields]=\"employeeSearchGridFields\"\n                            [searchGridFields]=\"employeeSearchGridFields\" [searchGridData]=\"employeeSearchGridData\"\n                            [multiple]=\"false\" [lookupSuggestions]=\"employeeLookupSuggestions\" (onLookupRequest)=\"onEmployeeLookupRequest($event)\"\n                            (onSearchRequest)=\"onEmployeeSearchRequest($event)\" lookupDisplayField=\"label\"\n                            [searchTotalRecords]=employeeSearchTotalRecords [searchTitle]=\"'hcm_clocking_event_foundation.general.overtime_authorization_employee_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\" [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: employeeSearchTotalRecords}\"></s-lookup>\n                            <s-control-errors [control]=\"formGroup.controls['employee']\"\n                            [errorMessages]=\"{\n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate\n                            }\"\n                        ></s-control-errors>\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.employee.visualizar\" class=\"ui-g-12 ui-md-6\">\n                        <label for=\"authorizer\">{{\"hcm_clocking_event_foundation.general.overtime_authorization_authorizer\" | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"authorizer\" name=\"authorizer\" formControlName=\"authorizer\" [searchFields]=\"authorizerSearchGridFields\"\n                            [searchGridFields]=\"authorizerSearchGridFields\" [searchGridData]=\"authorizerSearchGridData\"\n                            [multiple]=\"false\" [lookupSuggestions]=\"authorizerLookupSuggestions\" (onLookupRequest)=\"onAuthorizerLookupRequest($event)\"\n                            (onSearchRequest)=\"onAuthorizerSearchRequest($event)\" lookupDisplayField=\"label\"\n                            [searchTotalRecords]=authorizerSearchTotalRecords [searchTitle]=\"'hcm_clocking_event_foundation.general.overtime_authorization_authorizer_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\" [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: authorizerSearchTotalRecords}\"></s-lookup>\n                    </div>\n                    <div class=\"ui-g-6 ui-md-3 required\">\n                        <label for=\"startDate\">{{\"hcm_clocking_event_foundation.general.overtime_authorization_start_date\" | translate}}</label>\n                        <p-calendar inputId=\"startDate\" name=\"startDate\" [showIcon]=\"true\" formControlName=\"startDate\"\n                          [locale]=\"localeConfig.calendar\" [dateFormat]=\"localeConfig.calendar.dateFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['startDate']\"\n                            [errorMessages]=\"{\n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                                startDateIsBeforeEndDate: 'hcm_clocking_event_foundation.general.overtime_authorization_start_date_is_before_end_date_to_start_date' | translate\n                            }\"\n                        ></s-control-errors>\n                    </div>\n                    <div class=\"ui-g-6 ui-md-3 required\">\n                      <label for=\"startTime\">{{\"hcm_clocking_event_foundation.general.overtime_authorization_start_time\" | translate}}</label>\n                      <p-calendar icon=\"fa fa-clock-o\" inputId=\"startTime\" name=\"startTime\" [showIcon]=\"true\"  formControlName=\"startTime\"\n                        [locale]=\"localeConfig.calendar\" [timeOnly]=\"true\" [hourFormat]=\"localeConfig.calendar.hourFormat\"></p-calendar>\n                      <s-control-errors [control]=\"formGroup.controls['startTime']\"\n                          [errorMessages]=\"{\n                              required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                              startTimeIsBeforeEndTime: 'hcm_clocking_event_foundation.general.overtime_authorization_error_start_time_after_end_time_to_start_date' | translate\n                          }\"\n                      ></s-control-errors>\n                  </div>\n                    <div class=\"ui-g-6 ui-md-3 required\">\n                        <label for=\"endDate\">{{\"hcm_clocking_event_foundation.general.overtime_authorization_end_date\" | translate}}</label>\n                        <p-calendar inputId=\"endDate\" name=\"endDate\" [showIcon]=\"true\" formControlName=\"endDate\"\n                          [locale]=\"localeConfig.calendar\" [dateFormat]=\"localeConfig.calendar.dateFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['endDate']\"\n                        [errorMessages]=\"{\n                            required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                            startDateIsBeforeEndDate: 'hcm_clocking_event_foundation.general.overtime_authorization_start_date_is_before_end_date_to_end_date' | translate\n                        }\"\n                        ></s-control-errors>\n                    </div>\n                    <div class=\"ui-g-6 ui-md-3 required\">\n                      <label for=\"endTime\">{{\"hcm_clocking_event_foundation.general.overtime_authorization_end_time\" | translate}}</label>\n                      <p-calendar icon=\"fa fa-clock-o\" inputId=\"endTime\" name=\"endTime\" [showIcon]=\"true\" [timeOnly]=\"true\" formControlName=\"endTime\"\n                        [locale]=\"localeConfig.calendar\" [hourFormat]=\"localeConfig.calendar.hourFormat\"></p-calendar>\n                      <s-control-errors [control]=\"formGroup.controls['endTime']\"\n                      [errorMessages]=\"{\n                          required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                          startTimeIsBeforeEndTime: 'hcm_clocking_event_foundation.general.overtime_authorization_error_start_time_after_end_time_to_end_date' | translate\n                      }\"\n                      ></s-control-errors>\n                  </div>\n                    <div class=\"ui-g-12 ui-md-12\">\n                        <label for=\"observation\">{{\"hcm_clocking_event_foundation.general.overtime_authorization_observation\" | translate}}</label>\n                        <textarea #observationFormInput type=\"text\" id=\"observation\" name=\"observation\" pInputTextarea formControlName=\"observation\" rows=\"5\" autocomplete=\"off\"></textarea>\n                            <s-control-errors [control]=\"formGroup.controls['observation']\" [errorMessages]=\"{ maxlength: 'hcm_clocking_event_foundation.general.error_max_length' | translate: {value: '255'} }\"></s-control-errors>\n                    </div>\n                </div>\n            </div>\n            <s-custom-fields domain=\"hcm_clocking_event_foundation\" service=\"general\" entity=\"overtimeAuthorization\"\n                formControlName=\"custom\" [invalidErrorLabel]=\"'hcm_clocking_event_foundation.general.error_invalid' | translate\"></s-custom-fields>\n            <div class=\"ui-g\" *ngIf=\"!isNew() && !lockedEmployee\">\n                <div class=\"ui-g-12 ui-inputgroup\">\n                    <label *ngIf=\"formGroup.get('createdBy').value !== ''\" style=\"color: #a3a3a3; margin-right: 2px;\">{{'hcm_clocking_event_foundation.general.created_by' | translate}} {{formGroup.get('createdBy').value}} {{'hcm_clocking_event_foundation.general.at_date' | translate}} {{formGroup.get('createdDate').value | date: 'dd/MM/yyyy'}} {{'hcm_clocking_event_foundation.general.at_time' | translate}} {{formGroup.get('createdDate').value | date: 'HH:mm'}}. </label>\n                    <label *ngIf=\"formGroup.get('lastModifiedBy').value !== ''\" style=\"color: #a3a3a3;\">{{'hcm_clocking_event_foundation.general.updated_by' | translate}} {{formGroup.get('lastModifiedBy').value}} {{'hcm_clocking_event_foundation.general.at_date' | translate}} {{formGroup.get('lastModifiedDate').value | date: 'dd/MM/yyyy'}} {{'hcm_clocking_event_foundation.general.at_time' | translate}} {{formGroup.get('lastModifiedDate').value | date: 'HH:mm'}}.</label>\n                </div>\n            </div>\n            <p-footer *ngIf=\"!lockedEmployee\">\n                <button id=\"save-button\" title=\"{{'hcm_clocking_event_foundation.general.save' | translate}} (Alt + Shift + S)\"\n                    type=\"submit\" pButton label=\"{{'hcm_clocking_event_foundation.general.save' | translate}}\"\n                    (click)=\"onSave()\" *ngIf=\"isNew() || permissions.editar\"></button>\n                <button id=\"delete-button\" title=\"{{'hcm_clocking_event_foundation.general.delete' | translate}} (Alt + Shift + X)\"\n                    type=\"button\" class=\"ui-button-secondary\" pButton label=\"{{'hcm_clocking_event_foundation.general.delete' | translate}}\"\n                    (click)=\"onDelete()\" *ngIf=\"!isNew() && permissions.excluir\" [disabled]=\"loading\"></button>\n                <button id=\"cancel-button\" title=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}} (Alt + Shift + C)\"\n                    type=\"button\" class=\"ui-button-link\" pButton label=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}}\"\n                    (click)=\"onCancel()\"></button>\n            </p-footer>\n        </p-panel>\n    </form>\n</div>\n<!--{CA:FILE_CONTENTS:START}-->\n<!--{CA:FILE_CONTENTS:END}-->\n",
        providers: [
            ConfirmationService,
        ],
        selector: "cem-overtime-authorization-form",
        styles: [":host ::ng-deep .sidebar-panel{border:none!important;padding-left:0!important}#observation{max-width:100%!important}"]
    }) /*{CA:CLASS_INTERFACES:START}*/ /*{CA:CLASS_INTERFACES:END}*/,
    __metadata("design:paramtypes", [OvertimeAuthorizationService,
        Router,
        ActivatedRoute,
        MessageService,
        ConfirmationService,
        FormBuilder,
        TranslateService,
        HotkeysService,
        FieldCustomizationService,
        FocusService,
        Renderer2,
        EmployeeService])
], OvertimeAuthorizationFormComponent);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

let OvertimeAuthorizationFormModule = class OvertimeAuthorizationFormModule {
};
OvertimeAuthorizationFormModule = __decorate([
    NgModule({
        imports: [
            LocaleModule.forChild(),
            SharedScheduleModule
        ],
        declarations: [
            OvertimeAuthorizationFormComponent
        ],
        exports: [
            OvertimeAuthorizationFormComponent
        ]
    })
], OvertimeAuthorizationFormModule);

/*{CA:PACKAGE_IMPORTS:START}*/
const moment$d = moment_; // @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class Workshift {
    constructor() {
        this.deleted = false;
        /*{CA:CLASS_METHODS:START}*/
        /*{CA:CLASS_METHODS:END}*/
    }
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    static fromDto(workshiftDto, originEntity) {
        const model = Object.assign({}, workshiftDto);
        model.createdDate = model.createdDate && moment$d(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$d(model.lastModifiedDate).toDate();
        const lookupSeparator = " - ";
        const displayFields = [
            "id",
            "code",
            "workshiftType",
            "name",
            "deleted",
            "extIntSts",
            "extIntMsg",
            "createdBy",
            "createdDate",
            "lastModifiedBy",
            "lastModifiedDate",
        ];
        model.label = displayFields.map(field => model[field]).join(lookupSeparator);
        return model;
    }
    static toDto(workshift, originEntity) {
        const dto = Object.assign({}, workshift);
        dto.createdDate = dto.createdDate && moment$d(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$d(dto.lastModifiedDate).format();
        delete dto.label;
        return dto;
    }
}
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PACKAGE_IMPORTS:START}*/
const moment$e = moment_; // @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class WorkshiftGroup {
    constructor() {
        this.deleted = false;
        /*{CA:CLASS_METHODS:START}*/
        /*{CA:CLASS_METHODS:END}*/
    }
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    static fromDto(workshiftGroupDto, originEntity) {
        const model = Object.assign({}, workshiftGroupDto);
        model.baseDate = model.baseDate && moment$e(model.baseDate).toDate();
        model.createdDate = model.createdDate && moment$e(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$e(model.lastModifiedDate).toDate();
        const lookupSeparator = " - ";
        const displayFields = [
            "id",
            "code",
            "baseDate",
            "deleted",
            "extIntSts",
            "extIntMsg",
            "createdBy",
            "createdDate",
            "lastModifiedBy",
            "lastModifiedDate",
        ];
        model.label = displayFields.map(field => model[field]).join(lookupSeparator);
        return model;
    }
    static toDto(workshiftGroup, originEntity) {
        const dto = Object.assign({}, workshiftGroup);
        dto.baseDate = dto.baseDate && moment$e(dto.baseDate).format("YYYY-MM-DD");
        dto.createdDate = dto.createdDate && moment$e(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$e(dto.lastModifiedDate).format();
        delete dto.label;
        return dto;
    }
}
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PACKAGE_IMPORTS:START}*/
const moment$f = moment_; // @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class WorkshiftChange {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    static fromDto(workshiftChangeDto, originEntity) {
        const model = Object.assign({}, workshiftChangeDto);
        model.startDate = model.startDate && moment$f(model.startDate).toDate();
        model.endDate = model.endDate && moment$f(model.endDate).toDate();
        model.createdDate = model.createdDate && moment$f(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$f(model.lastModifiedDate).toDate();
        const lookupSeparator = " - ";
        const displayFields = [
            "id",
            "employee.code",
            "employee.person.nomPes",
            "startDate",
            "endDate",
            "workshift.code",
            "workshift.workshiftType",
            "workshift.name",
            "workshiftGroup.code",
            "workshiftGroup.baseDate",
            "createdBy",
            "createdDate",
            "lastModifiedBy",
            "lastModifiedDate",
        ];
        model.label = displayFields.map(field => model[field]).join(lookupSeparator);
        if (originEntity !== "Employee" && model.employee)
            model.employee = Employee.fromDto(model.employee, "WorkshiftChange");
        if (originEntity !== "Workshift" && model.workshift)
            model.workshift = Workshift.fromDto(model.workshift, "WorkshiftChange");
        if (originEntity !== "WorkshiftGroup" && model.workshiftGroup)
            model.workshiftGroup = WorkshiftGroup.fromDto(model.workshiftGroup, "WorkshiftChange");
        return model;
    }
    static toDto(workshiftChange, originEntity) {
        const dto = Object.assign({}, workshiftChange);
        dto.startDate = dto.startDate && moment$f(dto.startDate).format("YYYY-MM-DD");
        dto.endDate = dto.endDate && moment$f(dto.endDate).format("YYYY-MM-DD");
        dto.createdDate = dto.createdDate && moment$f(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$f(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "Employee" && dto.employee)
            dto.employee = Employee.toDto(dto.employee, "WorkshiftChange");
        if (originEntity !== "Workshift" && dto.workshift)
            dto.workshift = Workshift.toDto(dto.workshift, "WorkshiftChange");
        if (originEntity !== "WorkshiftGroup" && dto.workshiftGroup)
            dto.workshiftGroup = WorkshiftGroup.toDto(dto.workshiftGroup, "WorkshiftChange");
        return dto;
    }
}
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let WorkshiftChangeService = class WorkshiftChangeService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/workshiftChange`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
};
WorkshiftChangeService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
WorkshiftChangeService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [HttpClient, MessageService, TranslateService])
], WorkshiftChangeService);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let WorkshiftGroupService = class WorkshiftGroupService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_foundation/work_schedule/entities/workshiftGroup`, `hcm_foundation/work_schedule/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
};
WorkshiftGroupService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
WorkshiftGroupService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [HttpClient, MessageService, TranslateService])
], WorkshiftGroupService);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let WorkshiftService = class WorkshiftService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_foundation/work_schedule/entities/workshift`, `hcm_foundation/work_schedule/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
    /*{CA:CLASS_METHODS:START}*/
    getCurrentWorkShiftIdByEmployeeId(employeeId) {
        return this.http.get(`hcm_contract/employment_contract_processor/queries/getCurrentWorkShiftByEmployeeId?employeeId=${employeeId}`);
    }
};
WorkshiftService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
WorkshiftService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [HttpClient, MessageService, TranslateService])
], WorkshiftService);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PACKAGE_IMPORTS:START}*/
const moment$g = moment_; // @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let WorkshiftChangeFormComponent = class WorkshiftChangeFormComponent {
    constructor(
    /*{CA:INJECTIONS:START}*/
    /*{CA:INJECTIONS:END}*/
    workshiftChangeService, router, route, messageService, confirmationService, formBuilder, translate, hotkeysService, fieldCustomization, focusService, workshiftGroupService, workshiftService, employeeService, companyClockingEventIndicationsService) {
        this.workshiftChangeService = workshiftChangeService;
        this.router = router;
        this.route = route;
        this.messageService = messageService;
        this.confirmationService = confirmationService;
        this.formBuilder = formBuilder;
        this.translate = translate;
        this.hotkeysService = hotkeysService;
        this.fieldCustomization = fieldCustomization;
        this.focusService = focusService;
        this.workshiftGroupService = workshiftGroupService;
        this.workshiftService = workshiftService;
        this.employeeService = employeeService;
        this.companyClockingEventIndicationsService = companyClockingEventIndicationsService;
        this.localeConfig = {};
        this.currencyLocaleOptions = {};
        this.permissions = {};
        this.allPermissions = {};
        this.mainPanelCollapsed = false;
        this.workshiftGroupLookupDisplayFields = ["code", "baseDate"];
        this.workshiftGroupAdvancedDisplayFields = ["code", "baseDate"];
        this.workshiftGroupLookupSeparator = " - ";
        this.workshiftLookupDisplayFields = ["code", "name"];
        this.workshiftAdvancedDisplayFields = ["code", "name", "workshiftType"];
        this.workshiftLookupSeparator = " - ";
        this.selectedWorkshiftId = '';
        this.workshiftType = [
            { label: this.translate.instant("hcm_clocking_event_foundation.general.workshift_change_workshift_type_permanent"), value: "PERMANENT" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.workshift_change_workshift_type_automatic_search"), value: "AUTOMATIC_SEARCH" },
        ];
        this.contractTypeOptions = [
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_employee"), value: "EMPLOYEE" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_director"), value: "DIRECTOR" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_trainee"), value: "TRAINEE" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_aprentice"), value: "APRENTICE" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_third_party"), value: "THIRD_PARTY" },
        ];
        this.employeeLookupDisplayFields = ["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractType", "hireDate", "dismissalDate"];
        this.employeeLabelDisplayFields = ["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractType"];
        this.employeeLookupSeparator = " - ";
        this.indications = new Array();
        /*{CA:CLASS_ATTRIBUTES:START}*/
        this.cacheLimitDaysBackwardScheduling = new Map();
        this.requiredChecker = {
            isRequired: false,
        };
        this.onClose = new Subject();
        this.onLoadFormSubject = new Subject();
        this.onCloseObservable = this.onClose.asObservable();
        this.onLoadForm = this.onLoadFormSubject.asObservable();
        this.ngUnsubscribe = new Subject();
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
    ngOnInit() {
        /*{CA:ON_INIT_START:START}*/
        this.route.params.pipe(takeUntil(this.ngUnsubscribe)).subscribe((params) => this.onRouteParamsChange(params));
        /*{CA:ON_INIT_START:END}*/
        this.formGroup = this.getFormGroup();
        if (this.lockedEmployee) {
            this.loadLockedEmployee(this.lockedEmployee);
            this.onSubmitObservable.pipe(takeUntil(this.ngUnsubscribe), filter(name => name === 'workshiftChange' || name === "workshiftChangeDelete")).subscribe((value) => {
                switch (value) {
                    case "workshiftChange":
                        this.confirmBeforeSave();
                        break;
                    case "workshiftChangeDelete":
                        this.onDelete();
                        break;
                    default:
                        break;
                }
            });
            this.onLockedEmployeeChanges
                .pipe(takeUntil(this.ngUnsubscribe))
                .subscribe((value) => {
                this.loadLockedEmployee(value);
            });
        }
        else {
            this.setHotkeys();
        }
        this.route.data.pipe(takeUntil(this.ngUnsubscribe)).subscribe((data) => this.onRouteDataChange(data));
        this.workshiftGroupSearchFields = this.getWorkshiftGroupSearchFields();
        this.workshiftGroupSearchGridFields = this.getWorkshiftGroupSearchGridFields();
        this.workshiftSearchFields = this.getWorkshiftSearchFields();
        this.workshiftSearchGridFields = this.getWorkshiftSearchGridFields();
        this.employeeSearchFields = this.getEmployeeSearchFields();
        this.employeeSearchGridFields = this.getEmployeeSearchGridFields();
        /*{CA:ON_INIT_END:START}*/
        /*{CA:ON_INIT_END:END}*/
    }
    patchValuesAndUpdateSuggestions(value, result) {
        this.updateSuggestions(this.workshiftChange);
        this.formGroup.patchValue(this.workshiftChange);
        this.formGroup.controls["employee"].disable();
        if (value.schedule) {
            this.formGroup.controls["startDate"].disable();
            this.formGroup.value.startDate = result.startDate;
            this.formGroup.value.id = result.id;
            const canEdit = this.permissions.editar;
            if (!canEdit) {
                this.formGroup.disable();
            }
        }
        this.loading = false;
    }
    loadLockedEmployee(value) {
        const employee = this.formGroup.controls['employee'].value;
        this.formGroup.reset();
        this.formGroup.controls['employee'].setValue(employee);
        if (this.formGroup.controls['employee'].value) {
            this.formGroup.controls['startDate'].setValue(moment$g(value.evaluationDate).toDate());
            this.onLoadFormSubject.next(false);
        }
        else {
            this.loading = true;
            this.employeeService.listExternalEmployee({
                filterQuery: `id eq '${value.employeeId}'`,
                displayFields: this.employeeLookupDisplayFields
            }).subscribe((dto) => {
                if (!value.schedule) {
                    this.workshiftChange = new WorkshiftChange();
                    this.workshiftChange.startDate = moment$g(value.evaluationDate).toDate();
                    this.workshiftChange.employee = Employee.fromDto(dto.contents[0], "workshifChange");
                    this.patchValuesAndUpdateSuggestions(value, null);
                }
                else {
                    this.workshiftChangeService.get(value.schedule).subscribe((result) => {
                        this.workshiftChange = WorkshiftChange.fromDto(result);
                        this.patchValuesAndUpdateSuggestions(value, result);
                    });
                }
                this.onLoadFormSubject.next(false);
            });
        }
    }
    ngAfterViewInit() {
        /*{CA:ON_VIEW_INIT_START:START}*/
        /*{CA:ON_VIEW_INIT_START:END}*/
        /*{CA:ON_VIEW_INIT_END:START}*/
        /*{CA:ON_VIEW_INIT_END:END}*/
    }
    ngOnDestroy() {
        /*{CA:ON_DESTROY_START:START}*/
        /*{CA:ON_DESTROY_START:END}*/
        this.ngUnsubscribe.next();
        this.ngUnsubscribe.complete();
        this.cacheLimitDaysBackwardScheduling.clear();
        /*{CA:ON_DESTROY_END:START}*/
        /*{CA:ON_DESTROY_END:END}*/
    }
    setHotkeys() {
        /*{CA:SET_HOTKEYS_START:START}*/
        /*{CA:SET_HOTKEYS_START:END}*/
        this.hotkeysService.add(new Hotkey("alt+shift+x", () => {
            if (this.permissions.excluir)
                this.onDelete();
            return false;
        }, ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+s", () => {
            if (this.isNew() || this.permissions.editar)
                this.onSave();
            return false;
        }, ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+c", () => {
            this.onCancel();
            return false;
        }, ["INPUT", "SELECT", "TEXTAREA"]));
        /*{CA:SET_HOTKEYS_END:START}*/
        /*{CA:SET_HOTKEYS_END:END}*/
    }
    isNew() {
        return this.routeParams.workshiftChange === "new";
    }
    onRouteParamsChange(params) {
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:END}*/
        this.routeParams = params;
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:END}*/
    }
    updateSuggestions(value) {
        /*{CA:ON_UPDATE_SUGGESTIONS_START:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_START:END}*/
        if (value.workshiftGroup) {
            value.workshiftGroup.label = this.getSuggestionValue(["code"], "workshiftGroup", value, this.workshiftGroupLookupSeparator);
            if (value.workshiftGroup.label.toString().trim() === this.workshiftGroupLookupSeparator.trim()) {
                delete value.workshiftGroup.label;
            }
        }
        if (value.workshift) {
            value.workshift.label = this.getSuggestionValue(["code", "name", "workshiftType"], "workshift", value, this.workshiftLookupSeparator);
            if (value.workshift.label.toString().trim() === this.workshiftLookupSeparator.trim()) {
                delete value.workshift.label;
            }
        }
        if (value.employee) {
            value.employee.employmentRelationship.contractTypeLabel = this.loadLabelFromEnum(value.employee.employmentRelationship.contractType);
            value.employee.label = this.getSuggestionValue(["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractTypeLabel"], "employee", value, this.employeeLookupSeparator);
            if (value.employee.label.toString().trim() === this.employeeLookupSeparator.trim()) {
                delete value.employee.label;
            }
        }
        /*{CA:ON_UPDATE_SUGGESTIONS_END:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_END:END}*/
    }
    getSuggestionValue(displayFields, ownerEntity, value, separator) {
        return displayFields
            .map(field => this.getProp(value, `${ownerEntity}.${field}`))
            .reduce((acc, val) => `${acc}${separator}${val}`);
    }
    onRouteDataChange(data) {
        /*{CA:ON_ROUTE_DATA_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_START:END}*/
        const { currencySymbol, thousandsSeparator, decimalSeparator } = data.localeConfig.number;
        this.localeConfig = data.localeConfig;
        this.currencyLocaleOptions = {
            align: "left",
            prefix: currencySymbol,
            thousands: thousandsSeparator,
            decimal: decimalSeparator,
        };
        this.permissions = data.allPermissions.workshiftChange;
        this.allPermissions = data.allPermissions;
        this.validateVisualization();
        if (this.lockedEmployee) {
            return;
        }
        else if (data.entity && data.entity[0]) {
            const canEdit = this.permissions.editar;
            if (!canEdit) {
                this.formGroup.disable();
            }
            const value = WorkshiftChange.fromDto(data.entity[0]);
            this.updateSuggestions(value);
            this.formGroup.patchValue(value);
            this.workShiftId = data.entity[0].workshift.id;
            this.employeeId = data.entity[0].employee.id;
            let limitDate = new Date();
            limitDate.setDate(limitDate.getDate() - data.entity[1].timeEvaluationDefinition.limitDaysBackwardScheduling);
            this.cacheLimitDaysBackwardScheduling.set(data.entity[1].id, limitDate);
            this.indications.push(data.entity[1]);
        }
        else {
            this.formGroup.patchValue(new WorkshiftChange());
        }
        /*{CA:ON_ROUTE_DATA_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_END:END}*/
    }
    onCancel() {
        /*{CA:ON_CANCEL_START:START}*/
        /*{CA:ON_CANCEL_START:END}*/
        this.goBack();
        /*{CA:ON_CANCEL_END:START}*/
        /*{CA:ON_CANCEL_END:END}*/
    }
    onSendFile(filesToDelete, filesToCommit) {
        /*{CA:ON_SEND_FILE:START}*/
        /*{CA:ON_SEND_FILE:END}*/
        const observables = [];
        if (!this.fieldCustomization.isEmpty(filesToDelete)) {
            observables.push(this.fieldCustomization.deleteFiles(filesToDelete));
        }
        if (!this.fieldCustomization.isEmpty(filesToCommit)) {
            observables.push(this.fieldCustomization.commitFiles(filesToCommit));
        }
        if (!this.fieldCustomization.isEmpty(observables)) {
            return forkJoin(observables);
        }
        else {
            return of({});
        }
    }
    onSave() {
        /*{CA:ON_SAVE_START:START}*/
        /*{CA:ON_SAVE_START:END}*/
        this.loading = true;
        this.onLoadFormSubject.next(true);
        if (!this.formGroup.valid) {
            this.loading = false;
            this.onLoadFormSubject.next(false);
            return this.validateAllFormFields(this.formGroup);
        }
        const { filesToDelete, filesToCommit } = this.fieldCustomization.getFiles(this.formGroup);
        this.getSaveObservable()
            .pipe(takeUntil(this.ngUnsubscribe), catchError((err) => {
            this.loading = false;
            this.onLoadFormSubject.next(false);
            return throwError(err);
        }))
            .subscribe(() => {
            /*{CA:ON_SAVE_START_TOP:START}*/
            /*{CA:ON_SAVE_START_TOP:END}*/
            this.onSendFile(filesToDelete, filesToCommit)
                .pipe(takeUntil(this.ngUnsubscribe), catchError((err) => {
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                this.loading = false;
                this.onLoadFormSubject.next(false);
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                return throwError(err);
            }))
                .subscribe(() => {
                this.addMessage("success", "hcm_clocking_event_foundation.general.saved_message_title", "hcm_clocking_event_foundation.general.saved_message_content");
                /*{CA:ON_SAVE_START_BOTTOM:START}*/
                this.finishOperation();
                /*{CA:ON_SAVE_START_BOTTOM:END}*/
            });
        });
        /*{CA:ON_SAVE_END:START}*/
        /*{CA:ON_SAVE_END:END}*/
    }
    onDelete() {
        /*{CA:ON_DELETE_START:START}*/
        /*{CA:ON_DELETE_START:END}*/
        this.confirmationService.confirm({
            message: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_message"),
            header: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_title"),
            accept: () => {
                this.loading = true;
                this.onLoadFormSubject.next(true);
                this.getDeleteObservable()
                    .pipe(takeUntil(this.ngUnsubscribe))
                    .subscribe(() => this.finishOperation());
            },
            reject: () => this.loading = false
        });
        /*{CA:ON_DELETE_END:START}*/
        /*{CA:ON_DELETE_END:END}*/
    }
    finishOperation() {
        if (this.lockedEmployee) {
            this.onClose.next();
            this.loading = false;
        }
        else {
            this.goBack();
        }
    }
    getProp(obj, path) {
        return path.split(".").reduce((result, prop) => (result[prop] === undefined ? "" : result[prop]), obj);
    }
    loadLabelFromEnum(value) {
        return this.contractTypeOptions.filter(r => r.value === value)[0].label;
    }
    loadEnumFromLabel(value) {
        value = value.toUpperCase().trim();
        if (value && value !== undefined) {
            return this.contractTypeOptions.filter(r => {
                const match = r.label.toUpperCase().match(value);
                return match !== null && match.length !== 0;
            })
                .map(r => r.value);
        }
        return [];
    }
    onWorkshiftGroupLookupRequest(value) {
        /*{CA:ON_WORKSHIFT_GROUP_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_WORKSHIFT_GROUP_LOOKUP_REQUEST_START:END}*/
        const sort = ["code"].map((field) => ({ field, order: 1 }));
        let filterQuery = this.getWorkshiftGroupSearchFields()
            .filter(({ type }) => isValidFilter(type, value))
            .map(({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$g(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$g(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$g(value).format()}'`;
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`;
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        })
            .join(" or ");
        let filters = [`workshift eq '${this.selectedWorkshiftId}'`];
        filters.push(`baseDate <= '${moment$g(this.formGroup.value.startDate).format("YYYY-MM-DD")}'`);
        if (filterQuery !== '')
            filters.push(filterQuery);
        filterQuery = filters.join(' and ');
        const displayFields = mergeUnique(this.workshiftGroupLookupDisplayFields, this.workshiftGroupAdvancedDisplayFields);
        this.workshiftGroupService
            .list({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.workshiftGroupLookupDisplayFields
                    .map(field => this.formatWorkshiftGroupBaseDate(item, field))
                    .join(this.workshiftGroupLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.workshiftGroupLookupSuggestions = list.contents;
        });
        /*{CA:ON_WORKSHIFT_GROUP_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_WORKSHIFT_GROUP_LOOKUP_REQUEST_END:END}*/
    }
    onWorkshiftGroupSearchRequest(event) {
        /*{CA:ON_WORKSHIFT_GROUP_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_WORKSHIFT_GROUP_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        const page = first / rows;
        const sort = multiSortMeta;
        let filterQuery = this.getWorkshiftGroupSearchFields()
            .filter(({ name }) => filterData[name] != undefined && filterData[name] != "")
            .map(({ name, type }) => {
            const value = filterData[name];
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$g(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$g(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$g(value).format()}'`;
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`;
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        })
            .join(" and ");
        let filters = [`workshift eq '${this.selectedWorkshiftId}'`];
        filters.push(`baseDate <= '${moment$g(this.formGroup.value.startDate).format("YYYY-MM-DD")}'`);
        if (filterQuery !== '')
            filters.push(filterQuery);
        filterQuery = filters.join(' and ');
        const displayFields = mergeUnique(this.workshiftGroupLookupDisplayFields, this.workshiftGroupAdvancedDisplayFields);
        this.workshiftGroupService
            .list({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.workshiftGroupLookupDisplayFields
                    .map(field => this.formatWorkshiftGroupBaseDate(item, field))
                    .join(this.workshiftGroupLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.workshiftGroupSearchGridData = list.contents;
            this.workshiftGroupSearchTotalRecords = list.totalElements;
        });
        /*{CA:ON_WORKSHIFT_GROUP_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_WORKSHIFT_GROUP_SEARCH_REQUEST_END:END}*/
    }
    onWorkshiftLookupRequest(value) {
        /*{CA:ON_WORKSHIFT_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_WORKSHIFT_LOOKUP_REQUEST_START:END}*/
        const sort = this.workshiftLookupDisplayFields.map((field) => ({ field, order: 1 }));
        let filterQuery = this.getWorkshiftSearchFields()
            .filter(({ type }) => isValidFilter(type, value) && type !== FieldType.Enum)
            .map(({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`; // NOSONAR
            else if (type == FieldType.Date)
                return `${name} eq '${moment$g(value).format("YYYY-MM-DD")}'`; // NOSONAR
            else if (type == FieldType.Time)
                return `${name} eq '${moment$g(value).format("HH:mm:ss")}'`; // NOSONAR
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$g(value).format()}'`; // NOSONAR
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`; // NOSONAR
            else
                return `${name} eq '${value}'`; // NOSONAR
        }) // NOSONAR
            .filter(filter => filter !== '')
            .join(" or "); // NOSONAR
        const startDate = moment$g(this.formGroup.value.startDate).format("YYYY-MM-DD");
        const endDate = moment$g(this.formGroup.value.endDate).format("YYYY-MM-DD");
        const filters = [
            `(initialValidity <= '${startDate}' and finalValidity >= '${endDate}'
            or initialValidity is null and finalValidity >= '${endDate}'
            or initialValidity <= '${startDate}' and finalValidity is null
            or initialValidity is null and finalValidity is null)`,
        ];
        if (filterQuery !== '')
            filters.push(filterQuery);
        filterQuery = filters.join(' and ');
        const displayFields = mergeUnique(["code", "name", "initialValidity", "finalValidity"], ["code", "name", "workshiftType", "initialValidity", "finalValidity"]);
        this.workshiftService
            .list({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.workshiftLookupDisplayFields
                    .map(field => {
                    if (field.indexOf(".") > 0)
                        return this.getProp(item, field);
                    return item[field];
                })
                    .join(this.workshiftLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.workshiftLookupSuggestions = list.contents;
        });
        /*{CA:ON_WORKSHIFT_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_WORKSHIFT_LOOKUP_REQUEST_END:END}*/
    }
    onWorkshiftSearchRequest(event) {
        /*{CA:ON_WORKSHIFT_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_WORKSHIFT_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        const page = first / rows;
        const sort = multiSortMeta;
        let filterQuery = this.getWorkshiftSearchFields()
            .filter(({ name }) => filterData[name] != undefined && filterData[name] != "")
            .map(({ name, type }) => {
            const value = filterData[name]; // NOSONAR
            if (typeof value == "number")
                return `${name} eq ${value}`; // NOSONAR
            else if (type == FieldType.Date)
                return `${name} eq '${moment$g(value).format("YYYY-MM-DD")}'`; // NOSONAR
            else if (type == FieldType.Time)
                return `${name} eq '${moment$g(value).format("HH:mm:ss")}'`; // NOSONAR
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$g(value).format()}'`; // NOSONAR
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`; // NOSONAR
            else
                return `${name} eq '${value}'`; // NOSONAR
        }) // NOSONAR
            .join(" and "); // NOSONAR
        const startDate = moment$g(this.formGroup.value.startDate).format("YYYY-MM-DD");
        const endDate = moment$g(this.formGroup.value.endDate).format("YYYY-MM-DD");
        const filters = [
            `(initialValidity <= '${startDate}' and finalValidity >= '${endDate}'
            or initialValidity is null and finalValidity >= '${endDate}'
            or initialValidity <= '${startDate}' and finalValidity is null
            or initialValidity is null and finalValidity is null)`,
        ];
        if (filterQuery !== '')
            filters.push(filterQuery);
        filterQuery = filters.join(' and ');
        const displayFields = mergeUnique(["code", "name", "initialValidity", "finalValidity"], ["code", "name", "workshiftType", "initialValidity", "finalValidity"]);
        this.workshiftService
            .list({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.workshiftLookupDisplayFields
                    .map(field => {
                    if (field.indexOf(".") > 0)
                        return this.getProp(item, field);
                    return item[field];
                })
                    .join(this.workshiftLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.workshiftSearchGridData = list.contents;
            this.workshiftSearchTotalRecords = list.totalElements;
        });
        /*{CA:ON_WORKSHIFT_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_WORKSHIFT_SEARCH_REQUEST_END:END}*/
    }
    onEmployeeLookupRequest(value) {
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:END}*/
        const sort = this.employeeLookupDisplayFields.map((field) => ({ field, order: 1 }));
        const filterQuery = this.getEmployeeSearchFields()
            .filter(({ type }) => isValidFilter(type, value))
            .map(({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$g(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$g(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$g(value).format()}'`;
            else if (type == FieldType.Enum)
                return this.loadEnumFromLabel(value).map(enumConstant => `${name} eq '${enumConstant}'`).join(' or ');
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        })
            .filter(filter => filter !== '')
            .join(" or ");
        const displayFields = this.employeeLookupDisplayFields;
        this.employeeService
            .listExternalEmployee({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.employeeLabelDisplayFields
                    .map(field => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field);
                    if (field === 'employmentRelationship.contractType') {
                        item[field] = this.loadLabelFromEnum(item[field]);
                    }
                    return item[field];
                })
                    .join(this.employeeLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.employeeLookupSuggestions = list.contents;
        });
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:END}*/
    }
    onEmployeeSearchRequest(event) {
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        const page = first / rows;
        const sort = multiSortMeta;
        const filterQuery = this.getEmployeeSearchFields()
            .filter(({ name }) => filterData[name] != undefined && filterData[name] != "")
            .map(({ name, type }) => {
            const value = filterData[name]; // NOSONAR
            if (typeof value == "number")
                return `${name} eq ${value}`; // NOSONAR
            else if (type == FieldType.Date)
                return `${name} eq '${moment$g(value).format("YYYY-MM-DD")}'`; // NOSONAR
            else if (type == FieldType.Time)
                return `${name} eq '${moment$g(value).format("HH:mm:ss")}'`; // NOSONAR
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$g(value).format()}'`; // NOSONAR
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`; // NOSONAR
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`; // NOSONAR
            else
                return `${name} eq '${value}'`; // NOSONAR
        }) // NOSONAR
            .join(" and "); // NOSONAR
        const displayFields = this.employeeLookupDisplayFields;
        this.employeeService
            .listExternalEmployee({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.employeeLabelDisplayFields
                    .map(field => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field); // NOSONAR
                    if (field === 'employmentRelationship.contractType') { // NOSONAR
                        item[field] = this.loadLabelFromEnum(item[field]); // NOSONAR
                    } // NOSONAR
                    return item[field]; // NOSONAR
                }) // NOSONAR
                    .join(this.employeeLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.employeeSearchGridData = list.contents;
            this.employeeSearchTotalRecords = list.totalElements;
        });
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:END}*/
    }
    getFormGroup() {
        const formGroup = this.formBuilder.group({
            id: [{ value: undefined, disabled: true }, Validators.compose([])],
            employee: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            startDate: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            endDate: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            workshift: [{ value: undefined, disabled: true }, Validators.compose([Validators.required])],
            workshiftGroup: [{ value: undefined, disabled: true }, Validators.compose([])],
            createdBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            createdDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            custom: [],
        }, {
            validators: [
                this.startDateIsBeforeEndDate(),
                this.validLimitDaysBackwardScheduling(),
            ]
        });
        /*{CA:GET_FORM_CONTROLS:START}*/
        formGroup.controls.employee.valueChanges.subscribe(employee => {
            if (employee) {
                let limitDaysBackwardScheduling = this.cacheLimitDaysBackwardScheduling.get(employee.employer.id);
                if (limitDaysBackwardScheduling === undefined) {
                    this.companyClockingEventIndicationsService
                        .list({
                        filterQuery: `id eq '${employee.employer.id}'`,
                        displayFields: ['timeEvaluationDefinition.limitDaysBackwardScheduling']
                    })
                        .pipe(map((data) => data.contents[0]), catchError(error => {
                        formGroup.controls.employee.setErrors({ hasNotCompanyClockingEventIndications: { value: error } });
                        return throwError(error);
                    })).subscribe((companyClockingEventIndications) => {
                        let limitDate = new Date();
                        limitDate.setDate(limitDate.getDate() - companyClockingEventIndications.timeEvaluationDefinition.limitDaysBackwardScheduling);
                        this.cacheLimitDaysBackwardScheduling.set(companyClockingEventIndications.id, limitDate);
                    });
                }
            }
        });
        formGroup.controls.workshift.valueChanges.subscribe(workshift => {
            this.selectedWorkshiftId = workshift ? workshift.id : null;
            this.setWorkshiftGroupMandatory(this.requiredChecker.isRequired, formGroup);
            if (!workshift || this.lastWorkshiftId !== workshift.id) {
                formGroup.controls.workshiftGroup.setValue(null);
            }
            this.lastWorkshiftId = workshift && workshift.id;
        });
        formGroup.controls.startDate.valueChanges.subscribe(startDate => {
            this.verifyWorkshiftLookupDisabled(startDate, this.formGroup.value.endDate);
            const workshift = this.formGroup.value['workshift'];
            if (workshift && startDate) {
                const workshiftGroup = this.formGroup.value['workshiftGroup'];
                if (workshift.initialValidity && moment$g(workshift.initialValidity).isAfter(startDate)) {
                    this.formGroup.controls['workshift'].setValue(null);
                }
                else if (workshift.finalValidity && moment$g(workshift.finalValidity).isBefore(startDate)) {
                    this.formGroup.controls['workshift'].setValue(null);
                }
                else if (workshiftGroup && workshiftGroup.baseDate && moment$g(startDate).isBefore(workshiftGroup.baseDate)) {
                    this.formGroup.controls['workshiftGroup'].setValue(null);
                }
            }
        });
        formGroup.controls.endDate.valueChanges.subscribe(endDate => {
            this.verifyWorkshiftLookupDisabled(this.formGroup.value.startDate, endDate);
        });
        this.disableFieldsOnEdit(formGroup);
        /*{CA:GET_FORM_CONTROLS:END}*/
        return formGroup;
    }
    getWorkshiftGroupSearchFields() {
        const searchFields = [
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workshift_group_code"),
                type: FieldType.Integer,
            })
        ];
        /*{CA:GET_WORKSHIFT_GROUP_SEARCH_FIELDS:START}*/
        /*{CA:GET_WORKSHIFT_GROUP_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    getWorkshiftGroupSearchGridFields() {
        const searchGridFields = [
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workshift_group_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "baseDate",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workshift_group_base_date"),
                type: FieldType.Date,
            }),
        ];
        /*{CA:GET_WORKSHIFT_GROUP_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_WORKSHIFT_GROUP_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    getWorkshiftSearchFields() {
        const searchFields = [
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workshift_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "name",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workshift_name"),
                type: FieldType.String,
            }),
            new FormField({
                name: "workshiftType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workshift_change_workshift_type"),
                type: FieldType.Enum,
                options: this.workshiftType,
            }),
        ];
        /*{CA:GET_WORKSHIFT_SEARCH_FIELDS:START}*/
        /*{CA:GET_WORKSHIFT_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    getWorkshiftSearchGridFields() {
        const searchGridFields = [
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workshift_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "name",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workshift_name"),
                type: FieldType.String,
            }),
            new FormField({
                name: "workshiftType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workshift_change_workshift_type"),
                type: FieldType.Enum,
                options: this.workshiftType,
            }),
        ];
        /*{CA:GET_WORKSHIFT_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_WORKSHIFT_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    getEmployeeSearchFields() {
        const searchFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions
            })
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    getEmployeeSearchGridFields() {
        const searchGridFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions
            }),
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    goBack() {
        const previousRoute = "../";
        this.router.navigate([previousRoute], { relativeTo: this.route.parent });
    }
    validateAllFormFields(formGroup) {
        Object.keys(formGroup.controls).forEach(field => {
            const control = formGroup.get(field);
            if (control instanceof FormControl)
                control.markAsDirty({ onlySelf: true });
            else if (control instanceof FormGroup)
                this.validateAllFormFields(control);
        });
        this.focusService.focusFirstInvalidInput();
        /*{CA:FOCUS_FIRST_INVALID:START}*/
        /*{CA:FOCUS_FIRST_INVALID:END}*/
    }
    getSaveObservable() {
        const { value } = this.formGroup;
        value.employee = this.formGroup.controls['employee'].value;
        value.id = this.formGroup.controls['id'].value;
        value.startDate = this.formGroup.controls['startDate'].value;
        const workshiftChangeDto = WorkshiftChange.toDto(value);
        let observable;
        if (this.isNew() || (this.lockedEmployee && !value.id)) {
            observable = this.workshiftChangeService.insert(workshiftChangeDto);
        }
        else {
            const id = this.lockedEmployee ? value.id : this.routeParams.workshiftChange;
            observable = this.workshiftChangeService.update(id, workshiftChangeDto);
        }
        return observable;
    }
    getDeleteObservable() {
        let workshiftChangeId = this.routeParams.workshiftChange;
        if (this.lockedEmployee && this.lockedEmployee.schedule) {
            workshiftChangeId = this.lockedEmployee.schedule;
        }
        return this.workshiftChangeService.delete(workshiftChangeId).pipe(tap(() => {
            this.addMessage(// NOSONAR
            "success", // NOSONAR
            "hcm_clocking_event_foundation.general.deleted_message_title", // NOSONAR
            "hcm_clocking_event_foundation.general.deleted_message_content" // NOSONAR
            ); // NOSONAR
        }));
    }
    validateVisualization() {
        /*{CA:VALIDATE_VISUALIZATION_START:START}*/
        /*{CA:VALIDATE_VISUALIZATION_START:END}*/
        const toValidate = ["employee", "workshift"];
        if (!toValidate.every(e => this.allPermissions[e] && this.allPermissions[e].visualizar)) {
            this.router.navigate(["forbidden"]);
        }
        /*{CA:VALIDATE_VISUALIZATION_END:START}*/
        /*{CA:VALIDATE_VISUALIZATION_END:END}*/
    }
    /*{CA:CLASS_METHODS:START}*/
    startDateIsBeforeEndDate() {
        return (control) => {
            const startDate = control.get('startDate');
            const endDate = control.get('endDate');
            return startDateIsBeforeOrEqualToEndDateValidator(startDate, endDate);
        };
    }
    validLimitDaysBackwardScheduling() {
        return (control) => {
            const startDate = control.get('startDate');
            const employee = control.get('employee');
            if (employee.value && startDate.value) {
                const limitDate = this.cacheLimitDaysBackwardScheduling.get(employee.value.employer.id);
                if (limitDate && moment$g(startDate.value).isBefore(limitDate, 'day')) {
                    startDate.setErrors({ exceededLimit: { value: startDate.value } });
                }
                else {
                    removeErrorFromField(startDate, 'exceededLimit');
                }
            }
            else {
                removeErrorFromField(startDate, 'exceededLimit');
            }
            return null;
        };
    }
    confirmBeforeSave() {
        this.loading = true;
        if (!this.formGroup.valid) {
            this.loading = false;
            return this.validateAllFormFields(this.formGroup);
        }
        this.workshiftService.getCurrentWorkShiftIdByEmployeeId(this.formGroup.controls.employee.value.id).subscribe((dto) => {
            this.loading = false;
            if ((this.formGroup.controls.workshift.value.id != this.workShiftId || this.formGroup.controls.employee.value.id != this.employeeId) && this.formGroup.controls.workshift.value.id == dto.workShiftId) {
                this.confirmationService.confirm({
                    key: "customized",
                    message: this.translate.instant("hcm_clocking_event_foundation.general.validation_employee_has_currently_this_work_shift"),
                    accept: () => this.onSave(),
                    reject: () => this.loading = false
                });
            }
            else {
                this.onSave();
            }
        });
    }
    setWorkshiftGroupMandatory(isEnabled, formGroup) {
        const workshift = formGroup.controls.workshift;
        const workshiftGroup = formGroup.controls.workshiftGroup;
        if (workshift.value == null) {
            this.requiredChecker.isRequired = false;
            workshiftGroup.disable();
            workshiftGroup.setValue(null);
        }
        else {
            this.requiredChecker.isRequired = true;
            workshiftGroup.enable();
            workshiftGroup.setValidators(Validators.required);
        }
    }
    /*{CA:CLASS_METHODS:END}*/
    addMessage(severity, summary, detail) {
        if (this.lockedEmployee) {
            this.messageService.add({
                key: "employee-clocking-event-adjustment-list-view",
                severity,
                summary: this.translate.instant(summary),
                detail: this.translate.instant(detail),
            });
        }
        else {
            this.messageService.add({
                severity,
                summary: this.translate.instant(summary),
                detail: this.translate.instant(detail),
            });
        }
    }
    getWorkshiftGroup() {
        return this.translate.instant('hcm_clocking_event_foundation.general.workshift_change_workshift_group_info_sign');
    }
    formatWorkshiftGroupBaseDate(item, field) {
        if (field.indexOf(".") > 0)
            return this.getProp(item, field);
        if (field === 'baseDate') {
            return moment$g(item[field]).format(this.localeConfig.calendar.dateFormat.replace('yy', 'YYYY').toUpperCase());
        }
        return item[field];
    }
    verifyWorkshiftLookupDisabled(startDate = this.formGroup.controls.startDate.value, endDate = this.formGroup.controls.endDate.value) {
        if (startDate != null && endDate != null) {
            this.formGroup.controls.workshift.enable();
        }
        else {
            this.formGroup.controls.workshift.disable();
            this.formGroup.controls.workshift.setValue(null);
        }
    }
    disableFieldsOnEdit(formGroup) {
        if (!this.isNew() && !this.lockedEmployee) {
            formGroup.controls.employee.disable();
        }
    }
};
WorkshiftChangeFormComponent.ctorParameters = () => [
    { type: WorkshiftChangeService },
    { type: Router },
    { type: ActivatedRoute },
    { type: MessageService },
    { type: ConfirmationService },
    { type: FormBuilder },
    { type: TranslateService },
    { type: HotkeysService },
    { type: FieldCustomizationService },
    { type: FocusService },
    { type: WorkshiftGroupService },
    { type: WorkshiftService },
    { type: EmployeeService },
    { type: CompanyClockingEventIndicationsService }
];
__decorate([
    ViewChild("customTemplate"),
    __metadata("design:type", TemplateRef)
], WorkshiftChangeFormComponent.prototype, "customTemplate", void 0);
__decorate([
    ViewChild("customFormFields"),
    __metadata("design:type", TemplateRef)
], WorkshiftChangeFormComponent.prototype, "customFormFields", void 0);
__decorate([
    Input(),
    __metadata("design:type", Observable)
], WorkshiftChangeFormComponent.prototype, "onSubmitObservable", void 0);
__decorate([
    Input(),
    __metadata("design:type", Observable)
], WorkshiftChangeFormComponent.prototype, "onLockedEmployeeChanges", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], WorkshiftChangeFormComponent.prototype, "lockedEmployee", void 0);
__decorate([
    Output(),
    __metadata("design:type", Observable)
], WorkshiftChangeFormComponent.prototype, "onCloseObservable", void 0);
__decorate([
    Output(),
    __metadata("design:type", Observable)
], WorkshiftChangeFormComponent.prototype, "onLoadForm", void 0);
WorkshiftChangeFormComponent = __decorate([
    Component({
        template: "<div *ngIf=\"!customTemplate else customTemplate\">\n    <p-confirmDialog acceptLabel=\"{{'hcm_clocking_event_foundation.general.yes' | translate}}\" acceptIcon=\"\" appendTo=\"body\"\n        rejectLabel=\"{{'hcm_clocking_event_foundation.general.no' | translate}}\" rejectIcon=\"\">\n    </p-confirmDialog>\n    <form [formGroup]=\"formGroup\" novalidate>\n        <p-panel *sLoadingState=\"loading\" [styleClass]=\"lockedEmployee ? 'form-group sidebar-panel' : 'form-group'\" [toggleable]=\"false\" [collapsed]=\"mainPanelCollapsed\" [showHeader]=\"!lockedEmployee\">\n            <p-header>\n                {{\"hcm_clocking_event_foundation.general.workshift_change_form_general_title\" | translate}}\n            </p-header>\n            <div class=\"ui-fluid\" *ngIf=\"!customFormFields else customFormFields\">\n                <div class=\"ui-g\">\n                    <div [attr.data-hidden]=\"true\" class=\"ui-g-12 ui-md-6\">\n                        <label for=\"id\">{{\"hcm_clocking_event_foundation.general.workshift_change_id\" | translate}}</label>\n                        <input #idFormInput type=\"text\" id=\"id\" name=\"id\" pInputText formControlName=\"id\" autocomplete=\"off\"\n                        />\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.employee.visualizar\" class=\"ui-g-12 required\" [ngClass]=\"lockedEmployee ? '' : 'ui-md-12 ui-lg-6'\">\n                        <label for=\"employee\">{{\"hcm_clocking_event_foundation.general.workshift_change_employee\" | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"employee\" name=\"employee\" formControlName=\"employee\" [searchFields]=\"employeeSearchGridFields\"\n                            [searchGridFields]=\"employeeSearchGridFields\" [searchGridData]=\"employeeSearchGridData\" [multiple]=\"false\"\n                            [lookupSuggestions]=\"employeeLookupSuggestions\" (onLookupRequest)=\"onEmployeeLookupRequest($event)\"\n                            (onSearchRequest)=\"onEmployeeSearchRequest($event)\" lookupDisplayField=\"label\"\n                            [searchTotalRecords]=employeeSearchTotalRecords [searchTitle]=\"'hcm_clocking_event_foundation.general.workshift_change_employee_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\" [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: employeeSearchTotalRecords}\"></s-lookup>\n\n                        <s-control-errors [control]=\"formGroup.controls['employee']\" [errorMessages]=\"{ required: 'hcm_clocking_event_foundation.general.error_required' | translate }\"></s-control-errors>\n                    </div>\n                    <div  class=\"ui-g-12 ui-md-6 required\" [ngClass]=\"lockedEmployee ? '' : 'ui-md-6 ui-lg-3'\">\n                        <label for=\"startDate\">{{\"hcm_clocking_event_foundation.general.workshift_change_start_date\" | translate}}</label>\n                        <p-calendar #startDateFormInput inputId=\"startDate\" name=\"startDate\" [showIcon]=\"true\" formControlName=\"startDate\"\n                            [locale]=\"localeConfig.calendar\" [dateFormat]=\"localeConfig.calendar.dateFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['startDate']\" [errorMessages]=\"{ required: 'hcm_clocking_event_foundation.general.error_required' | translate, startDateIsBeforeEndDate: 'hcm_clocking_event_foundation.general.error_start_date_after_end_date' | translate, exceededLimit: 'hcm_clocking_event_foundation.general.error_exceeded_limit_days_backward_scheduling' | translate }\">\n                        </s-control-errors>\n                    </div>\n                    <div  class=\"ui-g-12 ui-md-6 required\" [ngClass]=\"lockedEmployee ? '' : 'ui-md-6 ui-lg-3'\">\n                        <label for=\"endDate\">{{\"hcm_clocking_event_foundation.general.workshift_change_end_date\" | translate}}</label>\n                        <p-calendar #endDateFormInput inputId=\"endDate\" name=\"endDate\" [showIcon]=\"true\" formControlName=\"endDate\"\n                            [locale]=\"localeConfig.calendar\" [dateFormat]=\"localeConfig.calendar.dateFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['endDate']\" [errorMessages]=\"{ required: 'hcm_clocking_event_foundation.general.error_required' | translate, startDateIsBeforeEndDate: 'hcm_clocking_event_foundation.general.error_end_date_before_start_date' | translate }\"></s-control-errors>\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.workshift.visualizar\" class=\"ui-g-12 ui-md-6 required\">\n                        <label for=\"workshift\">{{\"hcm_clocking_event_foundation.general.workshift_change_workshift\" | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"workshift\" name=\"workshift\" formControlName=\"workshift\" [searchFields]=\"workshiftSearchFields\"\n                            [searchGridFields]=\"workshiftSearchGridFields\" [searchGridData]=\"workshiftSearchGridData\"\n                            [multiple]=\"false\" [lookupSuggestions]=\"workshiftLookupSuggestions\" (onLookupRequest)=\"onWorkshiftLookupRequest($event)\"\n                            (onSearchRequest)=\"onWorkshiftSearchRequest($event)\" lookupDisplayField=\"label\"\n                            [searchTotalRecords]=workshiftSearchTotalRecords [searchTitle]=\"'hcm_clocking_event_foundation.general.workshift_change_workshift_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\"\n                            [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: workshiftSearchTotalRecords}\"\n                            [emptyFieldLabel]=\"'hcm_clocking_event_foundation.general.list_grid_empty_field' | translate\"></s-lookup>\n                        <s-control-errors [control]=\"formGroup.controls['workshift']\" [errorMessages]=\"{ required: 'hcm_clocking_event_foundation.general.error_required' | translate }\"></s-control-errors>\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.workshiftGroup.visualizar\" class=\"ui-g-12 ui-md-6\">\n                        <label for=\"workshiftGroup\">{{\"hcm_clocking_event_foundation.general.workshift_change_workshift_group\" | translate}}\n                            <span [ngClass]=\"requiredChecker.isRequired ? 'required' : ' '\">\n                                <label style=\"display: inline\"></label>\n                            </span>\n                            <span *sInfoSign=\"getWorkshiftGroup()\"></span>\n                        </label>\n                        <s-lookup dataKey=\"id\" id=\"workshiftGroup\" name=\"workshiftGroup\" formControlName=\"workshiftGroup\" [searchFields]=\"workshiftGroupSearchFields\"\n                            [searchGridFields]=\"workshiftGroupSearchGridFields\" [searchGridData]=\"workshiftGroupSearchGridData\"\n                            [multiple]=\"false\" [lookupSuggestions]=\"workshiftGroupLookupSuggestions\" (onLookupRequest)=\"onWorkshiftGroupLookupRequest($event)\"\n                            (onSearchRequest)=\"onWorkshiftGroupSearchRequest($event)\" lookupDisplayField=\"label\"\n                            [searchTotalRecords]=workshiftGroupSearchTotalRecords [searchTitle]=\"'hcm_clocking_event_foundation.general.workshift_change_workshift_group_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\" [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: workshiftGroupSearchTotalRecords}\"></s-lookup>\n                            <s-control-errors [control]=\"formGroup.controls['workshiftGroup']\" [errorMessages]=\"{ required: 'hcm_clocking_event_foundation.general.error_required' | translate }\"></s-control-errors>\n                    </div>\n                </div>\n            </div>\n            <s-custom-fields domain=\"hcm_clocking_event_foundation\" service=\"general\" entity=\"workshiftChange\" formControlName=\"custom\"\n                [invalidErrorLabel]=\"'hcm_clocking_event_foundation.general.error_invalid' | translate\"></s-custom-fields>\n            <div class=\"ui-g\" *ngIf=\"!isNew() && !lockedEmployee\">\n                <div class=\"ui-g-12 ui-inputgroup\">\n                    <label *ngIf=\"formGroup.get('createdBy').value !== ''\" style=\"color: #a3a3a3; margin-right: 2px;\">{{'hcm_clocking_event_foundation.general.created_by' | translate}} {{formGroup.get('createdBy').value}} {{'hcm_clocking_event_foundation.general.at_date' | translate}} {{formGroup.get('createdDate').value | date: 'dd/MM/yyyy'}} {{'hcm_clocking_event_foundation.general.at_time' | translate}} {{formGroup.get('createdDate').value | date: 'HH:mm'}}. </label>\n                    <label *ngIf=\"formGroup.get('lastModifiedBy').value !== ''\" style=\"color: #a3a3a3;\">{{'hcm_clocking_event_foundation.general.updated_by' | translate}} {{formGroup.get('lastModifiedBy').value}} {{'hcm_clocking_event_foundation.general.at_date' | translate}} {{formGroup.get('lastModifiedDate').value | date: 'dd/MM/yyyy'}} {{'hcm_clocking_event_foundation.general.at_time' | translate}} {{formGroup.get('lastModifiedDate').value | date: 'HH:mm'}}.</label>\n                </div>\n            </div>\n            <p-footer *ngIf=\"!lockedEmployee\">\n                <button id=\"save-button\" title=\"{{'hcm_clocking_event_foundation.general.save' | translate}} (Alt + Shift + S)\"\n                    type=\"submit\" pButton label=\"{{'hcm_clocking_event_foundation.general.save' | translate}}\"\n                    (click)=\"confirmBeforeSave()\" *ngIf=\"isNew() || permissions.editar\"></button>\n                <button id=\"delete-button\" title=\"{{'hcm_clocking_event_foundation.general.delete' | translate}} (Alt + Shift + X)\"\n                    type=\"button\" class=\"ui-button-secondary\" pButton label=\"{{'hcm_clocking_event_foundation.general.delete' | translate}}\"\n                    (click)=\"onDelete()\" *ngIf=\"!isNew() && permissions.excluir\" [disabled]=\"loading\"></button>\n                <button id=\"cancel-button\" title=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}} (Alt + Shift + C)\"\n                    type=\"button\" class=\"ui-button-link\" pButton label=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}}\"\n                    (click)=\"onCancel()\"></button>\n            </p-footer>\n        </p-panel>\n    </form>\n</div>\n<!--{CA:FILE_CONTENTS:START}-->\n<p-confirmDialog key=\"customized\" #customized header=\"{{ 'hcm_clocking_event_foundation.general.generic_confirm' | translate }}\" appendTo=\"body\">\n    <p-footer>\n        <s-button label=\"{{ 'hcm_clocking_event_foundation.general.generic_yes' | translate }}\" (onClick)=\"customized.accept()\" priority=\"primary\" [disabled]=\"false\"\n            [auxiliary]=\"false\">\n        </s-button>\n        <s-button label=\"{{ 'hcm_clocking_event_foundation.general.generic_no' | translate }}\" (onClick)=\"customized.reject()\" priority=\"secondary\" [disabled]=\"false\"\n            [auxiliary]=\"false\">\n        </s-button>\n    </p-footer>\n</p-confirmDialog>\n<!--{CA:FILE_CONTENTS:END}-->\n",
        providers: [
            ConfirmationService,
        ],
        /*{CA:COMPONENT_CONFIG:START}*/
        selector: 'cem-workshift-change-form'
        /*{CA:COMPONENT_CONFIG:END}*/
        ,
        styles: [":host ::ng-deep .sidebar-panel{border:none!important;padding-left:0!important}"]
    }),
    __metadata("design:paramtypes", [WorkshiftChangeService,
        Router,
        ActivatedRoute,
        MessageService,
        ConfirmationService,
        FormBuilder,
        TranslateService,
        HotkeysService,
        FieldCustomizationService,
        FocusService,
        WorkshiftGroupService,
        WorkshiftService,
        EmployeeService,
        CompanyClockingEventIndicationsService])
], WorkshiftChangeFormComponent);
/*{CA:FILE_CONTENTS:END}*/

let WorkshiftChangeFormModule = class WorkshiftChangeFormModule {
};
WorkshiftChangeFormModule = __decorate([
    NgModule({
        imports: [
            LocaleModule.forChild(),
            SharedScheduleModule,
            InfoSignModule
        ],
        declarations: [
            WorkshiftChangeFormComponent
        ],
        exports: [
            WorkshiftChangeFormComponent
        ]
    })
], WorkshiftChangeFormModule);

var CompensationType;
(function (CompensationType) {
    CompensationType["V1"] = "V1";
    CompensationType["V2"] = "V2";
    CompensationType["V4"] = "V4";
    CompensationType["V5"] = "V5";
    CompensationType["V6"] = "V6";
})(CompensationType || (CompensationType = {}));

var PeriodType;
(function (PeriodType) {
    PeriodType["V1"] = "V1";
    PeriodType["V2"] = "V2";
    PeriodType["V3"] = "V3";
    PeriodType["V4"] = "V4";
    PeriodType["V5"] = "V5";
    PeriodType["V6"] = "V6";
    PeriodType["V7"] = "V7";
    PeriodType["V8"] = "V8";
    PeriodType["V9"] = "V9";
})(PeriodType || (PeriodType = {}));

/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
const moment$h = moment_; // @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class AdjustmentReason {
    constructor() {
        this.mandatoryObservation = false;
        /*{CA:CLASS_METHODS:START}*/
        /*{CA:CLASS_METHODS:END}*/
    }
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    static fromDto(adjustmentReasonDto, originEntity) {
        const model = Object.assign({}, adjustmentReasonDto);
        model.createdDate = model.createdDate && moment$h(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$h(model.lastModifiedDate).toDate();
        const lookupSeparator = " - ";
        const displayFields = [
            "id",
            "code",
            "name",
            "mandatoryObservation",
            "createdBy",
            "createdDate",
            "lastModifiedBy",
            "lastModifiedDate",
        ];
        model.label = displayFields.map(field => model[field]).join(lookupSeparator);
        return model;
    }
    static toDto(adjustmentReason, originEntity) {
        const dto = Object.assign({}, adjustmentReason);
        dto.createdDate = dto.createdDate && moment$h(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$h(dto.lastModifiedDate).format();
        delete dto.label;
        return dto;
    }
}
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:END}*/
const moment$i = moment_; // @HACK Necessary because of https://github.com/rollup/rollup/issues/670
class Compensation {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    static fromDto(compensationDto, originEntity) {
        const model = Object.assign({}, compensationDto);
        model.startDate = model.startDate && moment$i(model.startDate).toDate();
        model.endDate = model.endDate && moment$i(model.endDate).toDate();
        model.intervalStart = model.intervalStart && moment$i(model.intervalStart, "HH:mm:ss").toDate();
        model.intervalEnd = model.intervalEnd && moment$i(model.intervalEnd, "HH:mm:ss").toDate();
        model.createdDate = model.createdDate && moment$i(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$i(model.lastModifiedDate).toDate();
        if (model.numberOfHours) {
            model.numberOfHours = this.convertMinuteToTime(model.numberOfHours);
        }
        const lookupSeparator = " - ";
        const displayFields = [
            "employee.code",
            "employee.person.nomPes",
            "startDate",
            "compensationType",
            "periodType",
            "endDate",
            "situation.code",
            "situation.name",
            "situation.situationType",
            "workschedule.code",
            "workschedule.name",
        ];
        model.label = displayFields.map(field => model[field]).join(lookupSeparator);
        if (originEntity !== "Employee" && model.employee) {
            model.employee = Employee.fromDto(model.employee, "Compensation");
        }
        if (originEntity !== "Situation" && model.situation) {
            model.situation = Situation.fromDto(model.situation, "Compensation");
        }
        if (originEntity !== "Workschedule" && model.workschedule) {
            model.workschedule = Workschedule.fromDto(model.workschedule, "Compensation");
        }
        if (originEntity !== "AdjustmentReason" && model.adjustmentReason) {
            model.adjustmentReason = AdjustmentReason.fromDto(model.adjustmentReason, "Compensation");
        }
        return model;
    }
    static toDto(compensation, originEntity) {
        const dto = Object.assign({}, compensation);
        dto.startDate = dto.startDate && moment$i(dto.startDate).format("YYYY-MM-DD");
        dto.endDate = dto.endDate && moment$i(dto.endDate).format("YYYY-MM-DD");
        dto.intervalStart = dto.intervalStart && moment$i(dto.intervalStart).format("HH:mm:ss");
        dto.intervalEnd = dto.intervalEnd && moment$i(dto.intervalEnd).format("HH:mm:ss");
        dto.createdDate = dto.createdDate && moment$i(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$i(dto.lastModifiedDate).format();
        dto.numberOfHours = convertTimeToMinutes(dto.numberOfHours);
        delete dto.label;
        if (originEntity !== "Employee" && dto.employee) {
            dto.employee = Employee.toDto(dto.employee, "Compensation");
        }
        if (originEntity !== "Situation" && dto.situation) {
            dto.situation = Situation.toDto(dto.situation, "Compensation");
        }
        if (originEntity !== "Workschedule" && dto.workschedule) {
            dto.workschedule = Workschedule.toDto(dto.workschedule, "Compensation");
        }
        if (originEntity !== "AdjustmentReason" && dto.adjustmentReason) {
            dto.adjustmentReason = AdjustmentReason.toDto(dto.adjustmentReason, "Compensation");
        }
        return dto;
    }
    /*{CA:CLASS_METHODS:START}*/
    static convertMinuteToTime(minutes, monthMinute) {
        const minute = minutes.toString();
        return convertMinutesToTime(minute, monthMinute);
    }
}
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let CompensationService = class CompensationService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/compensation`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
};
CompensationService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
CompensationService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [HttpClient, MessageService, TranslateService])
], CompensationService);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let AdjustmentReasonSituationService = class AdjustmentReasonSituationService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/adjustmentReasonSituation`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
};
AdjustmentReasonSituationService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
AdjustmentReasonSituationService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [HttpClient, MessageService, TranslateService])
], AdjustmentReasonSituationService);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let SituationClockingEventService = class SituationClockingEventService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/situationClockingEvent`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
};
SituationClockingEventService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
SituationClockingEventService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [HttpClient, MessageService, TranslateService])
], SituationClockingEventService);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
const moment$j = moment_; // @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PROJECT_IMPORTS:END}*/
let CompensationFormComponent = class CompensationFormComponent {
    constructor(
    /*{CA:INJECTIONS:START}*/
    companyClockingEventIndicationsService, 
    /*{CA:INJECTIONS:END}*/
    compensationService, router, route, messageService, confirmationService, formBuilder, translate, hotkeysService, fieldCustomization, focusService, adjustmentReasonSituationService, workscheduleService, employeeService, situationService, situationClockingEventService) {
        this.companyClockingEventIndicationsService = companyClockingEventIndicationsService;
        this.compensationService = compensationService;
        this.router = router;
        this.route = route;
        this.messageService = messageService;
        this.confirmationService = confirmationService;
        this.formBuilder = formBuilder;
        this.translate = translate;
        this.hotkeysService = hotkeysService;
        this.fieldCustomization = fieldCustomization;
        this.focusService = focusService;
        this.adjustmentReasonSituationService = adjustmentReasonSituationService;
        this.workscheduleService = workscheduleService;
        this.employeeService = employeeService;
        this.situationService = situationService;
        this.situationClockingEventService = situationClockingEventService;
        this.localeConfig = {};
        this.currencyLocaleOptions = {};
        this.permissions = {};
        this.allPermissions = {};
        this.mainPanelCollapsed = false;
        this.compensationType = [
            { label: this.translate.instant("hcm_clocking_event_foundation.general.compensation_type_v_1"), value: CompensationType.V1 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.compensation_type_v_2"), value: CompensationType.V2 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.compensation_type_v_4"), value: CompensationType.V4 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.compensation_type_v_5"), value: CompensationType.V5 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.compensation_type_v_6"), value: CompensationType.V6 },
        ];
        this.adjustmentReasonLookupDisplayFields = ["adjustmentReason.code", "adjustmentReason.name"];
        this.adjustmentReasonAdvancedDisplayFields = ["adjustmentReason.code", "adjustmentReason.name"];
        this.adjustmentReasonLookupSeparator = " - ";
        this.workscheduleLookupDisplayFields = ["code", "name"];
        this.workscheduleAdvancedDisplayFields = ["code", "name"];
        this.workscheduleLookupSeparator = " - ";
        this.contractTypeOptions = [
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_employee"), value: "EMPLOYEE" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_director"), value: "DIRECTOR" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_trainee"), value: "TRAINEE" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_aprentice"), value: "APRENTICE" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_third_party"), value: "THIRD_PARTY" },
        ];
        this.employeeLookupDisplayFields = ["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractType"];
        this.employeeAdvancedDisplayFields = ["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractType"];
        this.employeeLookupSeparator = " - ";
        this.situationLookupDisplayFields = ["code", "name"];
        this.situationAdvancedDisplayFields = ["code", "name", "situationType"];
        this.situationLookupSeparator = " - ";
        this.onClose = new Subject();
        this.onLoadFormSubject = new Subject();
        this.onCloseObservable = this.onClose.asObservable();
        this.onLoadForm = this.onLoadFormSubject.asObservable();
        this.selectedSituationId = "";
        this.controlAdjustmentReason = false;
        this.mandatoryAdjustmentReasonBySituation = new Map();
        this.mandatoryAdjustmentReason = false;
        this.cacheAdjustmentReasonIsEnable = new Map();
        this.cacheLimitDaysBackwardScheduling = new Map();
        this.enablePeriods = [
            { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_1"), value: PeriodType.V1 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_2"), value: PeriodType.V2 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_3"), value: PeriodType.V3 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_4"), value: PeriodType.V4 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_5"), value: PeriodType.V5 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_6"), value: PeriodType.V6 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_7"), value: PeriodType.V7 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_8"), value: PeriodType.V8 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_9"), value: PeriodType.V9 },
        ];
        this.enableFileds = {
            interval: true,
            numberOfHours: true,
            workSchedule: true,
            periods: this.enablePeriods
        };
        this.controlOfFormFields = new Map([
            [CompensationType.V1, {
                    interval: false,
                    numberOfHours: true,
                    workSchedule: false,
                    periods: [
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_1"), value: PeriodType.V1 },
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_2"), value: PeriodType.V2 },
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_3"), value: PeriodType.V3 },
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_4"), value: PeriodType.V4 },
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_5"), value: PeriodType.V5 },
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_6"), value: PeriodType.V6 },
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_7"), value: PeriodType.V7 },
                    ]
                }],
            [CompensationType.V2, {
                    interval: false,
                    numberOfHours: true,
                    workSchedule: false,
                    periods: [
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_1"), value: PeriodType.V1 },
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_2"), value: PeriodType.V2 },
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_3"), value: PeriodType.V3 },
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_4"), value: PeriodType.V4 },
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_5"), value: PeriodType.V5 },
                    ]
                }],
            [CompensationType.V4, {
                    interval: false,
                    numberOfHours: false,
                    workSchedule: false,
                    periods: [
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_8"), value: PeriodType.V8 },
                        { label: this.translate.instant("hcm_clocking_event_foundation.general.period_type_v_9"), value: PeriodType.V9 },
                    ]
                }],
            [CompensationType.V5, {
                    interval: true,
                    numberOfHours: false,
                    workSchedule: false,
                    periods: []
                }],
            [CompensationType.V6, {
                    interval: true,
                    numberOfHours: false,
                    workSchedule: true,
                    periods: []
                }]
        ]);
        this.adjustmentReasonIsRequired = false;
        this.ngUnsubscribe = new Subject();
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
    ngOnInit() {
        /*{CA:ON_INIT_START:START}*/
        this.route.params.pipe(takeUntil(this.ngUnsubscribe)).subscribe((params) => this.onRouteParamsChange(params));
        /*{CA:ON_INIT_START:END}*/
        this.formGroup = this.getFormGroup();
        if (this.lockedEmployee) {
            this.loadLockedEmployee(this.lockedEmployee);
            this.onSubmitObservable.pipe(takeUntil(this.ngUnsubscribe), filter(name => name === "compensation" || name === "compensationDelete")).subscribe((value) => {
                switch (value) {
                    case "compensation":
                        this.onSave();
                        break;
                    case "compensationDelete":
                        this.onDelete();
                        break;
                    default:
                        break;
                }
            });
            this.onLockedEmployeeChanges
                .pipe(takeUntil(this.ngUnsubscribe))
                .subscribe((value) => {
                this.compensation = value.schedule;
                this.loadLockedEmployee(value);
            });
        }
        else {
            this.setHotkeys();
        }
        this.route.data.pipe(takeUntil(this.ngUnsubscribe)).subscribe((data) => this.onRouteDataChange(data));
        this.adjustmentReasonSearchFields = this.getAdjustmentReasonSearchFields();
        this.adjustmentReasonSearchGridFields = this.getAdjustmentReasonSearchGridFields();
        this.workscheduleSearchFields = this.getWorkscheduleSearchFields();
        this.workscheduleSearchGridFields = this.getWorkscheduleSearchGridFields();
        this.employeeSearchFields = this.getEmployeeSearchFields();
        this.employeeSearchGridFields = this.getEmployeeSearchGridFields();
        this.situationSearchFields = this.getSituationSearchFields();
        this.situationSearchGridFields = this.getSituationSearchGridFields();
        this.setHotkeys();
        /*{CA:ON_INIT_END:START}*/
        /*{CA:ON_INIT_END:END}*/
    }
    ngAfterViewInit() {
        /*{CA:ON_VIEW_INIT_START:START}*/
        /*{CA:ON_VIEW_INIT_START:END}*/
        /*{CA:ON_VIEW_INIT_END:START}*/
        /*{CA:ON_VIEW_INIT_END:END}*/
    }
    ngOnDestroy() {
        /*{CA:ON_DESTROY_START:START}*/
        /*{CA:ON_DESTROY_START:END}*/
        this.ngUnsubscribe.next();
        this.ngUnsubscribe.complete();
        this.cacheLimitDaysBackwardScheduling.clear();
        /*{CA:ON_DESTROY_END:START}*/
        /*{CA:ON_DESTROY_END:END}*/
    }
    setHotkeys() {
        /*{CA:SET_HOTKEYS_START:START}*/
        /*{CA:SET_HOTKEYS_START:END}*/
        this.hotkeysService.add(new Hotkey("alt+shift+x", () => {
            if (this.permissions.excluir) {
                this.onDelete();
            }
            return false;
        }, ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+s", () => {
            if (this.isNew() || this.permissions.editar) {
                this.onSave();
            }
            return false;
        }, ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+c", () => {
            this.onCancel();
            return false;
        }, ["INPUT", "SELECT", "TEXTAREA"]));
        /*{CA:SET_HOTKEYS_END:START}*/
        /*{CA:SET_HOTKEYS_END:END}*/
    }
    isNew() {
        return this.routeParams.compensation === "new";
    }
    onRouteParamsChange(params) {
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:END}*/
        this.routeParams = params;
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:END}*/
    }
    updateSuggestions(value) {
        /*{CA:ON_UPDATE_SUGGESTIONS_START:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_START:END}*/
        if (value.adjustmentReason) {
            value.adjustmentReason.label = this.getSuggestionValue(["code", "name"], "adjustmentReason", value, this.adjustmentReasonLookupSeparator);
            if (value.adjustmentReason.label.trim() === this.adjustmentReasonLookupSeparator.trim()) {
                delete value.adjustmentReason.label;
            }
        }
        if (value.workschedule) {
            value.workschedule.label = this.getSuggestionValue(["code", "name"], "workschedule", value, this.workscheduleLookupSeparator);
            if (value.workschedule.label.trim() === this.workscheduleLookupSeparator.trim()) {
                delete value.workschedule.label;
            }
        }
        if (value.employee) {
            const contractType = value.employee.employmentRelationship.contractType;
            value.employee.employmentRelationship.contractTypeLabel = this.loadLabelFromEnum(contractType);
            value.employee.label = this.getSuggestionValue(["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractTypeLabel"], "employee", value, this.employeeLookupSeparator);
            if (value.employee.label.toString().trim() === this.employeeLookupSeparator.trim()) {
                delete value.employee.label;
            }
        }
        if (value.situation) {
            value.situation.label = this.getSuggestionValue(["code", "name"], "situation", value, this.situationLookupSeparator);
            if (value.situation.label.trim() === this.situationLookupSeparator.trim()) {
                delete value.situation.label;
            }
        }
        /*{CA:ON_UPDATE_SUGGESTIONS_END:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_END:END}*/
    }
    getSuggestionValue(displayFields, ownerEntity, value, separator) {
        return displayFields
            .map(field => this.getProp(value, `${ownerEntity}.${field}`))
            .reduce((acc, val) => `${acc}${separator}${val}`);
    }
    onRouteDataChange(data) {
        /*{CA:ON_ROUTE_DATA_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_START:END}*/
        const { currencySymbol, thousandsSeparator, decimalSeparator } = data.localeConfig.number;
        this.localeConfig = data.localeConfig;
        this.currencyLocaleOptions = {
            align: "left",
            prefix: currencySymbol,
            thousands: thousandsSeparator,
            decimal: decimalSeparator,
        };
        this.permissions = data.allPermissions.compensation;
        this.allPermissions = data.allPermissions;
        this.validateVisualization();
        if (this.lockedEmployee) {
            return;
        }
        else if (data.entity && data.entity[0]) {
            const canEdit = this.permissions.editar;
            if (!canEdit) {
                this.formGroup.disable();
            }
            const value = Compensation.fromDto(data.entity[0]);
            this.updateSuggestions(value);
            this.formGroup.patchValue(value);
            const timeEvaluationDefinition = data.entity[1].timeEvaluationDefinition;
            this.controlAdjustmentReason = timeEvaluationDefinition.controlAdjustmentReason;
            this.cacheAdjustmentReasonIsEnable.set(data.entity[1].company.id, timeEvaluationDefinition.controlAdjustmentReason);
            this.mandatoryAdjustmentReasonValidator(this.formGroup);
            this.setCahceLimmitDays(data.entity[1].company.id, timeEvaluationDefinition.limitDaysBackwardScheduling);
        }
        else {
            this.formGroup.patchValue(new Compensation());
            this.mandatoryAdjustmentReasonValidator(this.formGroup);
        }
        /*{CA:ON_ROUTE_DATA_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_END:END}*/
    }
    onCancel() {
        /*{CA:ON_CANCEL_START:START}*/
        /*{CA:ON_CANCEL_START:END}*/
        this.goBack();
        /*{CA:ON_CANCEL_END:START}*/
        /*{CA:ON_CANCEL_END:END}*/
    }
    onSendFile(filesToDelete, filesToCommit) {
        /*{CA:ON_SEND_FILE:START}*/
        /*{CA:ON_SEND_FILE:END}*/
        const observables = [];
        if (!this.fieldCustomization.isEmpty(filesToDelete)) {
            observables.push(this.fieldCustomization.deleteFiles(filesToDelete));
        }
        if (!this.fieldCustomization.isEmpty(filesToCommit)) {
            observables.push(this.fieldCustomization.commitFiles(filesToCommit));
        }
        if (!this.fieldCustomization.isEmpty(observables)) {
            return forkJoin(observables);
        }
        else {
            return of({});
        }
    }
    onSave() {
        /*{CA:ON_SAVE_START:START}*/
        /*{CA:ON_SAVE_START:END}*/
        this.loading = true;
        this.onLoadFormSubject.next(true);
        if (!this.formGroup.valid) {
            this.loading = false;
            this.onLoadFormSubject.next(false);
            return this.validateAllFormFields(this.formGroup);
        }
        const { filesToDelete, filesToCommit } = this.fieldCustomization.getFiles(this.formGroup);
        this.getSaveObservable()
            .pipe(takeUntil(this.ngUnsubscribe), catchError((err) => {
            this.loading = false;
            this.onLoadFormSubject.next(false);
            return throwError(err);
        }))
            .subscribe(() => {
            /*{CA:ON_SAVE_START_TOP:START}*/
            /*{CA:ON_SAVE_START_TOP:END}*/
            this.onSendFile(filesToDelete, filesToCommit)
                .pipe(takeUntil(this.ngUnsubscribe), catchError((err) => {
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                this.loading = false;
                this.onLoadFormSubject.next(false);
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                return throwError(err);
            }))
                .subscribe(() => {
                this.addMessage("success", "hcm_clocking_event_foundation.general.saved_message_title", "hcm_clocking_event_foundation.general.saved_message_content");
                this.finishOperation();
                /*{CA:ON_SAVE_START_BOTTOM:START}*/
                /*{CA:ON_SAVE_START_BOTTOM:END}*/
            });
        });
        /*{CA:ON_SAVE_END:START}*/
        /*{CA:ON_SAVE_END:END}*/
    }
    finishOperation() {
        if (this.lockedEmployee) {
            this.onClose.next(true);
            this.loading = false;
        }
        else {
            this.goBack();
        }
    }
    onDelete() {
        /*{CA:ON_DELETE_START:START}*/
        /*{CA:ON_DELETE_START:END}*/
        this.confirmationService.confirm({
            message: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_message"),
            header: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_title"),
            accept: () => {
                this.loading = true;
                this.onLoadFormSubject.next(true);
                this.getDeleteObservable()
                    .pipe(takeUntil(this.ngUnsubscribe))
                    .subscribe(() => this.finishOperation());
            },
            reject: () => this.loading = false
        });
        /*{CA:ON_DELETE_END:START}*/
        /*{CA:ON_DELETE_END:END}*/
    }
    getProp(obj, path) {
        return path.split(".").reduce((result, prop) => (result[prop] === undefined ? "" : result[prop]), obj);
    }
    onAdjustmentReasonLookupRequest(value) {
        /*{CA:ON_ADJUSTMENT_REASON_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_ADJUSTMENT_REASON_LOOKUP_REQUEST_START:END}*/
        const sort = ["adjustmentReason.code"].map((field) => ({ field, order: 1 }));
        let filterQuery = this.getAdjustmentReasonSearchFields()
            .filter(({ type }) => isValidFilter(type, value))
            .map(({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$j(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$j(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$j(value).format()}'`;
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        })
            .join(" or ");
        let filters = [`situation eq '${this.selectedSituationId}'`];
        if (filterQuery !== '')
            filters.push(filterQuery);
        filterQuery = filters.join(' and ');
        const displayFields = mergeUnique(this.adjustmentReasonLookupDisplayFields, this.adjustmentReasonAdvancedDisplayFields);
        this.adjustmentReasonSituationService
            .list({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.adjustmentReasonLookupDisplayFields
                    .map(field => {
                    if (field.indexOf(".") > 0)
                        return this.getProp(item, field);
                    return item[field];
                })
                    .join(this.adjustmentReasonLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.adjustmentReasonLookupSuggestions = list.contents;
        });
        /*{CA:ON_ADJUSTMENT_REASON_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_ADJUSTMENT_REASON_LOOKUP_REQUEST_END:END}*/
    }
    onAdjustmentReasonSearchRequest(event) {
        /*{CA:ON_ADJUSTMENT_REASON_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_ADJUSTMENT_REASON_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        const page = first / rows;
        const sort = multiSortMeta;
        let filterQuery = this.getAdjustmentReasonSearchFields()
            .filter(({ name }) => filterData[name] != undefined && filterData[name] != "")
            .map(({ name, type }) => {
            const value = filterData[name];
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$j(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$j(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$j(value).format()}'`;
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`;
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        })
            .join(" and ");
        let filters = [`situation eq '${this.selectedSituationId}'`];
        if (filterQuery !== '')
            filters.push(filterQuery);
        filterQuery = filters.join(' and ');
        this.adjustmentReasonSituationService
            .list({ page, sort, filterQuery })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.adjustmentReasonLookupDisplayFields
                    .map(field => {
                    if (field.indexOf(".") > 0)
                        return this.getProp(item, field);
                    return item[field];
                })
                    .join(this.adjustmentReasonLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.adjustmentReasonSearchGridData = list.contents;
            this.adjustmentReasonSearchTotalRecords = list.totalElements;
        });
        /*{CA:ON_ADJUSTMENT_REASON_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_ADJUSTMENT_REASON_SEARCH_REQUEST_END:END}*/
    }
    onWorkscheduleLookupRequest(value) {
        /*{CA:ON_WORKSCHEDULE_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_WORKSCHEDULE_LOOKUP_REQUEST_START:END}*/
        const sort = this.workscheduleLookupDisplayFields.map((field) => ({ field, order: 1 }));
        const filterQuery = this.getWorkscheduleSearchFields()
            .filter(({ type }) => isValidFilter(type, value))
            .map(({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`; // NOSONAR
            else if (type == FieldType.Date)
                return `${name} eq '${moment$j(value).format("YYYY-MM-DD")}'`; // NOSONAR
            else if (type == FieldType.Time)
                return `${name} eq '${moment$j(value).format("HH:mm:ss")}'`; // NOSONAR
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$j(value).format()}'`; // NOSONAR
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`; // NOSONAR
            else
                return `${name} eq '${value}'`; // NOSONAR
        }) // NOSONAR
            .join(" or "); // NOSONAR
        const displayFields = mergeUnique(this.workscheduleLookupDisplayFields, this.workscheduleAdvancedDisplayFields);
        this.workscheduleService
            .list({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.workscheduleLookupDisplayFields
                    .map(field => {
                    if (field.indexOf(".") > 0)
                        return this.getProp(item, field);
                    return item[field];
                })
                    .join(this.workscheduleLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.workscheduleLookupSuggestions = list.contents;
        });
        /*{CA:ON_WORKSCHEDULE_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_WORKSCHEDULE_LOOKUP_REQUEST_END:END}*/
    }
    onWorkscheduleSearchRequest(event) {
        /*{CA:ON_WORKSCHEDULE_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_WORKSCHEDULE_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        const page = first / rows;
        const sort = multiSortMeta;
        const filterQuery = this.getWorkscheduleSearchFields()
            .filter(({ name }) => filterData[name] != undefined && filterData[name] != "")
            .map(({ name, type }) => {
            const value = filterData[name]; // NOSONAR
            if (typeof value == "number")
                return `${name} eq ${value}`; // NOSONAR
            else if (type == FieldType.Date)
                return `${name} eq '${moment$j(value).format("YYYY-MM-DD")}'`; // NOSONAR
            else if (type == FieldType.Time)
                return `${name} eq '${moment$j(value).format("HH:mm:ss")}'`; // NOSONAR
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$j(value).format()}'`; // NOSONAR
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`; // NOSONAR
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`; // NOSONAR
            else
                return `${name} eq '${value}'`; // NOSONAR
        }) // NOSONAR
            .join(" and "); // NOSONAR
        const displayFields = mergeUnique(this.workscheduleLookupDisplayFields, this.workscheduleAdvancedDisplayFields);
        this.workscheduleService
            .list({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.workscheduleLookupDisplayFields
                    .map(field => {
                    if (field.indexOf(".") > 0)
                        return this.getProp(item, field);
                    return item[field];
                })
                    .join(this.workscheduleLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.workscheduleSearchGridData = list.contents;
            this.workscheduleSearchTotalRecords = list.totalElements;
        });
        /*{CA:ON_WORKSCHEDULE_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_WORKSCHEDULE_SEARCH_REQUEST_END:END}*/
    }
    onEmployeeLookupRequest(value) {
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:END}*/
        const sort = this.employeeLookupDisplayFields.map((field) => ({ field, order: 1 }));
        const filterQuery = this.getEmployeeSearchFields()
            .filter(({ type }) => isValidFilter(type, value))
            .map(({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$j(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$j(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$j(value).format()}'`;
            else if (type == FieldType.Enum)
                return this.loadEnumFromLabel(value).map(enumConstant => `${name} eq '${enumConstant}'`).join(' or ');
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        })
            .filter(filter => filter !== '')
            .join(" or ");
        const displayFields = mergeUnique(this.employeeLookupDisplayFields, this.employeeAdvancedDisplayFields).concat('hireDate', 'dismissalDate');
        this.employeeService
            .listExternalEmployee({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.employeeLookupDisplayFields
                    .map(field => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field);
                    if (field === 'employmentRelationship.contractType') {
                        item[field] = this.loadLabelFromEnum(item[field]);
                    }
                    return item[field];
                })
                    .join(this.employeeLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.employeeLookupSuggestions = list.contents;
        });
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:END}*/
    }
    onEmployeeSearchRequest(event) {
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        const page = first / rows;
        const sort = multiSortMeta;
        const filterQuery = this.getEmployeeSearchFields()
            .filter(({ name }) => filterData[name] != undefined && filterData[name] != "")
            .map(({ name, type }) => {
            const value = filterData[name]; // NOSONAR
            if (typeof value == "number")
                return `${name} eq ${value}`; // NOSONAR
            else if (type == FieldType.Date)
                return `${name} eq '${moment$j(value).format("YYYY-MM-DD")}'`; // NOSONAR
            else if (type == FieldType.Time)
                return `${name} eq '${moment$j(value).format("HH:mm:ss")}'`; // NOSONAR
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$j(value).format()}'`; // NOSONAR
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`; // NOSONAR
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`; // NOSONAR
            else
                return `${name} eq '${value}'`; // NOSONAR
        }) // NOSONAR
            .join(" and "); // NOSONAR
        const displayFields = mergeUnique(this.employeeLookupDisplayFields, this.employeeAdvancedDisplayFields).concat('hireDate', 'dismissalDate');
        this.employeeService
            .listExternalEmployee({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.employeeLookupDisplayFields
                    .map(field => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field);
                    if (field === 'employmentRelationship.contractType') {
                        item[field] = this.loadLabelFromEnum(item[field]);
                    }
                    return item[field];
                })
                    .join(this.employeeLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.employeeSearchGridData = list.contents;
            this.employeeSearchTotalRecords = list.totalElements;
        });
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:END}*/
    }
    onSituationLookupRequest(value) {
        /*{CA:ON_SITUATION_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_SITUATION_LOOKUP_REQUEST_START:END}*/
        const sort = this.situationLookupDisplayFields.map((field) => ({ field, order: 1 }));
        const filterQuery = this.getSituationSearchFields()
            .filter(({ type }) => isValidFilter(type, value))
            .map(({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`; // NOSONAR
            else if (type == FieldType.Date)
                return `${name} eq '${moment$j(value).format("YYYY-MM-DD")}'`; // NOSONAR
            else if (type == FieldType.Time)
                return `${name} eq '${moment$j(value).format("HH:mm:ss")}'`; // NOSONAR
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$j(value).format()}'`; // NOSONAR
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`; // NOSONAR
            else
                return `${name} eq '${value}'`; // NOSONAR
        }) // NOSONAR
            .join(" or "); // NOSONAR
        const displayFields = mergeUnique(this.situationLookupDisplayFields, this.situationAdvancedDisplayFields).concat("situationClockingEvent.mandatoryAdjustmentReason");
        this.situationService
            .list({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.situationLookupDisplayFields
                    .map(field => {
                    if (field.indexOf(".") > 0)
                        return this.getProp(item, field);
                    return item[field];
                })
                    .join(this.situationLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.situationLookupSuggestions = list.contents;
        });
        /*{CA:ON_SITUATION_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_SITUATION_LOOKUP_REQUEST_END:END}*/
    }
    onSituationSearchRequest(event) {
        /*{CA:ON_SITUATION_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_SITUATION_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        const page = first / rows;
        const sort = multiSortMeta;
        const filterQuery = this.getSituationSearchFields()
            .filter(({ name }) => filterData[name] != undefined && filterData[name] != "")
            .map(({ name, type }) => {
            const value = filterData[name]; // NOSONAR
            if (typeof value == "number")
                return `${name} eq ${value}`; // NOSONAR
            else if (type == FieldType.Date)
                return `${name} eq '${moment$j(value).format("YYYY-MM-DD")}'`; // NOSONAR
            else if (type == FieldType.Time)
                return `${name} eq '${moment$j(value).format("HH:mm:ss")}'`; // NOSONAR
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$j(value).format()}'`; // NOSONAR
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`; // NOSONAR
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`; // NOSONAR
            else
                return `${name} eq '${value}'`; // NOSONAR
        }) // NOSONAR
            .join(" and "); // NOSONAR
        const displayFields = mergeUnique(this.situationLookupDisplayFields, this.situationAdvancedDisplayFields).concat("situationClockingEvent.mandatoryAdjustmentReason");
        this.situationService
            .list({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.situationLookupDisplayFields
                    .map(field => {
                    if (field.indexOf(".") > 0)
                        return this.getProp(item, field);
                    return item[field];
                })
                    .join(this.situationLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.situationSearchGridData = list.contents;
            this.situationSearchTotalRecords = list.totalElements;
        });
        /*{CA:ON_SITUATION_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_SITUATION_SEARCH_REQUEST_END:END}*/
    }
    getFormGroup() {
        const formGroup = this.formBuilder.group({
            id: [{ value: undefined, disabled: true }, Validators.compose([])],
            employee: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            startDate: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            endDate: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            intervalStart: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            intervalEnd: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            compensationType: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            periodType: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            numberOfHours: [
                { value: undefined, disabled: false },
                Validators.compose([Validators.required, Validators.max(5999), Validators.pattern(/^([0-9]{1,3}):[0-5][0-9]$/)]),
            ],
            situation: [{ value: undefined, disabled: false }, [Validators.compose([Validators.required])]],
            workschedule: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            adjustmentReason: [{ value: undefined, disabled: false }, Validators.compose([])],
            createdBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            createdDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            custom: [],
        }, {
            validators: [
                this.validLimitDaysBackwardScheduling(),
                this.startDateIsBeforeOrEqualToEndDate()
            ]
        });
        /*{CA:GET_FORM_CONTROLS:START}*/
        this.disableFieldsOnEdit(formGroup);
        formGroup.controls.employee.valueChanges.subscribe(employee => {
            if (employee) {
                let limitDaysBackwardScheduling = this.cacheLimitDaysBackwardScheduling.get(employee.employer.id);
                if (limitDaysBackwardScheduling === undefined) {
                    this.companyClockingEventIndicationsService.get(employee.employer.id).pipe().subscribe((companyClockingEventIndications) => {
                        this.controlAdjustmentReason = companyClockingEventIndications.timeEvaluationDefinition.controlAdjustmentReason;
                        this.cacheAdjustmentReasonIsEnable.set(companyClockingEventIndications.id, companyClockingEventIndications.timeEvaluationDefinition.controlAdjustmentReason);
                        this.setCahceLimmitDays(companyClockingEventIndications.id, companyClockingEventIndications.timeEvaluationDefinition.limitDaysBackwardScheduling);
                        this.mandatoryAdjustmentReasonValidator(formGroup);
                    });
                }
                else {
                    this.mandatoryAdjustmentReasonValidator(formGroup);
                }
            }
            else {
                this.mandatoryAdjustmentReasonValidator(formGroup);
            }
        });
        formGroup.controls.compensationType.valueChanges.subscribe(compensationType => {
            if (compensationType) {
                this.enableFileds = this.controlOfFormFields.get(compensationType);
                this.enableAndDisableFields(formGroup);
            }
        });
        formGroup.controls.situation.valueChanges.subscribe(() => this.mandatoryAdjustmentReasonValidator(formGroup));
        /*{CA:GET_FORM_CONTROLS:END}*/
        return formGroup;
    }
    getAdjustmentReasonSearchFields() {
        const searchFields = [
            new FormField({
                name: "adjustmentReason.code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.adjustment_reason_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "adjustmentReason.name",
                label: this.translate.instant("hcm_clocking_event_foundation.general.adjustment_reason_name"),
                type: FieldType.String,
            }),
        ];
        /*{CA:GET_ADJUSTMENT_REASON_SEARCH_FIELDS:START}*/
        /*{CA:GET_ADJUSTMENT_REASON_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    getAdjustmentReasonSearchGridFields() {
        const searchGridFields = [
            new FormField({
                name: "adjustmentReason.code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.adjustment_reason_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "adjustmentReason.name",
                label: this.translate.instant("hcm_clocking_event_foundation.general.adjustment_reason_name"),
                type: FieldType.String,
            }),
        ];
        /*{CA:GET_ADJUSTMENT_REASON_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_ADJUSTMENT_REASON_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    getWorkscheduleSearchFields() {
        const searchFields = [
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workschedule_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "name",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workschedule_name"),
                type: FieldType.String,
            }),
        ]; // NOSONAR
        /*{CA:GET_WORKSCHEDULE_SEARCH_FIELDS:START}*/
        /*{CA:GET_WORKSCHEDULE_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    getWorkscheduleSearchGridFields() {
        const searchGridFields = [
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workschedule_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "name",
                label: this.translate.instant("hcm_clocking_event_foundation.general.workschedule_name"),
                type: FieldType.String,
            }),
        ]; // NOSONAR
        /*{CA:GET_WORKSCHEDULE_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_WORKSCHEDULE_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    getEmployeeSearchFields() {
        const searchFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions
            })
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    getEmployeeSearchGridFields() {
        const searchGridFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions
            }),
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    getSituationSearchFields() {
        const searchFields = [
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.situation_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "name",
                label: this.translate.instant("hcm_clocking_event_foundation.general.situation_name"),
                type: FieldType.String,
            }),
        ]; // NOSONAR
        /*{CA:GET_SITUATION_SEARCH_FIELDS:START}*/
        /*{CA:GET_SITUATION_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    getSituationSearchGridFields() {
        const searchGridFields = [
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.situation_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "name",
                label: this.translate.instant("hcm_clocking_event_foundation.general.situation_name"),
                type: FieldType.String,
            }),
            new FormField({
                name: "situationType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.situation_situation_type"),
                type: FieldType.Enum,
                placeholder: this.translate.instant("hcm_clocking_event_foundation.general.situation_situation_type_placeholder"),
                options: [
                    { label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_working"), value: "WORKING" },
                    { label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_vacation"), value: "VACATION" },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_illnessaid"),
                        value: "ILLNESSAID",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_laboraccident"),
                        value: "LABORACCIDENT",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_militaryservice"),
                        value: "MILITARYSERVICE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_maternityleave"),
                        value: "MATERNITYLEAVE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_maternityleavenoncriminalabortion"),
                        value: "MATERNITYLEAVENONCRIMINALABORTION",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_maternityleaveanticipationextension"),
                        value: "MATERNITYLEAVEANTICIPATIONEXTENSION",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_citizencompanymaternity"),
                        value: "CITIZENCOMPANYMATERNITY",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_inssmaternityleave"),
                        value: "INSSMATERNITYLEAVE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_leavewithoutcompensation"),
                        value: "LEAVEWITHOUTCOMPENSATION",
                    },
                    { label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_paidleave"), value: "PAIDLEAVE" },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_paternityleave"),
                        value: "PATERNITYLEAVE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_citizencompanypaternity"),
                        value: "CITIZENCOMPANYPATERNITY",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_collectivevacation"),
                        value: "COLLECTIVEVACATION",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_medicalleave"),
                        value: "MEDICALLEAVE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_medicalleavewithoutinss"),
                        value: "MEDICALLEAVEWITHOUTINSS",
                    },
                    { label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_absences"), value: "ABSENCES" },
                    { label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_overtime"), value: "OVERTIME" },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_timeevaluationsituation"),
                        value: "TIMEEVALUATIONSITUATION",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_precautionreadiness"),
                        value: "PRECAUTIONREADINESS",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_tradeunionmandate"),
                        value: "TRADEUNIONMANDATE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_workaccidentleave"),
                        value: "WORKACCIDENTLEAVE",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_workaccidentleavewithoutinss"),
                        value: "WORKACCIDENTLEAVEWITHOUTINSS",
                    },
                    {
                        label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_retirementduetodisability"),
                        value: "RETIREMENTDUETODISABILITY",
                    },
                    { label: this.translate.instant("hcm_clocking_event_foundation.general.situation_type_others"), value: "OTHERS" },
                ],
            }),
        ];
        /*{CA:GET_SITUATION_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_SITUATION_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    goBack() {
        const previousRoute = "../";
        this.router.navigate([previousRoute], { relativeTo: this.route.parent });
    }
    validateAllFormFields(formGroup) {
        Object.keys(formGroup.controls).forEach(field => {
            const control = formGroup.get(field);
            if (control instanceof FormControl)
                control.markAsDirty({ onlySelf: true });
            else if (control instanceof FormGroup)
                this.validateAllFormFields(control);
        });
        this.focusService.focusFirstInvalidInput();
        /*{CA:FOCUS_FIRST_INVALID:START}*/
        /*{CA:FOCUS_FIRST_INVALID:END}*/
    }
    getSaveObservable() {
        const { value } = this.formGroup;
        value.employee = this.formGroup.controls["employee"].value;
        value.id = this.formGroup.controls["id"].value;
        value.compensationType = this.formGroup.controls["compensationType"].value;
        value.periodType = this.formGroup.controls["periodType"].value;
        value.startDate = this.formGroup.controls["startDate"].value;
        value.intervalStart = this.formGroup.controls["intervalStart"].value;
        value.intervalEnd = this.formGroup.controls["intervalEnd"].value;
        value.workschedule = this.formGroup.controls["workschedule"].value;
        value.adjustmentReason = value.adjustmentReason && value.adjustmentReason.adjustmentReason ? value.adjustmentReason.adjustmentReason : value.adjustmentReason;
        const compensationDto = Compensation.toDto(value);
        let observable;
        if (this.isNew() || (this.lockedEmployee && !value.id)) {
            observable = this.compensationService.insert(compensationDto);
        }
        else {
            const id = this.lockedEmployee ? value.id : this.routeParams.compensation;
            observable = this.compensationService.update(id, compensationDto);
        }
        return observable;
    }
    getDeleteObservable() {
        let compensationId = this.routeParams.compensation;
        if (this.lockedEmployee && this.lockedEmployee.schedule) {
            compensationId = this.lockedEmployee.schedule;
        }
        return this.compensationService.delete(compensationId).pipe(tap(() => {
            this.addMessage(// NOSONAR
            "success", // NOSONAR
            "hcm_clocking_event_foundation.general.deleted_message_title", // NOSONAR
            "hcm_clocking_event_foundation.general.deleted_message_content" // NOSONAR
            ); // NOSONAR
        }) // NOSONAR
        ); // NOSONAR
    } // NOSONAR
    validateVisualization() {
        /*{CA:VALIDATE_VISUALIZATION_START:START}*/
        /*{CA:VALIDATE_VISUALIZATION_START:END}*/
        const toValidate = ["employee", "situation", "workschedule"];
        if (!toValidate.every(e => this.allPermissions[e] && this.allPermissions[e].visualizar)) {
            this.router.navigate(["forbidden"]);
        }
        /*{CA:VALIDATE_VISUALIZATION_END:START}*/
        /*{CA:VALIDATE_VISUALIZATION_END:END}*/
    }
    /*{CA:CLASS_METHODS:START}*/
    loadLabelFromEnum(value) {
        return this.contractTypeOptions.filter(r => r.value === value)[0].label;
    }
    loadEnumFromLabel(value) {
        value = value.toUpperCase().trim();
        if (value && value !== undefined) {
            return this.contractTypeOptions
                .filter(r => {
                const match = r.label.toUpperCase().match(value);
                return match !== null && match.length !== 0;
            })
                .map(r => r.value);
        }
        return [];
    }
    validLimitDaysBackwardScheduling() {
        return (control) => {
            const startDate = control.get('startDate');
            const employee = control.get('employee');
            if (employee.value && startDate.value) {
                const limitDate = this.cacheLimitDaysBackwardScheduling.get(employee.value.employer.id);
                if (limitDate && moment$j(startDate.value).isBefore(limitDate, 'day')) {
                    startDate.setErrors({ exceededLimit: { value: startDate.value } });
                }
                else {
                    removeErrorFromField(startDate, 'exceededLimit');
                }
            }
            else {
                removeErrorFromField(startDate, 'exceededLimit');
            }
            return null;
        };
    }
    startDateIsBeforeOrEqualToEndDate() {
        return (control) => {
            const startDateTime = control.get('startDate');
            const endDateTime = control.get('endDate');
            startDateIsBeforeOrEqualToEndDateValidator(startDateTime, endDateTime);
            return null;
        };
    }
    enableAndDisableFields(formGroup) {
        this.enableOrDisableField(this.enableFileds.numberOfHours, formGroup.controls.numberOfHours);
        this.enablePeriods = this.enableFileds.periods;
        if (!this.enablePeriods.some(period => period.value === formGroup.controls.periodType.value)) {
            formGroup.controls.periodType.setValue(null);
        }
        this.enableOrDisableField(this.enablePeriods.length > 0, formGroup.controls.periodType);
        this.enableOrDisableField(this.enableFileds.workSchedule, formGroup.controls.workschedule);
        this.enableOrDisableField(this.enableFileds.interval, formGroup.controls.intervalStart);
        this.enableOrDisableField(this.enableFileds.interval, formGroup.controls.intervalEnd);
    }
    enableOrDisableField(isEnabled, field) {
        if (isEnabled && field.disabled) {
            field.enable();
            field.setErrors({ required: true });
            field.setValidators(Validators.required);
        }
        else if (!isEnabled && field.enabled) {
            field.setValidators(null);
            removeErrorFromField(field, 'required');
            field.setValue(null);
            field.disable();
        }
    }
    setCahceLimmitDays(companyId, limitDays) {
        if (limitDays && limitDays > 0) {
            let limitDate = new Date();
            limitDate.setDate(limitDate.getDate() - limitDays);
            this.cacheLimitDaysBackwardScheduling.set(companyId, limitDate);
        }
        else {
            this.cacheLimitDaysBackwardScheduling.set(companyId, null);
        }
    }
    getAdjustmentReasonInfoSign() {
        return this.translate.instant('hcm_clocking_event_foundation.general.compensation_adjustment_reason_info_sign');
    }
    /**
     * Verifica na definição de apuração se é utilizado e depois se é obrigatório na especialização do ponto da situação.
     *
     * @param formGroup Formulario
     */
    mandatoryAdjustmentReasonValidator(formGroup) {
        const adjustmentReason = formGroup.controls['adjustmentReason'];
        const employee = this.formGroup.controls['employee'];
        const situation = formGroup.controls['situation'];
        if (this.controlAdjustmentReason) {
            if (situation.value && situation.value.situationClockingEvent) {
                if (employee.value) {
                    this.enableAdjustmentReason(situation, adjustmentReason);
                }
                removeErrorFromField(situation, 'hasNotSituationClockingEvent');
            }
            else {
                adjustmentReason.disable();
                adjustmentReason.setValue(null);
                situation.setErrors({ 'hasNotSituationClockingEvent': true });
            }
        }
        else {
            adjustmentReason.disable();
            adjustmentReason.setValue(null);
        }
    }
    enableAdjustmentReason(situation, adjustmentReason) {
        adjustmentReason.enable();
        this.selectedSituationId = situation.value.id;
        if (situation.value.situationClockingEvent.mandatoryAdjustmentReason) {
            adjustmentReason.setValidators(Validators.required);
            adjustmentReason.updateValueAndValidity();
            this.adjustmentReasonIsRequired = true;
        }
        else {
            adjustmentReason.clearValidators();
            adjustmentReason.updateValueAndValidity();
            this.adjustmentReasonIsRequired = false;
        }
    }
    patchValuesAndUpdateSuggestions(value, result) {
        this.updateSuggestions(this.compensation);
        this.formGroup.patchValue(this.compensation);
        this.formGroup.controls["employee"].disable();
        if (value.schedule) {
            this.formGroup.controls["compensationType"].disable();
            this.formGroup.value.compensationType = result.compensationType;
            this.formGroup.controls["periodType"].disable();
            this.formGroup.value.periodType = result.periodType;
            this.formGroup.controls["startDate"].disable();
            this.formGroup.value.startDate = result.startDate;
            this.formGroup.controls["intervalStart"].disable();
            this.formGroup.value.intervalStart = result.intervalStart;
            this.formGroup.controls["intervalEnd"].disable();
            this.formGroup.value.intervalEnd = result.intervalEnd;
            this.formGroup.controls["workschedule"].disable();
            this.formGroup.value.workschedule = result.workschedule;
            this.formGroup.value.id = result.id;
            const canEdit = this.permissions.editar;
            if (!canEdit) {
                this.formGroup.disable();
            }
        }
        this.loading = false;
    }
    loadLockedEmployee(value) {
        const employee = this.formGroup.controls["employee"].value;
        this.formGroup.reset();
        this.formGroup.controls["employee"].setValue(employee);
        if (this.formGroup.controls["employee"].value) {
            this.compensation.startDateTime = moment$j(value.evaluationDate).toDate();
            this.onLoadFormSubject.next(false);
        }
        else {
            this.loading = true;
            this.employeeService.listExternalEmployee({
                filterQuery: `id eq '${value.employeeId}'`,
                displayFields: this.employeeLookupDisplayFields
            }).subscribe((dto) => {
                this.onLoadFormSubject.next(false);
                if (!value.schedule) {
                    this.compensation = new Compensation();
                    this.compensation.startDate = moment$j(value.evaluationDate).toDate();
                    this.compensation.employee = Employee.fromDto(dto.contents[0], "Compensation");
                    this.patchValuesAndUpdateSuggestions(value, null);
                }
                else {
                    this.compensationService.get(value.schedule).subscribe((result) => {
                        this.compensation = Compensation.fromDto(result);
                        this.patchValuesAndUpdateSuggestions(value, result);
                    });
                }
                this.onLoadFormSubject.next(false);
            });
        }
    }
    /*{CA:CLASS_METHODS:END}*/
    addMessage(severity, summary, detail) {
        if (this.lockedEmployee) {
            this.messageService.add({
                key: "employee-clocking-event-adjustment-list-view",
                severity,
                summary: this.translate.instant(summary),
                detail: this.translate.instant(detail),
            });
        }
        else {
            this.messageService.add({
                severity,
                summary: this.translate.instant(summary),
                detail: this.translate.instant(detail),
            });
        }
    }
    disableFieldsOnEdit(formGroup) {
        if (!this.isNew() && !this.lockedEmployee) {
            formGroup.controls.employee.disable();
        }
    }
};
CompensationFormComponent.ctorParameters = () => [
    { type: CompanyClockingEventIndicationsService },
    { type: CompensationService },
    { type: Router },
    { type: ActivatedRoute },
    { type: MessageService },
    { type: ConfirmationService },
    { type: FormBuilder },
    { type: TranslateService },
    { type: HotkeysService },
    { type: FieldCustomizationService },
    { type: FocusService },
    { type: AdjustmentReasonSituationService },
    { type: WorkscheduleService },
    { type: EmployeeService },
    { type: SituationService },
    { type: SituationClockingEventService }
];
__decorate([
    ViewChild("customTemplate"),
    __metadata("design:type", TemplateRef)
], CompensationFormComponent.prototype, "customTemplate", void 0);
__decorate([
    ViewChild("customFormFields"),
    __metadata("design:type", TemplateRef)
], CompensationFormComponent.prototype, "customFormFields", void 0);
__decorate([
    Input(),
    __metadata("design:type", Observable)
], CompensationFormComponent.prototype, "onSubmitObservable", void 0);
__decorate([
    Input(),
    __metadata("design:type", Observable)
], CompensationFormComponent.prototype, "onLockedEmployeeChanges", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], CompensationFormComponent.prototype, "lockedEmployee", void 0);
__decorate([
    Output(),
    __metadata("design:type", Observable)
], CompensationFormComponent.prototype, "onCloseObservable", void 0);
__decorate([
    Output(),
    __metadata("design:type", Observable)
], CompensationFormComponent.prototype, "onLoadForm", void 0);
CompensationFormComponent = __decorate([
    Component({
        template: "<div *ngIf=\"!customTemplate else customTemplate\">\n    <p-confirmDialog acceptLabel=\"{{'hcm_clocking_event_foundation.general.yes' | translate}}\" acceptIcon=\"\" appendTo=\"body\"\n        rejectLabel=\"{{'hcm_clocking_event_foundation.general.no' | translate}}\" rejectIcon=\"\">\n    </p-confirmDialog>\n    <form [formGroup]=\"formGroup\" novalidate>\n        <p-panel\n            *sLoadingState=\"loading\"\n            [styleClass]=\"lockedEmployee ? 'form-group sidebar-panel' : 'form-group'\"\n            [toggleable]=\"false\"\n            [collapsed]=\"mainPanelCollapsed\"\n            [showHeader]=\"!lockedEmployee\">\n            <p-header>\n                {{\"hcm_clocking_event_foundation.general.compensation_form_general_title\" | translate}}\n            </p-header>\n            <div class=\"ui-fluid\" *ngIf=\"!customFormFields else customFormFields\">\n                <div class=\"ui-g\">\n                    <div [attr.data-hidden]=\"true\" class=\"ui-g-12 ui-md-6 ui-xl-6\">\n                        <label for=\"id\">{{\"hcm_clocking_event_foundation.general.compensation_id\" | translate}}</label>\n                        <input #idFormInput type=\"text\" id=\"id\" name=\"id\" pInputText formControlName=\"id\" autocomplete=\"off\"\n                        />\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.employee.visualizar\" class=\"ui-g-12 ui-md-12 ui-lg-12 ui-xl-4 required\">\n                        <label for=\"employee\">{{\"hcm_clocking_event_foundation.general.compensation_employee\" | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"employee\" name=\"employee\" formControlName=\"employee\" [searchFields]=\"employeeSearchFields\"\n                            [searchGridFields]=\"employeeSearchGridFields\" [searchGridData]=\"employeeSearchGridData\"\n                            [multiple]=\"false\" [lookupSuggestions]=\"employeeLookupSuggestions\" (onLookupRequest)=\"onEmployeeLookupRequest($event)\"\n                            (onSearchRequest)=\"onEmployeeSearchRequest($event)\" lookupDisplayField=\"label\"\n                            [searchTotalRecords]=employeeSearchTotalRecords [searchTitle]=\"'hcm_clocking_event_foundation.general.compensation_employee_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\" [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: employeeSearchTotalRecords}\"></s-lookup>\n                         <s-control-errors [control]=\"formGroup.controls['employee']\" [errorMessages]=\"{\n                            required: 'hcm_clocking_event_foundation.general.error_required' | translate\n                          }\"></s-control-errors>\n                    </div>\n                    <div class=\"ui-g-12 ui-md-12 ui-lg-12 ui-xl-4 required\">\n                        <label for=\"compensationType\">{{\"hcm_clocking_event_foundation.general.compensation_compensation_type\" | translate}}</label>\n                        <p-dropdown inputId=\"compensationType\" name=\"compensationType\" [options]=\"compensationType\" formControlName=\"compensationType\"\n                            placeholder=\"{{'hcm_clocking_event_foundation.general.compensation_compensation_type_placeholder' | translate}}\"></p-dropdown>\n                        <s-control-errors [control]=\"formGroup.controls['compensationType']\" [errorMessages]=\"{ required: 'hcm_clocking_event_foundation.general.error_required' | translate }\"></s-control-errors>\n                    </div>\n                    <div [ngClass]=\"enableFileds.periods.length > 0 ? 'ui-g-12 ui-md-12 ui-lg-12 ui-xl-4 required' : 'ui-g-12 ui-md-12 ui-lg-12 ui-xl-4'\">\n                        <label for=\"periodType\">{{\"hcm_clocking_event_foundation.general.compensation_period_type\" | translate}}</label>\n                        <p-dropdown inputId=\"periodType\" name=\"periodType\" [options]=\"enablePeriods\" formControlName=\"periodType\"\n                            placeholder=\"{{'hcm_clocking_event_foundation.general.compensation_period_type_placeholder' | translate}}\"></p-dropdown>\n                        <s-control-errors [control]=\"formGroup.controls['periodType']\"\n                            [errorMessages]=\"{\n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate\n                            }\"\n                        ></s-control-errors>\n                    </div>\n                    <div class=\"ui-g-12 ui-md-6 ui-lg-6 ui-xl-3 required\">\n                        <label for=\"startDate\">{{\"hcm_clocking_event_foundation.general.compensation_start_date\" | translate}}</label>\n                        <p-calendar #startDateFormInput inputId=\"startDate\" name=\"startDate\" [showIcon]=\"true\" formControlName=\"startDate\"\n                            [locale]=\"localeConfig.calendar\" [dateFormat]=\"localeConfig.calendar.dateFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['startDate']\"\n                            [errorMessages]=\"{\n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                                startDateIsBeforeEndDate: 'hcm_clocking_event_foundation.general.error_start_date_after_end_date' | translate,\n                                exceededLimit: 'hcm_clocking_event_foundation.general.error_exceeded_limit_days_backward_scheduling' | translate\n                            }\">\n                        </s-control-errors>\n                    </div>\n                    <div class=\"ui-g-12 ui-md-6 ui-lg-6 ui-xl-3 required\">\n                        <label for=\"endDate\">{{\"hcm_clocking_event_foundation.general.compensation_end_date\" | translate}}</label>\n                        <p-calendar #endDateFormInput inputId=\"endDate\" name=\"endDate\" [showIcon]=\"true\" formControlName=\"endDate\"\n                            [locale]=\"localeConfig.calendar\" [dateFormat]=\"localeConfig.calendar.dateFormat\"></p-calendar>\n                            <s-control-errors [control]=\"formGroup.controls['endDate']\"\n                            [errorMessages]=\"{\n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                                startDateIsBeforeEndDate: 'hcm_clocking_event_foundation.general.error_end_date_before_start_date' | translate\n                            }\">\n                        </s-control-errors>\n                    </div>\n                    <div [ngClass]=\"enableFileds.interval ? 'ui-g-12 ui-md-6 ui-lg-6 ui-xl-3 required' : 'ui-g-12 ui-md-6 ui-lg-6'\" class=\"ui-g-12 ui-md-6 ui-lg-6 ui-xl-3\">\n                        <label for=\"intervalStart\">{{\"hcm_clocking_event_foundation.general.compensation_interval_start\" | translate}}</label>\n                        <p-calendar #intervalStartFormInput inputId=\"intervalStart\" name=\"intervalStart\" [showIcon]=\"true\" [timeOnly]=\"true\"\n                            [showSeconds]=\"false\" icon=\"fa fa-clock-o\" formControlName=\"intervalStart\" [hourFormat]=\"localeConfig.calendar.hourFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['intervalStart']\"\n                            [errorMessages]=\"{\n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate\n                            }\"\n                        ></s-control-errors>\n                    </div>\n                    <div [ngClass]=\"enableFileds.interval ? 'ui-g-12 ui-md-6 ui-lg-6 ui-xl-3 required' : 'ui-g-12 ui-md-6 ui-lg-6 ui-xl-3'\">\n                        <label for=\"intervalEnd\">{{\"hcm_clocking_event_foundation.general.compensation_interval_end\" | translate}}</label>\n                        <p-calendar #intervalEndFormInput inputId=\"intervalEnd\" name=\"intervalEnd\" [showIcon]=\"true\" [timeOnly]=\"true\"\n                            [showSeconds]=\"false\" icon=\"fa fa-clock-o\" formControlName=\"intervalEnd\" [hourFormat]=\"localeConfig.calendar.hourFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['intervalEnd']\"\n                            [errorMessages]=\"{\n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate\n                            }\"\n                        ></s-control-errors>\n                    </div>\n                    <div [ngClass]=\"enableFileds.numberOfHours ? 'ui-g-12 ui-md-12 ui-lg-6 required' : 'ui-g-12 ui-md-12 ui-lg-6'\">\n                        <label for=\"numberOfHours\">{{\"hcm_clocking_event_foundation.general.compensation_number_of_hours\" | translate}}</label>\n                        <p-inputMask\n                            #numberOfHoursFormInput\n                            id=\"numberOfHours\"\n                            name=\"numberOfHours\"\n                            formControlName=\"numberOfHours\"\n                            mask=\"99:99\"\n                            placeholder=\"hh:mm\"\n                        ></p-inputMask>\n                        <s-control-errors [control]=\"formGroup.controls['numberOfHours']\"\n                            [errorMessages]=\"{\n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                                pattern: 'hcm_clocking_event_foundation.general.error_invalid' | translate\n                            }\"></s-control-errors>\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.situation.visualizar\" class=\"ui-g-12 ui-md-12 ui-lg-6 required\">\n                        <label for=\"situation\">{{\"hcm_clocking_event_foundation.general.compensation_situation\" | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"situation\" name=\"situation\" formControlName=\"situation\" [searchFields]=\"situationSearchFields\"\n                            [searchGridFields]=\"situationSearchGridFields\" [searchGridData]=\"situationSearchGridData\"\n                            [multiple]=\"false\" [lookupSuggestions]=\"situationLookupSuggestions\" (onLookupRequest)=\"onSituationLookupRequest($event)\"\n                            (onSearchRequest)=\"onSituationSearchRequest($event)\" lookupDisplayField=\"label\"\n                            [searchTotalRecords]=situationSearchTotalRecords [searchTitle]=\"'hcm_clocking_event_foundation.general.compensation_situation_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\" [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: situationSearchTotalRecords}\"\n                            [emptyFieldLabel]=\"'hcm_clocking_event_foundation.general.list_grid_empty_field' | translate\"></s-lookup>\n                        <s-control-errors [control]=\"formGroup.controls['situation']\" [errorMessages]=\"{\n                            required: 'hcm_clocking_event_foundation.general.error_required' | translate,\n                            hasNotSituationClockingEvent: 'hcm_clocking_event_foundation.general.situation_has_no_situation_clocking_event' | translate\n                        }\"></s-control-errors>\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.adjustmentReason.visualizar\" class=\"ui-g-12 ui-md-12 ui-lg-6\" [ngClass]=\"adjustmentReasonIsRequired ? 'required' : ''\">\n                        <label for=\"adjustmentReason\">{{\"hcm_clocking_event_foundation.general.compensation_adjustment_reason\" | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"adjustmentReason\" name=\"adjustmentReason\" formControlName=\"adjustmentReason\"\n                            [searchFields]=\"adjustmentReasonSearchFields\" [searchGridFields]=\"adjustmentReasonSearchGridFields\"\n                            [searchGridData]=\"adjustmentReasonSearchGridData\" [multiple]=\"false\" [lookupSuggestions]=\"adjustmentReasonLookupSuggestions\"\n                            (onLookupRequest)=\"onAdjustmentReasonLookupRequest($event)\" (onSearchRequest)=\"onAdjustmentReasonSearchRequest($event)\"\n                            lookupDisplayField=\"label\" [searchTotalRecords]=adjustmentReasonSearchTotalRecords\n                            [searchTitle]=\"'hcm_clocking_event_foundation.general.compensation_adjustment_reason_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\" [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: adjustmentReasonSearchTotalRecords}\"\n                            [emptyFieldLabel]=\"'hcm_clocking_event_foundation.general.list_grid_empty_field' | translate\"></s-lookup>\n                            <s-control-errors [control]=\"formGroup.controls['adjustmentReason']\" [errorMessages]=\"{ required: 'hcm_clocking_event_foundation.general.error_required' | translate }\"></s-control-errors>\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.workschedule.visualizar\" [ngClass]=\"enableFileds.workSchedule ? 'ui-g-12 ui-md-12 ui-lg-6 required' : 'ui-g-12 ui-md-12 ui-lg-6'\">\n                        <label for=\"workschedule\">{{\"hcm_clocking_event_foundation.general.compensation_workschedule\" | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"workschedule\" name=\"workschedule\" formControlName=\"workschedule\" [searchFields]=\"workscheduleSearchFields\"\n                            [searchGridFields]=\"workscheduleSearchGridFields\" [searchGridData]=\"workscheduleSearchGridData\"\n                            [multiple]=\"false\" [lookupSuggestions]=\"workscheduleLookupSuggestions\" (onLookupRequest)=\"onWorkscheduleLookupRequest($event)\"\n                            (onSearchRequest)=\"onWorkscheduleSearchRequest($event)\" lookupDisplayField=\"label\"\n                            [searchTotalRecords]=workscheduleSearchTotalRecords [searchTitle]=\"'hcm_clocking_event_foundation.general.compensation_workschedule_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\" [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\" [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\" [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: workscheduleSearchTotalRecords}\"\n                            [emptyFieldLabel]=\"'hcm_clocking_event_foundation.general.list_grid_empty_field' | translate\"></s-lookup>\n                        <s-control-errors [control]=\"formGroup.controls['workschedule']\"\n                            [errorMessages]=\"{\n                                required: 'hcm_clocking_event_foundation.general.error_required' | translate\n                            }\"\n                        ></s-control-errors>\n\n                    </div>\n                </div>\n            </div>\n            <s-custom-fields domain=\"hcm_clocking_event_foundation\" service=\"general\" entity=\"compensation\" formControlName=\"custom\"\n                [invalidErrorLabel]=\"'hcm_clocking_event_foundation.general.error_invalid' | translate\"></s-custom-fields>\n            <div class=\"ui-g\" *ngIf=\"!isNew() && !lockedEmployee\">\n                <div class=\"ui-g-12 ui-inputgroup\">\n                    <label *ngIf=\"formGroup.get('createdBy').value !== ''\" style=\"color: #a3a3a3; margin-right: 2px;\">{{'hcm_clocking_event_foundation.general.created_by' | translate}} {{formGroup.get('createdBy').value}} {{'hcm_clocking_event_foundation.general.at_date' | translate}} {{formGroup.get('createdDate').value | date: 'dd/MM/yyyy'}} {{'hcm_clocking_event_foundation.general.at_time' | translate}} {{formGroup.get('createdDate').value | date: 'HH:mm'}}. </label>\n                    <label *ngIf=\"formGroup.get('lastModifiedBy').value !== ''\" style=\"color: #a3a3a3;\">{{'hcm_clocking_event_foundation.general.updated_by' | translate}} {{formGroup.get('lastModifiedBy').value}} {{'hcm_clocking_event_foundation.general.at_date' | translate}} {{formGroup.get('lastModifiedDate').value | date: 'dd/MM/yyyy'}} {{'hcm_clocking_event_foundation.general.at_time' | translate}} {{formGroup.get('lastModifiedDate').value | date: 'HH:mm'}}.</label>\n                </div>\n            </div>\n            <p-footer *ngIf=\"!lockedEmployee\">\n                <button id=\"save-button\" title=\"{{'hcm_clocking_event_foundation.general.save' | translate}} (Alt + Shift + S)\"\n                    type=\"submit\" pButton label=\"{{'hcm_clocking_event_foundation.general.save' | translate}}\"\n                    (click)=\"onSave()\" *ngIf=\"isNew() || permissions.editar\"></button>\n                <button id=\"delete-button\" title=\"{{'hcm_clocking_event_foundation.general.delete' | translate}} (Alt + Shift + X)\"\n                    type=\"button\" class=\"ui-button-secondary\" pButton label=\"{{'hcm_clocking_event_foundation.general.delete' | translate}}\"\n                    (click)=\"onDelete()\" *ngIf=\"!isNew() && permissions.excluir\" [disabled]=\"loading\"></button>\n                <button id=\"cancel-button\" title=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}} (Alt + Shift + C)\"\n                    type=\"button\" class=\"ui-button-link\" pButton label=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}}\"\n                    (click)=\"onCancel()\"></button>\n            </p-footer>\n        </p-panel>\n    </form>\n</div>\n<!--{CA:FILE_CONTENTS:START}-->\n<!--{CA:FILE_CONTENTS:END}-->\n",
        selector: "cem-compensation-form",
        providers: [
            ConfirmationService,
        ],
        styles: [":host ::ng-deep .sidebar-panel{border:none!important;padding-left:0!important}"]
    }),
    __metadata("design:paramtypes", [CompanyClockingEventIndicationsService,
        CompensationService,
        Router,
        ActivatedRoute,
        MessageService,
        ConfirmationService,
        FormBuilder,
        TranslateService,
        HotkeysService,
        FieldCustomizationService,
        FocusService,
        AdjustmentReasonSituationService,
        WorkscheduleService,
        EmployeeService,
        SituationService,
        SituationClockingEventService])
], CompensationFormComponent);
/*{CA:FILE_CONTENTS:END}*/

let CompensationFormModule = class CompensationFormModule {
};
CompensationFormModule = __decorate([
    NgModule({
        imports: [
            LocaleModule.forChild(),
            SharedScheduleModule,
            DropdownModule,
            InfoSignModule,
            InputMaskModule
        ],
        declarations: [
            CompensationFormComponent
        ],
        exports: [
            CompensationFormComponent
        ]
    })
], CompensationFormModule);

/*{CA:PACKAGE_IMPORTS:START}*/
const moment$k = moment_; // @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PACKAGE_IMPORTS:END}*/
class TimeEvaluationSituationDefinition {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    static fromDto(timeEvaluationSituationDefinitionDto, originEntity) {
        const model = Object.assign({}, timeEvaluationSituationDefinitionDto);
        model.createdDate = model.createdDate && moment$k(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$k(model.lastModifiedDate).toDate();
        const lookupSeparator = " - ";
        const displayFields = ["code", "name"];
        model.label = displayFields.map(field => model[field]).join(lookupSeparator);
        return model;
    }
    static toDto(timeEvaluationSituationDefinition, originEntity) {
        const dto = Object.assign({}, timeEvaluationSituationDefinition);
        dto.createdDate = dto.createdDate && moment$k(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$k(dto.lastModifiedDate).format();
        delete dto.label;
        return dto;
    }
}
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let TimeEvaluationSituationDefinitionService = class TimeEvaluationSituationDefinitionService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/timeEvaluationSituationDefinition`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
    getTimeEvaluationSituationDefinitionHistory(timeEvaluationSituationDefinitionId, id) {
        return this.http
            .get(`hcm_clocking_event_foundation/general/entities/timeEvaluationSituationDefinitionHistory/${id}`)
            .pipe(this.defaultCatch());
    }
    updateTimeEvaluationSituationDefinitionHistory(timeEvaluationSituationDefinitionId, id, timeEvaluationSituationDefinitionHistoryDto) {
        return this.http
            .put(`hcm_clocking_event_foundation/general/entities/timeEvaluationSituationDefinitionHistory/${id}`, timeEvaluationSituationDefinitionHistoryDto)
            .pipe(this.defaultCatch());
    }
    listTimeEvaluationSituationDefinitionHistory(timeEvaluationSituationDefinitionId, listParams) {
        return this.http
            .get(`hcm_clocking_event_foundation/general/entities/timeEvaluationSituationDefinitionHistory`, { params: this.getListQueryParams(listParams) })
            .pipe(this.defaultCatch());
    }
    insertTimeEvaluationSituationDefinitionHistory(timeEvaluationSituationDefinitionId, timeEvaluationSituationDefinitionHistoryDto) {
        return this.http
            .post(`hcm_clocking_event_foundation/general/entities/timeEvaluationSituationDefinitionHistory`, timeEvaluationSituationDefinitionHistoryDto)
            .pipe(this.defaultCatch());
    }
    deleteTimeEvaluationSituationDefinitionHistory(timeEvaluationSituationDefinitionId, id) {
        return this.http
            .delete(`hcm_clocking_event_foundation/general/entities/timeEvaluationSituationDefinitionHistory/${id}`)
            .pipe(this.defaultCatch());
    }
};
TimeEvaluationSituationDefinitionService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
TimeEvaluationSituationDefinitionService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [HttpClient, MessageService, TranslateService])
], TimeEvaluationSituationDefinitionService);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PACKAGE_IMPORTS:START}*/
const moment$l = moment_;
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class TimeEvaluationHistory {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    static fromDto(timeEvaluationHistoryDto, originEntity) {
        const model = Object.assign({}, timeEvaluationHistoryDto);
        model.startDate = model.startDate && moment$l(model.startDate).toDate();
        model.createdDate = model.createdDate && moment$l(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$l(model.lastModifiedDate).toDate();
        const lookupSeparator = " - ";
        const displayFields = ["employee.code", "employee.person.nomPes", "startDate"];
        model.label = displayFields.map(field => model[field]).join(lookupSeparator);
        if (originEntity !== "Employee" && model.employee)
            model.employee = Employee.fromDto(model.employee, "TimeEvaluationHistory");
        if (originEntity !== "TimeEvaluationSituationDefinition" && model.situationDefinition)
            model.situationDefinition = TimeEvaluationSituationDefinition.fromDto(model.situationDefinition, "TimeEvaluationHistory");
        return model;
    }
    static toDto(timeEvaluationHistory, originEntity) {
        const dto = Object.assign({}, timeEvaluationHistory);
        dto.startDate = dto.startDate && moment$l(dto.startDate).format("YYYY-MM-DD");
        dto.createdDate = dto.createdDate && moment$l(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$l(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "Employee" && dto.employee)
            dto.employee = Employee.toDto(dto.employee, "TimeEvaluationHistory");
        if (originEntity !== "TimeEvaluationSituationDefinition" && dto.situationDefinition)
            dto.situationDefinition = TimeEvaluationSituationDefinition.toDto(dto.situationDefinition, "TimeEvaluationHistory");
        return dto;
    }
}
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let TimeEvaluationHistoryService = class TimeEvaluationHistoryService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/timeEvaluationHistory`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
};
TimeEvaluationHistoryService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
TimeEvaluationHistoryService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [HttpClient, MessageService, TranslateService])
], TimeEvaluationHistoryService);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

var Article62CltType;
(function (Article62CltType) {
    Article62CltType["V1"] = "V1";
    Article62CltType["V2"] = "V2";
    Article62CltType["V3"] = "V3";
    Article62CltType["V4"] = "V4";
})(Article62CltType || (Article62CltType = {}));

var TimeEvaluationType;
(function (TimeEvaluationType) {
    TimeEvaluationType["V1"] = "V1";
    TimeEvaluationType["V2"] = "V2";
    TimeEvaluationType["V3"] = "V3";
    TimeEvaluationType["V4"] = "V4";
    TimeEvaluationType["V5"] = "V5";
    TimeEvaluationType["V6"] = "V6";
    TimeEvaluationType["V7"] = "V7";
})(TimeEvaluationType || (TimeEvaluationType = {}));

/*{CA:PROJECT_IMPORTS:START}*/
const moment$m = moment_;
/*{CA:PROJECT_IMPORTS:END}*/
let TimeEvaluationHistoryFormComponent = class TimeEvaluationHistoryFormComponent {
    constructor(
    /*{CA:INJECTIONS:START}*/
    /*{CA:INJECTIONS:END}*/
    timeEvaluationHistoryService, router, route, messageService, confirmationService, formBuilder, translate, hotkeysService, fieldCustomization, focusService, employeeService, timeEvaluationSituationDefinitionService) {
        this.timeEvaluationHistoryService = timeEvaluationHistoryService;
        this.router = router;
        this.route = route;
        this.messageService = messageService;
        this.confirmationService = confirmationService;
        this.formBuilder = formBuilder;
        this.translate = translate;
        this.hotkeysService = hotkeysService;
        this.fieldCustomization = fieldCustomization;
        this.focusService = focusService;
        this.employeeService = employeeService;
        this.timeEvaluationSituationDefinitionService = timeEvaluationSituationDefinitionService;
        this.localeConfig = {};
        this.currencyLocaleOptions = {};
        this.permissions = {};
        this.allPermissions = {};
        this.mainPanelCollapsed = false;
        this.timeEvaluationType = [
            { label: this.translate.instant("hcm_clocking_event_foundation.general.time_evaluation_type_v_1"), value: TimeEvaluationType.V1 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.time_evaluation_type_v_2"), value: TimeEvaluationType.V2 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.time_evaluation_type_v_7"), value: TimeEvaluationType.V7 }
        ];
        this.article62CltType = [
            { label: this.translate.instant("hcm_clocking_event_foundation.general.article_62_clt_type_v_1"), value: Article62CltType.V1 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.article_62_clt_type_v_2"), value: Article62CltType.V2 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.article_62_clt_type_v_3"), value: Article62CltType.V3 },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.article_62_clt_type_v_4"), value: Article62CltType.V4 },
        ];
        this.contractTypeOptions = [
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_employee"), value: "EMPLOYEE" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_director"), value: "DIRECTOR" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_trainee"), value: "TRAINEE" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_aprentice"), value: "APRENTICE" },
            { label: this.translate.instant("hcm_clocking_event_foundation.general.contract_type_third_party"), value: "THIRD_PARTY" },
        ];
        this.employeeLookupDisplayFields = ["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractType"];
        this.employeeAdvancedDisplayFields = ["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractType"];
        this.employeeLookupSeparator = " - ";
        this.situationDefinitionLookupDisplayFields = ["code", "name"];
        this.situationDefinitionAdvancedDisplayFields = ["code", "name"];
        this.situationDefinitionLookupSeparator = " - ";
        /*{CA:CLASS_ATTRIBUTES:START}*/
        this.enableFileds = {
            article62Clt: true,
        };
        this.controlOfFormFields = new Map([
            [TimeEvaluationType.V1, {
                    article62Clt: false
                }],
            [TimeEvaluationType.V2, {
                    article62Clt: true
                }],
            [TimeEvaluationType.V7, {
                    article62Clt: true
                }],
        ]);
        this.onClose = new Subject();
        this.onLoadFormSubject = new Subject();
        this.onCloseObservable = this.onClose.asObservable();
        this.onLoadForm = this.onLoadFormSubject.asObservable();
        this.ngUnsubscribe = new Subject();
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
    ngOnInit() {
        /*{CA:ON_INIT_START:START}*/
        this.route.params.pipe(takeUntil(this.ngUnsubscribe)).subscribe((params) => this.onRouteParamsChange(params));
        /*{CA:ON_INIT_START:END}*/
        this.formGroup = this.getFormGroup();
        if (this.lockedEmployee) {
            this.loadLockedEmployee(this.lockedEmployee);
            this.onSubmitObservable.pipe(takeUntil(this.ngUnsubscribe), filter(name => name === 'timeEvaluationHistory')).subscribe(() => {
                this.onSave();
            });
            this.onLockedEmployeeChanges
                .pipe(takeUntil(this.ngUnsubscribe))
                .subscribe((value) => {
                this.loadLockedEmployee(value);
            });
        }
        else {
            this.setHotkeys();
        }
        this.route.data.pipe(takeUntil(this.ngUnsubscribe)).subscribe((data) => this.onRouteDataChange(data));
        this.employeeSearchFields = this.getEmployeeSearchFields();
        this.employeeSearchGridFields = this.getEmployeeSearchGridFields();
        this.situationDefinitionSearchFields = this.getSituationDefinitionSearchFields();
        this.situationDefinitionSearchGridFields = this.getSituationDefinitionSearchGridFields();
        /*{CA:ON_INIT_END:START}*/
        /*{CA:ON_INIT_END:END}*/
    }
    loadLockedEmployee(value) {
        const employee = this.formGroup.controls['employee'].value;
        this.formGroup.reset();
        this.formGroup.controls['processAdjustment'].setValue(false);
        this.formGroup.controls['approveOwnClocking'].disable();
        // this.formGroup.controls['approveOwnClocking'].setValue(undefined);
        this.formGroup.controls['clockingAdjustment'].disable();
        // this.formGroup.controls['clockingAdjustment'].setValue(undefined);
        this.formGroup.controls['employee'].setValue(employee);
        if (this.formGroup.controls['employee'].value) {
            this.formGroup.controls['startDate'].setValue(moment$m(value.evaluationDate).toDate());
            this.onLoadFormSubject.next(false);
        }
        else {
            this.loading = true;
            this.employeeService.listExternalEmployee({
                filterQuery: `id eq '${value.employeeId}'`,
                displayFields: this.employeeLookupDisplayFields
            }).subscribe((dto) => {
                this.onLoadFormSubject.next(false);
                const timeEvaluationHistory = new TimeEvaluationHistory();
                timeEvaluationHistory.startDate = moment$m(value.evaluationDate).toDate();
                timeEvaluationHistory.employee = Employee.fromDto(dto.contents[0], "TimeEvaluationHistory");
                this.updateSuggestions(timeEvaluationHistory);
                this.formGroup.patchValue(timeEvaluationHistory);
                this.formGroup.controls['employee'].disable();
                this.loading = false;
            });
        }
    }
    ngAfterViewInit() {
        /*{CA:ON_VIEW_INIT_START:START}*/
        /*{CA:ON_VIEW_INIT_START:END}*/
        /*{CA:ON_VIEW_INIT_END:START}*/
        /*{CA:ON_VIEW_INIT_END:END}*/
    }
    ngOnDestroy() {
        /*{CA:ON_DESTROY_START:START}*/
        /*{CA:ON_DESTROY_START:END}*/
        this.ngUnsubscribe.next();
        this.ngUnsubscribe.complete();
        /*{CA:ON_DESTROY_END:START}*/
        /*{CA:ON_DESTROY_END:END}*/
    }
    setHotkeys() {
        /*{CA:SET_HOTKEYS_START:START}*/
        /*{CA:SET_HOTKEYS_START:END}*/
        this.hotkeysService.add(new Hotkey("alt+shift+x", () => {
            if (this.permissions.excluir)
                this.onDelete();
            return false;
        }, ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+s", () => {
            if (this.isNew() || this.permissions.editar)
                this.onSave();
            return false;
        }, ["INPUT", "SELECT", "TEXTAREA"]));
        this.hotkeysService.add(new Hotkey("alt+shift+c", () => {
            this.onCancel();
            return false;
        }, ["INPUT", "SELECT", "TEXTAREA"]));
        /*{CA:SET_HOTKEYS_END:START}*/
        /*{CA:SET_HOTKEYS_END:END}*/
    }
    isNew() {
        return this.routeParams.timeEvaluationHistory == "new";
    }
    onRouteParamsChange(params) {
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_START:END}*/
        this.routeParams = params;
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_PARAMS_CHANGE_END:END}*/
    }
    updateSuggestions(value) {
        /*{CA:ON_UPDATE_SUGGESTIONS_START:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_START:END}*/
        if (value.employee) {
            value.employee.employmentRelationship.contractTypeLabel = this.loadLabelFromEnum(value.employee.employmentRelationship.contractType);
            value.employee.label = this.getSuggestionValue(["employer.codEmp", "code", "person.nomPes", "employmentRelationship.contractTypeLabel"], "employee", value, this.employeeLookupSeparator);
            if (value.employee.label.trim() === this.employeeLookupSeparator.trim()) {
                delete value.employee.label;
            }
        }
        if (value.situationDefinition) {
            value.situationDefinition.label = this.getSuggestionValue(["code", "name"], "situationDefinition", value, this.situationDefinitionLookupSeparator);
            if (value.situationDefinition.label.trim() === this.situationDefinitionLookupSeparator.trim()) {
                delete value.situationDefinition.label;
            }
        }
        /*{CA:ON_UPDATE_SUGGESTIONS_END:START}*/
        /*{CA:ON_UPDATE_SUGGESTIONS_END:END}*/
    }
    getSuggestionValue(displayFields, ownerEntity, value, separator) {
        return displayFields
            .map(field => this.getProp(value, `${ownerEntity}.${field}`))
            .reduce((acc, val) => `${acc}${separator}${val}`);
    }
    onRouteDataChange(data) {
        /*{CA:ON_ROUTE_DATA_CHANGE_START:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_START:END}*/
        const { currencySymbol, thousandsSeparator, decimalSeparator } = data.localeConfig.number;
        this.localeConfig = data.localeConfig;
        this.currencyLocaleOptions = {
            align: "left",
            prefix: currencySymbol,
            thousands: thousandsSeparator,
            decimal: decimalSeparator,
        };
        this.permissions = data.allPermissions.timeEvaluationHistory;
        this.allPermissions = data.allPermissions;
        this.validateVisualization();
        if (this.lockedEmployee) {
            return;
        }
        else if (data.entity) {
            const canEdit = this.permissions.editar;
            if (!canEdit)
                this.formGroup.disable();
            const value = TimeEvaluationHistory.fromDto(data.entity);
            this.updateSuggestions(value);
            this.formGroup.patchValue(value);
        }
        else {
            this.formGroup.patchValue(new TimeEvaluationHistory());
        }
        /*{CA:ON_ROUTE_DATA_CHANGE_END:START}*/
        /*{CA:ON_ROUTE_DATA_CHANGE_END:END}*/
    }
    onCancel() {
        /*{CA:ON_CANCEL_START:START}*/
        /*{CA:ON_CANCEL_START:END}*/
        this.goBack();
        /*{CA:ON_CANCEL_END:START}*/
        /*{CA:ON_CANCEL_END:END}*/
    }
    onSendFile(filesToDelete, filesToCommit) {
        /*{CA:ON_SEND_FILE:START}*/
        /*{CA:ON_SEND_FILE:END}*/
        const observables = [];
        if (!this.fieldCustomization.isEmpty(filesToDelete)) {
            observables.push(this.fieldCustomization.deleteFiles(filesToDelete));
        }
        if (!this.fieldCustomization.isEmpty(filesToCommit)) {
            observables.push(this.fieldCustomization.commitFiles(filesToCommit));
        }
        if (!this.fieldCustomization.isEmpty(observables)) {
            return forkJoin(observables);
        }
        else {
            return of({});
        }
    }
    onSave() {
        /*{CA:ON_SAVE_START:START}*/
        /*{CA:ON_SAVE_START:END}*/
        this.loading = true;
        this.onLoadFormSubject.next(true);
        if (!this.formGroup.valid) {
            this.loading = false;
            this.onLoadFormSubject.next(false);
            return this.validateAllFormFields(this.formGroup);
        }
        const { filesToDelete, filesToCommit } = this.fieldCustomization.getFiles(this.formGroup);
        this.getSaveObservable()
            .pipe(takeUntil(this.ngUnsubscribe), catchError((err) => {
            this.loading = false;
            this.onLoadFormSubject.next(false);
            return throwError(err);
        }))
            .subscribe(() => {
            /*{CA:ON_SAVE_START_TOP:START}*/
            /*{CA:ON_SAVE_START_TOP:END}*/
            this.onSendFile(filesToDelete, filesToCommit)
                .pipe(takeUntil(this.ngUnsubscribe), catchError((err) => {
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                this.loading = false;
                this.onLoadFormSubject.next(false);
                /*{CA:ON_SEND_ERROR_TOP:START}*/
                /*{CA:ON_SEND_ERROR_BOTTOM:END}*/
                return throwError(err);
            }))
                .subscribe(() => {
                this.addMessage("success", "hcm_clocking_event_foundation.general.saved_message_title", "hcm_clocking_event_foundation.general.saved_message_content");
                /*{CA:ON_SAVE_START_BOTTOM:START}*/
                if (this.lockedEmployee) {
                    this.onClose.next();
                    this.loading = false;
                }
                else {
                    this.goBack();
                }
                /*{CA:ON_SAVE_START_BOTTOM:END}*/
            });
        });
        /*{CA:ON_SAVE_END:START}*/
        /*{CA:ON_SAVE_END:END}*/
    }
    onDelete() {
        /*{CA:ON_DELETE_START:START}*/
        /*{CA:ON_DELETE_START:END}*/
        this.confirmationService.confirm({
            message: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_message"),
            header: this.translate.instant("hcm_clocking_event_foundation.general.delete_confirmation_title"),
            accept: () => this.getDeleteObservable()
                .pipe(takeUntil(this.ngUnsubscribe))
                .subscribe(),
        });
        /*{CA:ON_DELETE_END:START}*/
        /*{CA:ON_DELETE_END:END}*/
    }
    getProp(obj, path) {
        return path.split(".").reduce((result, prop) => (result[prop] === undefined ? "" : result[prop]), obj);
    }
    loadLabelFromEnum(value) {
        return this.contractTypeOptions.filter(r => r.value === value)[0].label;
    }
    loadEnumFromLabel(value) {
        value = value.toUpperCase().trim();
        if (value && value !== undefined) {
            return this.contractTypeOptions.filter(r => {
                const match = r.label.toUpperCase().match(value);
                return match !== null && match.length !== 0;
            })
                .map(r => r.value);
        }
        return [];
    }
    onEmployeeLookupRequest(value) {
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_START:END}*/
        const sort = this.employeeLookupDisplayFields.map((field) => ({ field, order: 1 }));
        const filterQuery = this.getEmployeeSearchFields()
            .filter(({ type }) => isValidFilter(type, value))
            .map(({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$m(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$m(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$m(value).format()}'`;
            else if (type == FieldType.Enum)
                return this.loadEnumFromLabel(value).map(enumConstant => `${name} eq '${enumConstant}'`).join(' or ');
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        })
            .filter(filter => filter !== '')
            .join(" or ");
        const displayFields = mergeUnique(this.employeeLookupDisplayFields, this.employeeAdvancedDisplayFields).concat("hireDate", "dismissalDate");
        this.employeeService
            .listExternalEmployee({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.employeeLookupDisplayFields
                    .map(field => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field);
                    if (field === 'employmentRelationship.contractType') {
                        item[field] = this.loadLabelFromEnum(item[field]);
                    }
                    return item[field];
                })
                    .join(this.employeeLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.employeeLookupSuggestions = list.contents;
        });
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_LOOKUP_REQUEST_END:END}*/
    }
    onEmployeeSearchRequest(event) {
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        const page = first / rows;
        const sort = multiSortMeta;
        const filterQuery = this.getEmployeeSearchFields()
            .filter(({ name }) => filterData[name] != undefined && filterData[name] != "")
            .map(({ name, type }) => {
            const value = filterData[name];
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$m(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$m(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$m(value).format()}'`;
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`;
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        })
            .join(" and ");
        const displayFields = mergeUnique(this.employeeLookupDisplayFields, this.employeeAdvancedDisplayFields).concat("hireDate", "dismissalDate");
        this.employeeService
            .listExternalEmployee({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.employeeLookupDisplayFields
                    .map(field => {
                    if (field.indexOf(".") > 0)
                        item[field] = this.getProp(item, field); // NOSONAR
                    if (field === 'employmentRelationship.contractType') { // NOSONAR
                        item[field] = this.loadLabelFromEnum(item[field]); // NOSONAR
                    } // NOSONAR
                    return item[field]; // NOSONAR
                }) // NOSONAR
                    .join(this.employeeLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.employeeSearchGridData = list.contents;
            this.employeeSearchTotalRecords = list.totalElements;
        });
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_EMPLOYEE_SEARCH_REQUEST_END:END}*/
    }
    onSituationDefinitionLookupRequest(value) {
        /*{CA:ON_SITUATION_DEFINITION_LOOKUP_REQUEST_START:START}*/
        /*{CA:ON_SITUATION_DEFINITION_LOOKUP_REQUEST_START:END}*/
        const sort = this.situationDefinitionLookupDisplayFields.map((field) => ({ field, order: 1 }));
        const filterQuery = this.getSituationDefinitionSearchFields()
            .filter(({ type }) => isValidFilter(type, value))
            .map(({ name, type }) => {
            if (typeof value == "number")
                return `${name} eq ${value}`;
            else if (type == FieldType.Date)
                return `${name} eq '${moment$m(value).format("YYYY-MM-DD")}'`;
            else if (type == FieldType.Time)
                return `${name} eq '${moment$m(value).format("HH:mm:ss")}'`;
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$m(value).format()}'`;
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`;
            else
                return `${name} eq '${value}'`;
        })
            .join(" or ");
        const displayFields = mergeUnique(this.situationDefinitionLookupDisplayFields, this.situationDefinitionAdvancedDisplayFields);
        this.timeEvaluationSituationDefinitionService
            .list({ sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.situationDefinitionLookupDisplayFields
                    .map(field => {
                    if (field.indexOf(".") > 0)
                        return this.getProp(item, field);
                    return item[field];
                })
                    .join(this.situationDefinitionLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.situationDefinitionLookupSuggestions = list.contents;
        });
        /*{CA:ON_SITUATION_DEFINITION_LOOKUP_REQUEST_END:START}*/
        /*{CA:ON_SITUATION_DEFINITION_LOOKUP_REQUEST_END:END}*/
    }
    onSituationDefinitionSearchRequest(event) {
        /*{CA:ON_SITUATION_DEFINITION_SEARCH_REQUEST_START:START}*/
        /*{CA:ON_SITUATION_DEFINITION_SEARCH_REQUEST_START:END}*/
        const { first, rows, multiSortMeta, filterData } = event;
        const page = first / rows;
        const sort = multiSortMeta;
        const filterQuery = this.getSituationDefinitionSearchFields()
            .filter(({ name }) => filterData[name] != undefined && filterData[name] != "")
            .map(({ name, type }) => {
            const value = filterData[name]; // NOSONAR
            if (typeof value == "number")
                return `${name} eq ${value}`; // NOSONAR
            else if (type == FieldType.Date)
                return `${name} eq '${moment$m(value).format("YYYY-MM-DD")}'`; // NOSONAR
            else if (type == FieldType.Time)
                return `${name} eq '${moment$m(value).format("HH:mm:ss")}'`; // NOSONAR
            else if (type == FieldType.DateTime)
                return `${name} eq '${moment$m(value).format()}'`; // NOSONAR
            else if (type == FieldType.Enum)
                return `${name} eq '${value}'`; // NOSONAR
            else if (type == FieldType.String)
                return `containing(upper(${name}), upper('${value.replace(/'/g, "\\'")}'))`; // NOSONAR
            else
                return `${name} eq '${value}'`; // NOSONAR
        }) // NOSONAR
            .join(" and "); // NOSONAR
        const displayFields = mergeUnique(this.situationDefinitionLookupDisplayFields, this.situationDefinitionAdvancedDisplayFields);
        this.timeEvaluationSituationDefinitionService
            .list({ page, sort, filterQuery, displayFields })
            .pipe(takeUntil(this.ngUnsubscribe))
            .pipe(map((list) => (Object.assign(Object.assign({}, list), { contents: list.contents.map((item) => (Object.assign(Object.assign({}, item), { label: this.situationDefinitionLookupDisplayFields
                    .map(field => {
                    if (field.indexOf(".") > 0)
                        return this.getProp(item, field);
                    return item[field];
                })
                    .join(this.situationDefinitionLookupSeparator) }))) }))))
            .subscribe((list) => {
            this.situationDefinitionSearchGridData = list.contents;
            this.situationDefinitionSearchTotalRecords = list.totalElements;
        });
        /*{CA:ON_SITUATION_DEFINITION_SEARCH_REQUEST_END:START}*/
        /*{CA:ON_SITUATION_DEFINITION_SEARCH_REQUEST_END:END}*/
    }
    getFormGroup() {
        const formGroup = this.formBuilder.group({
            id: [{ value: undefined, disabled: true }, Validators.compose([])],
            employee: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            startDate: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            timeEvaluationType: [{ value: undefined, disabled: false }, Validators.compose([Validators.required])],
            processAdjustment: [{ value: false, disabled: false }, Validators.compose([])],
            clockingAdjustment: [{ value: false, disabled: true }, Validators.compose([])],
            approveOwnClocking: [{ value: false, disabled: true }, Validators.compose([])],
            article62Clt: [{ value: undefined, disabled: true }, Validators.compose([Validators.required])],
            situationDefinition: [{ value: undefined, disabled: false }, Validators.compose([])],
            createdBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            createdDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedBy: [{ value: undefined, disabled: true }, Validators.compose([])],
            lastModifiedDate: [{ value: undefined, disabled: true }, Validators.compose([])],
            custom: [],
        });
        /*{CA:GET_FORM_CONTROLS:START}*/
        formGroup.controls.timeEvaluationType.valueChanges.subscribe(timeEvaluationType => {
            if (timeEvaluationType) {
                this.enableFileds = this.controlOfFormFields.get(timeEvaluationType);
                this.enableAndDisableFields(formGroup);
            }
        });
        formGroup.controls['processAdjustment'].valueChanges.subscribe(value => {
            const control = this.formGroup.controls['clockingAdjustment'];
            if (value) {
                control.enable();
                control.setValue(false);
            }
            else {
                control.disable();
                control.setValue(undefined);
            }
        });
        formGroup.controls['clockingAdjustment'].valueChanges.subscribe(value => {
            const control = this.formGroup.controls['approveOwnClocking'];
            if (value) {
                control.enable();
                control.setValue(false);
            }
            else {
                control.disable();
                control.setValue(undefined);
            }
        });
        this.disableFieldsOnEdit(formGroup);
        /*{CA:GET_FORM_CONTROLS:END}*/
        return formGroup;
    }
    getEmployeeSearchFields() {
        const searchFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions
            })
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    getEmployeeSearchGridFields() {
        const searchGridFields = [
            new FormField({
                name: "employer.codEmp",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employer_cod_emp"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "person.nomPes",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_person_nom_pes"),
                type: FieldType.String,
            }),
            new FormField({
                name: "employmentRelationship.contractType",
                label: this.translate.instant("hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type"),
                type: FieldType.Enum,
                options: this.contractTypeOptions
            }),
        ];
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_EMPLOYEE_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    getSituationDefinitionSearchFields() {
        const searchFields = [
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.time_evaluation_situation_definition_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "name",
                label: this.translate.instant("hcm_clocking_event_foundation.general.time_evaluation_situation_definition_name"),
                type: FieldType.String,
            }),
        ];
        /*{CA:GET_SITUATION_DEFINITION_SEARCH_FIELDS:START}*/
        /*{CA:GET_SITUATION_DEFINITION_SEARCH_FIELDS:END}*/
        return searchFields;
    }
    getSituationDefinitionSearchGridFields() {
        const searchGridFields = [
            new FormField({
                name: "code",
                label: this.translate.instant("hcm_clocking_event_foundation.general.time_evaluation_situation_definition_code"),
                type: FieldType.Integer,
            }),
            new FormField({
                name: "name",
                label: this.translate.instant("hcm_clocking_event_foundation.general.time_evaluation_situation_definition_name"),
                type: FieldType.String,
            }),
        ];
        /*{CA:GET_SITUATION_DEFINITION_SEARCH_GRID_FIELDS:START}*/
        /*{CA:GET_SITUATION_DEFINITION_SEARCH_GRID_FIELDS:END}*/
        return searchGridFields;
    }
    goBack() {
        const previousRoute = "../";
        this.router.navigate([previousRoute], { relativeTo: this.route.parent });
    }
    validateAllFormFields(formGroup) {
        Object.keys(formGroup.controls).forEach(field => {
            const control = formGroup.get(field);
            if (control instanceof FormControl)
                control.markAsDirty({ onlySelf: true });
            else if (control instanceof FormGroup)
                this.validateAllFormFields(control);
        });
        this.focusService.focusFirstInvalidInput();
        /*{CA:FOCUS_FIRST_INVALID:START}*/
        /*{CA:FOCUS_FIRST_INVALID:END}*/
    }
    getSaveObservable() {
        const { value } = this.formGroup;
        value.employee = this.formGroup.controls['employee'].value;
        const timeEvaluationHistoryDto = TimeEvaluationHistory.toDto(value);
        let observable;
        if (this.isNew() || (this.lockedEmployee && !value.id)) {
            observable = this.timeEvaluationHistoryService.insert(timeEvaluationHistoryDto);
        }
        else {
            const id = this.routeParams.timeEvaluationHistory;
            observable = this.timeEvaluationHistoryService.update(id, timeEvaluationHistoryDto);
        }
        return observable;
    }
    getDeleteObservable() {
        return this.timeEvaluationHistoryService.delete(this.routeParams.timeEvaluationHistory).pipe(tap(() => {
            this.addMessage(// NOSONAR
            "success", // NOSONAR
            "hcm_clocking_event_foundation.general.deleted_message_title", // NOSONAR
            "hcm_clocking_event_foundation.general.deleted_message_content" // NOSONAR
            ); // NOSONAR
            this.goBack(); // NOSONAR
        }) // NOSONAR
        ); // NOSONAR
    }
    validateVisualization() {
        /*{CA:VALIDATE_VISUALIZATION_START:START}*/
        /*{CA:VALIDATE_VISUALIZATION_START:END}*/
        const toValidate = ["employee"];
        if (!toValidate.every(e => this.allPermissions[e] && this.allPermissions[e].visualizar)) {
            this.router.navigate(["forbidden"]);
        }
        /*{CA:VALIDATE_VISUALIZATION_END:START}*/
        /*{CA:VALIDATE_VISUALIZATION_END:END}*/
    }
    /*{CA:CLASS_METHODS:START}*/
    enableAndDisableFields(formGroup) {
        this.enableOrDisableField(this.enableFileds.article62Clt, formGroup.controls.article62Clt);
    }
    enableOrDisableField(isEnabled, field) {
        if (isEnabled && field.disabled) {
            field.enable();
            field.setErrors({ required: true });
            field.setValidators(Validators.required);
        }
        else if (!isEnabled && field.enabled) {
            field.setValidators(Validators.compose([]));
            removeErrorFromField(field, 'required');
            field.setValue(undefined);
            field.disable();
            field.markAsPristine();
        }
    }
    getClockingAdjustment() {
        return this.translate.instant('hcm_clocking_event_foundation.general.time_evaluation_history_clocking_adjustment_info_sign');
    }
    getApproveOwnClocking() {
        return this.translate.instant('hcm_clocking_event_foundation.general.time_evaluation_history_approve_own_clocking_info_sign');
    }
    getArticle62Clt() {
        return this.translate.instant('hcm_clocking_event_foundation.general.time_evaluation_history_article_62_clt_info_sign');
    }
    /*{CA:CLASS_METHODS:END}*/
    addMessage(severity, summary, detail) {
        if (this.lockedEmployee) {
            this.messageService.add({
                key: "employee-clocking-event-adjustment-list-view",
                severity,
                summary: this.translate.instant(summary),
                detail: this.translate.instant(detail),
            });
        }
        else {
            this.messageService.add({
                severity,
                summary: this.translate.instant(summary),
                detail: this.translate.instant(detail),
            });
        }
    }
    setFalseValuesIfProcessAdjustedDisabled() {
        if (!this.formGroup.get('processAdjustment').value) {
            this.formGroup.get('clockingAdjustment').setValue(false);
            this.formGroup.get('approveOwnClocking').setValue(false);
        }
    }
    setFalseValueIfClockingAdjustmentDisabled() {
        if (!this.formGroup.get('clockingAdjustment').value) {
            this.formGroup.get('approveOwnClocking').setValue(false);
        }
    }
    verifyRequired() {
        if (this.formGroup.get('timeEvaluationType').value === "V2") {
            return true;
        }
        if (this.formGroup.get('timeEvaluationType').value === "V7") {
            return true;
        }
        return false;
    }
    disableFieldsOnEdit(formGroup) {
        if (!this.isNew() && !this.lockedEmployee) {
            formGroup.controls.employee.disable();
        }
    }
};
TimeEvaluationHistoryFormComponent.ctorParameters = () => [
    { type: TimeEvaluationHistoryService },
    { type: Router },
    { type: ActivatedRoute },
    { type: MessageService },
    { type: ConfirmationService },
    { type: FormBuilder },
    { type: TranslateService },
    { type: HotkeysService },
    { type: FieldCustomizationService },
    { type: FocusService },
    { type: EmployeeService },
    { type: TimeEvaluationSituationDefinitionService }
];
__decorate([
    ViewChild("customTemplate"),
    __metadata("design:type", TemplateRef)
], TimeEvaluationHistoryFormComponent.prototype, "customTemplate", void 0);
__decorate([
    ViewChild("customFormFields"),
    __metadata("design:type", TemplateRef)
], TimeEvaluationHistoryFormComponent.prototype, "customFormFields", void 0);
__decorate([
    ViewChild("clockingAdjustmentInputSwitch"),
    __metadata("design:type", InputSwitch)
], TimeEvaluationHistoryFormComponent.prototype, "clockingAdjustmentInputSwitch", void 0);
__decorate([
    Input(),
    __metadata("design:type", Observable)
], TimeEvaluationHistoryFormComponent.prototype, "onSubmitObservable", void 0);
__decorate([
    Input(),
    __metadata("design:type", Observable)
], TimeEvaluationHistoryFormComponent.prototype, "onLockedEmployeeChanges", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], TimeEvaluationHistoryFormComponent.prototype, "lockedEmployee", void 0);
__decorate([
    Output(),
    __metadata("design:type", Observable)
], TimeEvaluationHistoryFormComponent.prototype, "onCloseObservable", void 0);
__decorate([
    Output(),
    __metadata("design:type", Observable)
], TimeEvaluationHistoryFormComponent.prototype, "onLoadForm", void 0);
TimeEvaluationHistoryFormComponent = __decorate([
    Component({
        template: "<div *ngIf=\"!customTemplate else customTemplate\">\n    <p-confirmDialog acceptLabel=\"{{'hcm_clocking_event_foundation.general.yes' | translate}}\" acceptIcon=\"\"\n        rejectLabel=\"{{'hcm_clocking_event_foundation.general.no' | translate}}\" rejectIcon=\"\">\n    </p-confirmDialog>\n    <form [formGroup]=\"formGroup\" novalidate>\n        <p-panel *sLoadingState=\"loading\" [styleClass]=\"lockedEmployee ? 'form-group sidebar-panel' : 'form-group'\"\n            [toggleable]=\"false\" [collapsed]=\"mainPanelCollapsed\" [showHeader]=\"!lockedEmployee\">\n            <p-header>\n                {{\"hcm_clocking_event_foundation.general.time_evaluation_history_form_general_title\" | translate}}\n            </p-header>\n            <div class=\"ui-fluid\" *ngIf=\"!customFormFields else customFormFields\">\n                <div class=\"ui-g\">\n                    <div [attr.data-hidden]=\"true\" class=\"ui-g-12 ui-md-6\">\n                        <label for=\"id\">{{\"hcm_clocking_event_foundation.general.time_evaluation_history_id\" |\n                            translate}}</label>\n                        <input #idFormInput type=\"text\" id=\"id\" name=\"id\" pInputText formControlName=\"id\"\n                            autocomplete=\"off\" />\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.employee.visualizar\" class=\"ui-g-12 required\"\n                        [ngClass]=\"lockedEmployee ? '' : 'ui-md-6'\">\n                        <label for=\"employee\">{{\"hcm_clocking_event_foundation.general.time_evaluation_history_employee\"\n                            | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"employee\" name=\"employee\" formControlName=\"employee\"\n                            [searchFields]=\"employeeSearchGridFields\" [searchGridFields]=\"employeeSearchGridFields\"\n                            [searchGridData]=\"employeeSearchGridData\" [multiple]=\"false\"\n                            [lookupSuggestions]=\"employeeLookupSuggestions\"\n                            (onLookupRequest)=\"onEmployeeLookupRequest($event)\"\n                            (onSearchRequest)=\"onEmployeeSearchRequest($event)\" lookupDisplayField=\"label\"\n                            [searchTotalRecords]=employeeSearchTotalRecords\n                            [searchTitle]=\"'hcm_clocking_event_foundation.general.time_evaluation_history_employee_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\"\n                            [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\"\n                            [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\"\n                            [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: employeeSearchTotalRecords}\">\n                        </s-lookup>\n                        <s-control-errors [control]=\"formGroup.controls['employee']\"\n                            [errorMessages]=\"{ required: 'hcm_clocking_event_foundation.general.error_required' | translate }\">\n                        </s-control-errors>\n                    </div>\n                    <div class=\"ui-g-12 ui-md-6 required\">\n                        <label\n                            for=\"startDate\">{{\"hcm_clocking_event_foundation.general.time_evaluation_history_start_date\"\n                            | translate}}</label>\n                        <p-calendar #startDateFormInput inputId=\"startDate\" name=\"startDate\" [showIcon]=\"true\"\n                            formControlName=\"startDate\" [locale]=\"localeConfig.calendar\"\n                            [dateFormat]=\"localeConfig.calendar.dateFormat\"></p-calendar>\n                        <s-control-errors [control]=\"formGroup.controls['startDate']\" [errorMessages]=\"{\n                            required: 'hcm_clocking_event_foundation.general.error_required' | translate }\">\n                        </s-control-errors>\n                    </div>\n                    <div class=\"ui-g-12 ui-md-6 required\" [ngClass]=\"lockedEmployee ? '' : 'ui-lg-4'\">\n                        <label\n                            for=\"timeEvaluationType\">{{\"hcm_clocking_event_foundation.general.time_evaluation_history_time_evaluation_type\"\n                            | translate}}</label>\n                        <p-dropdown inputId=\"timeEvaluationType\" name=\"timeEvaluationType\"\n                            [options]=\"timeEvaluationType\" formControlName=\"timeEvaluationType\"\n                            placeholder=\"{{'hcm_clocking_event_foundation.general.time_evaluation_history_time_evaluation_type_placeholder' | translate}}\">\n                        </p-dropdown>\n                        <s-control-errors [control]=\"formGroup.controls['timeEvaluationType']\"\n                            [errorMessages]=\"{ required: 'hcm_clocking_event_foundation.general.error_required' | translate }\">\n                        </s-control-errors>\n                    </div>\n\n                    <div class=\"ui-g-12 ui-md-6\" [ngClass]=\"lockedEmployee ? '' : 'ui-lg-4'\">\n                        <label\n                            for=\"article62Clt\">{{\"hcm_clocking_event_foundation.general.time_evaluation_history_article_62_clt\"\n                            | translate}}\n                            <span [ngClass]=\"verifyRequired() ? ' required' : ' ' \">\n                                <label style=\"display: inline\"></label>\n                            </span>\n                            <span *sInfoSign=\"getArticle62Clt()\"></span>\n                        </label>\n                        <p-dropdown inputId=\"article62Clt\" name=\"article62Clt\" [options]=\"article62CltType\"\n                            formControlName=\"article62Clt\"\n                            placeholder=\"{{'hcm_clocking_event_foundation.general.time_evaluation_history_article_62_clt_placeholder' | translate}}\">\n                        </p-dropdown>\n                        <s-control-errors [control]=\"formGroup.controls['article62Clt']\"\n                            [errorMessages]=\"{ required: 'hcm_clocking_event_foundation.general.error_required' | translate }\">\n                        </s-control-errors>\n                    </div>\n                    <div [attr.data-hidden]=\"!allPermissions?.timeEvaluationSituationDefinition.visualizar\"\n                        class=\"ui-g-12 ui-md-6\" [ngClass]=\"lockedEmployee ? '' : 'ui-lg-4'\">\n                        <label\n                            for=\"situationDefinition\">{{\"hcm_clocking_event_foundation.general.time_evaluation_history_situation_definition\"\n                            | translate}}</label>\n                        <s-lookup dataKey=\"id\" id=\"situationDefinition\" name=\"situationDefinition\"\n                            formControlName=\"situationDefinition\" [searchFields]=\"situationDefinitionSearchFields\"\n                            [searchGridFields]=\"situationDefinitionSearchGridFields\"\n                            [searchGridData]=\"situationDefinitionSearchGridData\" [multiple]=\"false\"\n                            [lookupSuggestions]=\"situationDefinitionLookupSuggestions\"\n                            (onLookupRequest)=\"onSituationDefinitionLookupRequest($event)\"\n                            (onSearchRequest)=\"onSituationDefinitionSearchRequest($event)\" lookupDisplayField=\"label\"\n                            [searchTotalRecords]=situationDefinitionSearchTotalRecords\n                            [searchTitle]=\"'hcm_clocking_event_foundation.general.time_evaluation_history_situation_definition_search_title' | translate\"\n                            [searchEmptyTitle]=\"'hcm_clocking_event_foundation.general.nothing_found' | translate\"\n                            [filterLabel]=\"'hcm_clocking_event_foundation.general.filter' | translate\"\n                            [filterTitle]=\"'hcm_clocking_event_foundation.general.filters' | translate\"\n                            [clearLabel]=\"'hcm_clocking_event_foundation.general.clear' | translate\"\n                            [cancelLabel]=\"'hcm_clocking_event_foundation.general.cancel' | translate\"\n                            [selectLabel]=\"'hcm_clocking_event_foundation.general.select' | translate\"\n                            [searchTotalRecordsLabel]=\"'hcm_clocking_event_foundation.general.total_records' | translate: {value: situationDefinitionSearchTotalRecords}\"\n                            [emptyFieldLabel]=\"'hcm_clocking_event_foundation.general.list_grid_empty_field' | translate\">\n                        </s-lookup>\n                    </div>\n                    <div class=\"ui-g-12 ui-md-6\" [ngClass]=\"lockedEmployee ? 'ui-xl-4' : 'ui-lg-4'\">\n                        <label\n                            for=\"processAdjustment\">{{\"hcm_clocking_event_foundation.general.time_evaluation_history_process_adjustment\"\n                            | translate}}</label>\n                        <div class=\"ui-inputgroup\">\n                            <p-inputSwitch (click)=\"setFalseValuesIfProcessAdjustedDisabled()\" id=\"process-adjustment\"\n                                formControlName=\"processAdjustment\"></p-inputSwitch>\n                            <div style=\"padding-right: 0.75em;\"></div>\n                            <ng-container *ngIf=\"formGroup.get('processAdjustment').value; else noProcessAdjustment\">\n                                <span>{{ 'hcm_clocking_event_foundation.general.generic_yes' | translate }}</span>\n                            </ng-container>\n                            <ng-template #noProcessAdjustment>\n                                <span>{{ 'hcm_clocking_event_foundation.general.generic_no' | translate }}</span>\n                            </ng-template>\n                        </div>\n                    </div>\n                    <div class=\"ui-g-12 ui-md-6\" [ngClass]=\"lockedEmployee ? 'ui-xl-4' : 'ui-lg-4'\">\n                        <label for=\"clockingAdjustment\"\n                            *sInfoSign=\"getClockingAdjustment()\">{{\"hcm_clocking_event_foundation.general.time_evaluation_history_clocking_adjustment\"\n                            | translate}}</label>\n                        <div class=\"ui-inputgroup\">\n                            <p-inputSwitch (click)=\"setFalseValueIfClockingAdjustmentDisabled()\"\n                                #clockingAdjustmentInputSwitch [inputId]=\"'clocking-adjustment-input'\"\n                                id=\"clocking-adjustment\" formControlName=\"clockingAdjustment\"></p-inputSwitch>\n                            <div style=\"padding-right: 0.75em;\"></div>\n                            <ng-container *ngIf=\"formGroup.get('clockingAdjustment').value; else noClockingAdjustment\">\n                                <span> {{ 'hcm_clocking_event_foundation.general.generic_yes' | translate }}</span>\n                            </ng-container>\n                            <ng-template #noClockingAdjustment>\n                                <span [appDescriptionSwitch]=\"formGroup.get('clockingAdjustment')\"\n                                    [parentComponent]=\"formGroup.get('processAdjustment')\"\n                                    [defaultStyle]=\"false\"></span>\n                            </ng-template>\n                        </div>\n                    </div>\n                    <div class=\"ui-g-12 ui-md-6\" [ngClass]=\"lockedEmployee ? 'ui-xl-4' : 'ui-lg-4'\">\n                        <label for=\"approveOwnClocking\"\n                            *sInfoSign=\"getApproveOwnClocking()\">{{\"hcm_clocking_event_foundation.general.time_evaluation_history_approve_own_clocking\"\n                            | translate}}</label>\n                        <div class=\"ui-inputgroup\">\n                            <p-inputSwitch id=\"approve-own-clocking\" formControlName=\"approveOwnClocking\">\n                            </p-inputSwitch>\n                            <div style=\"padding-right: 0.75em;\"></div>\n                            <ng-container *ngIf=\"formGroup.get('approveOwnClocking').value; else noApproveOwnClocking\">\n                                <span> {{ 'hcm_clocking_event_foundation.general.generic_yes' | translate }}</span>\n                            </ng-container>\n                            <ng-template #noApproveOwnClocking>\n                                <span [appDescriptionSwitch]=\"formGroup.get('approveOwnClocking')\"\n                                    [parentComponent]=\"formGroup.get('clockingAdjustment')\"\n                                    [defaultStyle]=\"false\"></span>\n                            </ng-template>\n                        </div>\n                    </div>\n                </div>\n            </div>\n            <s-custom-fields domain=\"hcm_clocking_event_foundation\" service=\"general\"\n                *ngIf=\"formGroup.controls['custom']\" entity=\"timeEvaluationHistory\" formControlName=\"custom\"\n                [invalidErrorLabel]=\"'hcm_clocking_event_foundation.general.error_invalid' | translate\">\n            </s-custom-fields>\n            <div class=\"ui-g\" *ngIf=\"!isNew() && !lockedEmployee\">\n                <div class=\"ui-g-12 ui-inputgroup\">\n                    <label *ngIf=\"formGroup.get('createdBy').value !== ''\"\n                        style=\"color: #a3a3a3; margin-right: 2px;\">{{'hcm_clocking_event_foundation.general.created_by'\n                        | translate}} {{formGroup.get('createdBy').value}}\n                        {{'hcm_clocking_event_foundation.general.at_date' | translate}}\n                        {{formGroup.get('createdDate').value | date: 'dd/MM/yyyy'}}\n                        {{'hcm_clocking_event_foundation.general.at_time' | translate}}\n                        {{formGroup.get('createdDate').value | date: 'HH:mm'}}. </label>\n                    <label *ngIf=\"formGroup.get('lastModifiedBy').value !== ''\"\n                        style=\"color: #a3a3a3;\">{{'hcm_clocking_event_foundation.general.updated_by' | translate}}\n                        {{formGroup.get('lastModifiedBy').value}} {{'hcm_clocking_event_foundation.general.at_date' |\n                        translate}} {{formGroup.get('lastModifiedDate').value | date: 'dd/MM/yyyy'}}\n                        {{'hcm_clocking_event_foundation.general.at_time' | translate}}\n                        {{formGroup.get('lastModifiedDate').value | date: 'HH:mm'}}.</label>\n                </div>\n            </div>\n            <p-footer *ngIf=\"!lockedEmployee\">\n                <button id=\"save-button\"\n                    title=\"{{'hcm_clocking_event_foundation.general.save' | translate}} (Alt + Shift + S)\" type=\"submit\"\n                    pButton label=\"{{'hcm_clocking_event_foundation.general.save' | translate}}\" (click)=\"onSave()\"\n                    *ngIf=\"isNew() || permissions.editar\"></button>\n                <button id=\"delete-button\"\n                    title=\"{{'hcm_clocking_event_foundation.general.delete' | translate}} (Alt + Shift + X)\"\n                    type=\"button\" class=\"ui-button-secondary\" pButton\n                    label=\"{{'hcm_clocking_event_foundation.general.delete' | translate}}\" (click)=\"onDelete()\"\n                    *ngIf=\"!isNew() && permissions.excluir\" [disabled]=\"loading\"></button>\n                <button id=\"cancel-button\"\n                    title=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}} (Alt + Shift + C)\"\n                    type=\"button\" class=\"ui-button-link\" pButton\n                    label=\"{{'hcm_clocking_event_foundation.general.cancel' | translate}}\"\n                    (click)=\"onCancel()\"></button>\n            </p-footer>\n        </p-panel>\n    </form>\n</div>\n<!--{CA:FILE_CONTENTS:START}-->\n<!--{CA:FILE_CONTENTS:END}-->",
        providers: [
            ConfirmationService,
        ],
        /*{CA:COMPONENT_CONFIG:START}*/
        selector: "cem-time-evaluation-history-form"
        /*{CA:COMPONENT_CONFIG:END}*/
        ,
        styles: [":host ::ng-deep .sidebar-panel{border:none!important;padding-left:0!important}"]
    }),
    __metadata("design:paramtypes", [TimeEvaluationHistoryService,
        Router,
        ActivatedRoute,
        MessageService,
        ConfirmationService,
        FormBuilder,
        TranslateService,
        HotkeysService,
        FieldCustomizationService,
        FocusService,
        EmployeeService,
        TimeEvaluationSituationDefinitionService])
], TimeEvaluationHistoryFormComponent);
/*{CA:FILE_CONTENTS:END}*/

let TimeEvaluationHistoryFormModule = class TimeEvaluationHistoryFormModule {
};
TimeEvaluationHistoryFormModule = __decorate([
    NgModule({
        imports: [
            LocaleModule.forChild(),
            SharedScheduleModule,
            DropdownModule,
            InfoSignModule
        ],
        declarations: [
            TimeEvaluationHistoryFormComponent
        ],
        exports: [
            TimeEvaluationHistoryFormComponent
        ]
    })
], TimeEvaluationHistoryFormModule);

/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let AdjustmentReasonSituationModule = class AdjustmentReasonSituationModule {
};
AdjustmentReasonSituationModule = __decorate([
    NgModule({
        imports: [
            PermissionsModule.forChild([
                {
                    name: "adjustmentReasonSituation",
                    actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                    uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/adjustmentReasonSituation`,
                },
            ]),
        ],
        providers: [
            AdjustmentReasonSituationService,
        ],
        declarations: [
        /*{CA:MODULE_DECLARATIONS:START}*/
        /*{CA:MODULE_DECLARATIONS:END}*/
        ],
        exports: [
        /*{CA:MODULE_EXPORTS:START}*/
        /*{CA:MODULE_EXPORTS:END}*/
        ],
    })
], AdjustmentReasonSituationModule);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let AdjustmentReasonService = class AdjustmentReasonService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/adjustmentReason`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
    /*{CA:CLASS_METHODS:START}*/
    listAdjustmentReasonsBySituation(situationId) {
        const url = "hcm_clocking_event_foundation/general/queries/getAllAdjustmentReasonsBySituation";
        return this.http
            .post(url, situationId)
            .pipe(this.defaultCatch());
    }
};
AdjustmentReasonService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
AdjustmentReasonService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [HttpClient, MessageService, TranslateService])
], AdjustmentReasonService);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let AdjustmentReasonModule = class AdjustmentReasonModule {
};
AdjustmentReasonModule = __decorate([
    NgModule({
        imports: [
            PermissionsModule.forChild([
                {
                    name: "adjustmentReason",
                    actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                    uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/adjustmentReason`,
                },
            ]),
        ],
        providers: [
            AdjustmentReasonService,
        ],
        declarations: [
        /*{CA:MODULE_DECLARATIONS:START}*/
        /*{CA:MODULE_DECLARATIONS:END}*/
        ],
        exports: [
        /*{CA:MODULE_EXPORTS:START}*/
        /*{CA:MODULE_EXPORTS:END}*/
        ],
    })
], AdjustmentReasonModule);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

let BridgeModule = class BridgeModule {
};
BridgeModule = __decorate([
    NgModule({
        imports: [
            PermissionsModule.forChild([
                {
                    name: "bridge",
                    actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                    uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/bridge`,
                },
            ]),
        ],
        providers: [
            BridgeService
        ]
    })
], BridgeModule);

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let CompanyClockingEventIndicationsModule = class CompanyClockingEventIndicationsModule {
};
CompanyClockingEventIndicationsModule = __decorate([
    NgModule({
        imports: [
            PermissionsModule.forChild([
                {
                    name: "companyClockingEventIndications",
                    actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                    uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/companyClockingEventIndications`,
                },
            ]),
        ],
        providers: [
            CompanyClockingEventIndicationsService,
        ],
        declarations: [
        /*{CA:MODULE_DECLARATIONS:START}*/
        /*{CA:MODULE_DECLARATIONS:END}*/
        ],
        exports: [
        /*{CA:MODULE_EXPORTS:START}*/
        /*{CA:MODULE_EXPORTS:END}*/
        ],
    })
], CompanyClockingEventIndicationsModule);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let CompensationModule = class CompensationModule {
};
CompensationModule = __decorate([
    NgModule({
        imports: [
            PermissionsModule.forChild([
                {
                    name: "compensation",
                    actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                    uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/compensation`,
                },
            ]),
        ],
        providers: [
            CompensationService,
        ],
        declarations: [
        /*{CA:MODULE_DECLARATIONS:START}*/
        /*{CA:MODULE_DECLARATIONS:END}*/
        ],
        exports: [
        /*{CA:MODULE_EXPORTS:START}*/
        /*{CA:MODULE_EXPORTS:END}*/
        ],
    })
], CompensationModule);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

let E001PesService = class E001PesService extends EntityService {
    constructor(http, messageService, translate) {
        super(http, messageService, `erpx_fnd/pessoa/entities/e001pes`, `erpx_fnd/pessoa/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
    }
    listExternalE001Pes(listParams) {
        return this.http
            .get("erpx_fnd/pessoa/entities/e001pes", {
            params: this.getListQueryParams(listParams),
        })
            .pipe(this.defaultCatch());
    }
};
E001PesService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
E001PesService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [HttpClient, MessageService, TranslateService])
], E001PesService);

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let E001PesModule = class E001PesModule {
};
E001PesModule = __decorate([
    NgModule({
        imports: [
            PermissionsModule.forChild([
                {
                    name: "e001pes",
                    actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                    uri: `res://senior.com.br/erpx_fnd/pessoa/entities/e001pes`,
                },
            ]),
        ],
        providers: [
            E001PesService,
        ],
        declarations: [
        /*{CA:MODULE_DECLARATIONS:START}*/
        /*{CA:MODULE_DECLARATIONS:END}*/
        ],
        exports: [
        /*{CA:MODULE_EXPORTS:START}*/
        /*{CA:MODULE_EXPORTS:END}*/
        ],
    })
], E001PesModule);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let EmployeeModule = class EmployeeModule {
};
EmployeeModule = __decorate([
    NgModule({
        imports: [
            PermissionsModule.forChild([
                {
                    name: "employee",
                    actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                    uri: `res://senior.com.br/hcm_contract/employment_contract/entities/employee`,
                },
            ]),
        ],
        providers: [
            EmployeeService,
        ],
        declarations: [
        /*{CA:MODULE_DECLARATIONS:START}*/
        /*{CA:MODULE_DECLARATIONS:END}*/
        ],
        exports: [
        /*{CA:MODULE_EXPORTS:START}*/
        /*{CA:MODULE_EXPORTS:END}*/
        ],
    })
], EmployeeModule);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

let OvertimeAuthorizationModule = class OvertimeAuthorizationModule {
};
OvertimeAuthorizationModule = __decorate([
    NgModule({
        imports: [
            PermissionsModule.forChild([
                {
                    name: "overtimeAuthorization",
                    actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                    uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/overtimeAuthorization`,
                },
            ]),
        ],
        providers: [
            OvertimeAuthorizationService,
        ],
        declarations: [],
        exports: [],
    })
], OvertimeAuthorizationModule);

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let ReadinessModule = class ReadinessModule {
};
ReadinessModule = __decorate([
    NgModule({
        imports: [
            PermissionsModule.forChild([
                {
                    name: "readiness",
                    actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                    uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/readiness`,
                },
            ]),
        ],
        providers: [
            ReadinessService,
        ],
        declarations: [
        /*{CA:MODULE_DECLARATIONS:START}*/
        /*{CA:MODULE_DECLARATIONS:END}*/
        ],
        exports: [
        /*{CA:MODULE_EXPORTS:START}*/
        /*{CA:MODULE_EXPORTS:END}*/
        ],
    })
], ReadinessModule);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let SituationClockingEventModule = class SituationClockingEventModule {
};
SituationClockingEventModule = __decorate([
    NgModule({
        imports: [
            PermissionsModule.forChild([
                {
                    name: "situationClockingEvent",
                    actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                    uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/situationClockingEvent`,
                },
            ]),
        ],
        providers: [
            SituationClockingEventService,
        ],
        declarations: [
        /*{CA:MODULE_DECLARATIONS:START}*/
        /*{CA:MODULE_DECLARATIONS:END}*/
        ],
        exports: [
        /*{CA:MODULE_EXPORTS:START}*/
        /*{CA:MODULE_EXPORTS:END}*/
        ],
    })
], SituationClockingEventModule);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let SituationModule = class SituationModule {
};
SituationModule = __decorate([
    NgModule({
        imports: [
            PermissionsModule.forChild([
                {
                    name: "situation",
                    actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                    uri: `res://senior.com.br/hcm_foundation/general/entities/situation`,
                },
            ]),
        ],
        providers: [
            SituationService,
        ],
        declarations: [
        /*{CA:MODULE_DECLARATIONS:START}*/
        /*{CA:MODULE_DECLARATIONS:END}*/
        ],
        exports: [
        /*{CA:MODULE_EXPORTS:START}*/
        /*{CA:MODULE_EXPORTS:END}*/
        ],
    })
], SituationModule);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let TimeEvaluationDefinitionService = class TimeEvaluationDefinitionService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/timeEvaluationDefinition`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
};
TimeEvaluationDefinitionService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
TimeEvaluationDefinitionService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [HttpClient, MessageService, TranslateService])
], TimeEvaluationDefinitionService);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let TimeEvaluationDefinitionModule = class TimeEvaluationDefinitionModule {
};
TimeEvaluationDefinitionModule = __decorate([
    NgModule({
        imports: [
            PermissionsModule.forChild([
                {
                    name: "timeEvaluationDefinition",
                    actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                    uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/timeEvaluationDefinition`,
                },
            ]),
        ],
        providers: [
            TimeEvaluationDefinitionService,
        ],
        declarations: [
        /*{CA:MODULE_DECLARATIONS:START}*/
        /*{CA:MODULE_DECLARATIONS:END}*/
        ],
        exports: [
        /*{CA:MODULE_EXPORTS:START}*/
        /*{CA:MODULE_EXPORTS:END}*/
        ],
    })
], TimeEvaluationDefinitionModule);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let TimeEvaluationHistoryModule = class TimeEvaluationHistoryModule {
};
TimeEvaluationHistoryModule = __decorate([
    NgModule({
        imports: [
            PermissionsModule.forChild([
                {
                    name: "timeEvaluationHistory",
                    actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                    uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/timeEvaluationHistory`,
                },
            ]),
        ],
        providers: [
            TimeEvaluationHistoryService,
        ],
        declarations: [
        /*{CA:MODULE_DECLARATIONS:START}*/
        /*{CA:MODULE_DECLARATIONS:END}*/
        ],
        exports: [
        /*{CA:MODULE_EXPORTS:START}*/
        /*{CA:MODULE_EXPORTS:END}*/
        ],
    })
], TimeEvaluationHistoryModule);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let TimeEvaluationSituationDefinitionHistoryService = class TimeEvaluationSituationDefinitionHistoryService extends EntityService {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    constructor(http, messageService, translate) {
        super(http, messageService, `hcm_clocking_event_foundation/general/entities/timeEvaluationSituationDefinitionHistory`, `hcm_clocking_event_foundation/general/actions`, translate);
        this.http = http;
        this.messageService = messageService;
        this.translate = translate;
        /*{CA:CONSTRUCTOR_END:START}*/
        /*{CA:CONSTRUCTOR_END:END}*/
    }
};
TimeEvaluationSituationDefinitionHistoryService.ctorParameters = () => [
    { type: HttpClient },
    { type: MessageService },
    { type: TranslateService }
];
TimeEvaluationSituationDefinitionHistoryService = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [HttpClient, MessageService, TranslateService])
], TimeEvaluationSituationDefinitionHistoryService);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let TimeEvaluationSituationDefinitionHistoryModule = class TimeEvaluationSituationDefinitionHistoryModule {
};
TimeEvaluationSituationDefinitionHistoryModule = __decorate([
    NgModule({
        imports: [
            PermissionsModule.forChild([
                {
                    name: "timeEvaluationSituationDefinitionHistory",
                    actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                    uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/timeEvaluationSituationDefinitionHistory`,
                },
            ]),
        ],
        providers: [
            TimeEvaluationSituationDefinitionHistoryService,
        ],
        declarations: [
        /*{CA:MODULE_DECLARATIONS:START}*/
        /*{CA:MODULE_DECLARATIONS:END}*/
        ],
        exports: [
        /*{CA:MODULE_EXPORTS:START}*/
        /*{CA:MODULE_EXPORTS:END}*/
        ],
    })
], TimeEvaluationSituationDefinitionHistoryModule);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let TimeEvaluationSituationDefinitionModule = class TimeEvaluationSituationDefinitionModule {
};
TimeEvaluationSituationDefinitionModule = __decorate([
    NgModule({
        imports: [
            PermissionsModule.forChild([
                {
                    name: "timeEvaluationSituationDefinition",
                    actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                    uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/timeEvaluationSituationDefinition`,
                },
            ]),
        ],
        providers: [
            TimeEvaluationSituationDefinitionService,
        ],
        declarations: [
        /*{CA:MODULE_DECLARATIONS:START}*/
        /*{CA:MODULE_DECLARATIONS:END}*/
        ],
        exports: [
        /*{CA:MODULE_EXPORTS:START}*/
        /*{CA:MODULE_EXPORTS:END}*/
        ],
    })
], TimeEvaluationSituationDefinitionModule);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let WorkScheduleChangeModule = class WorkScheduleChangeModule {
};
WorkScheduleChangeModule = __decorate([
    NgModule({
        imports: [
            PermissionsModule.forChild([
                {
                    name: "workScheduleChange",
                    actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                    uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/workScheduleChange`,
                },
            ]),
        ],
        providers: [
            WorkScheduleChangeService,
        ],
        declarations: [
        /*{CA:MODULE_DECLARATIONS:START}*/
        /*{CA:MODULE_DECLARATIONS:END}*/
        ],
        exports: [
        /*{CA:MODULE_EXPORTS:START}*/
        /*{CA:MODULE_EXPORTS:END}*/
        ],
    })
], WorkScheduleChangeModule);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let WorkscheduleModule = class WorkscheduleModule {
};
WorkscheduleModule = __decorate([
    NgModule({
        imports: [
            PermissionsModule.forChild([
                {
                    name: "workschedule",
                    actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                    uri: `res://senior.com.br/hcm_foundation/work_schedule/entities/workschedule`,
                },
            ]),
        ],
        providers: [
            WorkscheduleService,
        ],
        declarations: [
        /*{CA:MODULE_DECLARATIONS:START}*/
        /*{CA:MODULE_DECLARATIONS:END}*/
        ],
        exports: [
        /*{CA:MODULE_EXPORTS:START}*/
        /*{CA:MODULE_EXPORTS:END}*/
        ],
    })
], WorkscheduleModule);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let WorkshiftChangeModule = class WorkshiftChangeModule {
};
WorkshiftChangeModule = __decorate([
    NgModule({
        imports: [
            PermissionsModule.forChild([
                {
                    name: "workshiftChange",
                    actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                    uri: `res://senior.com.br/hcm_clocking_event_foundation/general/entities/workshiftChange`,
                },
            ]),
        ],
        providers: [
            WorkshiftChangeService,
        ],
        declarations: [
        /*{CA:MODULE_DECLARATIONS:START}*/
        /*{CA:MODULE_DECLARATIONS:END}*/
        ],
        exports: [
        /*{CA:MODULE_EXPORTS:START}*/
        /*{CA:MODULE_EXPORTS:END}*/
        ],
    })
], WorkshiftChangeModule);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let WorkshiftGroupModule = class WorkshiftGroupModule {
};
WorkshiftGroupModule = __decorate([
    NgModule({
        imports: [
            PermissionsModule.forChild([
                {
                    name: "workshiftGroup",
                    actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                    uri: `res://senior.com.br/hcm_foundation/work_schedule/entities/workshiftGroup`,
                },
            ]),
        ],
        providers: [
            WorkshiftGroupService,
        ],
        declarations: [
        /*{CA:MODULE_DECLARATIONS:START}*/
        /*{CA:MODULE_DECLARATIONS:END}*/
        ],
        exports: [
        /*{CA:MODULE_EXPORTS:START}*/
        /*{CA:MODULE_EXPORTS:END}*/
        ],
    })
], WorkshiftGroupModule);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
let WorkshiftModule = class WorkshiftModule {
};
WorkshiftModule = __decorate([
    NgModule({
        imports: [
            PermissionsModule.forChild([
                {
                    name: "workshift",
                    actions: ["Visualizar", "Incluir", "Editar", "Excluir"],
                    uri: `res://senior.com.br/hcm_foundation/work_schedule/entities/workshift`,
                },
            ]),
        ],
        providers: [
            WorkshiftService,
        ],
        declarations: [
        /*{CA:MODULE_DECLARATIONS:START}*/
        /*{CA:MODULE_DECLARATIONS:END}*/
        ],
        exports: [
        /*{CA:MODULE_EXPORTS:START}*/
        /*{CA:MODULE_EXPORTS:END}*/
        ],
    })
], WorkshiftModule);
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

let CoreSchedulesHistoriesModule = class CoreSchedulesHistoriesModule {
};
CoreSchedulesHistoriesModule = __decorate([
    NgModule({
        imports: [
            BridgeModule,
            OvertimeAuthorizationModule,
            EmployeeModule,
            E001PesModule,
            WorkshiftGroupModule,
            WorkshiftModule,
            CompanyClockingEventIndicationsModule,
            TimeEvaluationDefinitionModule,
            SituationModule,
            TimeEvaluationSituationDefinitionModule,
            TimeEvaluationSituationDefinitionHistoryModule,
            SituationClockingEventModule,
            WorkscheduleModule,
            WorkScheduleChangeModule,
            ReadinessModule,
            WorkshiftChangeModule,
            CompensationModule,
            AdjustmentReasonModule,
            AdjustmentReasonSituationModule,
            TimeEvaluationHistoryModule
        ]
    })
], CoreSchedulesHistoriesModule);

/*{CA:PACKAGE_IMPORTS:START}*/
/*{CA:PACKAGE_IMPORTS:END}*/
/*{CA:PROJECT_IMPORTS:START}*/
const moment$n = moment_; // @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PROJECT_IMPORTS:END}*/
class TimeEvaluationDefinition {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    static fromDto(timeEvaluationDefinitionDto, originEntity) {
        const model = Object.assign({}, timeEvaluationDefinitionDto);
        model.createdDate = model.createdDate && moment$n(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$n(model.lastModifiedDate).toDate();
        const lookupSeparator = " - ";
        const displayFields = ["code", "name"];
        model.label = displayFields.map(field => model[field]).join(lookupSeparator);
        if (originEntity !== "Situation" && model.incompleteJourneySituation)
            model.incompleteJourneySituation = Situation.fromDto(model.incompleteJourneySituation, "TimeEvaluationDefinition");
        return model;
    }
    static toDto(timeEvaluationDefinition, originEntity) {
        const dto = Object.assign({}, timeEvaluationDefinition);
        dto.createdDate = dto.createdDate && moment$n(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$n(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "Situation" && dto.incompleteJourneySituation)
            dto.incompleteJourneySituation = Situation.toDto(dto.incompleteJourneySituation, "TimeEvaluationDefinition");
        return dto;
    }
}
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

const moment$o = moment_; // @HACK Necessary because of https://github.com/rollup/rollup/issues/670
class CompanyClockingEventIndications {
    static fromDto(companyClockingEventIndicationsDto, originEntity) {
        const model = Object.assign({}, companyClockingEventIndicationsDto);
        model.createdDate = model.createdDate && moment$o(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$o(model.lastModifiedDate).toDate();
        const lookupSeparator = " - ";
        const displayFields = [
            "timeEvaluationDefinition.code",
            "timeEvaluationDefinition.name",
            "timeEvaluationSituationDefinition.code",
            "timeEvaluationSituationDefinition.name",
        ];
        model.label = displayFields.map(field => model[field]).join(lookupSeparator);
        if (originEntity !== "TimeEvaluationDefinition" && model.timeEvaluationDefinition)
            model.timeEvaluationDefinition = TimeEvaluationDefinition.fromDto(model.timeEvaluationDefinition, "CompanyClockingEventIndications");
        if (originEntity !== "TimeEvaluationSituationDefinition" && model.timeEvaluationSituationDefinition)
            model.timeEvaluationSituationDefinition = TimeEvaluationSituationDefinition.fromDto(model.timeEvaluationSituationDefinition, "CompanyClockingEventIndications");
        return model;
    }
    static toDto(companyClockingEventIndications, originEntity) {
        const dto = Object.assign({}, companyClockingEventIndications);
        dto.createdDate = dto.createdDate && moment$o(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$o(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "TimeEvaluationDefinition" && dto.timeEvaluationDefinition)
            dto.timeEvaluationDefinition = TimeEvaluationDefinition.toDto(dto.timeEvaluationDefinition, "CompanyClockingEventIndications");
        if (originEntity !== "TimeEvaluationSituationDefinition" && dto.timeEvaluationSituationDefinition)
            dto.timeEvaluationSituationDefinition = TimeEvaluationSituationDefinition.toDto(dto.timeEvaluationSituationDefinition, "CompanyClockingEventIndications");
        return dto;
    }
}
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PACKAGE_IMPORTS:START}*/
const moment$p = moment_; // @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
class TimeEvaluationSituationDefinitionHistory {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    static fromDto(timeEvaluationSituationDefinitionHistoryDto, originEntity) {
        const model = Object.assign({}, timeEvaluationSituationDefinitionHistoryDto);
        model.startDate = model.startDate && moment$p(model.startDate).toDate();
        model.endDate = model.endDate && moment$p(model.endDate).toDate();
        model.createdDate = model.createdDate && moment$p(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$p(model.lastModifiedDate).toDate();
        if (model.normalOvertimeSeparationLimit && model.normalOvertimeSeparationLimit !== undefined) {
            model.normalOvertimeSeparationLimit = moment$p().startOf('day').add(model.normalOvertimeSeparationLimit, 'minutes').format('HH:mm:ss');
            model.normalOvertimeSeparationLimit = model.normalOvertimeSeparationLimit && moment$p(model.normalOvertimeSeparationLimit, "HH:mm:ss").toDate();
        }
        if (model.overtimeSeparationLimitDuringRest && model.overtimeSeparationLimitDuringRest !== undefined) {
            model.overtimeSeparationLimitDuringRest = convertMinutesToTime(model.overtimeSeparationLimitDuringRest.toString());
        }
        if (model.overtimeSeparationLimitDuringCompensatedDays && model.overtimeSeparationLimitDuringCompensatedDays !== undefined) {
            model.overtimeSeparationLimitDuringCompensatedDays = convertMinutesToTime(model.overtimeSeparationLimitDuringCompensatedDays.toString());
        }
        if (model.overtimeSeparationLimitDuringHoliday && model.overtimeSeparationLimitDuringHoliday !== undefined) {
            model.overtimeSeparationLimitDuringHoliday = convertMinutesToTime(model.overtimeSeparationLimitDuringHoliday.toString());
        }
        if (model.overtimeSeparationLimitDuringDayOff && model.overtimeSeparationLimitDuringDayOff !== undefined) {
            model.overtimeSeparationLimitDuringDayOff = convertMinutesToTime(model.overtimeSeparationLimitDuringDayOff.toString());
        }
        const lookupSeparator = " - ";
        const displayFields = ["situationDefinition.code", "situationDefinition.name", "startDate", "endDate"];
        model.label = displayFields.map(field => model[field]).join(lookupSeparator);
        if (originEntity !== "TimeEvaluationSituationDefinition" && model.situationDefinition)
            model.situationDefinition = TimeEvaluationSituationDefinition.fromDto(model.situationDefinition, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.workSituation)
            model.workSituation = Situation.fromDto(model.workSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.nightShiftWorkPremium)
            model.nightShiftWorkPremium = Situation.fromDto(model.nightShiftWorkPremium, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.invalidEventsSituation)
            model.invalidEventsSituation = Situation.fromDto(model.invalidEventsSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.vacationPaidLeaveSituation)
            model.vacationPaidLeaveSituation = Situation.fromDto(model.vacationPaidLeaveSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.dailyRestViolationSituation)
            model.dailyRestViolationSituation = Situation.fromDto(model.dailyRestViolationSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.workBreakViolationSituation)
            model.workBreakViolationSituation = Situation.fromDto(model.workBreakViolationSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.absenceSituation)
            model.absenceSituation = Situation.fromDto(model.absenceSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.tardinessSituation)
            model.tardinessSituation = Situation.fromDto(model.tardinessSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.intermediateLeaveSituation)
            model.intermediateLeaveSituation = Situation.fromDto(model.intermediateLeaveSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.earlyLeaveSituation)
            model.earlyLeaveSituation = Situation.fromDto(model.earlyLeaveSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.absenceSituationOnRelayScheduleHolidays)
            model.absenceSituationOnRelayScheduleHolidays = Situation.fromDto(model.absenceSituationOnRelayScheduleHolidays, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.unauthorizedOvertime)
            model.unauthorizedOvertime = Situation.fromDto(model.unauthorizedOvertime, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.overtimeBefore)
            model.overtimeBefore = Situation.fromDto(model.overtimeBefore, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.overtimeEntry)
            model.overtimeEntry = Situation.fromDto(model.overtimeEntry, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.overtimeDuringMeal)
            model.overtimeDuringMeal = Situation.fromDto(model.overtimeDuringMeal, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.leaveOvertime)
            model.leaveOvertime = Situation.fromDto(model.leaveOvertime, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.overtimeAfter)
            model.overtimeAfter = Situation.fromDto(model.overtimeAfter, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.overtimeDuringRest)
            model.overtimeDuringRest = Situation.fromDto(model.overtimeDuringRest, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.overtimeOnCompensatedDays)
            model.overtimeOnCompensatedDays = Situation.fromDto(model.overtimeOnCompensatedDays, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.overtimeDuringHoliday)
            model.overtimeDuringHoliday = Situation.fromDto(model.overtimeDuringHoliday, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.overtimeDuringDayOff)
            model.overtimeDuringDayOff = Situation.fromDto(model.overtimeDuringDayOff, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.overtimeSituationOnRelayScheduleHolidays)
            model.overtimeSituationOnRelayScheduleHolidays = Situation.fromDto(model.overtimeSituationOnRelayScheduleHolidays, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.nightShiftOvertimePremiumSituation)
            model.nightShiftOvertimePremiumSituation = Situation.fromDto(model.nightShiftOvertimePremiumSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.overtimeSeparationBefore)
            model.overtimeSeparationBefore = Situation.fromDto(model.overtimeSeparationBefore, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.overtimeSeparationEntry)
            model.overtimeSeparationEntry = Situation.fromDto(model.overtimeSeparationEntry, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.overtimeSeparationDuringMeal)
            model.overtimeSeparationDuringMeal = Situation.fromDto(model.overtimeSeparationDuringMeal, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.overtimeSeparationLeave)
            model.overtimeSeparationLeave = Situation.fromDto(model.overtimeSeparationLeave, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.overtimeSeparationAfter)
            model.overtimeSeparationAfter = Situation.fromDto(model.overtimeSeparationAfter, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.overtimeSeparationDuringRest)
            model.overtimeSeparationDuringRest = Situation.fromDto(model.overtimeSeparationDuringRest, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.overtimeSeparationDuringCompensatedDays)
            model.overtimeSeparationDuringCompensatedDays = Situation.fromDto(model.overtimeSeparationDuringCompensatedDays, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.overtimeSeparationDuringHoliday)
            model.overtimeSeparationDuringHoliday = Situation.fromDto(model.overtimeSeparationDuringHoliday, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && model.overtimeSeparationDuringDayOff)
            model.overtimeSeparationDuringDayOff = Situation.fromDto(model.overtimeSeparationDuringDayOff, "TimeEvaluationSituationDefinitionHistory");
        return model;
    }
    static toDto(timeEvaluationSituationDefinitionHistory, originEntity) {
        const dto = Object.assign({}, timeEvaluationSituationDefinitionHistory);
        if (dto.normalOvertimeSeparationLimit && dto.normalOvertimeSeparationLimit !== undefined) {
            dto.normalOvertimeSeparationLimit = moment$p(dto.normalOvertimeSeparationLimit).format("HH:mm");
            dto.normalOvertimeSeparationLimit = convertTimeToMinutes(dto.normalOvertimeSeparationLimit);
        }
        if (dto.overtimeSeparationLimitDuringRest && dto.overtimeSeparationLimitDuringRest !== undefined) {
            dto.overtimeSeparationLimitDuringRest = convertTimeToMinutes(dto.overtimeSeparationLimitDuringRest);
        }
        if (dto.overtimeSeparationLimitDuringCompensatedDays && dto.overtimeSeparationLimitDuringCompensatedDays !== undefined) {
            dto.overtimeSeparationLimitDuringCompensatedDays = convertTimeToMinutes(dto.overtimeSeparationLimitDuringCompensatedDays);
        }
        if (dto.overtimeSeparationLimitDuringHoliday && dto.overtimeSeparationLimitDuringHoliday !== undefined) {
            dto.overtimeSeparationLimitDuringHoliday = convertTimeToMinutes(dto.overtimeSeparationLimitDuringHoliday);
        }
        if (dto.overtimeSeparationLimitDuringDayOff && dto.overtimeSeparationLimitDuringDayOff !== undefined) {
            dto.overtimeSeparationLimitDuringDayOff = convertTimeToMinutes(dto.overtimeSeparationLimitDuringDayOff);
        }
        dto.startDate = dto.startDate && moment$p(dto.startDate).format("YYYY-MM-DD");
        dto.endDate = dto.endDate && moment$p(dto.endDate).format("YYYY-MM-DD");
        dto.createdDate = dto.createdDate && moment$p(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$p(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "TimeEvaluationSituationDefinition" && dto.situationDefinition)
            dto.situationDefinition = TimeEvaluationSituationDefinition.toDto(dto.situationDefinition, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.workSituation)
            dto.workSituation = Situation.toDto(dto.workSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.nightShiftWorkPremium)
            dto.nightShiftWorkPremium = Situation.toDto(dto.nightShiftWorkPremium, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.invalidEventsSituation)
            dto.invalidEventsSituation = Situation.toDto(dto.invalidEventsSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.vacationPaidLeaveSituation)
            dto.vacationPaidLeaveSituation = Situation.toDto(dto.vacationPaidLeaveSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.dailyRestViolationSituation)
            dto.dailyRestViolationSituation = Situation.toDto(dto.dailyRestViolationSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.workBreakViolationSituation)
            dto.workBreakViolationSituation = Situation.toDto(dto.workBreakViolationSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.absenceSituation)
            dto.absenceSituation = Situation.toDto(dto.absenceSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.tardinessSituation)
            dto.tardinessSituation = Situation.toDto(dto.tardinessSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.intermediateLeaveSituation)
            dto.intermediateLeaveSituation = Situation.toDto(dto.intermediateLeaveSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.earlyLeaveSituation)
            dto.earlyLeaveSituation = Situation.toDto(dto.earlyLeaveSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.absenceSituationOnRelayScheduleHolidays)
            dto.absenceSituationOnRelayScheduleHolidays = Situation.toDto(dto.absenceSituationOnRelayScheduleHolidays, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.unauthorizedOvertime)
            dto.unauthorizedOvertime = Situation.toDto(dto.unauthorizedOvertime, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.overtimeBefore)
            dto.overtimeBefore = Situation.toDto(dto.overtimeBefore, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.overtimeEntry)
            dto.overtimeEntry = Situation.toDto(dto.overtimeEntry, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.overtimeDuringMeal)
            dto.overtimeDuringMeal = Situation.toDto(dto.overtimeDuringMeal, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.leaveOvertime)
            dto.leaveOvertime = Situation.toDto(dto.leaveOvertime, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.overtimeAfter)
            dto.overtimeAfter = Situation.toDto(dto.overtimeAfter, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.overtimeDuringRest)
            dto.overtimeDuringRest = Situation.toDto(dto.overtimeDuringRest, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.overtimeOnCompensatedDays)
            dto.overtimeOnCompensatedDays = Situation.toDto(dto.overtimeOnCompensatedDays, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.overtimeDuringHoliday)
            dto.overtimeDuringHoliday = Situation.toDto(dto.overtimeDuringHoliday, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.overtimeDuringDayOff)
            dto.overtimeDuringDayOff = Situation.toDto(dto.overtimeDuringDayOff, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.overtimeSituationOnRelayScheduleHolidays)
            dto.overtimeSituationOnRelayScheduleHolidays = Situation.toDto(dto.overtimeSituationOnRelayScheduleHolidays, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.nightShiftOvertimePremiumSituation)
            dto.nightShiftOvertimePremiumSituation = Situation.toDto(dto.nightShiftOvertimePremiumSituation, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.overtimeSeparationBefore)
            dto.overtimeSeparationBefore = Situation.toDto(dto.overtimeSeparationBefore, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.overtimeSeparationEntry)
            dto.overtimeSeparationEntry = Situation.toDto(dto.overtimeSeparationEntry, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.overtimeSeparationDuringMeal)
            dto.overtimeSeparationDuringMeal = Situation.toDto(dto.overtimeSeparationDuringMeal, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.overtimeSeparationLeave)
            dto.overtimeSeparationLeave = Situation.toDto(dto.overtimeSeparationLeave, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.overtimeSeparationAfter)
            dto.overtimeSeparationAfter = Situation.toDto(dto.overtimeSeparationAfter, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.overtimeSeparationDuringRest)
            dto.overtimeSeparationDuringRest = Situation.toDto(dto.overtimeSeparationDuringRest, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.overtimeSeparationDuringCompensatedDays)
            dto.overtimeSeparationDuringCompensatedDays = Situation.toDto(dto.overtimeSeparationDuringCompensatedDays, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.overtimeSeparationDuringHoliday)
            dto.overtimeSeparationDuringHoliday = Situation.toDto(dto.overtimeSeparationDuringHoliday, "TimeEvaluationSituationDefinitionHistory");
        if (originEntity !== "Situation" && dto.overtimeSeparationDuringDayOff)
            dto.overtimeSeparationDuringDayOff = Situation.toDto(dto.overtimeSeparationDuringDayOff, "TimeEvaluationSituationDefinitionHistory");
        return dto;
    }
}
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
const moment$q = moment_; // @HACK Necessary because of https://github.com/rollup/rollup/issues/670
/*{CA:PROJECT_IMPORTS:END}*/
class SituationClockingEvent {
    constructor() {
        this.daytimeSituation = false;
        /*{CA:CLASS_METHODS:START}*/
        /*{CA:CLASS_METHODS:END}*/
    }
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    static fromDto(situationClockingEventDto, originEntity) {
        const model = Object.assign({}, situationClockingEventDto);
        model.createdDate = model.createdDate && moment$q(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$q(model.lastModifiedDate).toDate();
        const lookupSeparator = " - ";
        const displayFields = [
            "id",
            "complementarySituation.code",
            "complementarySituation.name",
            "exceptionSituation",
            "mandatoryAdjustmentReason",
            "daytimeSituation",
            "convertNightHours",
            "obligateAttachmentOnLeave",
            "createdBy",
            "createdDate",
            "lastModifiedBy",
            "lastModifiedDate",
        ];
        model.label = displayFields.map(field => model[field]).join(lookupSeparator);
        if (originEntity !== "Situation" && model.situation)
            model.situation = Situation.fromDto(model.situation, "SituationClockingEvent");
        if (originEntity !== "Situation" && model.complementarySituation)
            model.complementarySituation = Situation.fromDto(model.complementarySituation, "SituationClockingEvent");
        return model;
    }
    static toDto(situationClockingEvent, originEntity) {
        const dto = Object.assign({}, situationClockingEvent);
        dto.createdDate = dto.createdDate && moment$q(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$q(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "Situation" && dto.situation)
            dto.situation = Situation.toDto(dto.situation, "SituationClockingEvent");
        if (originEntity !== "Situation" && dto.complementarySituation)
            dto.complementarySituation = Situation.toDto(dto.complementarySituation, "SituationClockingEvent");
        return dto;
    }
}
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

/*{CA:PROJECT_IMPORTS:START}*/
/*{CA:PROJECT_IMPORTS:END}*/
const moment$r = moment_; // @HACK Necessary because of https://github.com/rollup/rollup/issues/670
class AdjustmentReasonSituation {
    /*{CA:CLASS_ATTRIBUTES:START}*/
    /*{CA:CLASS_ATTRIBUTES:END}*/
    static fromDto(adjustmentReasonSituationDto, originEntity) {
        const model = Object.assign({}, adjustmentReasonSituationDto);
        model.createdDate = model.createdDate && moment$r(model.createdDate).toDate();
        model.lastModifiedDate = model.lastModifiedDate && moment$r(model.lastModifiedDate).toDate();
        const lookupSeparator = " - ";
        const displayFields = [
            "id",
            "situation.code",
            "situation.name",
            "adjustmentReason.code",
            "adjustmentReason.name",
            "createdBy",
            "createdDate",
            "lastModifiedBy",
            "lastModifiedDate",
        ];
        model.label = displayFields.map(field => model[field]).join(lookupSeparator);
        if (originEntity !== "Situation" && model.situation) {
            model.situation = Situation.fromDto(model.situation, "AdjustmentReasonSituation");
        }
        if (originEntity !== "AdjustmentReason" && model.adjustmentReason) {
            model.adjustmentReason = AdjustmentReason.fromDto(model.adjustmentReason, "AdjustmentReasonSituation");
        }
        return model;
    }
    static toDto(adjustmentReasonSituation, originEntity) {
        const dto = Object.assign({}, adjustmentReasonSituation);
        dto.createdDate = dto.createdDate && moment$r(dto.createdDate).format();
        dto.lastModifiedDate = dto.lastModifiedDate && moment$r(dto.lastModifiedDate).format();
        delete dto.label;
        if (originEntity !== "Situation" && dto.situation) {
            dto.situation = Situation.toDto(dto.situation, "AdjustmentReasonSituation");
        }
        if (originEntity !== "AdjustmentReason" && dto.adjustmentReason) {
            dto.adjustmentReason = AdjustmentReason.toDto(dto.adjustmentReason, "AdjustmentReasonSituation");
        }
        return dto;
    }
}
/*{CA:FILE_CONTENTS:START}*/
/*{CA:FILE_CONTENTS:END}*/

var ClockingEventToleranceType;
(function (ClockingEventToleranceType) {
    ClockingEventToleranceType["V1"] = "V1";
    ClockingEventToleranceType["V2"] = "V2";
})(ClockingEventToleranceType || (ClockingEventToleranceType = {}));

var ConsiderClockingEventIntervalType;
(function (ConsiderClockingEventIntervalType) {
    ConsiderClockingEventIntervalType["V1"] = "V1";
    ConsiderClockingEventIntervalType["V2"] = "V2";
    ConsiderClockingEventIntervalType["V3"] = "V3";
    ConsiderClockingEventIntervalType["V4"] = "V4";
})(ConsiderClockingEventIntervalType || (ConsiderClockingEventIntervalType = {}));

var RetroactiveAdjustmentType;
(function (RetroactiveAdjustmentType) {
    RetroactiveAdjustmentType["V1"] = "V1";
    RetroactiveAdjustmentType["V2"] = "V2";
})(RetroactiveAdjustmentType || (RetroactiveAdjustmentType = {}));

var VerifiedDaysControlType;
(function (VerifiedDaysControlType) {
    VerifiedDaysControlType["V0"] = "V0";
    VerifiedDaysControlType["V1"] = "V1";
    VerifiedDaysControlType["V2"] = "V2";
})(VerifiedDaysControlType || (VerifiedDaysControlType = {}));

// Core Module

const fallback = {
    "hcm_clocking_event_foundation.general.click_here": "clique aqui",
    "hcm_clocking_event_foundation.general.compensation_end_date": "Data final",
    "hcm_clocking_event_foundation.general.compensation_interval_end": "Fim do intervalo",
    "hcm_clocking_event_foundation.general.compensation_interval_start": "Início do intervalo",
    "hcm_clocking_event_foundation.general.compensation_start_date": "Data inicial",
    "hcm_clocking_event_foundation.general.confirm_process_message": "O processo acontecerá em segundo plano. Quando concluído informaremos o resultado por notificação.<br><br>Confirma a execução do processo?",
    "hcm_clocking_event_foundation.general.detail_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.detail_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.employees_and_companies_are_empty": "Ao menos um dos filtros deve ser preenchido",
    "hcm_clocking_event_foundation.general.error_end_date_before_start_date": "A data final deve ser maior que a data inicial",
    "hcm_clocking_event_foundation.general.error_start_date_after_dismissal_date": "A data inicial deve ser menor ou igual à data de demissão",
    "hcm_clocking_event_foundation.general.error_start_date_after_end_date_to_end_date": "A data final deve ser maior que a data inicial",
    "hcm_clocking_event_foundation.general.evaluate_process_start": "O processo foi iniciado. Você será notificado quando o processo acabar. O andamento estará disponível na tela de logs de processo. ",
    "hcm_clocking_event_foundation.general.generic_btn_cancel_label": "Cancelar",
    "hcm_clocking_event_foundation.general.generic_btn_select_label": "Selecionar",
    "hcm_clocking_event_foundation.general.generic_clear_label": "Limpar",
    "hcm_clocking_event_foundation.general.generic_filter_label": "Filtrar",
    "hcm_clocking_event_foundation.general.generic_filter_title": "Filtros",
    "hcm_clocking_event_foundation.general.generic_lookup_empty_message": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.generic_n_records_found": "{{value}} registros encontrados",
    "hcm_clocking_event_foundation.general.generic_no_records_found": "Nenhum registro encontrado",
    "hcm_clocking_event_foundation.general.generic_record_found": "{{value}} registro encontrado",
    "hcm_clocking_event_foundation.general.generic_total_records": "{{value}} registro(s) encontrado(s)",
    "hcm_clocking_event_foundation.general.go_to_logs": "Para acessar",
    "hcm_clocking_event_foundation.general.lookup_company_code": "Código",
    "hcm_clocking_event_foundation.general.lookup_company_name": "Nome",
    "hcm_clocking_event_foundation.general.start_date_is_before_end_date_to_end_date": "A data final deve ser maior ou igual à data inicial",
    "hcm_clocking_event_foundation.general.start_date_is_before_end_date_to_start_date": "A data inicial deve ser menor ou igual à data final",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_form_detail_title": "Detalhes da definição de situações da apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_time_evaluation_situation_definition_history_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_time_evaluation_situation_definition_history_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_time_evaluation_situation_definition_history": "Histórico da definição de situações da apuração",
    "hcm_clocking_event_foundation.general.add_collective": "Adicionar coletivamente",
    "hcm_clocking_event_foundation.general.add": "Adicionar",
    "hcm_clocking_event_foundation.general.adjustment_reason_code": "Código",
    "hcm_clocking_event_foundation.general.adjustment_reason_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.adjustment_reason_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.adjustment_reason_form_general_title": "Motivos de acertos",
    "hcm_clocking_event_foundation.general.adjustment_reason_form_title": "Motivos de acertos",
    "hcm_clocking_event_foundation.general.adjustment_reason_id": "Identificador único",
    "hcm_clocking_event_foundation.general.adjustment_reason_list_grid_title": "Lista de motivos de acertos",
    "hcm_clocking_event_foundation.general.adjustment_reason_list_title": "Motivos de acertos",
    "hcm_clocking_event_foundation.general.adjustment_reason_mandatory_observation": "Observação Obrigatória",
    "hcm_clocking_event_foundation.general.adjustment_reason_name": "Descrição",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_adjustment_reason_code": "Motivo",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_adjustment_reason_name": "Descrição do motivo",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_adjustment_reason_search_title": "Motivo",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_adjustment_reason": "Motivo",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_form_general_title": "Motivos por Situação",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_form_title": "Motivos por Situação",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_id": "Identificador único",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_list_grid_title": "Lista de motivos por situação",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_list_title": "Motivos por situação",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_situation_code": "Situação",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_situation_name": "Descrição da situação",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_situation_search_title": "Situação",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation_situation": "Situação",
    "hcm_clocking_event_foundation.general.adjustment_reason_situation": "Motivos por Situação",
    "hcm_clocking_event_foundation.general.adjustment_reason": "Motivos de acertos",
    "hcm_clocking_event_foundation.general.and": "e",
    "hcm_clocking_event_foundation.general.article_62_clt_type_v_1": "Não se aplica",
    "hcm_clocking_event_foundation.general.article_62_clt_type_v_2": "Atividade externa especificada no inciso I",
    "hcm_clocking_event_foundation.general.article_62_clt_type_v_3": "Funções especificadas no inciso II",
    "hcm_clocking_event_foundation.general.article_62_clt_type_v_4": "Teletrabalho, previsto no inciso III",
    "hcm_clocking_event_foundation.general.at_date": "em",
    "hcm_clocking_event_foundation.general.at_time": "às",
    "hcm_clocking_event_foundation.general.batch_filters": "Filtros",
    "hcm_clocking_event_foundation.general.bridge_destination_date": "Data destino",
    "hcm_clocking_event_foundation.general.bridge_employee_code": "Colaborador",
    "hcm_clocking_event_foundation.general.bridge_employee_person_nom_pes": "Nome colaborador",
    "hcm_clocking_event_foundation.general.bridge_employee_search_title": "Colaborador",
    "hcm_clocking_event_foundation.general.bridge_employee": "Colaborador",
    "hcm_clocking_event_foundation.general.bridge_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.bridge_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.bridge_form_general_title": "Ponte",
    "hcm_clocking_event_foundation.general.bridge_form_title": "Ponte",
    "hcm_clocking_event_foundation.general.bridge_id": "Identificador único",
    "hcm_clocking_event_foundation.general.bridge_list_grid_title": "Lista de Pontes",
    "hcm_clocking_event_foundation.general.bridge_list_title": "Pontes",
    "hcm_clocking_event_foundation.general.bridge_origin_date": "Data origem",
    "hcm_clocking_event_foundation.general.bridge": "Pontes",
    "hcm_clocking_event_foundation.general.cancel_label": "Cancelar",
    "hcm_clocking_event_foundation.general.cancel": "Cancelar",
    "hcm_clocking_event_foundation.general.choose_label": "Selecionar",
    "hcm_clocking_event_foundation.general.clear": "Limpar",
    "hcm_clocking_event_foundation.general.clocking_event_tolerance_type_v_1": "Avaliação Independente",
    "hcm_clocking_event_foundation.general.clocking_event_tolerance_type_v_2": "Avaliação Dependente",
    "hcm_clocking_event_foundation.general.compensation_adjustment_reason_info_sign": "Este campo só poderá ser habilitado se o campo 'Controlar motivos de acerto' na Definição de apuração estiver selecionado. Ele será obrigatório quando o campo 'Motivo de acerto obrigatório' na Situação do ponto estiver selecionado",
    "hcm_clocking_event_foundation.general.compensation_adjustment_reason_search_title": "Localizar motivo da situação",
    "hcm_clocking_event_foundation.general.compensation_adjustment_reason": "Motivo da situação",
    "hcm_clocking_event_foundation.general.compensation_collective_companies_search_title": "Pesquisa de Empresas",
    "hcm_clocking_event_foundation.general.compensation_collective_companies": "Empresas",
    "hcm_clocking_event_foundation.general.compensation_collective_employee_search_title": "Pesquisa de Colaboradores",
    "hcm_clocking_event_foundation.general.compensation_collective_employees": "Colaboradores",
    "hcm_clocking_event_foundation.general.compensation_collective_form_general_title": "Compensação - Inclusão Coletiva",
    "hcm_clocking_event_foundation.general.compensation_compensation_type_placeholder": "Escolha um tipo de compensação",
    "hcm_clocking_event_foundation.general.compensation_compensation_type": "Tipo de compensação",
    "hcm_clocking_event_foundation.general.compensation_employee_code": "Colaborador",
    "hcm_clocking_event_foundation.general.compensation_employee_person_nom_pes": "Nome Colaborador",
    "hcm_clocking_event_foundation.general.compensation_employee_search_title": "Localizar o colaborador",
    "hcm_clocking_event_foundation.general.compensation_employee": "Colaborador",
    "hcm_clocking_event_foundation.general.compensation_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.compensation_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.compensation_form_general_title": "Compensação",
    "hcm_clocking_event_foundation.general.compensation_form_title": "Compensação",
    "hcm_clocking_event_foundation.general.compensation_id": "Identificador único",
    "hcm_clocking_event_foundation.general.compensation_list_grid_title": "Lista de compensações",
    "hcm_clocking_event_foundation.general.compensation_list_title": "Compensações",
    "hcm_clocking_event_foundation.general.compensation_number_of_hours": "Quantidade de Horas",
    "hcm_clocking_event_foundation.general.compensation_period_type_placeholder": "Escolha um tipo de período",
    "hcm_clocking_event_foundation.general.compensation_period_type": "Tipo de período",
    "hcm_clocking_event_foundation.general.compensation_situation_code": "Situação",
    "hcm_clocking_event_foundation.general.compensation_situation_name": "Descrição Situação",
    "hcm_clocking_event_foundation.general.compensation_situation_search_title": "Localizar a situação",
    "hcm_clocking_event_foundation.general.compensation_situation": "Situação",
    "hcm_clocking_event_foundation.general.compensation_type_v_1": "Extra para compensação",
    "hcm_clocking_event_foundation.general.compensation_type_v_2": "Ausência para compensação",
    "hcm_clocking_event_foundation.general.compensation_type_v_4": "Dispensar parte expediente",
    "hcm_clocking_event_foundation.general.compensation_type_v_5": "Dispensar intervalo horas",
    "hcm_clocking_event_foundation.general.compensation_type_v_6": "Programar intervalo fora expediente",
    "hcm_clocking_event_foundation.general.compensation_workschedule_code": "Horário",
    "hcm_clocking_event_foundation.general.compensation_workschedule_name": "Descrição Horário",
    "hcm_clocking_event_foundation.general.compensation_workschedule_search_title": "Localizar o horário",
    "hcm_clocking_event_foundation.general.compensation_workschedule": "Horário",
    "hcm_clocking_event_foundation.general.compensation": "Compensação",
    "hcm_clocking_event_foundation.general.consider_clocking_event_interval_type_v_1": "Não considerar",
    "hcm_clocking_event_foundation.general.consider_clocking_event_interval_type_v_2": "Segundo data e hora das marcações",
    "hcm_clocking_event_foundation.general.consider_clocking_event_interval_type_v_3": "Segundo data, hora, relógio e função das marcações",
    "hcm_clocking_event_foundation.general.consider_clocking_event_interval_type_v_4": "Segundo data, hora e uso de marcação",
    "hcm_clocking_event_foundation.general.contract_type_aprentice": "Aprendiz",
    "hcm_clocking_event_foundation.general.contract_type_director": "Diretor",
    "hcm_clocking_event_foundation.general.contract_type_employee": "Empregado",
    "hcm_clocking_event_foundation.general.contract_type_third_party": "Terceiro",
    "hcm_clocking_event_foundation.general.contract_type_trainee": "Estagiário",
    "hcm_clocking_event_foundation.general.created_by": "Criado por",
    "hcm_clocking_event_foundation.general.delete_confirmation_message": "Após excluir o(s) registro(s), não será mais possível consultá-lo(s)",
    "hcm_clocking_event_foundation.general.delete_confirmation_title": "Deseja excluir o(s) registro(s) selecionado(s)?",
    "hcm_clocking_event_foundation.general.delete": "Excluir",
    "hcm_clocking_event_foundation.general.deleted_message_content": "Registro(s) excluído(s) com sucesso",
    "hcm_clocking_event_foundation.general.deleted_message_title": "Sucesso",
    "hcm_clocking_event_foundation.general.e_001_pes_cod_pes": "Código",
    "hcm_clocking_event_foundation.general.e_001_pes_created_by": "Criado por",
    "hcm_clocking_event_foundation.general.e_001_pes_created_date": "Data da criação",
    "hcm_clocking_event_foundation.general.e_001_pes_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.e_001_pes_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.e_001_pes_excluido": "Indica se o registro foi excluído",
    "hcm_clocking_event_foundation.general.e_001_pes_ext_int_msg": "Indica a mensagem da replicação",
    "hcm_clocking_event_foundation.general.e_001_pes_ext_int_sts": "Indica status da replicação",
    "hcm_clocking_event_foundation.general.e_001_pes_id": "Identificador único",
    "hcm_clocking_event_foundation.general.e_001_pes_last_modified_by": "Última modificação por",
    "hcm_clocking_event_foundation.general.e_001_pes_last_modified_date": "Data da última modificação",
    "hcm_clocking_event_foundation.general.e_001_pes_nom_pes": "Nome",
    "hcm_clocking_event_foundation.general.e_001_pes": "Pessoa",
    "hcm_clocking_event_foundation.general.edit": "Editar",
    "hcm_clocking_event_foundation.general.employee_code": "Código do colaborador",
    "hcm_clocking_event_foundation.general.employee_employer_cod_emp": "Código da empresa",
    "hcm_clocking_event_foundation.general.employee_employment_relationship_contract_type": "Tipo de contrato",
    "hcm_clocking_event_foundation.general.employee_person_nom_pes": "Nome do colaborador",
    "hcm_clocking_event_foundation.general.empty_label": "Não informar",
    "hcm_clocking_event_foundation.general.error_company_of_employee_need_time_evaluation_definition": "A empresa do colaborador deve ter assinalamentos do ponto",
    "hcm_clocking_event_foundation.general.error_destination_date_is_after_dismissal_date": "A data de destino deve ser maior ou igual à data de demissão do colaborador",
    "hcm_clocking_event_foundation.general.error_end_date_after_admission_date": "A data final deve ser menor ou igual à data de demissão",
    "hcm_clocking_event_foundation.general.error_end_date_time_is_after_authorizer_dismissal_date": "A data/hora final deve ser menor ou igual a data de demissão do autorizador",
    "hcm_clocking_event_foundation.general.error_end_date_time_is_after_dismissal_date": "A data/hora final deve ser menor ou igual a data de demissão do colaborador",
    "hcm_clocking_event_foundation.general.error_evaluation_time_is_after_dismissal_date": "O início da apuração deve ser menor ou igual à data de demissão do colaborador",
    "hcm_clocking_event_foundation.general.error_evaluation_time_start_time_is_before_hire_date": "O início da apuração deve ser maior ou igual à data de admissão do colaborador",
    "hcm_clocking_event_foundation.general.error_exceeded_limit_days_backward_scheduling": "O limite de dias para programações retroativas foi excedido",
    "hcm_clocking_event_foundation.general.error_forbidden_description": "Você não possui permissão para acessar este conteúdo",
    "hcm_clocking_event_foundation.general.error_forbidden_title": "403 - Acesso negado",
    "hcm_clocking_event_foundation.general.error_invalid": "O valor é inválido",
    "hcm_clocking_event_foundation.general.error_max_length": "Tamanho maior que o permitido",
    "hcm_clocking_event_foundation.general.error_max_value": "Valor maior que o permitido",
    "hcm_clocking_event_foundation.general.error_min_value": "Valor menor que o permitido",
    "hcm_clocking_event_foundation.general.error_missing_company_clocking_event_indications": "Não possui assinalamentos do ponto para a empresa",
    "hcm_clocking_event_foundation.general.error_not_found_description": "O endereço pode estar incorreto, não estar disponível ou o conteúdo pode ter sido removido",
    "hcm_clocking_event_foundation.general.error_not_found_title": "404 - Página não encontrada",
    "hcm_clocking_event_foundation.general.error_origin_date_after_destination_date_to_end_date": "A data de destino deve ser maior que a data de origem",
    "hcm_clocking_event_foundation.general.error_origin_date_after_destination_date_to_start_date": "A data de origem deve ser menor que a data de destino",
    "hcm_clocking_event_foundation.general.error_origin_date_is_after_dismissal_date": "A data de origem deve ser menor ou igual à data de demissão do colaborador",
    "hcm_clocking_event_foundation.general.error_origin_date_is_before_hire_date": "A data de origem deve ser maior ou igual à data de admissão do colaborador",
    "hcm_clocking_event_foundation.general.error_required": "O campo é obrigatório",
    "hcm_clocking_event_foundation.general.error_server_description": "Ocorreu um erro no sistema que impediu a exibição do conteúdo. Contate o administrador do sistema",
    "hcm_clocking_event_foundation.general.error_server_title": "500 - Erro interno do servidor",
    "hcm_clocking_event_foundation.general.error_server_try_again": "Tentar novamente",
    "hcm_clocking_event_foundation.general.error_situation_clocking_event_not_found": "Situação do ponto não encontrada",
    "hcm_clocking_event_foundation.general.error_start_date_after_end_date_to_start_date": "A data inicial deve ser menor que a data final",
    "hcm_clocking_event_foundation.general.error_start_date_after_end_date": "A data inicial deve ser menor que a data final",
    "hcm_clocking_event_foundation.general.error_start_date_before_admission_date": "A data inicial deve ser maior ou igual à data de admissão",
    "hcm_clocking_event_foundation.general.error_start_date_time_is_after_authorizer_dismissal_date": "A data/hora inicial deve ser menor ou igual à data de demissão do autorizador",
    "hcm_clocking_event_foundation.general.error_start_date_time_is_after_dismissal_date": "A data/hora inicial deve ser menor ou igual a data de demissão do colaborador",
    "hcm_clocking_event_foundation.general.error_start_date_time_is_before_authorizer_hire_date": "A data inicial deve ser maior ou igual a data de admissão do autorizador",
    "hcm_clocking_event_foundation.general.error_start_date_time_is_before_hire_date": "A data/hora inicial deve ser maior ou igual a data de admissão do colaborador",
    "hcm_clocking_event_foundation.general.error_unauthorized_description": "Usuário não autorizado",
    "hcm_clocking_event_foundation.general.error_unauthorized_title": "Não autorizado",
    "hcm_clocking_event_foundation.general.error_verify_start_date_or_and_date": "Verifique a data inicial ou a data final",
    "hcm_clocking_event_foundation.general.false_label": "Não",
    "hcm_clocking_event_foundation.general.filter": "Filtrar",
    "hcm_clocking_event_foundation.general.filters": "Filtros",
    "hcm_clocking_event_foundation.general.generic_confirm": "Confirmação",
    "hcm_clocking_event_foundation.general.generic_no": "Não",
    "hcm_clocking_event_foundation.general.generic_yes": "Sim",
    "hcm_clocking_event_foundation.general.info_employee_is_leave_on_destination_date": "O colaborador está afastado na data de destino",
    "hcm_clocking_event_foundation.general.info_employee_is_leave_on_origin_date": "O colaborador está afastado na data de origem",
    "hcm_clocking_event_foundation.general.list_grid_boolean_false": "Não",
    "hcm_clocking_event_foundation.general.list_grid_boolean_true": "Sim",
    "hcm_clocking_event_foundation.general.list_grid_empty_field": "Não informado",
    "hcm_clocking_event_foundation.general.no": "Não",
    "hcm_clocking_event_foundation.general.nothing_found": "Nenhum registro encontrado",
    "hcm_clocking_event_foundation.general.other_actions": "Outras ações",
    "hcm_clocking_event_foundation.general.overtime_authorization_authorizer_code": "Autorizador",
    "hcm_clocking_event_foundation.general.overtime_authorization_authorizer_person_nom_pes": "Nome do autorizador",
    "hcm_clocking_event_foundation.general.overtime_authorization_authorizer_search_title": "Autorizador",
    "hcm_clocking_event_foundation.general.overtime_authorization_authorizer": "Autorizador",
    "hcm_clocking_event_foundation.general.overtime_authorization_created_by": "Criado por",
    "hcm_clocking_event_foundation.general.overtime_authorization_created_date": "Data da criação",
    "hcm_clocking_event_foundation.general.overtime_authorization_employee_code": "Colaborador",
    "hcm_clocking_event_foundation.general.overtime_authorization_employee_person_nom_pes": "Nome do colaborador",
    "hcm_clocking_event_foundation.general.overtime_authorization_employee_search_title": "Colaborador",
    "hcm_clocking_event_foundation.general.overtime_authorization_employee": "Colaborador",
    "hcm_clocking_event_foundation.general.overtime_authorization_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.overtime_authorization_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.overtime_authorization_end_date_time": "Data/Hora Final",
    "hcm_clocking_event_foundation.general.overtime_authorization_form_general_title": "Autorização de horas extras",
    "hcm_clocking_event_foundation.general.overtime_authorization_form_title": "Autorização de horas extras",
    "hcm_clocking_event_foundation.general.overtime_authorization_id": "Identificador único",
    "hcm_clocking_event_foundation.general.overtime_authorization_last_modified_by": "Última modificação por",
    "hcm_clocking_event_foundation.general.overtime_authorization_last_modified_date": "Data da última modificação",
    "hcm_clocking_event_foundation.general.overtime_authorization_list_grid_title": "Lista de autorizações de horas extras",
    "hcm_clocking_event_foundation.general.overtime_authorization_list_title": "Autorizações de horas extras",
    "hcm_clocking_event_foundation.general.overtime_authorization_observation": "Observação",
    "hcm_clocking_event_foundation.general.overtime_authorization_start_date_time": "Data/Hora Inicial",
    "hcm_clocking_event_foundation.general.overtime_authorization": "Autorização de horas extras",
    "hcm_clocking_event_foundation.general.period_type_v_1": "Qualquer parte do expediente",
    "hcm_clocking_event_foundation.general.period_type_v_2": "Início e fim do expediente",
    "hcm_clocking_event_foundation.general.period_type_v_3": "Durante intervalos de refeição",
    "hcm_clocking_event_foundation.general.period_type_v_4": "Início do expediente",
    "hcm_clocking_event_foundation.general.period_type_v_5": "Final do expediente",
    "hcm_clocking_event_foundation.general.period_type_v_6": "Início do expediente antecipando horário",
    "hcm_clocking_event_foundation.general.period_type_v_7": "Final do expediente prorrogando horário",
    "hcm_clocking_event_foundation.general.period_type_v_8": "Dispensar 1ª parte do expediente",
    "hcm_clocking_event_foundation.general.period_type_v_9": "Dispensar 2ª parte do expediente",
    "hcm_clocking_event_foundation.general.product_header_title": "Gestão de Pessoas",
    "hcm_clocking_event_foundation.general.readiness_continuous": "Contínuo",
    "hcm_clocking_event_foundation.general.readiness_created_by": "Criado por",
    "hcm_clocking_event_foundation.general.readiness_created_date": "Data da criação",
    "hcm_clocking_event_foundation.general.readiness_employee_code": "Colaborador",
    "hcm_clocking_event_foundation.general.readiness_employee_person_nom_pes": "Nome do colaborador",
    "hcm_clocking_event_foundation.general.readiness_employee_search_title": "Localizar o colaborador",
    "hcm_clocking_event_foundation.general.readiness_employee": "Colaborador",
    "hcm_clocking_event_foundation.general.readiness_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.readiness_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.readiness_end_date_time": "Data/Hora Final",
    "hcm_clocking_event_foundation.general.readiness_form_general_title": "Sobreaviso",
    "hcm_clocking_event_foundation.general.readiness_form_title": "Sobreaviso",
    "hcm_clocking_event_foundation.general.readiness_id": "Identificador único",
    "hcm_clocking_event_foundation.general.readiness_last_modified_by": "Última modificação",
    "hcm_clocking_event_foundation.general.readiness_last_modified_date": "Data da última modificação",
    "hcm_clocking_event_foundation.general.readiness_list_grid_title": "Lista de sobreavisos",
    "hcm_clocking_event_foundation.general.readiness_list_title": "Sobreavisos",
    "hcm_clocking_event_foundation.general.readiness_observation": "Observação",
    "hcm_clocking_event_foundation.general.readiness_situation_code": "Situação",
    "hcm_clocking_event_foundation.general.readiness_situation_name": "Nome da situação",
    "hcm_clocking_event_foundation.general.readiness_situation_search_title": "Localizar a situação",
    "hcm_clocking_event_foundation.general.readiness_situation_situation_type": "Tipo da situação",
    "hcm_clocking_event_foundation.general.readiness_situation": "Situação",
    "hcm_clocking_event_foundation.general.readiness_start_date_time": "Data/Hora Inicial",
    "hcm_clocking_event_foundation.general.readiness": "Sobreaviso",
    "hcm_clocking_event_foundation.general.register_justification_code": "Código",
    "hcm_clocking_event_foundation.general.register_justification_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.register_justification_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.register_justification_form_general_title": "Justificativas de Acerto",
    "hcm_clocking_event_foundation.general.register_justification_form_title": "Justificativa de Acerto",
    "hcm_clocking_event_foundation.general.register_justification_id": "Identificador único",
    "hcm_clocking_event_foundation.general.register_justification_list_grid_title": "Lista de justificativas de Acerto",
    "hcm_clocking_event_foundation.general.register_justification_list_title": "Justificativas de Acerto",
    "hcm_clocking_event_foundation.general.register_justification_name": "Descrição",
    "hcm_clocking_event_foundation.general.register_justification": "Justificativa de Acerto",
    "hcm_clocking_event_foundation.general.remove_label": "Excluir",
    "hcm_clocking_event_foundation.general.retroactive_adjustment_type_v_1": "Alertar",
    "hcm_clocking_event_foundation.general.retroactive_adjustment_type_v_2": "Ignorar",
    "hcm_clocking_event_foundation.general.save": "Salvar",
    "hcm_clocking_event_foundation.general.saved_message_content": "Registro(s) salvo(s) com sucesso",
    "hcm_clocking_event_foundation.general.saved_message_title": "Sucesso",
    "hcm_clocking_event_foundation.general.see_details": "Ver detalhes",
    "hcm_clocking_event_foundation.general.select": "Selecionar",
    "hcm_clocking_event_foundation.general.situation_clocking_event_complementary_situation_code": "Código",
    "hcm_clocking_event_foundation.general.situation_clocking_event_complementary_situation_name": "Descrição",
    "hcm_clocking_event_foundation.general.situation_clocking_event_complementary_situation_search_title": "Pesquisa de situações complementares",
    "hcm_clocking_event_foundation.general.situation_clocking_event_complementary_situation": "Situação complementar",
    "hcm_clocking_event_foundation.general.situation_clocking_event_convert_night_hours": "Converte em horas noturnas",
    "hcm_clocking_event_foundation.general.situation_clocking_event_created_by": "Criado por",
    "hcm_clocking_event_foundation.general.situation_clocking_event_created_date": "Data da criação",
    "hcm_clocking_event_foundation.general.situation_clocking_event_daytime_situation": "Situação diurna",
    "hcm_clocking_event_foundation.general.situation_clocking_event_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.situation_clocking_event_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.situation_clocking_event_exception_situation": "Situação de exceção",
    "hcm_clocking_event_foundation.general.situation_clocking_event_form_general_title": "Situação do ponto",
    "hcm_clocking_event_foundation.general.situation_clocking_event_form_title": "Situação do ponto",
    "hcm_clocking_event_foundation.general.situation_clocking_event_id": "Identificador único",
    "hcm_clocking_event_foundation.general.situation_clocking_event_last_modified_by": "Última modificação",
    "hcm_clocking_event_foundation.general.situation_clocking_event_last_modified_date": "Data da última modificação",
    "hcm_clocking_event_foundation.general.situation_clocking_event_list_grid_title": "Lista de situações do ponto",
    "hcm_clocking_event_foundation.general.situation_clocking_event_list_title": "Situações do ponto",
    "hcm_clocking_event_foundation.general.situation_clocking_event_mandatory_adjustment_reason": "Motivo de acerto obrigatório",
    "hcm_clocking_event_foundation.general.situation_clocking_event_obligate_attachment_on_leave": "Obrigar anexo no afastamento",
    "hcm_clocking_event_foundation.general.situation_clocking_event_situation_code": "Código",
    "hcm_clocking_event_foundation.general.situation_clocking_event_situation_name": "Descrição",
    "hcm_clocking_event_foundation.general.situation_clocking_event_situation_search_title": "Pesquisa de situações",
    "hcm_clocking_event_foundation.general.situation_clocking_event_situation": "Situação",
    "hcm_clocking_event_foundation.general.situation_code": "Código",
    "hcm_clocking_event_foundation.general.situation_deleted": "Indica se o registro foi excluído",
    "hcm_clocking_event_foundation.general.situation_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.situation_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.situation_ext_int_msg": "Indica a mensagem da replicação",
    "hcm_clocking_event_foundation.general.situation_ext_int_sts": "Indica status da replicação",
    "hcm_clocking_event_foundation.general.situation_id": "Identificador único",
    "hcm_clocking_event_foundation.general.situation_name": "Nome",
    "hcm_clocking_event_foundation.general.situation_situation_type_placeholder": "Selecione o tipo da situação",
    "hcm_clocking_event_foundation.general.situation_situation_type": "Tipo da situação",
    "hcm_clocking_event_foundation.general.situation_type_absences": "Faltas",
    "hcm_clocking_event_foundation.general.situation_type_citizencompanymaternity": "Maternidade empresa cidadã",
    "hcm_clocking_event_foundation.general.situation_type_citizencompanypaternity": "Paternidade empresa cidadã",
    "hcm_clocking_event_foundation.general.situation_type_collectivevacation": "Férias coletivas",
    "hcm_clocking_event_foundation.general.situation_type_illnessaid": "Auxílio doença",
    "hcm_clocking_event_foundation.general.situation_type_inssmaternityleave": "Licença maternidade INSS",
    "hcm_clocking_event_foundation.general.situation_type_laboraccident": "Acidente de trabalho",
    "hcm_clocking_event_foundation.general.situation_type_leavewithoutcompensation": "Licença sem remuneração",
    "hcm_clocking_event_foundation.general.situation_type_maternityleave": "Licença maternidade",
    "hcm_clocking_event_foundation.general.situation_type_medicalleave": "Licença médica (pgto Empresa)",
    "hcm_clocking_event_foundation.general.situation_type_militaryservice": "Serviço militar",
    "hcm_clocking_event_foundation.general.situation_type_others": "Outros",
    "hcm_clocking_event_foundation.general.situation_type_overtime": "Horas extras",
    "hcm_clocking_event_foundation.general.situation_type_paidleave": "Licença remunerada",
    "hcm_clocking_event_foundation.general.situation_type_paternityleave": "Licença paternidade",
    "hcm_clocking_event_foundation.general.situation_type_precautionreadiness": "Sobreaviso/Prontidão",
    "hcm_clocking_event_foundation.general.situation_type_retirementduetodisability": "Aposentadoria por invalidez",
    "hcm_clocking_event_foundation.general.situation_type_timeevaluationsituation": "Situação de apuração ponto",
    "hcm_clocking_event_foundation.general.situation_type_tradeunionmandate": "Mandato sindical",
    "hcm_clocking_event_foundation.general.situation_type_vacation": "Férias",
    "hcm_clocking_event_foundation.general.situation_type_workaccidentleave": "Licença acidente de trabalho (pgto empresa)",
    "hcm_clocking_event_foundation.general.situation_type_working": "Trabalhando",
    "hcm_clocking_event_foundation.general.situation": "Situação",
    "hcm_clocking_event_foundation.general.success_tooltip": "Sucesso",
    "hcm_clocking_event_foundation.general.time_evaluation_history_article_62_clt_placeholder": "Selecione uma opção do artigo 62 da CLT",
    "hcm_clocking_event_foundation.general.time_evaluation_history_article_62_clt": "Artigo 62 da CLT",
    "hcm_clocking_event_foundation.general.time_evaluation_history_clocking_adjustment": "Ajusta ponto",
    "hcm_clocking_event_foundation.general.time_evaluation_history_employee_code": "Colaborador",
    "hcm_clocking_event_foundation.general.time_evaluation_history_employee_person_nom_pes": "Nome do Colaborador",
    "hcm_clocking_event_foundation.general.time_evaluation_history_employee_search_title": "Pesquisa de colaborador",
    "hcm_clocking_event_foundation.general.time_evaluation_history_employee": "Colaborador",
    "hcm_clocking_event_foundation.general.time_evaluation_history_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.time_evaluation_history_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.time_evaluation_history_form_general_title": "Histórico de apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_history_form_title": "Histórico de apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_history_id": "Identificador único",
    "hcm_clocking_event_foundation.general.time_evaluation_history_list_grid_title": "Lista de históricos de apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_history_list_title": "Históricos de apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_history_process_adjustment": "Participa do processo de acerto",
    "hcm_clocking_event_foundation.general.time_evaluation_history_situation_definition_search_title": "Busca de definições de situações",
    "hcm_clocking_event_foundation.general.time_evaluation_history_situation_definition": "Definição de situações",
    "hcm_clocking_event_foundation.general.time_evaluation_history_start_date": "Início da apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_history_time_evaluation_type_placeholder": "Selecione um tipo de apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_history_time_evaluation_type": "Tipo de apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_history": "Histórico de apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_code": "Código",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_form_general_title": "Definição de situações da apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_form_title": "Definição de situações da apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_absence_situation_on_relay_schedule_holidays_search_title": "Pesquisa das situações de faltas no feriado em escala de revezamento",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_absence_situation_on_relay_schedule_holidays_situation_code": "Código da situação de faltas no feriado em escala de revezamento",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_absence_situation_on_relay_schedule_holidays_situation_name": "Descrição da situação de faltas no feriado em escala de revezamento",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_absence_situation_on_relay_schedule_holidays": "Situação de faltas no feriado em escala de revezamento",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_absence_situation_search_title": "Pesquisa das situações de falta",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_absence_situation_situation_code": "Código da situação de falta",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_absence_situation_situation_name": "Descrição da situação de falta",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_absence_situation": "Situação de falta",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_daily_rest_violation_situation_search_title": "Pesquisa das situações de violação de interjornada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_daily_rest_violation_situation_situation_code": "Código da situação de violação de interjornada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_daily_rest_violation_situation_situation_name": "Descrição da situação de violação de interjornada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_daily_rest_violation_situation": "Situação de violação de interjornada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_early_leave_situation_search_title": "Pesquisa das situações de saída antecipada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_early_leave_situation_situation_code": "Código da situação de saída antecipada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_early_leave_situation_situation_name": "Descrição da situação de saída antecipada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_early_leave_situation": "Situação de saída antecipada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_end_date": "Data final",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_form_detail_title": "Detalhes do histórico da definição de situações da apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_form_general_title": "Histórico da definição de situações da apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_form_title": "Histórico da definição de situações da apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_id": "Identificador único",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_intermediate_leave_situation_search_title": "Pesquisa das situações de saída intermediária",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_intermediate_leave_situation_situation_code": "Código da situação de saída intermediária",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_intermediate_leave_situation_situation_name": "Descrição da situação de saída intermediária",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_intermediate_leave_situation": "Situação de saída intermediária",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_invalid_events_situation_search_title": "Pesquisa das situações marcações inválidas",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_invalid_events_situation_situation_code": "Código da situação marcações inválidas",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_invalid_events_situation_situation_name": "Descrição da situação marcações inválidas",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_invalid_events_situation": "Situação marcações inválidas",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_leave_overtime_search_title": "Pesquisa das situações extras da saída",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_leave_overtime_situation_code": "Código da situação extra da saída",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_leave_overtime_situation_name": "Descrição da situação extra da saída",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_leave_overtime": "Extras da saída",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_list_grid_title": "Lista de históricos da definição de situações da apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_list_title": "Históricos da definição de situações da apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_night_shift_overtime_premium_situation_search_title": "Pesquisa de situações de adicional noturno extras",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_night_shift_overtime_premium_situation_situation_code": "Código da situação de adicional noturno extra",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_night_shift_overtime_premium_situation_situation_name": "Descrição da situação de adicional noturno extra",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_night_shift_overtime_premium_situation": "Situação de adicional noturno extras",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_night_shift_work_premium_search_title": "Pesquisa de situações adicional noturno trabalho",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_night_shift_work_premium_situation_code": "Código da situação adicional noturno trabalho",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_night_shift_work_premium_situation_name": "Descrição da situação adicional noturno trabalho",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_night_shift_work_premium": "Adicional noturno trabalho",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_normal_overtime_separation_limit": "Limite separação de extras normais",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_after_search_title": "Pesquisa de situações extras após",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_after_situation_code": "Código da situação extra após",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_after_situation_name": "Descrição da situação extra após",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_after": "Extras após",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_before_search_title": "Pesquisa de situações extras antes",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_before_situation_code": "Código da situação extra antes",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_before_situation_name": "Descrição da situação extra antes",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_before": "Extras antes",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_day_off_search_title": "Pesquisa de situações extras na folga",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_day_off_situation_code": "Código da situação extra na folga",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_day_off_situation_name": "Descrição da situação extra na folga",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_day_off": "Extras na folga",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_holiday_search_title": "Pesquisa de situações extras no feriado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_holiday_situation_code": "Código da situação extra no feriado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_holiday_situation_name": "Descrição da situação extra no feriado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_holiday": "Extras no feriado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_meal_search_title": "Pesquisa de situações extras na refeição",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_meal_situation_code": "Código da situação extra na refeição",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_meal_situation_name": "Descrição da situação extra na refeição",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_meal": "Extras na refeição",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_rest_search_title": "Pesquisa de situações extras no descanso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_rest_situation_code": "Código da situação extra no descanso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_rest_situation_name": "Descrição da situação extra no descanso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_during_rest": "Extras no descanso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_entry_search_title": "Pesquisa de situações extras na entrada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_entry_situation_code": "Código da situação extra na entrada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_entry_situation_name": "Descrição da situação extra na entrada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_entry": "Extras na entrada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_on_compensated_days_search_title": "Pesquisa de situações extras no compensado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_on_compensated_days_situation_code": "Código da situação extra no compensado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_on_compensated_days_situation_name": "Descrição da situação extra no compensado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_on_compensated_days": "Extras no compensado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_after_search_title": "Pesquisa de situações Extras Separação Após",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_after_situation_code": "Código da situação extra separação após",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_after_situation_name": "Descrição da situação extra separação após",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_after": "Extras Separação Após",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_before_search_title": "Pesquisa de situações Extras Separação Antes",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_before_situation_code": "Código da situação extra separação antes",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_before_situation_name": "Descrição da situação extra separação antes",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_before": "Extras Separação Antes",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_compensated_days_search_title": "Pesquisa de situações Extras Separação no Compensado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_compensated_days_situation_code": "Código da situação extra separação no compensado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_compensated_days_situation_name": "Descrição da situação extra separação no compensado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_compensated_days": "Extras Separação no Compensado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_day_off_search_title": "Pesquisa de situações Extras Separação na Folga",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_day_off_situation_code": "Código da situação extra separação na folga",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_day_off_situation_name": "Descrição da situação extra separação na folga",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_day_off": "Extras Separação na Folga",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_holiday_search_title": "Pesquisa de situações Extras Separação no Feriado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_holiday_situation_code": "Código da situação extra separação no feriado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_holiday_situation_name": "Descrição da situação extra separação no feriado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_holiday": "Extras Separação no Feriado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_meal_search_title": "Pesquisa de situações Extras Separação na Refeição",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_meal_situation_code": "Código da situação extra separação na refeição",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_meal_situation_name": "Descrição da situação extra separação na refeição",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_meal": "Extras Separação na Refeição",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_rest_search_title": "Pesquisa de situações Extras Separação no Descanso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_rest_situation_code": "Código da situação extra separação no descanso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_rest_situation_name": "Descrição da situação extra separação no descanso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_during_rest": "Extras Separação no Descanso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_entry_search_title": "Pesquisa de situações Extras Separação na Entrada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_entry_situation_code": "Código da situação extra separação na entrada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_entry_situation_name": "Descrição da situação extra separação na entrada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_entry": "Extras Separação na Entrada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_leave_search_title": "Pesquisa de situações Extras Separação na Saída",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_leave_situation_code": "Código da situação extra separação na saída",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_leave_situation_name": "Descrição da situação extra separação na saída",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_leave": "Extras Separação na Saída",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_limit_during_compensated_days": "Limite separação de extras no compensado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_limit_during_day_off": "Limite separação de extras na folga",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_limit_during_holiday": "Limite separação de extras no feriado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_separation_limit_during_rest": "Limite separação de extras no descanso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_situation_on_relay_schedule_holidays_search_title": "Pesquisa de situações de extra no feriado em escala de revezamento",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_situation_on_relay_schedule_holidays_situation_code": "Código da situação de extra no feriado em escala de revezamento",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_situation_on_relay_schedule_holidays_situation_name": "Descrição da situação de extra no feriado em escala de revezamento",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_overtime_situation_on_relay_schedule_holidays": "Situação de extra no feriado em escala de revezamento",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_percentage_next_day": "Percentual dia seguinte",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_separate_overtime_after_converting_night_shift_hours": "Separar extras após conversão das noturnas",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_situation_definition_code": "Código",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_situation_definition_name": "Descrição",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_situation_definition_search_title": "Pesquisa de definições das situações",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_situation_definition": "Definição de situações",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_situations_clocking_event_absence": "Ausências",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_situations_clocking_event_extra": "Extras",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_situations_clocking_event_general": "Gerais",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_situations_clocking_event_normal_overtimes": "Extras normais",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_situations_clocking_event_other_overtimes": "Outros parâmetros",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_situations_clocking_event_overtimes_during_day_off": "Extras na folga",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_situations_clocking_event_overtimes_during_holiday": "Extras no feriado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_situations_clocking_event_overtimes_during_rest": "Extras no descanso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_situations_clocking_event_overtimes_on_compensated_days": "Extras no compensado",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_start_date": "Data de alteração",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_tardiness_situation_search_title": "Pesquisa de situações de atraso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_tardiness_situation_situation_code": "Código da situação de atraso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_tardiness_situation_situation_name": "Descrição da situação de atraso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_tardiness_situation": "Situação de atraso",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_unauthorized_overtime_search_title": "Pesquisa de situações extras não autorizadas",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_unauthorized_overtime_situation_code": "Código da situação extra não autorizada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_unauthorized_overtime_situation_name": "Descrição da situação extra não autorizada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_unauthorized_overtime": "Extras não autorizadas",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_vacation_paid_leave_situation_search_title": "Pesquisa de situações licença remunerada férias",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_vacation_paid_leave_situation_situation_code": "Código da situação licença remunerada férias",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_vacation_paid_leave_situation_situation_name": "Descrição da situação licença remunerada férias",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_vacation_paid_leave_situation": "Situação licença remunerada férias",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_work_break_violation_situation_search_title": "Pesquisa de situações de violação de intrajornada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_work_break_violation_situation_situation_code": "Código da situação de violação de intrajornada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_work_break_violation_situation_situation_name": "Descrição da situação de violação de intrajornada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_work_break_violation_situation": "Situação de violação de intrajornada",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_work_situation_search_title": "Pesquisa de situações de trabalho",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_work_situation_situation_code": "Código da situação de trabalho",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_work_situation_situation_name": "Descrição da situação de trabalho",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history_work_situation": "Situação de trabalho",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_history": "Histórico da definição de situações da apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_id": "Identificador único",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_list_grid_title": "Lista das definições de situações da apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_list_title": "Definições das situações da apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition_name": "Descrição",
    "hcm_clocking_event_foundation.general.time_evaluation_situation_definition": "Definição de situações da apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_type_v_1": "Normal",
    "hcm_clocking_event_foundation.general.time_evaluation_type_v_2": "Dispensado do ponto",
    "hcm_clocking_event_foundation.general.time_evaluation_type_v_3": "Somente refeitório",
    "hcm_clocking_event_foundation.general.time_evaluation_type_v_4": "Dispensado do ponto - desconsidera todas as marcações",
    "hcm_clocking_event_foundation.general.time_evaluation_type_v_5": "Sem controle de ponto e refeitório",
    "hcm_clocking_event_foundation.general.time_evaluation_type_v_6": "Dispensado do ponto - desconsiderar marcações de ponto",
    "hcm_clocking_event_foundation.general.time_evaluation_type_v_7": "Ponto por exceção",
    "hcm_clocking_event_foundation.general.total_records": "{{value}} registro(s) encontrado(s)",
    "hcm_clocking_event_foundation.general.true_label": "Sim",
    "hcm_clocking_event_foundation.general.updated_by": "Atualizado por",
    "hcm_clocking_event_foundation.general.work_schedule_change_date": "Data da troca",
    "hcm_clocking_event_foundation.general.work_schedule_change_employee_code": "Contrato",
    "hcm_clocking_event_foundation.general.work_schedule_change_employee_person_nom_pes": "Colaborador",
    "hcm_clocking_event_foundation.general.work_schedule_change_employee_search_title": "Pesquisa de colaborador",
    "hcm_clocking_event_foundation.general.work_schedule_change_employee": "Colaborador",
    "hcm_clocking_event_foundation.general.work_schedule_change_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.work_schedule_change_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.work_schedule_change_form_general_title": "Troca de horário",
    "hcm_clocking_event_foundation.general.work_schedule_change_form_title": "Trocas de horário",
    "hcm_clocking_event_foundation.general.work_schedule_change_id": "Identificador único",
    "hcm_clocking_event_foundation.general.work_schedule_change_list_grid_title": "Lista de trocas de horário",
    "hcm_clocking_event_foundation.general.work_schedule_change_list_title": "Trocas de horário",
    "hcm_clocking_event_foundation.general.work_schedule_change_work_schedule_code": "Código do horário",
    "hcm_clocking_event_foundation.general.work_schedule_change_work_schedule_name": "Descrição do horário",
    "hcm_clocking_event_foundation.general.work_schedule_change_work_schedule_search_title": "Pesquisa de horários",
    "hcm_clocking_event_foundation.general.work_schedule_change_work_schedule": "Horário",
    "hcm_clocking_event_foundation.general.work_schedule_change": "Troca de horário",
    "hcm_clocking_event_foundation.general.workschedule_code": "Código",
    "hcm_clocking_event_foundation.general.workschedule_created_by": "Criado por",
    "hcm_clocking_event_foundation.general.workschedule_created_date": "Data da criação",
    "hcm_clocking_event_foundation.general.workschedule_deleted": "Indica se o registro foi excluído",
    "hcm_clocking_event_foundation.general.workschedule_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.workschedule_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.workschedule_ext_int_msg": "Indica a mensagem da replicação",
    "hcm_clocking_event_foundation.general.workschedule_ext_int_sts": "Indica status da replicação",
    "hcm_clocking_event_foundation.general.workschedule_id": "Identificador único",
    "hcm_clocking_event_foundation.general.workschedule_last_modified_by": "Última modificação por",
    "hcm_clocking_event_foundation.general.workschedule_last_modified_date": "Data da última modificação",
    "hcm_clocking_event_foundation.general.workschedule_name": "Descrição horário",
    "hcm_clocking_event_foundation.general.workschedule": "Horário",
    "hcm_clocking_event_foundation.general.workshift_change_employee_code": "Colaborador",
    "hcm_clocking_event_foundation.general.workshift_change_employee_person_nom_pes": "Nome do colaborador",
    "hcm_clocking_event_foundation.general.workshift_change_employee_search_title": "Colaborador",
    "hcm_clocking_event_foundation.general.workshift_change_employee": "Colaborador",
    "hcm_clocking_event_foundation.general.workshift_change_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.workshift_change_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.workshift_change_end_date": "Data Final",
    "hcm_clocking_event_foundation.general.workshift_change_form_general_title": "Troca de escala",
    "hcm_clocking_event_foundation.general.workshift_change_form_title": "Troca de escala",
    "hcm_clocking_event_foundation.general.workshift_change_id": "Identificador único",
    "hcm_clocking_event_foundation.general.workshift_change_list_grid_title": "Lista de trocas de escala",
    "hcm_clocking_event_foundation.general.workshift_change_list_title": "Trocas de escala",
    "hcm_clocking_event_foundation.general.workshift_change_start_date": "Data Inicial",
    "hcm_clocking_event_foundation.general.workshift_change_workshift_code": "Escala",
    "hcm_clocking_event_foundation.general.workshift_change_workshift_group_code": "Turma de escala",
    "hcm_clocking_event_foundation.general.workshift_change_workshift_group_search_title": "Turma de escala",
    "hcm_clocking_event_foundation.general.workshift_change_workshift_group": "Turma de escala",
    "hcm_clocking_event_foundation.general.workshift_change_workshift_search_title": "Escala",
    "hcm_clocking_event_foundation.general.workshift_change_workshift_name": "Descrição da escala",
    "hcm_clocking_event_foundation.general.workshift_change_workshift": "Escala",
    "hcm_clocking_event_foundation.general.workshift_change": "Troca de escala",
    "hcm_clocking_event_foundation.general.workshift_code": "Escala",
    "hcm_clocking_event_foundation.general.workshift_group_code": "Turma de escala",
    "hcm_clocking_event_foundation.general.workshift_group_base_date": "Data base",
    "hcm_clocking_event_foundation.general.workshift_name": "Descrição da escala",
    "hcm_clocking_event_foundation.general.yes": "Sim",
    "hcm_clocking_event_foundation.general.workshift_change_workshift_type": "Tipo de escala",
    "platform.backend.hcm_clocking_event_foundation_general_adjustment_reason_situation": "Motivo por Situação",
    "platform.backend.hcm_clocking_event_foundation_general_adjustment_reason": "Motivo de Acerto",
    "platform.backend.hcm_clocking_event_foundation_general_bridge": "Ponte",
    "platform.backend.hcm_clocking_event_foundation_general_compensation": "Compensação",
    "platform.backend.hcm_clocking_event_foundation_general_computation": "Cálculos",
    "platform.backend.hcm_clocking_event_foundation_general_definition": "Definições",
    "platform.backend.hcm_clocking_event_foundation_general_employees_histories": "Históricos",
    "platform.backend.hcm_clocking_event_foundation_general_employees": "Colaboradores",
    "platform.backend.hcm_clocking_event_foundation_general_overtime_authorization": "Autorização de Hora Extra",
    "platform.backend.hcm_clocking_event_foundation_general_readiness": "Sobreaviso",
    "platform.backend.hcm_clocking_event_foundation_general_records": "Cadastros",
    "platform.backend.hcm_clocking_event_foundation_general_register_justification": "Justificativa de Acerto",
    "platform.backend.hcm_clocking_event_foundation_general_scheduling": "Programações",
    "platform.backend.hcm_clocking_event_foundation_general_time_evaluation_definition": "Definição de Apuração",
    "platform.backend.hcm_clocking_event_foundation_general_time_evaluation_history": "Histórico de Apuração",
    "platform.backend.hcm_clocking_event_foundation_general_time_evaluation_situation_definition": "Situações de Apuração",
    "platform.backend.hcm_clocking_event_foundation_general_time_evaluation": "Apuração",
    "platform.backend.hcm_clocking_event_foundation_general_work_schedule_change": "Troca de Horário",
    "platform.backend.hcm_clocking_event_foundation_general_workshift_change": "Troca de Escala",
    "platform.backend.hcm_clocking_event_foundation_records": "Cadastros",
    "hcm_clocking_event_foundation.general.validation_date_is_after_hire_date": "Data de troca deve ser maior que a data de admissão do colaborador",
    "hcm_clocking_event_foundation.general.validation_date_is_before_dismissal_date": "Data de troca deve ser menor que a data de demissão do colaborador",
    "hcm_clocking_event_foundation.general.time_evaluation_definition": "Definição de apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_allow_clocking_event_modification_before_transference": "Alterar ponto antes da transferência de filial",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_allow_register_clocking_event_without_verification": "Permitir gravar marcações sem apurar",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_automatic_recalculation_scheduling_leave": "Recálculo automático em programações/afastamentos",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_bridge_overlaps_workschedule_change": "Ponte sobrepõe troca de horário",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_calculate_holiday_absence_rotation_workshift": "Calcular faltas no feriado em escala de revezamento",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_calculate_readiness": "Calcular sobreaviso",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_clocking_event_interval": "Intervalo entre marcações",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_clocking_event_tolerance": "Tolerância por marcação e dia",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_code": "Código",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_complement_work_waiting_time": "Complementar trabalho com cálculo de espera",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_consider_bridge_for_projection": "Considerar pontes para projeção em dias de folga",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_consider_clocking_event_interval": "Considerar intervalo",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_consider_clocking_event_interval_placeholder": "Escolha como considerar intervalo",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_consider_direction_clocking_event_order": "Considerar direção pela ordem de marcações",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_consider_pairs_day_off_day": "Considerar pares dias de folga",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_consider_pairs_normal_day": "Considerar pares dias normais",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_consider_workschedule_change_for_projection": "Considerar troca de horário para projeção",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_control_adjustment_reason": "Controlar motivos de acerto",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_control_observation": "Controlar observação",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_days_resume": "Dias para retomar",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_discount_hours_worked_readiness": "Descontar horas trabalhadas do sobreaviso",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_dismissal_situation": "Situação de demissão",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_eliminate_clocking_event": "Eliminar marcações",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_empty_state_description": "Não há registros cadastrados até o momento",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_empty_state_title": "Nenhum resultado encontrado",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_evaluate_incomplete_journey": "Apurar jornada incompleta",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_form_general_title": "Definição de apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_form_title": "Definição de apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_id": "Identificador único",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_incomplete_journey_situation": "Situação para jornada incompleta",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_incomplete_journey_situation_search_title": "Pesquisa de situações de jornada incompleta",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_justify_clocking_event": "Justificar marcações digitadas",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_limit_days_backward_scheduling": "Limite de dias para programações retroativas",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_list_grid_title": "Lista de definições de apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_list_title": "Definições de apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_name": "Descrição",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_night_hours_calculation": "Cálculo conversão noturnas",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_number_of_days_adjustment": "Quantidade de dias para realizar acertos",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_number_of_hours_journey_separation": "Separação jornada dia normal",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_retroactive_adjustment": "Acerto retroativo",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_retroactive_adjustment_placeholder": "Escolha o tipo de acerto retroativo",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_scheduling_overlaps_holiday": "Programação sobrepõe feriado",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_use_clocking_event_direction_allocation": "Utilizar direção para alocação",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_use_clocking_event_regularization": "Utiliza regularização de marcações",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_use_workschedule_day_off": "Utilizar horário na folga",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_verified_days_control": "Controle de dias verificados",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_verified_days_control_placeholder": "Escolha o tipo de controle de dias verificados",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_general": "Gerais",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_clocking_event": "Marcações",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_schedules_readiness": "Programações/Afastamentos",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_adjustment_process": "Processo de Acerto",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_form_detail_title": "Detalhes da definição de apuração",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_incomplete_journey_situation_code": "Código da jornada incompleta",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_incomplete_journey_situation_name": "Descrição da jornada incompleta",
    "hcm_clocking_event_foundation.general.verified_days_control_type_v_0": "Não utilizar",
    "hcm_clocking_event_foundation.general.verified_days_control_type_v_1": "Obrigatório",
    "hcm_clocking_event_foundation.general.verified_days_control_type_v_2": "Opcional",
    "hcm_clocking_event_foundation.general.validation_employee_has_currently_this_work_shift": "Este colaborador já tem a escala selecionada. Deseja continuar mesmo assim?",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_expiration_days": "Dias para Expiração",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_limit_of_days_after_point_closing": "Limite de dias após fechamento do ponto",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_block_pending_after_expires": "Bloqueia pendência após expirar",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_allows_take_ledger_pending": "Permite assumir pendência do liderado",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_allows_complete_untreated_pending": "Permite concluir pendência não tratada",
    "hcm_clocking_event_foundation.general.time_evaluation_history_clocking_adjustment_info_sign": "Este campo só poderá ser habilitado se o campo \"Participa do processo de acerto\" estiver selecionado",
    "hcm_clocking_event_foundation.general.time_evaluation_history_approve_own_clocking_info_sign": "Este campo só poderá ser habilitado se o campo \"Participa do processo de acerto\" e o \"Ajusta ponto\" estiverem selecionados",
    "hcm_clocking_event_foundation.general.time_evaluation_history_article_62_clt_info_sign": "Este campo só poderá ser habilitado se o campo \"Tipo de apuração\" estiver selecionado com \"Dispensado do ponto\"",
    "hcm_clocking_event_foundation.general.workshift_change_workshift_group_info_sign": "Este campo só poderá ser habilitado se o campo \"Escala\" estiver preenchido",
    "platform.backend.hcm_clocking_event": "Gestão do ponto",
    "hcm_clocking_event_foundation.general.workshift_change_workshift_type_permanent": "Permanente",
    "hcm_clocking_event_foundation.general.workshift_change_workshift_type_automatic_search": "Busca automática",
    "hcm_clocking_event_foundation.general.work_schedule_change_collective_form_general_title": "Troca de horário - Inclusão coletiva",
    "hcm_clocking_event_foundation.general.work_schedule_change_collective_employees": "Colaboradores",
    "hcm_clocking_event_foundation.general.work_schedule_change_collective_companies": "Empresas",
    "hcm_clocking_event_foundation.general.work_schedule_change_collective_employee_search_title": "Pesquisa de colaboradores",
    "hcm_clocking_event_foundation.general.work_schedule_change_collective_companies_search_title": "Pesquisa de empresas",
    "hcm_clocking_event_foundation.general.bridge_collective_form_general_title": "Ponte - Inclusão coletiva",
    "hcm_clocking_event_foundation.general.collective_employees": "Colaboradores",
    "hcm_clocking_event_foundation.general.collective_companies": "Empresas",
    "hcm_clocking_event_foundation.general.collective_employee_search_title": "Pesquisa de colaboradores",
    "hcm_clocking_event_foundation.general.collective_companies_search_title": "Pesquisa de empresas",
    "hcm_clocking_event_foundation.general.workshift_change_collective_form_general_title": "Troca de escala - Inclusão coletiva",
    "hcm_clocking_event_foundation.general.readiness_collective_form_general_title": "Sobreaviso - Inclusão coletiva",
    "hcm_clocking_event_foundation.general.overtime_authorization_collective_form_general_title": "Autorização de horas extras - Inclusão coletiva",
    "hcm_clocking_event_foundation.general.time_evaluation_history_start_date_is_equal_to_hire_date": "Não é permitido excluir o histórico de apuração com início igual a data de admissão do colaborador.",
    "hcm_clocking_event_foundation.general.compensation_collective_delete_form_title": "Compensação - Exclusão coletiva",
    "hcm_clocking_event_foundation.general.compensation_collective_delete_form_general_title": "Compensação - Exclusão coletiva",
    "hcm_clocking_event_foundation.general.bridge_collective_delete_form_general_title": "Ponte - Exclusão coletiva",
    "hcm_clocking_event_foundation.general.bridge_collective_delete_form_title": "Ponte - Exclusão coletiva",
    "hcm_clocking_event_foundation.general.readiness_collective_delete_form_general_title": "Sobreaviso - Exclusão Coletiva",
    "hcm_clocking_event_foundation.general.readiness_collective_delete_form_title": "Sobreaviso - Exclusão Coletiva",
    "hcm_clocking_event_foundation.general.workshift_change_collective_delete_form_title": "Troca de escala - Exclusão coletiva",
    "hcm_clocking_event_foundation.general.workshift_change_collective_delete_form_general_title": "Troca de escala - Exclusão coletiva",
    "hcm_clocking_event_foundation.general.remove_collective": "Excluir coletivamente",
    "hcm_clocking_event_foundation.general.work_schedule_change_collective_delete_form_title": "Troca de horário - Exclusão coletiva",
    "hcm_clocking_event_foundation.general.work_schedule_change_collective_delete_form_general_title": "Troca de horário - Exclusão coletiva",
    "hcm_clocking_event_foundation.general.work_schedule_change_collective_form_title": "Troca de horário - Inclusão coletiva",
    "hcm_clocking_event_foundation.general.workshift_change_collective_form_title": "Troca de escala - Inclusão coletiva",
    "hcm_clocking_event_foundation.general.bridge_collective_form_title": "Ponte - Inclusão coletiva",
    "hcm_clocking_event_foundation.general.readiness_collective_form_title": "Sobreaviso - Inclusão coletiva",
    "hcm_clocking_event_foundation.general.overtime_authorization_collective_form_title": "Autorização de horas extras - Inclusão coletiva",
    "hcm_clocking_event_foundation.general.overtime_authorization_delete_collective_form_title": "Autorização de horas extras - Exclusão coletiva",
    "hcm_clocking_event_foundation.general.overtime_authorization_collective_delete_form_general_title": "Autorização de horas extras - Exclusão coletiva",
    "hcm_clocking_event_foundation.general.compensation_collective_form_title": "Compensação - Inclusão coletiva",
    "hcm_clocking_event_foundation.general.time_evaluation_definition_clocking_event_tolerance_placeholder": "Escolha o tipo de tolerância por marcação e dia",
    "hcm_clocking_event_foundation.general.time_evaluation_history_collective_form_title": "Histórico de apuração - Inclusão coletiva",
    "hcm_clocking_event_foundation.general.time_evaluation_history_collective_form_general_title": "Histórico de apuração - Inclusão coletiva",
    "hcm_clocking_event_foundation.general.time_evaluation_history_collective_delete_form_general_title": "Histórico de apuração - Exclusão coletiva",
    "hcm_clocking_event_foundation.general.time_evaluation_history_collective_delete_form_title": "Histórico de apuração - Exclusão coletiva",
    "hcm_clocking_event_foundation.general.situation_has_no_situation_clocking_event": "A situação não possui definição geral do ponto",
    "hcm_clocking_event_foundation.general.situation_type_maternityleavenoncriminalabortion": "Licença maternidade - Aborto não criminoso",
    "hcm_clocking_event_foundation.general.situation_type_maternityleaveanticipationextension": "Licença maternidade - Prorrogação mediante atestado médico",
    "hcm_clocking_event_foundation.general.situation_type_workaccidentleavewithoutinss": "Licença acidente de trabalho sem incidência INSS",
    "hcm_clocking_event_foundation.general.situation_type_medicalleavewithoutinss": "Licença médica sem incidência INSS",
    "hcm_clocking_event_foundation.general.activate_incomplete_journey": "Ative a apuração de jornada incompleta para preencher o campo",
    "hcm_clocking_event_foundation.general.error_start_date_time_after_end_date_time_to_start_date": "A data/hora inicial deve ser menor que a data/hora final",
    "hcm_clocking_event_foundation.general.error_start_date_time_after_end_date_time_to_end_date": "A data/hora final deve ser maior que a data/hora inicial",
    "hcm_clocking_event_foundation.general.readiness_start_date": "Data inicial",
    "hcm_clocking_event_foundation.general.readiness_start_time": "Hora inicial",
    "hcm_clocking_event_foundation.general.readiness_end_date": "Data final",
    "hcm_clocking_event_foundation.general.readiness_end_time": "Hora final",
    "hcm_clocking_event_foundation.general.error_start_time_after_end_time_to_start_date": "A hora inicial deve ser menor que a hora final",
    "hcm_clocking_event_foundation.general.error_start_time_after_end_time_to_end_date": "A hora final deve ser maior que a hora inicial"
};

/**
 * Componets
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AdjustmentReason, AdjustmentReasonService, AdjustmentReasonSituation, AdjustmentReasonSituationService, Article62CltType, Bridge, BridgeFormComponent, BridgeFormModule, BridgeService, ClockingEventToleranceType, CompanyClockingEventIndications, CompanyClockingEventIndicationsService, Compensation, CompensationFormComponent, CompensationFormModule, CompensationService, CompensationType, ConsiderClockingEventIntervalType, CoreSchedulesHistoriesModule, E001Pes, E001PesService, Employee, EmployeeService, FieldCustomizationService, FiltersStorageService, FocusService, OvertimeAuthorization, OvertimeAuthorizationFormComponent, OvertimeAuthorizationFormModule, OvertimeAuthorizationService, PaginatorStorageService, PeriodType, Readiness, ReadinessFormComponent, ReadinessFormModule, ReadinessService, RetroactiveAdjustmentType, Situation, SituationClockingEvent, SituationClockingEventService, SituationService, StorageService, TimeEvaluationDefinition, TimeEvaluationDefinitionService, TimeEvaluationHistory, TimeEvaluationHistoryFormComponent, TimeEvaluationHistoryFormModule, TimeEvaluationHistoryService, TimeEvaluationSituationDefinition, TimeEvaluationSituationDefinitionHistory, TimeEvaluationSituationDefinitionHistoryService, TimeEvaluationSituationDefinitionService, TimeEvaluationType, VerifiedDaysControlType, WorkScheduleChange, WorkScheduleChangeFormComponent, WorkScheduleChangeFormModule, WorkScheduleChangeService, Workschedule, WorkscheduleService, Workshift, WorkshiftChange, WorkshiftChangeFormComponent, WorkshiftChangeFormModule, WorkshiftChangeService, WorkshiftGroup, WorkshiftGroupService, WorkshiftService, convertMinutesToTime, convertTimeToMinutes, fallback, getTypeInformation, isValidFilter, mergeDateTime, mergeUnique, ɵ0, SharedScheduleModule as ɵa, DescriptionSwitchDirective as ɵb, EntityService as ɵc, BridgeModule as ɵd, OvertimeAuthorizationModule as ɵe, EmployeeModule as ɵf, E001PesModule as ɵg, WorkshiftGroupModule as ɵh, WorkshiftModule as ɵi, CompanyClockingEventIndicationsModule as ɵj, TimeEvaluationDefinitionModule as ɵk, SituationModule as ɵl, TimeEvaluationSituationDefinitionModule as ɵm, TimeEvaluationSituationDefinitionHistoryModule as ɵn, SituationClockingEventModule as ɵo, WorkscheduleModule as ɵp, WorkScheduleChangeModule as ɵq, ReadinessModule as ɵr, WorkshiftChangeModule as ɵs, CompensationModule as ɵt, AdjustmentReasonModule as ɵu, AdjustmentReasonSituationModule as ɵv, TimeEvaluationHistoryModule as ɵw };
//# sourceMappingURL=senior-gestao-pessoas-hcm-clocking-event-foundation-schedules-histories.js.map
